@@ -1,5 +1,5 @@
-/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
-namespace Db4objects.Db4odoc.Blobs
+/* Copyright (C) 2009 Versant Inc. http://www.db4o.com */
+namespace Db4odoc.Blobs
 {
     using Db4objects.Db4o.Ext;
     using Db4objects.Db4o.Types;
@@ -33,22 +33,22 @@ namespace Db4objects.Db4odoc.Blobs
 		{
 			_blob.ReadFrom(new File(inFolder + _file));
 			double status = _blob.GetStatus();
-			while(status >  Status.COMPLETED){
+			while(status >  Status.Completed){
 					Thread.Sleep(50);
 					status = _blob.GetStatus();
 			}
-			return (status == Status.COMPLETED);
+			return (status == Status.Completed);
 		}
 		
 		public bool WriteFile()
 		{
 			_blob.WriteTo(new File(outFolder + _file));
 			double status = _blob.GetStatus();
-			while(status > Status.COMPLETED){
+			while(status > Status.Completed){
 					Thread.Sleep(50);
 					status = _blob.GetStatus();
 			}
-			return (status == Status.COMPLETED);
+			return (status == Status.Completed);
 		}
 	}
 }
\ No newline at end of file
