@@ -1,35 +1,36 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-
-package com.db4odoc.f1.persist;
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 
+package com.db4odoc.persist;
 
 public class Change2 implements Runnable {
 	Thread t;
+
 	Car car;
+
 	boolean running;
-	
-	public void init(Car car){
+
+	public void init(Car car) {
 		this.car = car;
 		running = true;
 		t = new Thread(this);
 		t.start();
 	}
-	
-	public void stop(){
+
+	public void stop() {
 		running = false;
 	}
-	
+
 	public void run() {
-		while(running)
-		{
+		while (running) {
 			car.setTemperature(getConditionerTemperature());
 			try {
 				Thread.sleep(10);
-			} catch (InterruptedException e) {}
-		}	
+			} catch (InterruptedException e) {
+			}
+		}
 	}
-	
-	private int getConditionerTemperature(){
+
+	private int getConditionerTemperature() {
 		return 17;
 	}
 
