@@ -6,7 +6,7 @@ namespace Db4objects.Db4odoc.ClassNameFormat
 {
     class ClassNameExample1
     {
-        public readonly static string YapFileName = "formula1.yap";
+        private const string Db4oFileName = "reference.db4o";
 
         public static void Main(string[] args) 
         {
@@ -15,10 +15,10 @@ namespace Db4objects.Db4odoc.ClassNameFormat
         // end Main
 
 
-        public static void StoreObjects()
+        private static void StoreObjects()
         {
-            File.Delete(YapFileName);
-            IObjectContainer container = Db4oFactory.OpenFile(YapFileName);
+            File.Delete(Db4oFileName);
+            IObjectContainer container = Db4oFactory.OpenFile(Db4oFileName);
             try
             {
                 // Store a simple class to the database
