@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2009 Versant Inc. http://www.db4o.com */
 
 package com.db4odoc.debugging;
 
@@ -6,11 +6,11 @@ import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.PrintStream;
+import java.util.List;
 
-import com.db4o.Db4o;
+import com.db4o.Db4oEmbedded;
 import com.db4o.ObjectContainer;
-import com.db4o.ObjectSet;
-import com.db4o.config.Configuration;
+import com.db4o.config.EmbeddedConfiguration;
 import com.db4o.query.Query;
 
 public class DebugExample {
@@ -28,22 +28,22 @@ public class DebugExample {
 
 	private static void setCars()
 	{
-		 // Set the debug message levet to the maximum
-		Configuration configuration = Db4o.newConfiguration();
-		configuration.messageLevel(3);
+		 // Set the debug message level to the maximum
+		EmbeddedConfiguration configuration = Db4oEmbedded.newConfiguration();
+		configuration.common().messageLevel(3);
 		
 		 // Do some db4o operations
 		new File(DB4O_FILE_NAME).delete();
-		ObjectContainer container=Db4o.openFile(configuration, DB4O_FILE_NAME);
+		ObjectContainer container=Db4oEmbedded.openFile(configuration, DB4O_FILE_NAME);
 		try {
 			Car car1 = new Car("BMW");
-			container.set(car1);
+			container.store(car1);
 			Car car2 = new Car("Ferrari");
-			container.set(car2);
+			container.store(car2);
 			container.deactivate(car1,2);
 			Query query = container.query();
 			query.constrain(Car.class);
-			ObjectSet results = query.execute();
+			List<Car> results = query.execute();
 			listResult(results);
 		} finally {
 			container.close();
@@ -58,24 +58,24 @@ public class DebugExample {
 		PrintStream debugWriter = new PrintStream(fos);
         
         // Redirect debug output to the specified writer
-		Configuration configuration = Db4o.newConfiguration();
-		configuration.setOut(debugWriter);
+		EmbeddedConfiguration configuration = Db4oEmbedded.newConfiguration();
+		configuration.common().outStream(debugWriter);
         
-        // Set the debug message levet to the maximum
-		configuration.messageLevel(3);
+        // Set the debug message level to the maximum
+		configuration.common().messageLevel(3);
 		
 		 // Do some db4o operations
 		 new File(DB4O_FILE_NAME).delete();
-		 ObjectContainer container=Db4o.openFile(configuration, DB4O_FILE_NAME);
+		 ObjectContainer container=Db4oEmbedded.openFile(configuration, DB4O_FILE_NAME);
 		try {
 			Car car1 = new Car("BMW");
-			container.set(car1);
+			container.store(car1);
 			Car car2 = new Car("Ferrari");
-			container.set(car2);
+			container.store(car2);
 			container.deactivate(car1,2);
 			Query query = container.query();
 			query.constrain(Car.class);
-			ObjectSet results = query.execute();
+			List<Car> results = query.execute();
 			listResult(results);
 		} finally {
 			container.close();
@@ -84,10 +84,10 @@ public class DebugExample {
 	}
 	// end setCarsWithFileOutput
 	
-	private static void listResult(ObjectSet result) {
+	private static<T> void listResult(List<T> result) {
         System.out.println(result.size());
-        while(result.hasNext()) {
-            System.out.println(result.next());
+        for (T t: result){
+            System.out.println(t);
         }
     }
     // end listResult
