@@ -1,6 +1,4 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-using System;
-
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 namespace Db4objects.Db4odoc.Refactoring.NewClasses
 {
 	public class Identity
@@ -27,7 +25,7 @@ namespace Db4objects.Db4odoc.Refactoring.NewClasses
 		}
 	
 	
-		public String toString() 
+		public override string ToString() 
 		{
 			return string.Format("{0}[{1}]", _name, _id);
 		}
