@@ -1,11 +1,11 @@
 /* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 
-namespace Db4objects.Db4odoc.Activating
+namespace Db4objects.Db4odoc.Utility
 {
 	public class SensorPanel
 	{
-		public object _sensor;
-		public SensorPanel _next;
+		private object _sensor;
+		private SensorPanel _next;
 	
 		public SensorPanel()
 		{
@@ -47,6 +47,19 @@ namespace Db4objects.Db4odoc.Activating
 				_next = value;
 			}
 		}
+
+		public object Sensor
+		{
+			get
+			{
+				return _sensor;
+			}
+            
+			set
+			{
+				_sensor = value;
+			}
+		}
 	
 		protected SensorPanel NewElement(int value)
 		{
