@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 using System;
 using System.IO;
 using System.Xml.Serialization;
@@ -9,8 +9,8 @@ namespace Db4objects.Db4odoc.Serializing
 {
 	public class SerializeExample
 	{
-		public readonly static string XmlFileName = "formula1.xml";
-		public readonly static string YapFileName = "formula1.yap";
+		private const string XmlFileName = "reference.xml";
+		private const string Db4oFileName = "reference.db4o";
 
 		public static void Main(string[] args) 
 		{
@@ -20,10 +20,10 @@ namespace Db4objects.Db4odoc.Serializing
 		}
 		// end Main
 
-		public static void SetObjects()
+		private static void SetObjects()
 		{
-			File.Delete(YapFileName);
-			IObjectContainer db = Db4oFactory.OpenFile(YapFileName);
+			File.Delete(Db4oFileName);
+			IObjectContainer db = Db4oFactory.OpenFile(Db4oFileName);
 			try 
 			{
 				Car car = new Car("BMW", new Pilot("Rubens Barrichello"));
@@ -38,11 +38,11 @@ namespace Db4objects.Db4odoc.Serializing
 		}
 		// end SetObjects
 
-		public static void ExportToXml()
+        private static void ExportToXml()
 		{
 			XmlSerializer carSerializer = new XmlSerializer(typeof(Car[]));
 			StreamWriter xmlWriter = new StreamWriter(XmlFileName);
-			IObjectContainer db = Db4oFactory.OpenFile(YapFileName);
+			IObjectContainer db = Db4oFactory.OpenFile(Db4oFileName);
 			try 
 			{
 				IObjectSet result = db.Get(typeof(Car));
@@ -62,27 +62,27 @@ namespace Db4objects.Db4odoc.Serializing
 		}
 		// end ExportToXml
 
-		public static void ImportFromXml()
+        private static void ImportFromXml()
 		{
-			File.Delete(YapFileName);
+			File.Delete(Db4oFileName);
 			XmlSerializer carSerializer = new XmlSerializer(typeof(Car[]));
 			FileStream xmlFileStream = new FileStream(XmlFileName, FileMode.Open);
 			Car[] cars = (Car[])carSerializer.Deserialize(xmlFileStream);
 			IObjectContainer db;
-			for (int i = 0; i < cars.Length; i++)
+			foreach (Car car in cars)
 			{
-				db = Db4oFactory.OpenFile(YapFileName);
+				db = Db4oFactory.OpenFile(Db4oFileName);
 				try 
 				{
-					Car car = (Car)cars[i];
-					db.Set(car);
+					Car newCar = (Car)car;
+					db.Set(newCar);
 				} 
 				finally 
 				{
 					db.Close();
 				}
 			}
-			db = Db4oFactory.OpenFile(YapFileName);
+			db = Db4oFactory.OpenFile(Db4oFileName);
 			try 
 			{
 				IObjectSet result = db.Get(typeof(Pilot));
@@ -97,7 +97,7 @@ namespace Db4objects.Db4odoc.Serializing
 		}
 		// end ImportFromXml
 
-		public static void ListResult(IObjectSet result)
+        private static void ListResult(IObjectSet result)
 		{
 			Console.WriteLine(result.Count);
 			foreach (object item in result)
