@@ -1,11 +1,11 @@
 /* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
 using System;
 
-namespace Db4objects.Db4odoc.SelectivePersistence
+namespace com.db4odoc.f1.selpersist
 {
 	public class Test
 	{
-        [Db4objects.Db4o.Transient]
+		[com.db4o.Transient]
 		string _transientField;
 		string _persistentField;
 
