@@ -1,8 +1,5 @@
-using System;
-using System.Collections.Generic;
-using System.Text;
-
-namespace Db4objects.Db4odoc.selectivepersistence
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
+namespace Db4objects.Db4odoc.SelectivePersistence
 {
     class Test2
     {
