@@ -1,21 +1,19 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-using System;
-
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 namespace Db4objects.Db4odoc.SelectivePersistence
 {
-	public class TestCusomized
+	public class TestCustomized
 	{
         [Db4objects.Db4odoc.SelectivePersistence.FieldTransient]
-		string _transientField;
+        string _transientField;
 		string _persistentField;
 
-		public TestCusomized(string transientField, string persistentField)
+		public TestCustomized(string transientField, string persistentField)
 		{
 			_transientField = transientField;
 			_persistentField = persistentField;
 		}
 
-		public override String ToString() 
+		public override string ToString() 
 		{
 			return "Customized test: persistent: " + _persistentField + ", transient: " + _transientField ;
 		}
