@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -18,11 +18,11 @@ using System.Runtime.CompilerServices;
 using System.Runtime.InteropServices;
 
 [assembly: AssemblyTitle("Db4oTool.MSBuild.Tests")]
-[assembly: AssemblyDescription("Db4oTool.MSBuild.Tests 7.4.121.14026 (.NET)")]
+[assembly: AssemblyDescription("Db4oTool.MSBuild.Tests 8.0.184.15484 (.NET)")]
 [assembly: AssemblyConfiguration(".NET")]
-[assembly: AssemblyCompany("db4objects Inc., San Mateo, CA, USA")]
+[assembly: AssemblyCompany("Versant Corp., Redwood City, CA, USA")]
 [assembly: AssemblyProduct("db4o - database for objects")]
-[assembly: AssemblyCopyright("db4o 2005 - 2009")]
+[assembly: AssemblyCopyright("Versant Corp. 2000 - 2011")]
 [assembly: AssemblyTrademark("")]
 [assembly: AssemblyCulture("")]
 
@@ -30,5 +30,5 @@ using System.Runtime.InteropServices;
 
 [assembly: Guid("b9bd9a7a-c50e-4c3c-8224-a033d747c1ca")]
 
-[assembly: AssemblyVersion("7.4.121.14026")]
-[assembly: AssemblyFileVersion("7.4.121.14026")]
+[assembly: AssemblyVersion("8.0.184.15484")]
+[assembly: AssemblyFileVersion("8.0.184.15484")]
