@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -24,15 +24,18 @@ namespace Db4oTool.Tests.Core
 		{
 			return new Type[]
 				{
-					typeof(Core.ByNameTestCase),
-					typeof(Core.ByAttributeTestCase),
-					typeof(Core.ByFilterTestCase),
-					typeof(Core.ByNotAttributeTestCase),
-					typeof(Core.ContextVariableTestCase),
-					typeof(Core.ILPatternTestCase),
-					typeof(Core.CustomInstrumentationTestCase),
-					typeof(Core.PreserveDebugInfoTestCase),
-					typeof(Core.InstrumentingCFAssemblyTestCase),
+					typeof(ByNameTestCase),
+					typeof(ByAttributeTestCase),
+					typeof(ByFilterTestCase),
+					typeof(ByNotAttributeTestCase),
+					typeof(ContextVariableTestCase),
+					typeof(DebugInformationTestSuite),
+					typeof(ILPatternTestCase),
+					typeof(InstallPerformanceCountersTestCase),
+					typeof(CustomInstrumentationTestCase),
+					typeof(PreserveDebugInfoTestCase),
+					typeof(InstrumentingCFAssemblyTestCase),
+					typeof(StackAnalyzerTestCase),
 				};
 		}
 	}
