@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -51,16 +51,16 @@ namespace Db4oTool.NQ
 
 		public void Process(MethodDefinition parent, Instruction queryInvocation)
 		{
-			CilWorker worker = parent.Body.CilWorker;
+			ILProcessor il = parent.Body.GetILProcessor ();
 			if (IsCachedStaticFieldPattern(queryInvocation))
 			{	
 				_context.TraceVerbose("static delegate field pattern found in {0}", parent.Name);
-				ProcessCachedStaticFieldPattern(worker, queryInvocation);
+				ProcessCachedStaticFieldPattern(il, queryInvocation);
 			}
 			else if (IsPredicateCreationPattern(queryInvocation))
 			{
 				_context.TraceVerbose("simple delegate pattern found in {0}", parent.Name);
-				ProcessPredicateCreationPattern(worker, queryInvocation);
+				ProcessPredicateCreationPattern(il, queryInvocation);
 			}
 			else
 			{
@@ -68,7 +68,7 @@ namespace Db4oTool.NQ
 			}
 		}
 
-		private void ProcessPredicateCreationPattern(CilWorker worker, Instruction queryInvocation)
+		private void ProcessPredicateCreationPattern(ILProcessor il, Instruction queryInvocation)
 		{
 		    MethodReference predicateReference = GetMethodReferenceFromInlinePredicatePattern(queryInvocation);
 		    MethodDefinition predicateMethod = Resolve(predicateReference);
@@ -83,25 +83,19 @@ namespace Db4oTool.NQ
                 
             _optimizer.OptimizePredicate(syntheticPredicate, predicateMethod, expression);
 
-            RemovePreviousInstrunctions(worker, queryInvocation, 2);
+            RemovePreviousInstrunctions(il, queryInvocation, 2);
 
             InjectSyntheticPredicateInstantiation(
                     queryInvocation,
-                    worker,
+                    il,
                     syntheticPredicate,
                     fields.Keys,
                     predicateReference.DeclaringType);
 
 		    ReplaceByExecuteEnhancedFilter(queryInvocation);
-            
-            //Debug.Write(Formatter.FormatMethodBody(worker.GetBody().Method));
-
-		    //Debug.Write(Formatter.FormatMethodBody((MethodDefinition) FindConstructor(syntheticPredicate, 1)));
-
-		    //Debug.Write(Formatter.FormatMethodBody(syntheticPredicate.Methods[0]));
 		}
 
-		private TypeDefinition NewSyntheticPredicateFor(IExpression expression, IMemberReference predicateMethod, out IDictionary<FieldReference, FieldDefinition> fields)
+		private TypeDefinition NewSyntheticPredicateFor(IExpression expression, MemberReference predicateMethod, out IDictionary<FieldReference, FieldDefinition> fields)
 	    {
 	        TypeDefinition syntheticPredicate = NewSyntheticPredicateFor(predicateMethod);
 
@@ -120,10 +114,10 @@ namespace Db4oTool.NQ
 	        return fields.Count > 0;
 	    }
 
-	    private void InjectSyntheticPredicateInstantiation(Instruction queryInvocation, CilWorker cil, TypeDefinition syntheticPredicate, ICollection<FieldReference> fieldValuesReferences, TypeReference closureType)
+	    private void InjectSyntheticPredicateInstantiation(Instruction queryInvocation, ILProcessor cil, TypeDefinition syntheticPredicate, ICollection<FieldReference> fieldValuesReferences, TypeReference closureType)
 	    {
             VariableDefinition closureObjVar = new VariableDefinition(closureType);
-            cil.GetBody().Variables.Add(closureObjVar);
+            cil.Body.Variables.Add(closureObjVar);
 
             Instruction ip = cil.Create(OpCodes.Stloc, closureObjVar);
             cil.InsertBefore(queryInvocation, ip);
@@ -139,35 +133,35 @@ namespace Db4oTool.NQ
             cil.InsertBefore(queryInvocation, newObj);
 	    }
 
-	    private void PushParameters(CilWorker worker, VariableDefinition closureObj, Instruction ip, IEnumerable<FieldReference> fieldValuesReferences)
+	    private void PushParameters(ILProcessor il, VariableDefinition closureObj, Instruction ip, IEnumerable<FieldReference> fieldValuesReferences)
 	    {
 	        foreach (FieldReference fieldReference in fieldValuesReferences)
 	        {
-	            Instruction instruction = worker.Create(OpCodes.Ldloc, closureObj);
-	            worker.InsertAfter(ip, instruction);
+	            Instruction instruction = il.Create(OpCodes.Ldloc, closureObj);
+	            il.InsertAfter(ip, instruction);
 
                 if (IsPublicField(fieldReference))
                 {
-                    worker.InsertAfter(instruction, worker.Create(OpCodes.Ldfld, fieldReference));
+                    il.InsertAfter(instruction, il.Create(OpCodes.Ldfld, fieldReference));
                 }
                 else
                 {
-                    ip = PushFieldContentsUsingReflection(fieldReference, worker, instruction);
+                    ip = PushFieldContentsUsingReflection(fieldReference, il, instruction);
                 }
 	            ip = ip.Next.Next;
 	        }
 	    }
 
-	    private bool IsPublicField(FieldReference reference)
+	    private bool IsPublicField(MemberReference reference)
 	    {
 	        TypeDefinition parentType = _reflector.ResolveTypeReference(reference.DeclaringType);
-	        return (parentType.Fields.GetField(reference.Name).Attributes & FieldAttributes.Public) == FieldAttributes.Public;
+			return (CecilReflector.GetField(parentType, reference.Name).Attributes & FieldAttributes.Public) == FieldAttributes.Public;
 	    }
 
 	    /**
          * Expects that the object reference is already in the stack
          */
-        private Instruction PushFieldContentsUsingReflection(FieldReference fieldReference, CilWorker cil, Instruction ip)
+        private Instruction PushFieldContentsUsingReflection(FieldReference fieldReference, ILProcessor cil, Instruction ip)
 	    {
             Instruction ldstr = cil.Create(OpCodes.Ldstr, fieldReference.Name);
             cil.InsertAfter(ip, ldstr);
@@ -185,22 +179,22 @@ namespace Db4oTool.NQ
             return InstantiateGenericMethod(getFieldMethod, extent);
 	    }
 
-	    private static void RemovePreviousInstrunctions(CilWorker worker, Instruction instruction, int n)
+	    private static void RemovePreviousInstrunctions(ILProcessor il, Instruction instruction, int n)
 	    {
 	        while (n-- > 0)
 	        {
-                worker.Remove(instruction.Previous);
+                il.Remove(instruction.Previous);
 	        }
         }
 
 	    private void AddConstructor(TypeDefinition type, IDictionary<FieldReference, FieldDefinition> fields)
 	    {
-	        MethodAttributes methodAttributes = MethodAttributes.SpecialName | Mono.Cecil.MethodAttributes.RTSpecialName | MethodAttributes.Public;
-	        MethodDefinition ctor = new MethodDefinition(MethodDefinition.Ctor, methodAttributes, Import(typeof(void)));
+	        const MethodAttributes methodAttributes = MethodAttributes.SpecialName | MethodAttributes.RTSpecialName | MethodAttributes.Public;
+	        MethodDefinition ctor = new MethodDefinition(".ctor", methodAttributes, Import(typeof(void)));
             
             AddMethodParameters(ctor, fields.Values);
 
-            CilWorker cil = ctor.Body.CilWorker;
+            ILProcessor cil = ctor.Body.GetILProcessor ();
             cil.Emit(OpCodes.Ldarg_0);
             cil.Emit(OpCodes.Call, DefaultObjectConstructor());
 
@@ -208,12 +202,12 @@ namespace Db4oTool.NQ
 
             cil.Emit(OpCodes.Ret);
 
-            type.Constructors.Add(ctor);
+            type.Methods.Add(ctor);
         }
 
-	    private static void EmitFieldInitialization(MethodDefinition ctor, IEnumerable<FieldDefinition> fields, ParameterDefinitionCollection parameters)
+	    private static void EmitFieldInitialization(MethodDefinition ctor, IEnumerable<FieldDefinition> fields, IList<ParameterDefinition> parameters)
 	    {
-            CilWorker cil = ctor.Body.CilWorker;
+            ILProcessor cil = ctor.Body.GetILProcessor ();
 
 	        int i = 0;
             foreach (FieldDefinition fieldReference in fields)
@@ -226,21 +220,20 @@ namespace Db4oTool.NQ
 
 	    private static void AddMethodParameters(IMethodSignature method, IEnumerable<FieldDefinition> fields)
 	    {
-            int i = 0;
-            foreach (FieldDefinition parameter in fields)
+	    	foreach (FieldDefinition parameter in fields)
             {
                 method.Parameters.Add(
-                    new ParameterDefinition(parameter.Name, i, ParameterAttributes.None, parameter.FieldType));
+                    new ParameterDefinition(parameter.Name, ParameterAttributes.None, parameter.FieldType));
             }
 	    }
 
-	    private static IDictionary<FieldReference,FieldDefinition> AddFields(TypeDefinition type, IEnumerable<IFieldRef> fields)
+		private static IDictionary<FieldReference, FieldDefinition> AddFields(TypeDefinition type, IEnumerable<IFieldRef> fields)
 	    {
             Dictionary<FieldReference, FieldDefinition> fieldMap = new Dictionary<FieldReference, FieldDefinition>();
             foreach (IFieldRef field in fields)
 	        {
 	            CecilFieldRef cecilFieldRef = (CecilFieldRef) field;
-	            FieldDefinition fieldDefinition = ((FieldDefinition) cecilFieldRef.Reference).Clone();
+	            FieldDefinition fieldDefinition = CloneField((FieldDefinition) cecilFieldRef.Reference);
                 fieldMap.Add(cecilFieldRef.Reference, fieldDefinition);
 	            type.Fields.Add(fieldDefinition);
             }
@@ -248,6 +241,19 @@ namespace Db4oTool.NQ
 	        return fieldMap;
 	    }
 
+		private static FieldDefinition CloneField (FieldDefinition subject)
+		{
+			FieldDefinition clone = new FieldDefinition (subject.Name, subject.Attributes, subject.FieldType);
+
+			if (subject.HasConstant)
+				clone.Constant = subject.Constant;
+
+			if (subject.HasLayoutInfo)
+				clone.Offset = subject.Offset;
+
+			return clone;
+		}
+
 	    private static IList<IFieldRef> CollectAccessedFields(IExpression expression)
 	    {
 	        FieldCollectorVisitor fieldCollector = new FieldCollectorVisitor();
@@ -256,7 +262,7 @@ namespace Db4oTool.NQ
 	        return fieldCollector.Fields;
 	    }
 
-	    private void ProcessCachedStaticFieldPattern(CilWorker worker, Instruction queryInvocation)
+	    private void ProcessCachedStaticFieldPattern(ILProcessor il, Instruction queryInvocation)
 		{
 			MethodReference predicateReference = GetMethodReferenceFromStaticFieldPattern(queryInvocation);
 			MethodDefinition predicateMethod = Resolve(predicateReference);
@@ -267,18 +273,18 @@ namespace Db4oTool.NQ
 			TypeDefinition syntheticPredicate = NewSyntheticPredicateFor(predicateMethod);
 			_optimizer.OptimizePredicate(syntheticPredicate, predicateMethod, expression);
 
-			Instruction newObj = worker.Create(OpCodes.Newobj, FindConstructor(syntheticPredicate, 0));
-			worker.Replace(queryInvocation.Previous, newObj);
+			Instruction newObj = il.Create(OpCodes.Newobj, FindConstructor(syntheticPredicate, 0));
+			il.Replace(queryInvocation.Previous, newObj);
 
 			ReplaceByExecuteEnhancedFilter(queryInvocation);
 		}
 
-		private TypeDefinition NewSyntheticPredicateFor(IMemberReference predicate)
+		private TypeDefinition NewSyntheticPredicateFor(MemberReference predicate)
 		{
 			ModuleDefinition module = MainModule();
-			TypeDefinition type = new TypeDefinition("Db4o$Predicate$" + module.Types.Count, predicate.DeclaringType.Namespace, TypeAttributes.Sealed|TypeAttributes.NotPublic, Import(typeof(object)));
+			TypeDefinition type = new TypeDefinition(predicate.DeclaringType.Namespace, "Db4o$Predicate$" + module.Types.Count, TypeAttributes.Sealed|TypeAttributes.NotPublic, Import(typeof(object)));
 
-			type.Constructors.Add(CreateDefaultConstructor());
+			type.Methods.Add(CreateDefaultConstructor());
 		
 			module.Types.Add(type);
 
@@ -288,11 +294,11 @@ namespace Db4oTool.NQ
 		private MethodDefinition CreateDefaultConstructor()
 		{
 			MethodDefinition ctor = new MethodDefinition(
-											MethodDefinition.Ctor,
+											".ctor",
 											MethodAttributes.SpecialName | MethodAttributes.RTSpecialName | MethodAttributes.Public,
 											Import(typeof(void)));
 
-			CilWorker worker = ctor.Body.CilWorker;
+			ILProcessor worker = ctor.Body.GetILProcessor ();
 			worker.Emit(OpCodes.Ldarg_0);
 			worker.Emit(OpCodes.Call, DefaultObjectConstructor());
 			worker.Emit(OpCodes.Ret);
@@ -322,7 +328,17 @@ namespace Db4oTool.NQ
 
 		private static MethodReference FindConstructor(TypeDefinition type, int index)
 		{
-			return type.Constructors[index];
+			return GetConstructors(type)[index];
+		}
+
+		private static List<MethodDefinition> GetConstructors(TypeDefinition type)
+		{
+			List<MethodDefinition> constructors = new List<MethodDefinition>();
+			foreach (MethodDefinition method in type.Methods)
+			{
+				if (method.IsConstructor) constructors.Add(method);
+			}
+			return constructors;
 		}
 
 		private MethodReference ExecuteEnhancedFilterMethod()
@@ -330,9 +346,15 @@ namespace Db4oTool.NQ
 			return _context.Import(typeof(NativeQueryHandler).GetMethod("ExecuteEnhancedFilter", new Type[] { typeof(IObjectContainer), typeof(IDb4oEnhancedFilter) }));
 		}
 
-		private static MethodDefinition Resolve(MethodReference reference)
+		private static MethodDefinition Resolve(MethodReference methodRef)
 		{
-			return (MethodDefinition) reference;
+			MethodDefinition methodDefinition = methodRef as MethodDefinition;
+			if (methodDefinition != null)
+				return methodDefinition;
+
+			AssemblyDefinition assemblyDefinition = AssemblyDefinition.ReadAssembly(methodRef.DeclaringType.Module.FullyQualifiedName);
+			TypeDefinition type = assemblyDefinition.MainModule.GetType (methodRef.DeclaringType.Name);
+			return CecilReflector.GetMethod(type, methodRef);
 		}
 
 		private static MethodReference GetMethodReferenceFromInlinePredicatePattern(Instruction queryInvocation)
