@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,10 +13,8 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System;
 using System.Windows.Forms;
-using System.Drawing;
-using WeifenLuo.WinFormsUI;
+using WeifenLuo.WinFormsUI.Docking;
 
 namespace Db4objects.Db4o.Tutorial
 {
@@ -29,20 +27,20 @@ namespace Db4objects.Db4o.Tutorial
 		
 		public OutputView(MainForm main)
 		{
-			this.CloseButton = false;
-			this.DockableAreas = (
+			CloseButton = false;
+			DockAreas = (
 					DockAreas.Float |
 					DockAreas.DockBottom |
 					DockAreas.DockTop |
 					DockAreas.DockLeft |
 					DockAreas.DockRight);
-			this.ShowHint = DockState.DockBottom;
-			this.Text = "Output";
+			ShowHint = DockState.DockBottom;
+			Text = "Output";
 			
 			_console = new OutputViewControl();
 			_console.MainForm = main;
 			_console.Dock = DockStyle.Fill;
-			this.Controls.Add(_console);
+			Controls.Add(_console);
 		}
 		
 		public void AppendText(string text)
