@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,49 +15,30 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit.Extensions;
 using Db4oUnit.Extensions.Fixtures;
-using Db4oUnit.Extensions.Util;
-using Db4objects.Db4o;
-using Db4objects.Db4o.Config;
 
 namespace Db4oUnit.Extensions.Fixtures
 {
 	public class Db4oSolo : AbstractFileBasedDb4oFixture
 	{
-		private static readonly string File = "db4oSoloTest.yap";
+		private static readonly string File = "db4oSoloTest.db4o";
 
-		public Db4oSolo() : this(new IndependentConfigurationSource())
+		public Db4oSolo()
 		{
 		}
 
-		public Db4oSolo(IConfigurationSource configSource) : base(configSource, FilePath(
-			))
-		{
-		}
-
-		public Db4oSolo(IFixtureConfiguration fixtureConfiguration) : this()
+		public Db4oSolo(IFixtureConfiguration fixtureConfiguration)
 		{
 			FixtureConfiguration(fixtureConfiguration);
 		}
 
-		protected override IObjectContainer CreateDatabase(IConfiguration config)
-		{
-			return Db4oFactory.OpenFile(config, GetAbsolutePath());
-		}
-
 		public override string Label()
 		{
 			return BuildLabel("SOLO");
 		}
 
-		/// <exception cref="System.Exception"></exception>
-		public override void Defragment()
+		protected override string FileName()
 		{
-			Defragment(FilePath());
-		}
-
-		private static string FilePath()
-		{
-			return CrossPlatformServices.DatabasePath(File);
+			return File;
 		}
 	}
 }
