@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,6 +13,8 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit.Extensions;
+
 namespace Db4oUnit.Extensions.Fixtures
 {
 	/// <summary>
@@ -24,7 +26,7 @@ namespace Db4oUnit.Extensions.Fixtures
 	/// excluded from running against specific fixtures. Concrete marker interfaces
 	/// for specific fixtures should extend OptOutFromTestFixture.
 	/// </remarks>
-	public interface IOptOutFromTestFixture
+	public interface IOptOutFromTestFixture : IDb4oTestCase
 	{
 	}
 }
