@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,7 +13,6 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System;
 using Db4oUnit.Extensions;
 using Db4objects.Db4o.Config;
 using Db4objects.Db4o.TA;
@@ -30,9 +29,9 @@ namespace Db4oUnit.Extensions
 	/// </remarks>
 	public class TAFixtureConfiguration : IFixtureConfiguration
 	{
-		public virtual void Configure(Type clazz, IConfiguration config)
+		public virtual void Configure(IDb4oTestCase testCase, IConfiguration config)
 		{
-			if (typeof(IOptOutTA).IsAssignableFrom(clazz))
+			if (testCase is IOptOutTA)
 			{
 				return;
 			}
