@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -28,8 +28,9 @@ namespace Db4oUnit.Extensions.Tests
 
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(DynamicFixtureTestCase), typeof(FixtureConfigurationTestCase
-				), typeof(FixtureTestCase) };
+			return new Type[] { typeof(Db4oEmbeddedSessionFixtureTestCase), typeof(DynamicFixtureTestCase
+				), typeof(ExcludingReflectorTestCase), typeof(FixtureConfigurationTestCase), typeof(
+				FixtureTestCase), typeof(UnhandledExceptionInThreadTestCase) };
 		}
 	}
 }
