@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,6 +15,7 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit;
 using Db4oUnit.Fixtures;
+using Db4objects.Db4o.Foundation;
 
 namespace Db4oUnit.Fixtures
 {
@@ -35,13 +36,38 @@ namespace Db4oUnit.Fixtures
 		}
 
 		public ITest Decorate(ITest test)
+		{
+			string label = Label();
+			return test.Transmogrify(new _IFunction4_22(this, label));
+		}
+
+		private sealed class _IFunction4_22 : IFunction4
+		{
+			public _IFunction4_22(FixtureDecorator _enclosing, string label)
+			{
+				this._enclosing = _enclosing;
+				this.label = label;
+			}
+
+			public object Apply(object innerTest)
+			{
+				return new TestWithFixture(((ITest)innerTest), label, this._enclosing._provider, 
+					this._enclosing._fixture);
+			}
+
+			private readonly FixtureDecorator _enclosing;
+
+			private readonly string label;
+		}
+
+		private string Label()
 		{
 			string label = _provider.Label + "[" + _fixtureIndex + "]";
 			if (_fixture is ILabeled)
 			{
 				label += ":" + ((ILabeled)_fixture).Label();
 			}
-			return new FixtureDecoration(test, label, _provider, _fixture);
+			return label;
 		}
 	}
 }
