@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -23,7 +23,7 @@ namespace Db4oUnit.Fixtures
 	{
 		public static object Value()
 		{
-			return _variable.Value;
+			return (object)_variable.Value;
 		}
 
 		private static readonly FixtureVariable _variable = new FixtureVariable("subject"
@@ -36,9 +36,8 @@ namespace Db4oUnit.Fixtures
 			_values = values;
 		}
 
-		public SubjectFixtureProvider(object[] values)
+		public SubjectFixtureProvider(object[] values) : this(Iterators.Iterable(values))
 		{
-			_values = Iterators.Iterable(values);
 		}
 
 		public virtual FixtureVariable Variable()
