@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,10 +14,11 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit;
+using Db4objects.Db4o.Foundation;
 
 namespace Db4oUnit
 {
-	public class TestDecorationAdapter : ITestDecoration
+	public class TestDecorationAdapter : ITest
 	{
 		private readonly ITest _test;
 
@@ -26,11 +27,6 @@ namespace Db4oUnit
 			_test = test;
 		}
 
-		public virtual ITest Test()
-		{
-			return _test;
-		}
-
 		public virtual string Label()
 		{
 			return _test.Label();
@@ -40,5 +36,15 @@ namespace Db4oUnit
 		{
 			_test.Run();
 		}
+
+		public virtual bool IsLeafTest()
+		{
+			return _test.IsLeafTest();
+		}
+
+		public virtual ITest Transmogrify(IFunction4 fun)
+		{
+			return ((ITest)fun.Apply(this));
+		}
 	}
 }
