@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -23,10 +23,13 @@ namespace Db4oUnit.Tests
 	{
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(AssertTestCase), typeof(CompositeTestListenerTestCase)
-				, typeof(FrameworkTestCase), typeof(ReflectionTestSuiteBuilderTestCase), typeof(
-				ReinstantiatePerMethodTest), typeof(TestLifeCycleTestCase), typeof(TestRunnerTestCase
-				), typeof(Db4oUnit.Tests.Fixtures.AllTests) };
+			return new Type[] { typeof(AssertTestCase), typeof(ClassLevelFixtureTestTestCase)
+				, typeof(CompositeTestListenerTestCase), typeof(ExceptionInTearDownDoesNotShadowTestCase
+				), typeof(FrameworkTestCase), typeof(OpaqueTestSuiteFailureTestCase), typeof(OpaqueTestSuiteTestCase
+				), typeof(ReflectionTestSuiteBuilderTestCase), typeof(ReinstantiatePerMethodTest
+				), typeof(TestExceptionWithInnerCause), typeof(TestLifeCycleTestCase), typeof(TestRunnerTestCase
+				), typeof(Db4oUnit.Tests.Data.AllTests), typeof(Db4oUnit.Tests.Fixtures.AllTests
+				) };
 		}
 
 		public static void Main(string[] args)
