@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,6 +14,7 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit;
+using Db4objects.Db4o.Foundation;
 
 namespace Db4oUnit.Tests
 {
@@ -27,5 +28,15 @@ namespace Db4oUnit.Tests
 		public virtual void Run()
 		{
 		}
+
+		public virtual bool IsLeafTest()
+		{
+			return true;
+		}
+
+		public virtual ITest Transmogrify(IFunction4 fun)
+		{
+			return ((ITest)fun.Apply(this));
+		}
 	}
 }
