@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,14 +15,15 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit;
 using Db4oUnit.Tests;
+using Db4objects.Db4o.Foundation;
 
 namespace Db4oUnit.Tests
 {
 	public class RunsLifeCycle : ITestCase, ITestLifeCycle
 	{
-		private bool _setupCalled = false;
+		public static DynamicVariable _tearDownCalled = DynamicVariable.NewInstance();
 
-		private bool _tearDownCalled = false;
+		private bool _setupCalled = false;
 
 		public virtual void SetUp()
 		{
@@ -31,7 +32,7 @@ namespace Db4oUnit.Tests
 
 		public virtual void TearDown()
 		{
-			_tearDownCalled = true;
+			TearDownCalled().value = true;
 		}
 
 		public virtual bool SetupCalled()
@@ -39,17 +40,17 @@ namespace Db4oUnit.Tests
 			return _setupCalled;
 		}
 
-		public virtual bool TearDownCalled()
-		{
-			return _tearDownCalled;
-		}
-
 		/// <exception cref="System.Exception"></exception>
 		public virtual void TestMethod()
 		{
 			Assert.IsTrue(_setupCalled);
-			Assert.IsTrue(!_tearDownCalled);
+			Assert.IsTrue(!(((bool)TearDownCalled().value)));
 			throw FrameworkTestCase.Exception;
 		}
+
+		private ByRef TearDownCalled()
+		{
+			return ((ByRef)_tearDownCalled.Value);
+		}
 	}
 }
