@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -17,6 +17,7 @@ using System.Collections;
 using Db4oUnit;
 using Db4oUnit.Tests;
 using Db4objects.Db4o.Foundation;
+using Sharpen.Lang;
 
 namespace Db4oUnit.Tests
 {
@@ -24,13 +25,24 @@ namespace Db4oUnit.Tests
 	{
 		public virtual void TestLifeCycle()
 		{
-			IEnumerator tests = new ReflectionTestSuiteBuilder(typeof(RunsLifeCycle)).GetEnumerator
-				();
-			ITest test = (ITest)Iterators.Next(tests);
-			FrameworkTestCase.RunTestAndExpect(test, 1);
-			RunsLifeCycle testSubject = (RunsLifeCycle)ReflectionTestSuiteBuilder.GetTestSubject
-				(test);
-			Assert.IsTrue(testSubject.TearDownCalled());
+			ByRef tearDownCalled = ByRef.NewInstance(false);
+			RunsLifeCycle._tearDownCalled.With(tearDownCalled, new _IRunnable_11());
+			Assert.IsTrue((((bool)tearDownCalled.value)));
+		}
+
+		private sealed class _IRunnable_11 : IRunnable
+		{
+			public _IRunnable_11()
+			{
+			}
+
+			public void Run()
+			{
+				IEnumerator tests = new ReflectionTestSuiteBuilder(typeof(RunsLifeCycle)).GetEnumerator
+					();
+				ITest test = (ITest)Iterators.Next(tests);
+				FrameworkTestCase.RunTestAndExpect(test, 1);
+			}
 		}
 	}
 }
