@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -21,9 +21,14 @@ namespace Db4oUnit
 
 	public partial class Assert
 	{
-		public static void Expect(System.Type exception, CodeBlock block)
+		public static Exception Expect(System.Type exception, CodeBlock block)
 		{
-			Assert.Expect(exception, new DelegateCodeBlock(block));
+			return Assert.Expect(exception, new DelegateCodeBlock(block));
+		}
+
+		public static Exception Expect<TException>(CodeBlock block) where TException : Exception
+		{
+			return Assert.Expect(typeof(TException), block);
 		}
 
 		private class DelegateCodeBlock : ICodeBlock
@@ -40,5 +45,10 @@ namespace Db4oUnit
 				_block();
 			}
 		}
+
+		public static void InRange(double value, double from, double to)
+		{
+			Assert.IsTrue(value >= from && value <= to, string.Format("'{0}' not in range '{1}'..'{2}'", value, from, to));
+		}
 	}
 }
