@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,27 +13,34 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+
 namespace Db4oUnit
 {
-	public class TestException : System.Exception
+	public class TestException : Exception
 	{
-        public TestException(string message, System.Exception reason)
-            : base(message, reason)
+        public TestException(string message, Exception reason) : base(message, reason)
         {
         }
 
-		public TestException(System.Exception reason) : base(reason.Message, reason)
+		public TestException(Exception reason) : base(reason.Message, reason)
 		{
 		}
 
-		public System.Exception GetReason()
+#if !CF && !SILVERLIGHT
+		public TestException(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context) : base(info, context)
 		{
-			return this.InnerException;
+		}
+#endif
+
+		public Exception GetReason()
+		{
+			return InnerException;
 		}
 		
 		override public string ToString()
 		{
-			if (null != this.InnerException) return this.InnerException.ToString();
+			if (null != InnerException) return InnerException.ToString();
 			return base.ToString();
 		}
 	}
