@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,17 +13,18 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using Db4objects.Db4o.Instrumentation.Api;
-
 namespace Db4objects.Db4o.Instrumentation.Api
 {
 	public sealed class CallingConvention
 	{
-		public static readonly CallingConvention Static = new CallingConvention();
+		public static readonly Db4objects.Db4o.Instrumentation.Api.CallingConvention Static
+			 = new Db4objects.Db4o.Instrumentation.Api.CallingConvention();
 
-		public static readonly CallingConvention Virtual = new CallingConvention();
+		public static readonly Db4objects.Db4o.Instrumentation.Api.CallingConvention Virtual
+			 = new Db4objects.Db4o.Instrumentation.Api.CallingConvention();
 
-		public static readonly CallingConvention Interface = new CallingConvention();
+		public static readonly Db4objects.Db4o.Instrumentation.Api.CallingConvention Interface
+			 = new Db4objects.Db4o.Instrumentation.Api.CallingConvention();
 
 		private CallingConvention()
 		{
