@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,9 +13,6 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System;
-
-using Db4objects.Db4o;
 using Db4objects.Db4o.Query;
 
 namespace Db4objects.Db4o.Linq.Tests.Queries
