@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,11 +13,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System;
 using System.Linq.Expressions;
-using System.Reflection;
-
-using Db4objects.Db4o.Linq.Caching;
 using Db4objects.Db4o.Linq.Internals;
 using Db4objects.Db4o.Query;
 
@@ -27,13 +23,30 @@ namespace Db4objects.Db4o.Linq.Expressions
 	{
 		protected abstract void ApplyDirection(IQuery query);
 
+		protected override void VisitMethodCall(MethodCallExpression methodCall)
+		{
+			Visit(methodCall.Object);
+			AnalyseMethod(Recorder, methodCall.Method);
+		}
+
 		protected override void VisitMemberAccess(MemberExpression m)
 		{
-			if (!IsParameterReference(m)) CannotOptimize(m);
-
 			ProcessMemberAccess(m);
+		}
 
-			Recorder.Add(ctx => ApplyDirection(ctx.CurrentQuery));
+		public override IQueryBuilderRecord Process(LambdaExpression expression)
+		{
+			if (!StartsWithParameterReference(expression.Body))
+				CannotOptimize(expression.Body);
+
+			return ApplyDirection(base.Process(expression));
+		}
+
+		private IQueryBuilderRecord ApplyDirection(IQueryBuilderRecord record)
+		{
+			QueryBuilderRecorder recorder = new QueryBuilderRecorder(record);
+			recorder.Add(ctx => ApplyDirection(ctx.CurrentQuery));
+			return recorder.Record;
 		}
 	}
 }
