@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,7 +16,7 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Linq.Expressions;
 using System.Reflection;
-
+using Db4objects.Db4o.Internal.Caching;
 using Db4objects.Db4o.Linq.Caching;
 using Db4objects.Db4o.Linq.Internals;
 using Db4objects.Db4o.Query;
@@ -25,10 +25,9 @@ namespace Db4objects.Db4o.Linq.Expressions
 {
 	internal class OrderByDescendingClauseVisitor : OrderByClauseVisitorBase
 	{
-		private static ICachingStrategy<Expression, IQueryBuilderRecord> _cache =
-			new SingleItemCachingStrategy<Expression, IQueryBuilderRecord>(ExpressionEqualityComparer.Instance);
+		private static ICache4<Expression, IQueryBuilderRecord> _cache = ExpressionCacheFactory.NewInstance(10);
 
-		protected override ICachingStrategy<Expression, IQueryBuilderRecord> GetCachingStrategy()
+		protected override ICache4<Expression, IQueryBuilderRecord> GetCachingStrategy()
 		{
 			return _cache;
 		}
