@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,29 +13,31 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System;
 using System.Collections;
 using System.Collections.Generic;
+using Db4objects.Db4o.Query;
 
 namespace Db4objects.Db4o.Linq.Internals
 {
 	internal class PlaceHolderQuery<T> : IDb4oLinqQuery<T>
 	{
-		private IObjectContainer _container;
+		private ISodaQueryFactory _queryFactory;
 
-		public IObjectContainer Container
+		public ISodaQueryFactory QueryFactory
 		{
-			get { return _container; }
+			get { return _queryFactory; }
 		}
 
-		public PlaceHolderQuery(IObjectContainer container)
+		public PlaceHolderQuery(ISodaQueryFactory queryFactory)
 		{
-			_container = container;
+			_queryFactory = queryFactory;
 		}
 
 		public IEnumerator<T> GetEnumerator()
 		{
-			return new ObjectSequence<T>(_container.Query(typeof(T))).GetEnumerator();
+			var query = _queryFactory.Query();
+			query.Constrain(typeof(T));
+			return new ObjectSequence<T>(query.Execute()).GetEnumerator();
 		}
 
 		IEnumerator IEnumerable.GetEnumerator()
