@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,22 +14,24 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System.Reflection;
-using System.Runtime.CompilerServices;
+using System.Runtime.InteropServices;
 using System.Security;
 
 [assembly: AssemblyTitle("db4o - native query handling")]
-[assembly: AssemblyCompany("db4objects Inc., San Mateo, CA, USA")]
+[assembly: AssemblyCompany("Versant Corp., Redwood City, CA, USA")]
 [assembly: AssemblyProduct("db4o - database for objects")]
-[assembly: AssemblyCopyright("db4o 2005 - 2009")]
+[assembly: AssemblyCopyright("Versant Corp. 2000 - 2011")]
 [assembly: AssemblyTrademark("")]
 [assembly: AssemblyCulture("")]
 
 // attributes are automatically set by the build
-[assembly: AssemblyVersion("7.4.121.14026")]
+[assembly: AssemblyVersion("8.0.184.15484")]
 [assembly: AssemblyKeyFile("")]
 [assembly: AssemblyConfiguration(".NET")]
-[assembly: AssemblyDescription("Db4objects.Db4o.NativeQueries 7.4.121.14026 (.NET)")]
+[assembly: AssemblyDescription("Db4objects.Db4o.NativeQueries 8.0.184.15484 (.NET)")]
 
 #if !CF
 [assembly: AllowPartiallyTrustedCallers]
-#endif
\ No newline at end of file
+#endif
+
+[assembly: ComVisible(false)]
