@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,9 +15,9 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Internal.Query
 {
-	public interface ICachingStrategy
+	public interface ICachingStrategy<K,V>
 	{
-		void Add(object key, object item);
-		object Get(object key);
+		void Add(K key, V item);
+		V Get(K key);
 	}
 }
\ No newline at end of file
