@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,9 +13,11 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+using System.Collections.Generic;
 using Db4objects.Db4o.Activation;
 using Db4objects.Db4o.Instrumentation.Cecil;
 using Db4objects.Db4o.TA;
+using Mono.Collections.Generic;
 
 namespace Db4objects.Db4o.NativeQueries
 {
@@ -30,118 +32,123 @@ namespace Db4objects.Db4o.NativeQueries
 	using Cecil.FlowAnalysis.CodeStructure;
 	using Ast = Cecil.FlowAnalysis.CodeStructure;
 
-	using Db4objects.Db4o.NativeQueries.Expr;
-	using Db4objects.Db4o.NativeQueries.Expr.Cmp;
-	using Db4objects.Db4o.NativeQueries.Expr.Cmp.Operand;
-	using NQExpression = Db4objects.Db4o.NativeQueries.Expr.IExpression;
-	using Db4objects.Db4o.Internal.Query;
+	using Expr;
+	using Expr.Cmp;
+	using Expr.Cmp.Operand;
+	using NQExpression = Expr.IExpression;
+	using Internal.Query;
 
 	/// <summary>
-	/// Build a Db4objects.Db4o.Nativequery.Expr tree out of
-	/// a predicate method definition.
+	/// Build a Db4objects.Db4o.Nativequery.Expr tree out of a predicate method definition.
 	/// </summary>
 	public class QueryExpressionBuilder
 	{
-		protected static ICachingStrategy _assemblyCachingStrategy = new SingleItemCachingStrategy();
+		protected static ICachingStrategy<string, AssemblyDefinition> _assemblyCachingStrategy = 
+				new SingleItemCachingStrategy<string, AssemblyDefinition>( delegate(string location)
+																			{
+																				return AssemblyDefinition.ReadAssembly(location);
+																			});
 
-		protected static ICachingStrategy _expressionCachingStrategy = new SingleItemCachingStrategy();
+		protected static ICachingStrategy<MethodBase, IExpression> _expressionCachingStrategy = 
+				new SingleItemCachingStrategy<MethodBase, IExpression>(
+																		delegate(MethodBase method)
+																			{
+																				MethodDefinition methodDef = GetMethodDefinition(method);
+																				return AdjustBoxedValueTypes(FromMethodDefinition(methodDef));
+																			}
+																		);
 
-		public static ICachingStrategy AssemblyCachingStrategy
-		{
-			get
-			{
-				return _assemblyCachingStrategy;
-			}
-
-			set
-			{
-				if (null == value) throw new ArgumentNullException("AssemblyCachingStrategy");
-				_assemblyCachingStrategy = value;
-			}
-		}
-
-		public static ICachingStrategy ExpressionCachingStrategy
-		{
-			get
-			{
-				return _expressionCachingStrategy;
-			}
-
-			set
-			{
-				if (null == value) throw new ArgumentNullException("ExpressionCachingStrategy");
-				_expressionCachingStrategy = value;
-			}
-		}
-
-		public NQExpression FromMethod(System.Reflection.MethodBase method)
+		public NQExpression FromMethod(MethodBase method)
 		{
 			if (method == null) throw new ArgumentNullException("method");
 			
-			NQExpression e = GetCachedExpression(method);
-			if (e != null) return e;
-
-			MethodDefinition methodDef = GetMethodDefinition(method);
-			e = AdjustBoxedValueTypes(FromMethodDefinition(methodDef));
-			CacheExpression(method, e);
-			
-			return e;
-		}
-
-		private static void CacheExpression(MethodBase method, NQExpression e)
-		{
-			_expressionCachingStrategy.Add(method, e);
+			return GetCachedExpression(method);
 		}
 
 		private static NQExpression GetCachedExpression(MethodBase method)
 		{
-			return (NQExpression)_expressionCachingStrategy.Get(method);
+			return _expressionCachingStrategy.Get(method);
 		}
 
 		private static MethodDefinition GetMethodDefinition(MethodBase method)
 		{
 			string location = GetAssemblyLocation(method);
-			AssemblyDefinition assembly = GetAssembly(location);
-			TypeDefinition type = FindTypeDefinition(assembly.MainModule, method.DeclaringType);
-			if (null == type) UnsupportedPredicate(string.Format("Unable to load type '{0}' from assembly '{1}'", method.DeclaringType.FullName, location));
-			MethodDefinition methodDef = type.Methods.GetMethod(method.Name, GetParameterTypes(method));
+#if CF
+			MethodDefinition methodDef = MethodDefinitionFor(method);
+#else
+			AssemblyDefinition assembly = _assemblyCachingStrategy.Get(location);
+
+			MethodDefinition methodDef = (MethodDefinition)assembly.MainModule.LookupToken(method.MetadataToken);
+#endif
 			if (null == methodDef) UnsupportedPredicate(string.Format("Unable to load the definition of '{0}' from assembly '{1}'", method, location));
+			
 			return methodDef;
 		}
 
-		private NQExpression AdjustBoxedValueTypes(NQExpression expression)
+		private static MethodDefinition MethodDefinitionFor(MethodBase method)
+		{
+			string location = GetAssemblyLocation(method);
+			AssemblyDefinition assembly = _assemblyCachingStrategy.Get(location);
+
+#if CF
+			TypeDefinition declaringType = FindTypeDefinition(assembly.MainModule, method.DeclaringType);
+			if (declaringType == null)
+			{
+				return null;
+			}
+
+			foreach (MethodDefinition candidate in declaringType.Methods)
+			{
+				if (candidate.Name != method.Name) continue;
+				if (candidate.Parameters.Count != method.GetParameters().Length) continue;
+				if (!ParametersMatch(candidate.Parameters, GetParameterTypes(method, assembly.MainModule))) continue;
+				{
+					return candidate;
+				}
+			}
+
+			return null;
+
+#else
+			return (MethodDefinition) assembly.MainModule.LookupToken(method.MetadataToken);
+#endif
+		}
+
+		private static NQExpression AdjustBoxedValueTypes(NQExpression expression)
 		{
 			expression.Accept(new BoxedValueTypeProcessor());
 			return expression;
 		}
 
-		private static AssemblyDefinition GetAssembly(string location)
+		private static IList<TypeReference> GetParameterTypes(MethodBase method, ModuleDefinition module)
 		{
-			AssemblyDefinition assembly = (AssemblyDefinition)_assemblyCachingStrategy.Get(location);
-			if (null == assembly)
+			IList<TypeReference> types = new List<TypeReference>();
+			foreach (ParameterInfo parameter in ParametersFor(method))
 			{
-				assembly = AssemblyFactory.GetAssembly(location);
-				_assemblyCachingStrategy.Add(location, assembly);
+				types.Add(FindTypeDefinition(module, parameter.ParameterType));
 			}
-			return assembly;
+
+			return types;
 		}
 
-		private static Type[] GetParameterTypes(MethodBase method)
+		private static ParameterInfo[] ParametersFor(MethodBase method)
 		{
-			ParameterInfo[] parameters = method.GetParameters();
-			Type[] types = new Type[parameters.Length];
-			for (int i = 0; i < parameters.Length; ++i)
+			if (method.IsGenericMethod)
 			{
-				types[i] = parameters[i].ParameterType;
+				MethodInfo methodInfo = (MethodInfo) method;
+				return methodInfo.GetGenericMethodDefinition().GetParameters();
 			}
-			return types;
+
+			return method.DeclaringType.IsGenericType 
+								? method.DeclaringType.GetGenericTypeDefinition().GetMethod(method.Name).GetParameters() 
+								: method.GetParameters();
 		}
 
 		private static TypeDefinition FindTypeDefinition(ModuleDefinition module, Type type)
 		{
 			return IsNested(type)
 				? FindNestedTypeDefinition(module, type)
-				: FindTypeDefinition(module, type.FullName);
+				: FindTypeDefinition(module, type.IsGenericType ? type.Name : type.FullName);
 		}
 
 		private static bool IsNested(Type type)
@@ -158,9 +165,9 @@ namespace Db4objects.Db4o.NativeQueries
 			return null;
 		}
 
-		private static TypeDefinition FindTypeDefinition(ModuleDefinition module, string fullName)
+		private static TypeDefinition FindTypeDefinition(ModuleDefinition module, string name)
 		{
-			return module.Types[fullName];
+			return module.GetType(name);
 		}
 
 		private static string GetAssemblyLocation(MethodBase method)
@@ -175,7 +182,7 @@ namespace Db4objects.Db4o.NativeQueries
 			Expression expression = GetQueryExpression(method);
 			if (null == expression) UnsupportedPredicate("No expression found.");
 			
-			Visitor visitor = new Visitor(method);
+			Visitor visitor = new Visitor(method, new AssemblyResolver(_assemblyCachingStrategy));
 			expression.Accept(visitor);
 			return visitor.Expression;
 		}
@@ -188,7 +195,7 @@ namespace Db4objects.Db4o.NativeQueries
 				UnsupportedPredicate("A predicate must take a single argument.");
 			if (0 != method.Body.ExceptionHandlers.Count)
 				UnsupportedPredicate("A predicate can not contain exception handlers.");
-			if (method.DeclaringType.Module.Import(typeof(bool)) != method.ReturnType.ReturnType)
+			if (method.ReturnType.FullName != typeof(bool).FullName)
 				UnsupportedPredicate("A predicate must have a boolean return type.");
 		}
 
@@ -210,7 +217,7 @@ namespace Db4objects.Db4o.NativeQueries
 
 		private static Expression GetQueryExpression(ActionFlowGraph afg)
 		{
-			Hashtable variables = new Hashtable();
+			IDictionary<int, Expression> variables = new Dictionary<int, Expression>();
 			ActionBlock block = afg.Blocks[0];
 			while (block != null)
 			{
@@ -219,11 +226,13 @@ namespace Db4objects.Db4o.NativeQueries
 					case ActionType.Invoke:
 						InvokeActionBlock invokeBlock = (InvokeActionBlock)block;
 						MethodInvocationExpression invocation = invokeBlock.Expression;
-						if (IsActivateInvocation(invocation))
+						if (IsActivateInvocation(invocation) 
+							|| IsNoSideEffectIndirectActivationInvocation(invocation))
 						{
 							block = invokeBlock.Next;
 							break;
 						}
+
 						UnsupportedExpression(invocation);
 						break;
 
@@ -246,8 +255,9 @@ namespace Db4objects.Db4o.NativeQueries
 							}
 							else
 							{
-								if (variables.Contains(variable.Variable.Index))
+								if (variables.ContainsKey(variable.Variable.Index))
 									UnsupportedExpression(assign.Expression);
+								
 								variables.Add(variable.Variable.Index, assign.Expression);
 								block = assignBlock.Next;
 							}
@@ -260,13 +270,36 @@ namespace Db4objects.Db4o.NativeQueries
 							VariableReferenceExpression variable = expression as VariableReferenceExpression;
 							return null == variable
 								? expression
-								: (Expression)variables[variable.Variable.Index];
+								: variables[variable.Variable.Index];
 						}
 				}
 			}
 			return null;
 		}
 
+		private static bool IsNoSideEffectIndirectActivationInvocation(MethodInvocationExpression invocation)
+		{
+			MethodDefinition methodDefinition = MethodDefinitionFor(invocation);
+			if (null == methodDefinition) return false;
+			ActionFlowGraph afg = FlowGraphFactory.CreateActionFlowGraph(FlowGraphFactory.CreateControlFlowGraph(methodDefinition));
+
+			if (afg.Blocks.Count == 2 && afg.Blocks[0].ActionType == ActionType.Invoke)
+			{
+				InvokeActionBlock invocationBlock = (InvokeActionBlock) afg.Blocks[0];
+				return IsActivateInvocation(invocationBlock.Expression);
+			}
+
+			return false;
+		}
+
+		private static MethodDefinition MethodDefinitionFor(MethodInvocationExpression invocation)
+		{
+			MethodReferenceExpression methodRef = invocation.Target as MethodReferenceExpression;
+			if (null == methodRef) return null;
+
+			return GetMethodDefinition(methodRef);
+		}
+
 		private static bool IsActivateInvocation(MethodInvocationExpression invocation)
 		{
 			MethodReferenceExpression methodRef = invocation.Target as MethodReferenceExpression;
@@ -304,19 +337,78 @@ namespace Db4objects.Db4o.NativeQueries
 			return false;
 		}
 
+		private static MethodDefinition GetMethodDefinition(MethodReferenceExpression methodRef)
+		{
+			MethodDefinition definition = methodRef.Method as MethodDefinition;
+			return definition ?? LoadExternalMethodDefinition(methodRef);
+		}
+
+		private static MethodDefinition LoadExternalMethodDefinition(MethodReferenceExpression methodRef)
+		{
+			MethodReference method = methodRef.Method;
+			AssemblyDefinition assemblyDef = new AssemblyResolver(_assemblyCachingStrategy).ForTypeReference(method.DeclaringType);
+			TypeDefinition type = assemblyDef.MainModule.GetType(method.DeclaringType.FullName);
+			return GetMethod(type, method);
+		}
+
+		private static MethodDefinition GetMethod(TypeDefinition type, MethodReference template)
+		{
+			foreach (MethodDefinition method in type.Methods)
+			{
+				if (method.Name != template.Name) continue;
+				if (method.Parameters.Count != template.Parameters.Count) continue;
+				if (!ParametersMatch(method.Parameters, template.Parameters)) continue;
+
+				return method;
+			}
+
+			return null;
+		}
+
+#if CF
+		private static bool ParametersMatch(Collection<ParameterDefinition> parameters, IList<TypeReference> templates)
+		{
+			return ParametersMatch(parameters, templates, delegate(ParameterDefinition candidate, TypeReference template)
+			{
+				return candidate.ParameterType.FullName == template.FullName;
+			});
+		}
+#endif
+
+		private static bool ParametersMatch(IList<ParameterDefinition> parameters, IList<ParameterDefinition> templates)
+		{
+			return ParametersMatch(parameters, templates, delegate(ParameterDefinition candidate, ParameterDefinition template)
+			                                               	{
+			                                               		return candidate.ParameterType.FullName == template.ParameterType.FullName;
+			                                               	});
+		}
+
+		private static bool ParametersMatch<T>(IList<ParameterDefinition> parameters, IList<T> templates, ParameterMatch<T> predicate)
+		{
+			if (parameters.Count != templates.Count) return false;
+
+			for (int i = 0; i < parameters.Count; i++)
+			{
+				ParameterDefinition parameter = parameters[i];
+				if (!predicate(parameter, templates[i])) return false;
+			}
+
+			return true;
+		}
+
+		private delegate bool ParameterMatch<T>(ParameterDefinition candidate, T template);
+
 		class Visitor : AbstractCodeStructureVisitor
 		{
-			object _current;
-			private int _insideCandidate = 0;
-			Hashtable _assemblies = new Hashtable();
-			IList _methodDefinitionStack = new ArrayList();
+			private object _current;
+			private int _insideCandidate;
+			readonly IList _methodDefinitionStack = new ArrayList();
 			private readonly CecilReferenceProvider _referenceProvider;
 
-			public Visitor(MethodDefinition topLevelMethod)
+			public Visitor(MethodDefinition topLevelMethod, AssemblyResolver resolver)
 			{
 				EnterMethodDefinition(topLevelMethod);
-				AssemblyDefinition assembly = topLevelMethod.DeclaringType.Module.Assembly;
-				RegisterAssembly(assembly);
+				AssemblyDefinition assembly = resolver.ForType(topLevelMethod.DeclaringType);
 				_referenceProvider = CecilReferenceProvider.ForModule(assembly.MainModule);
 			}
 
@@ -333,21 +425,6 @@ namespace Db4objects.Db4o.NativeQueries
 				_methodDefinitionStack.RemoveAt(lastIndex);
 			}
 
-			/// <summary>
-			/// Registers an assembly so it can be looked up by its assembly name
-			/// string later.
-			/// </summary>
-			/// <param name="assembly"></param>
-			private void RegisterAssembly(AssemblyDefinition assembly)
-			{
-				_assemblies.Add(assembly.Name.FullName, assembly);
-			}
-
-			private AssemblyDefinition LookupAssembly(string fullName)
-			{
-				return (AssemblyDefinition)_assemblies[fullName];
-			}
-
 			public NQExpression Expression
 			{
 				get
@@ -361,15 +438,15 @@ namespace Db4objects.Db4o.NativeQueries
 				}
 			}
 
-		    private NQExpression ToNQExpression(ConstValue value)
+		    private static NQExpression ToNQExpression(ConstValue value)
 		    {
                 if (IsTrue(value.Value())) return BoolConstExpression.True;
 		        return BoolConstExpression.False;
 		    }
 
-		    private bool IsTrue(object o)
+		    private static bool IsTrue(object o)
 		    {
-                return (o as IConvertible).ToBoolean(null);
+                return ((IConvertible) o).ToBoolean(null);
 		    }
 
 		    private bool InsideCandidate
@@ -377,6 +454,11 @@ namespace Db4objects.Db4o.NativeQueries
 				get { return _insideCandidate > 0; }
 			}
 
+			public override void Visit(CastExpression node)
+			{
+				node.Target.Accept(this);
+			}
+
 			public override void Visit(AssignExpression node)
 			{
 				UnsupportedExpression(node);
@@ -490,7 +572,7 @@ namespace Db4objects.Db4o.NativeQueries
 				}
 			}
 
-			private bool IsCandidateFieldValue(object o)
+			private static bool IsCandidateFieldValue(object o)
 			{
 				FieldValue value = o as FieldValue;
 				if (value == null) return false;
@@ -583,9 +665,9 @@ namespace Db4objects.Db4o.NativeQueries
 				}
 			}
 
-			private void ProcessOperatorMethodInvocation(MethodInvocationExpression node, MethodReference method)
+			private void ProcessOperatorMethodInvocation(MethodInvocationExpression node, MemberReference methodReference)
 			{
-				switch (method.Name)
+				switch (methodReference.Name)
 				{
 					case "op_Equality":
 						PushComparison(node.Arguments[0], node.Arguments[1], ComparisonOperator.ValueEquality);
@@ -622,17 +704,17 @@ namespace Db4objects.Db4o.NativeQueries
 				}
 			}
 
-			private void ProcessCandidateMethodInvocation(MethodInvocationExpression node, MethodReferenceExpression methodRef)
+			private void ProcessCandidateMethodInvocation(Expression methodInvocationExpression, MethodReferenceExpression methodRef)
 			{
 				MethodDefinition method = GetMethodDefinition(methodRef);
 				if (null == method)
-					UnsupportedExpression(node);
+					UnsupportedExpression(methodInvocationExpression);
 
-				AssertMethodCanBeVisited(node, method);
+				AssertMethodCanBeVisited(methodInvocationExpression, method);
 
 				Expression expression = GetQueryExpression(method);
 				if (null == expression)
-					UnsupportedExpression(node);
+					UnsupportedExpression(methodInvocationExpression);
 
 				EnterCandidateMethod(method);
 				try
@@ -645,41 +727,10 @@ namespace Db4objects.Db4o.NativeQueries
 				}
 			}
 
-			private void AssertMethodCanBeVisited(MethodInvocationExpression node, MethodDefinition method)
+			private void AssertMethodCanBeVisited(Expression methodInvocationExpression, MethodDefinition method)
 			{
 				if (_methodDefinitionStack.Contains(method))
-					UnsupportedExpression(node);
-			}
-
-			private MethodDefinition GetMethodDefinition(MethodReferenceExpression methodRef)
-			{
-				MethodDefinition definition = methodRef.Method as MethodDefinition;
-				return definition != null
-					? definition
-					: LoadExternalMethodDefinition(methodRef);
-			}
-
-			private MethodDefinition LoadExternalMethodDefinition(MethodReferenceExpression methodRef)
-			{
-				MethodReference method = methodRef.Method;
-				AssemblyDefinition assemblyDef = GetContainingAssembly(method.DeclaringType);
-				TypeDefinition type = assemblyDef.MainModule.Types[method.DeclaringType.FullName];
-				return type.Methods.GetMethod(method.Name, method.Parameters);
-			}
-
-			private AssemblyDefinition GetContainingAssembly(TypeReference type)
-			{
-				AssemblyNameReference scope = (AssemblyNameReference)type.Scope;
-				string assemblyName = scope.FullName;
-				AssemblyDefinition definition = LookupAssembly(assemblyName);
-				if (null == definition)
-				{
-					Assembly assembly = Assembly.Load(assemblyName);
-					string location = assembly.GetType(type.FullName).Module.FullyQualifiedName;
-					definition = QueryExpressionBuilder.GetAssembly(location);
-					RegisterAssembly(definition);
-				}
-				return definition;
+					UnsupportedExpression(methodInvocationExpression);
 			}
 
 			private void EnterCandidateMethod(MethodDefinition method)
@@ -701,11 +752,14 @@ namespace Db4objects.Db4o.NativeQueries
 
 			public override void Visit(FieldReferenceExpression node)
 			{
-				Expression target = node.Target;
+				PushFieldValueForTarget(node, node.Target);
+			}
+
+			private void PushFieldValueForTarget(FieldReferenceExpression node, Expression target)
+			{
 				switch (target.CodeElementType)
 				{
 					case CodeElementType.ArgumentReferenceExpression:
-						//IArgumentReferenceExpression arg = (IArgumentReferenceExpression)target;
 						PushFieldValue(CandidateFieldRoot.Instance, node.Field);
 						break;
 
@@ -734,6 +788,10 @@ namespace Db4objects.Db4o.NativeQueries
 						PushFieldValue(value, node.Field);
 						break;
 
+					case CodeElementType.CastExpression:
+						PushFieldValueForTarget(node, ((CastExpression)node.Target).Target);
+						break;
+
 					default:
 						UnsupportedExpression(node);
 						break;
@@ -792,7 +850,7 @@ namespace Db4objects.Db4o.NativeQueries
 				_current = value;
 			}
 
-			object Pop(Expression node, System.Type expectedType)
+			object Pop(Expression node, Type expectedType)
 			{
 				object value = Pop();
 				AssertType(value, expectedType, node);
@@ -818,7 +876,7 @@ namespace Db4objects.Db4o.NativeQueries
 				return value;
 			}
 
-			private void Assert(bool condition, string message)
+			private static void Assert(bool condition, string message)
 			{
 				System.Diagnostics.Debug.Assert(condition, message);
 			}
@@ -843,7 +901,7 @@ namespace Db4objects.Db4o.NativeQueries
 			return ((CecilFieldRef) field.Field).FieldType;
 		}
 
-		private void AdjustConstValue(TypeReference typeRef, ConstValue constValue)
+		private static void AdjustConstValue(TypeReference typeRef, ConstValue constValue)
 		{
 			object value = constValue.Value();
 			if (!value.GetType().IsValueType) return;
