@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,12 +19,24 @@ using Db4objects.Db4o.Tests.Common.Acid;
 
 namespace Db4objects.Db4o.Tests.Common.Acid
 {
-	public class AllTests : Db4oTestSuite
+	public class AllTests : ComposibleTestSuite
 	{
+		public static void Main(string[] args)
+		{
+			new Db4objects.Db4o.Tests.Common.Acid.AllTests().RunSolo();
+		}
+
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(CrashSimulatingTestCase), typeof(ReadCommittedIsolationTestCase
+			return ComposeWith();
+		}
+
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
+		{
+			return new Type[] { typeof(CrashSimulatingTestSuite), typeof(ReadCommittedIsolationTestCase
 				) };
 		}
+		#endif // !SILVERLIGHT
 	}
 }
