@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,20 +13,14 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System.IO;
 using Db4oUnit;
 using Db4objects.Db4o.Foundation.IO;
 
 namespace Db4objects.Db4o.Tests.Common.Api
 {
-	public class TestWithTempFile : ITestLifeCycle
+	public partial class TestWithTempFile : ITestLifeCycle
 	{
-		private readonly string _tempFile = Path.GetTempFileName();
-
-		protected virtual string TempFile()
-		{
-			return _tempFile;
-		}
+		private string _tempFile;
 
 		/// <exception cref="System.Exception"></exception>
 		public virtual void SetUp()
