@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,25 +13,29 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
-using System.IO;
 using Db4oUnit;
 using Db4objects.Db4o;
 using Db4objects.Db4o.Foundation.IO;
+using Db4objects.Db4o.Tests.Common.Api;
 
 namespace Db4objects.Db4o.Tests.Common.Assorted
 {
-	public class CloseUnlocksFileTestCase : ITestCase
+	public class CloseUnlocksFileTestCase : Db4oTestWithTempFile
 	{
-		private static readonly string File = Path.GetTempFileName();
-
+		[System.ObsoleteAttribute]
 		public virtual void Test()
 		{
-			File4.Delete(File);
-			Assert.IsFalse(System.IO.File.Exists(File));
-			IObjectContainer oc = Db4oFactory.OpenFile(File);
+			File4.Delete(TempFile());
+			Assert.IsFalse(Exists(TempFile()));
+			IObjectContainer oc = Db4oEmbedded.OpenFile(NewConfiguration(), TempFile());
 			oc.Close();
-			File4.Delete(File);
-			Assert.IsFalse(System.IO.File.Exists(File));
+			File4.Delete(TempFile());
+			Assert.IsFalse(Exists(TempFile()));
+		}
+
+		private bool Exists(string fileName)
+		{
+			return new Sharpen.IO.File(fileName).Exists();
 		}
 	}
 }
