@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,6 +13,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+#if !SILVERLIGHT
 using System;
 using Db4oUnit;
 using Db4oUnit.Extensions;
@@ -44,8 +45,9 @@ namespace Db4objects.Db4o.Tests.Common.Assorted
 
 		public virtual void Test()
 		{
-			Assert.AreEqual(typeof(string), ((PersistTypeTestCase.Item)RetrieveOnlyInstance(typeof(
-				PersistTypeTestCase.Item))).type);
+			Assert.AreEqual(typeof(string), ((PersistTypeTestCase.Item)((PersistTypeTestCase.Item
+				)RetrieveOnlyInstance(typeof(PersistTypeTestCase.Item)))).type);
 		}
 	}
 }
+#endif // !SILVERLIGHT
