@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,23 +13,31 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+#if !SILVERLIGHT
 using Db4oUnit.Extensions;
+using Db4oUnit.Extensions.Fixtures;
+using Db4objects.Db4o.CS.Internal;
 using Db4objects.Db4o.Foundation;
-using Db4objects.Db4o.Internal.CS;
 
 namespace Db4objects.Db4o.Tests.Common.CS
 {
-	public class ClientServerTestCaseBase : Db4oClientServerTestCase
+	public class ClientServerTestCaseBase : Db4oClientServerTestCase, IOptOutAllButNetworkingCS
 	{
 		protected virtual IServerMessageDispatcher ServerDispatcher()
 		{
-			ObjectServerImpl serverImpl = (ObjectServerImpl)ClientServerFixture().Server();
+			ObjectServerImpl serverImpl = Server();
 			return (IServerMessageDispatcher)Iterators.Next(serverImpl.IterateDispatchers());
 		}
 
+		protected virtual ObjectServerImpl Server()
+		{
+			return (ObjectServerImpl)ClientServerFixture().Server();
+		}
+
 		protected virtual ClientObjectContainer Client()
 		{
 			return (ClientObjectContainer)Db();
 		}
 	}
 }
+#endif // !SILVERLIGHT
