@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,8 +13,9 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+#if !SILVERLIGHT
 using Db4oUnit;
-using Db4objects.Db4o.Internal.CS.Messages;
+using Db4objects.Db4o.CS.Internal.Messages;
 using Db4objects.Db4o.Tests.Common.CS;
 
 namespace Db4objects.Db4o.Tests.Common.CS
@@ -23,12 +24,12 @@ namespace Db4objects.Db4o.Tests.Common.CS
 	{
 		public static void Main(string[] args)
 		{
-			new SendMessageToClientTestCase().RunClientServer();
+			new SendMessageToClientTestCase().RunNetworking();
 		}
 
 		public virtual void Test()
 		{
-			if (IsMTOC())
+			if (IsEmbedded())
 			{
 				// No sending messages back and forth on MTOC.
 				return;
@@ -39,3 +40,4 @@ namespace Db4objects.Db4o.Tests.Common.CS
 		}
 	}
 }
+#endif // !SILVERLIGHT
