@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,11 +13,12 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+#if !SILVERLIGHT
 using Db4oUnit;
-using Db4objects.Db4o;
-using Db4objects.Db4o.Config;
+using Db4objects.Db4o.CS;
+using Db4objects.Db4o.CS.Config;
+using Db4objects.Db4o.CS.Internal;
 using Db4objects.Db4o.IO;
-using Db4objects.Db4o.Internal.CS;
 using Sharpen.Lang;
 
 namespace Db4objects.Db4o.Tests.Common.CS
@@ -29,14 +30,15 @@ namespace Db4objects.Db4o.Tests.Common.CS
 		/// <exception cref="System.Exception"></exception>
 		public virtual void Test()
 		{
-			IConfiguration config = Db4oFactory.NewConfiguration();
-			config.ClientServer().TimeoutServerSocket(Timeout);
-			config.Io(new MemoryIoAdapter());
-			ObjectServerImpl server = (ObjectServerImpl)Db4oFactory.OpenServer(config, string.Empty
-				, -1);
+			IServerConfiguration config = Db4oClientServer.NewServerConfiguration();
+			config.TimeoutServerSocket = Timeout;
+			config.File.Storage = new MemoryStorage();
+			ObjectServerImpl server = (ObjectServerImpl)Db4oClientServer.OpenServer(config, string.Empty
+				, Db4oClientServer.ArbitraryPort);
 			Thread.Sleep(Timeout * 2);
 			Assert.AreEqual(0, server.TransactionCount());
 			server.Close();
 		}
 	}
 }
+#endif // !SILVERLIGHT
