@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,6 +13,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+#if !SILVERLIGHT
 using Db4oUnit;
 using Db4oUnit.Extensions;
 using Db4objects.Db4o.Ext;
@@ -35,12 +36,13 @@ namespace Db4objects.Db4o.Tests.Common.Concurrency
 
 		public virtual void Conc(IExtObjectContainer oc)
 		{
-			Assert.AreEqual(2, oc.QueryByExample(null).Size());
+			Assert.AreEqual(2, oc.QueryByExample(null).Count);
 		}
 
 		public virtual void ConcSODA(IExtObjectContainer oc)
 		{
-			Assert.AreEqual(2, oc.Query().Execute().Size());
+			Assert.AreEqual(2, oc.Query().Execute().Count);
 		}
 	}
 }
+#endif // !SILVERLIGHT
