@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -18,18 +18,13 @@ using Db4objects.Db4o.Tests.Common.Constraints;
 
 namespace Db4objects.Db4o.Tests.Common.Constraints
 {
-	public class UniqueFieldIndexWithVersionNumbersTestCase : UniqueFieldIndexTestCase
+	public class UniqueFieldIndexWithVersionNumbersTestCase : UniqueFieldValueConstraintTestCase
 	{
 		/// <exception cref="System.Exception"></exception>
 		protected override void Configure(IConfiguration config)
 		{
 			base.Configure(config);
-			config.GenerateVersionNumbers(ConfigScope.Globally);
-		}
-
-		public static void Main(string[] args)
-		{
-			new UniqueFieldIndexWithVersionNumbersTestCase().RunAll();
+			config.GenerateCommitTimestamps(true);
 		}
 	}
 }
