@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -23,15 +23,16 @@ namespace Db4objects.Db4o.Tests.Common.Defragment
 	{
 		public static void Main(string[] args)
 		{
-			new Db4objects.Db4o.Tests.Common.Defragment.AllTests().RunSolo();
+			new Db4objects.Db4o.Tests.Common.Defragment.AllTests().RunAll();
 		}
 
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(DefragEncryptedFileTestCase), typeof(BlockSizeDefragTestCase
-				), typeof(DefragInheritedFieldIndexTestCase), typeof(DefragmentUntypedPrimitiveArrayTestCase
-				), typeof(SlotDefragmentTestCase), typeof(StoredClassFilterTestCase), typeof(TranslatedDefragTestCase
-				) };
+			return new Type[] { typeof(BlockSizeDefragTestCase), typeof(CommitTimestampDefragmentTestCase
+				), typeof(DefragEncryptedFileTestCase), typeof(DefragInheritedFieldIndexTestCase
+				), typeof(DefragInMemoryTestSuite), typeof(DefragmentUntypedPrimitiveArrayTestCase
+				), typeof(IdMappingTestSuite), typeof(SlotDefragmentTestCase), typeof(StoredClassFilterTestCase
+				), typeof(TranslatedDefragTestCase) };
 		}
 	}
 }
