@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,9 +19,9 @@ namespace Db4objects.Db4o.Tests.Common.Defragment
 {
 	public abstract class SlotDefragmentTestConstants
 	{
-		public static readonly string Filename = Path.GetTempFileName();
+		private static readonly string Filename = Path.GetTempFileName();
 
-		public static readonly string Backupfilename = Filename + ".backup";
+		private static readonly string Backupfilename = Filename + ".backup";
 
 		private SlotDefragmentTestConstants()
 		{
