@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,7 +19,7 @@ using Db4objects.Db4o.Tests.Common.Diagnostics;
 
 namespace Db4objects.Db4o.Tests.Common.Diagnostics
 {
-	public class AllTests : Db4oTestSuite
+	public class AllTests : ComposibleTestSuite
 	{
 		public static void Main(string[] args)
 		{
@@ -28,7 +28,15 @@ namespace Db4objects.Db4o.Tests.Common.Diagnostics
 
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(IndexFieldDiagnosticTestCase) };
+			return ComposeTests(new Type[] { typeof(ClassHasNoFieldsTestCase), typeof(DescendIntoTranslatorTestCase
+				), typeof(DiagnosticsTestCase), typeof(IndexFieldDiagnosticTestCase) });
 		}
+
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
+		{
+			return new Type[] { typeof(MissingClassDiagnosticsTestCase) };
+		}
+		#endif // !SILVERLIGHT
 	}
 }
