@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,7 +19,7 @@ using Db4objects.Db4o.Tests.Common.Events;
 
 namespace Db4objects.Db4o.Tests.Common.Events
 {
-	public class AllTests : Db4oTestSuite
+	public class AllTests : ComposibleTestSuite
 	{
 		public static void Main(string[] args)
 		{
@@ -28,10 +28,20 @@ namespace Db4objects.Db4o.Tests.Common.Events
 
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(ActivationEventsTestCase), typeof(ClassRegistrationEventsTestCase
-				), typeof(DeletionEventExceptionTestCase), typeof(DeletionEventsTestCase), typeof(
-				EventArgsTransactionTestCase), typeof(InstantiationEventsTestCase), typeof(ObjectContainerEventsTestCase
+			return ComposeTests(new Type[] { typeof(ActivationEventsTestCase), typeof(ClassRegistrationEventsTestCase
+				), typeof(CreationEventsTestCase), typeof(DeleteEventOnClientTestCase), typeof(DeletionEventExceptionTestCase
+				), typeof(DeletionEventsTestCase), typeof(EventArgsTransactionTestCase), typeof(
+				EventCountTestCase), typeof(ExceptionPropagationInEventsTestSuite), typeof(InstantiationEventsTestCase
+				), typeof(ObjectContainerEventsTestCase), typeof(ObjectContainerOpenEventTestCase
+				), typeof(QueryEventsTestCase), typeof(UpdateInCallbackThrowsTestCase) });
+		}
+
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
+		{
+			return new Type[] { typeof(DeleteOnDeletingCallbackTestCase), typeof(OwnCommitCallbackFlaggedNetworkingTestSuite
 				) };
 		}
+		#endif // !SILVERLIGHT
 	}
 }
