@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,28 +16,56 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit.Extensions;
 using Db4oUnit.Extensions.Fixtures;
 using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.IO;
 using Db4objects.Db4o.Tests.Common.Exceptions;
 
 namespace Db4objects.Db4o.Tests.Common.Exceptions
 {
-	public class Db4oIOExceptionTestCaseBase : AbstractDb4oTestCase, IOptOutCS, IOptOutTA
+	public class Db4oIOExceptionTestCaseBase : AbstractDb4oTestCase, IOptOutMultiSession
+		, IOptOutTA
 	{
+		private ExceptionSimulatingStorage _storage;
+
 		protected override void Configure(IConfiguration config)
 		{
 			config.LockDatabaseFile(false);
-			config.Io(new ExceptionIOAdapter());
+			_storage = new ExceptionSimulatingStorage(new FileStorage(), new _IExceptionFactory_19
+				());
+			config.Storage = _storage;
+		}
+
+		private sealed class _IExceptionFactory_19 : IExceptionFactory
+		{
+			public _IExceptionFactory_19()
+			{
+			}
+
+			public void ThrowException()
+			{
+				throw new Db4oIOException();
+			}
+
+			public void ThrowOnClose()
+			{
+			}
 		}
 
 		/// <exception cref="System.Exception"></exception>
 		protected override void Db4oSetupBeforeStore()
 		{
-			ExceptionIOAdapter.exception = false;
+			TriggerException(false);
 		}
 
 		/// <exception cref="System.Exception"></exception>
 		protected override void Db4oTearDownBeforeClean()
 		{
-			ExceptionIOAdapter.exception = false;
+			TriggerException(false);
+		}
+
+		protected virtual void TriggerException(bool value)
+		{
+			_storage.TriggerException(value);
 		}
 	}
 }
