@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -23,7 +23,7 @@ using Db4objects.Db4o.Tests.Common.Fieldindex;
 
 namespace Db4objects.Db4o.Tests.Common.Fieldindex
 {
-	public class RuntimeFieldIndexTestCase : AbstractDb4oTestCase, IOptOutCS
+	public class RuntimeFieldIndexTestCase : AbstractDb4oTestCase, IOptOutMultiSession
 	{
 		private static readonly string Fieldname = "_id";
 
@@ -48,17 +48,37 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 
 		public virtual void TestCreateIndexAtRuntime()
 		{
-			IStoredField field = Db().StoredClass(typeof(RuntimeFieldIndexTestCase.Data)).StoredField
-				(Fieldname, null);
+			IStoredField field = StoredField();
 			Assert.IsFalse(field.HasIndex());
 			field.CreateIndex();
 			Assert.IsTrue(field.HasIndex());
+			AssertQuery();
+			field.CreateIndex();
+		}
+
+		// ensure that second call is ignored
+		private void AssertQuery()
+		{
 			IQuery query = NewQuery(typeof(RuntimeFieldIndexTestCase.Data));
 			query.Descend(Fieldname).Constrain(2);
 			IObjectSet result = query.Execute();
-			Assert.AreEqual(1, result.Size());
+			Assert.AreEqual(1, result.Count);
+		}
+
+		public virtual void TestDropIndex()
+		{
+			IStoredField field = StoredField();
 			field.CreateIndex();
+			AssertQuery();
+			field.DropIndex();
+			Assert.IsFalse(field.HasIndex());
+			AssertQuery();
+		}
+
+		private IStoredField StoredField()
+		{
+			return Db().StoredClass(typeof(RuntimeFieldIndexTestCase.Data)).StoredField(Fieldname
+				, null);
 		}
-		// ensure that second call is ignored
 	}
 }
