@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -22,10 +22,13 @@ namespace Db4objects.Db4o.Tests.Common.Foundation
 	/// <exclude></exclude>
 	public class Path4TestCase : ITestCase
 	{
+		#if !SILVERLIGHT
 		public virtual void TestGetTempFileName()
 		{
 			string tempFileName = Path.GetTempFileName();
 			Assert.IsTrue(System.IO.File.Exists(tempFileName));
+			File4.Delete(tempFileName);
 		}
+		#endif // !SILVERLIGHT
 	}
 }
