@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,18 +14,18 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4oUnit.Extensions;
+using Db4oUnit.Extensions.Fixtures;
 using Db4objects.Db4o.Internal;
 
 namespace Db4objects.Db4o.Tests.Common.Freespace
 {
-	public abstract class FileSizeTestCaseBase : AbstractDb4oTestCase, IOptOutTA
+	public abstract class FileSizeTestCaseBase : AbstractDb4oTestCase, IOptOutTA, IOptOutInMemory
 	{
 		protected virtual int DatabaseFileSize()
 		{
 			LocalObjectContainer localContainer = Fixture().FileSession();
-			IoAdaptedObjectContainer container = (IoAdaptedObjectContainer)localContainer;
-			container.SyncFiles();
-			long length = new Sharpen.IO.File(container.FileName()).Length();
+			localContainer.SyncFiles();
+			long length = new Sharpen.IO.File(localContainer.FileName()).Length();
 			return (int)length;
 		}
 	}
