@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,23 +14,34 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
-using System.Collections;
 using Db4oUnit;
+using Db4oUnit.Extensions;
 using Db4objects.Db4o.Tests.Common.IO;
 
 namespace Db4objects.Db4o.Tests.Common.IO
 {
-	public class AllTests : ITestSuiteBuilder
+	public class AllTests : ComposibleTestSuite
 	{
-		public virtual IEnumerator GetEnumerator()
-		{
-			return new ReflectionTestSuiteBuilder(new Type[] { typeof(IoAdapterTest), typeof(
-				MemoryIoAdapterTestCase) }).GetEnumerator();
-		}
-
-		public static void Main(string[] args)
+		public static void Main(string[] arguments)
 		{
 			new ConsoleTestRunner(typeof(Db4objects.Db4o.Tests.Common.IO.AllTests)).Run();
 		}
+
+		protected override Type[] TestCases()
+		{
+			return ComposeTests(new Type[] { typeof(BlockAwareBinTestSuite), typeof(MemoryBinGrowthTestCase
+				), typeof(MemoryBinIsReusableTestCase), typeof(MemoryIoAdapterTestCase), typeof(
+				NonFlushingStorageTestCase), typeof(RandomAccessFileStorageFactoryTestCase), typeof(
+				StorageTestSuite) });
+		}
+
+		// SaveAsStorageTestCase.class,  COR-2036
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
+		{
+			return new Type[] { typeof(BlockSizeDependentBinTestCase), typeof(IoAdapterTestSuite
+				), typeof(RandomAccessFileFactoryTestCase) };
+		}
+		#endif // !SILVERLIGHT
 	}
 }
