@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -28,12 +28,14 @@ namespace Db4objects.Db4o.Tests.Common.Internal
 			new SerializerTestCase().RunAll();
 		}
 
+		#if !SILVERLIGHT
 		/// <exception cref="System.Exception"></exception>
-		public virtual void TestMarshall()
+		public virtual void TestExceptionMarshalling()
 		{
 			ReflectException e = new ReflectException(new ArgumentNullException());
-			SerializedGraph marshalled = Serializer.Marshall(Stream().Container(), e);
+			SerializedGraph marshalled = Serializer.Marshall(Stream().Container, e);
 			Assert.IsTrue(marshalled.Length() > 0);
 		}
+		#endif // !SILVERLIGHT
 	}
 }
