@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,15 +12,21 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4oUnit.Extensions;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Querying;
+
 namespace Db4objects.Db4o.Tests.Common.Querying
 {
-	public class IndexedQueriesTestCase : Db4oUnit.Extensions.AbstractDb4oTestCase
+	public class IndexedQueriesTestCase : AbstractDb4oTestCase
 	{
 		public static void Main(string[] arguments)
 		{
-			new Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase().RunSolo();
+			new IndexedQueriesTestCase().RunSolo();
 		}
 
 		public class IndexedQueriesItem
@@ -51,18 +53,16 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 			}
 		}
 
-		protected override void Configure(Db4objects.Db4o.Config.IConfiguration config)
+		protected override void Configure(IConfiguration config)
 		{
 			IndexField(config, "_name");
 			IndexField(config, "_int");
 			IndexField(config, "_integer");
 		}
 
-		private void IndexField(Db4objects.Db4o.Config.IConfiguration config, string fieldName
-			)
+		private void IndexField(IConfiguration config, string fieldName)
 		{
-			IndexField(config, typeof(Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem)
-				, fieldName);
+			IndexField(config, typeof(IndexedQueriesTestCase.IndexedQueriesItem), fieldName);
 		}
 
 		protected override void Store()
@@ -70,14 +70,12 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 			string[] strings = new string[] { "a", "c", "b", "f", "e" };
 			for (int i = 0; i < strings.Length; i++)
 			{
-				Db().Set(new Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
-					(strings[i]));
+				Db().Store(new IndexedQueriesTestCase.IndexedQueriesItem(strings[i]));
 			}
 			int[] ints = new int[] { 1, 5, 7, 3, 2, 3 };
 			for (int i = 0; i < ints.Length; i++)
 			{
-				Db().Set(new Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
-					(ints[i]));
+				Db().Store(new IndexedQueriesTestCase.IndexedQueriesItem(ints[i]));
 			}
 		}
 
@@ -86,17 +84,15 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 			AssertInts(5);
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestStringQuery()
 		{
 			AssertNullNameCount(6);
-			Db().Set(new Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
-				("d"));
+			Db().Store(new IndexedQueriesTestCase.IndexedQueriesItem("d"));
 			AssertQuery(1, "b");
 			UpdateB();
-			Db().Set(new Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
-				("z"));
-			Db().Set(new Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
-				("y"));
+			Db().Store(new IndexedQueriesTestCase.IndexedQueriesItem("z"));
+			Db().Store(new IndexedQueriesTestCase.IndexedQueriesItem("y"));
 			Reopen();
 			AssertQuery(1, "b");
 			AssertInts(8);
@@ -104,7 +100,7 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 
 		private void AssertIntegers()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Descend("_integer").Constrain(4).Greater().Equal();
 			AssertIntsFound(new int[] { 5, 7 }, q);
 			q = NewQuery();
@@ -114,10 +110,10 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 
 		private void AssertInts(int expectedZeroSize)
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Descend("_int").Constrain(0);
-			int zeroSize = q.Execute().Size();
-			Db4oUnit.Assert.AreEqual(expectedZeroSize, zeroSize);
+			int zeroSize = q.Execute().Count;
+			Assert.AreEqual(expectedZeroSize, zeroSize);
 			q = NewQuery();
 			q.Descend("_int").Constrain(4).Greater().Equal();
 			AssertIntsFound(new int[] { 5, 7 }, q);
@@ -168,15 +164,13 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 			AssertIntsFound(new int[] {  }, expectedZeroSize, q);
 		}
 
-		private void AssertIntsFound(int[] ints, int zeroSize, Db4objects.Db4o.Query.IQuery
-			 q)
+		private void AssertIntsFound(int[] ints, int zeroSize, IQuery q)
 		{
-			Db4objects.Db4o.IObjectSet res = q.Execute();
-			Db4oUnit.Assert.AreEqual((ints.Length + zeroSize), res.Size());
+			IObjectSet res = q.Execute();
+			Assert.AreEqual((ints.Length + zeroSize), res.Count);
 			while (res.HasNext())
 			{
-				Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem ci
-					 = (Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
+				IndexedQueriesTestCase.IndexedQueriesItem ci = (IndexedQueriesTestCase.IndexedQueriesItem
 					)res.Next();
 				for (int i = 0; i < ints.Length; i++)
 				{
@@ -189,67 +183,63 @@ namespace Db4objects.Db4o.Tests.Common.Querying
 			}
 			for (int i = 0; i < ints.Length; i++)
 			{
-				Db4oUnit.Assert.AreEqual(0, ints[i]);
+				Assert.AreEqual(0, ints[i]);
 			}
 		}
 
-		private void AssertIntsFound(int[] ints, Db4objects.Db4o.Query.IQuery q)
+		private void AssertIntsFound(int[] ints, IQuery q)
 		{
 			AssertIntsFound(ints, 0, q);
 		}
 
 		private void AssertQuery(int count, string @string)
 		{
-			Db4objects.Db4o.IObjectSet res = QueryForName(@string);
-			Db4oUnit.Assert.AreEqual(count, res.Size());
-			Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem item
-				 = (Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
+			IObjectSet res = QueryForName(@string);
+			Assert.AreEqual(count, res.Count);
+			IndexedQueriesTestCase.IndexedQueriesItem item = (IndexedQueriesTestCase.IndexedQueriesItem
 				)res.Next();
-			Db4oUnit.Assert.AreEqual("b", item._name);
+			Assert.AreEqual("b", item._name);
 		}
 
 		private void AssertNullNameCount(int count)
 		{
-			Db4objects.Db4o.IObjectSet res = QueryForName(null);
-			Db4oUnit.Assert.AreEqual(count, res.Size());
+			IObjectSet res = QueryForName(null);
+			Assert.AreEqual(count, res.Count);
 			while (res.HasNext())
 			{
-				Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem ci
-					 = (Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
+				IndexedQueriesTestCase.IndexedQueriesItem ci = (IndexedQueriesTestCase.IndexedQueriesItem
 					)res.Next();
-				Db4oUnit.Assert.IsNull(ci._name);
+				Assert.IsNull(ci._name);
 			}
 		}
 
 		private void UpdateB()
 		{
-			Db4objects.Db4o.IObjectSet res = QueryForName("b");
-			Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem ci
-				 = (Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem
+			IObjectSet res = QueryForName("b");
+			IndexedQueriesTestCase.IndexedQueriesItem ci = (IndexedQueriesTestCase.IndexedQueriesItem
 				)res.Next();
 			ci._name = "j";
-			Db().Set(ci);
+			Db().Store(ci);
 			res = QueryForName("b");
-			Db4oUnit.Assert.AreEqual(0, res.Size());
+			Assert.AreEqual(0, res.Count);
 			res = QueryForName("j");
-			Db4oUnit.Assert.AreEqual(1, res.Size());
+			Assert.AreEqual(1, res.Count);
 			ci._name = "b";
-			Db().Set(ci);
+			Db().Store(ci);
 			AssertQuery(1, "b");
 		}
 
-		private Db4objects.Db4o.IObjectSet QueryForName(string n)
+		private IObjectSet QueryForName(string n)
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Descend("_name").Constrain(n);
 			return q.Execute();
 		}
 
-		protected override Db4objects.Db4o.Query.IQuery NewQuery()
+		protected override IQuery NewQuery()
 		{
-			Db4objects.Db4o.Query.IQuery q = base.NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Querying.IndexedQueriesTestCase.IndexedQueriesItem)
-				);
+			IQuery q = base.NewQuery();
+			q.Constrain(typeof(IndexedQueriesTestCase.IndexedQueriesItem));
 			return q;
 		}
 	}
