@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -29,8 +29,8 @@ namespace Db4objects.Db4o.Tests.Common.References
 		protected override Type[] TestCases()
 		{
 			return new Type[] { typeof(HardObjectReferenceTestCase), typeof(ReferenceSystemIntegrationTestCase
-				), typeof(ReferenceSystemIsolationTestCase), typeof(ReferenceSystemRegistryTestCase
-				), typeof(HashcodeReferenceSystemTestCase), typeof(TransactionalReferenceSystemTestCase
+				), typeof(ReferenceSystemRegistryTestCase), typeof(HashcodeReferenceSystemTestCase
+				), typeof(TransactionalReferenceSystemTestCase), typeof(WeakReferenceCollectionTestCase
 				) };
 		}
 	}
