@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,6 +16,7 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using Db4oUnit.Extensions;
 using Db4objects.Db4o.Tests.Common.Reflect;
+using Db4objects.Db4o.Tests.Common.Reflect.Generic;
 
 namespace Db4objects.Db4o.Tests.Common.Reflect
 {
@@ -24,7 +25,8 @@ namespace Db4objects.Db4o.Tests.Common.Reflect
 		protected override Type[] TestCases()
 		{
 			return new Type[] { typeof(GenericReflectorStateTest), typeof(NoTestConstructorsTestCase
-				), typeof(ReflectArrayTestCase), typeof(Db4objects.Db4o.Tests.Common.Reflect.Custom.AllTests
+				), typeof(ReflectArrayTestCase), typeof(ReflectClassTestCase), typeof(ReflectFieldExceptionTestCase
+				), typeof(Db4objects.Db4o.Tests.Common.Reflect.Custom.AllTests), typeof(GenericObjectsTest
 				) };
 		}
 
