@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,12 +19,19 @@ using Db4objects.Db4o.Tests.Common.Reflect.Custom;
 
 namespace Db4objects.Db4o.Tests.Common.Reflect.Custom
 {
-	public class AllTests : Db4oTestSuite
+	public class AllTests : ComposibleTestSuite
 	{
 		protected override Type[] TestCases()
+		{
+			return ComposeWith();
+		}
+
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
 		{
 			return new Type[] { typeof(CustomReflectorTestCase) };
 		}
+		#endif // !SILVERLIGHT
 
 		public static void Main(string[] args)
 		{
