@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,14 +19,21 @@ using Db4objects.Db4o.Tests.Common.Regression;
 
 namespace Db4objects.Db4o.Tests.Common.Regression
 {
-	public class AllTests : Db4oTestSuite
+	public class AllTests : ComposibleTestSuite
 	{
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(Case1207TestCase), typeof(COR57TestCase), typeof(COR234TestCase
-				), typeof(SetRollbackTestCase) };
+			return ComposeTests(new Type[] { typeof(Case1207TestCase), typeof(COR57TestCase), 
+				typeof(SetRollbackTestCase) });
 		}
 
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
+		{
+			return new Type[] { typeof(COR234TestCase) };
+		}
+		#endif // !SILVERLIGHT
+
 		public static void Main(string[] args)
 		{
 			new Db4objects.Db4o.Tests.Common.Regression.AllTests().RunSolo();
