@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -17,14 +17,13 @@ using Db4objects.Db4o.Tests.Common.Sampledata;
 
 namespace Db4objects.Db4o.Tests.Common.Sampledata
 {
-	public class MoleculeData : Db4objects.Db4o.Tests.Common.Sampledata.AtomData
+	public class MoleculeData : AtomData
 	{
 		public MoleculeData()
 		{
 		}
 
-		public MoleculeData(Db4objects.Db4o.Tests.Common.Sampledata.AtomData child) : base
-			(child)
+		public MoleculeData(AtomData child) : base(child)
 		{
 		}
 
@@ -32,14 +31,13 @@ namespace Db4objects.Db4o.Tests.Common.Sampledata
 		{
 		}
 
-		public MoleculeData(Db4objects.Db4o.Tests.Common.Sampledata.AtomData child, string
-			 name) : base(child, name)
+		public MoleculeData(AtomData child, string name) : base(child, name)
 		{
 		}
 
 		public override bool Equals(object obj)
 		{
-			if (obj is MoleculeData)
+			if (obj is Db4objects.Db4o.Tests.Common.Sampledata.MoleculeData)
 			{
 				return base.Equals(obj);
 			}
