@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,7 +19,7 @@ using Db4objects.Db4o.Tests.Common.Staging;
 
 namespace Db4objects.Db4o.Tests.Common.Staging
 {
-	public class AllTests : Db4oTestSuite
+	public class AllTests : ComposibleTestSuite
 	{
 		public static void Main(string[] args)
 		{
@@ -28,10 +28,27 @@ namespace Db4objects.Db4o.Tests.Common.Staging
 
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(ActivateDepthTestCase), typeof(ClientServerPingTestCase
-				), typeof(InterfaceQueryTestCase), typeof(LazyQueryDeleteTestCase), typeof(PingTestCase
-				), typeof(SODAClassTypeDescend) };
+			return ComposeTests(new Type[] { typeof(ActivateDepthTestCase), typeof(InterfaceQueryTestCase
+				), typeof(GenericClassWithExistingSuperClassTestCase), typeof(LazyQueryDeleteTestCase
+				), typeof(OldVersionReflectFieldAfterRefactorTestCase), typeof(RemovedFieldDefragmentTestCase
+				), typeof(StoredClassUnknownClassQueryTestCase), typeof(UntypedFieldSortingTestCase
+				) });
 		}
-		// TODO is there a Jira for this one?
+
+		// COR-1131
+		// COR-1959
+		// COR-1937
+		// COR-1542
+		#if !SILVERLIGHT
+		protected override Type[] ComposeWith()
+		{
+			return new Type[] { typeof(ClientServerPingTestCase), typeof(DeepPrefetchingCacheConcurrencyTestCase
+				), typeof(OwnCommitCallbackFlaggedEmbeddedTestSuite), typeof(PingTestCase), typeof(
+				TAUnavailableClassAtServer) };
+		}
+		#endif // !SILVERLIGHT
+		// COR-1762
+		// COR-1964
+		//COR-1987
 	}
 }
