@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -26,7 +26,7 @@ namespace Db4objects.Db4o.Tests.Common.Staging
 		protected override void Configure(IConfiguration config)
 		{
 			config.GenerateUUIDs(ConfigScope.Globally);
-			config.GenerateVersionNumbers(ConfigScope.Globally);
+			config.GenerateCommitTimestamps(true);
 		}
 
 		public virtual void Test()
@@ -35,12 +35,12 @@ namespace Db4objects.Db4o.Tests.Common.Staging
 			ObjectVersionTest.Item @object = new ObjectVersionTest.Item("c1");
 			oc.Store(@object);
 			IObjectInfo objectInfo1 = oc.GetObjectInfo(@object);
-			long oldVer = objectInfo1.GetVersion();
+			long oldVer = objectInfo1.GetCommitTimestamp();
 			//Update
 			@object.SetName("c3");
 			oc.Store(@object);
 			IObjectInfo objectInfo2 = oc.GetObjectInfo(@object);
-			long newVer = objectInfo2.GetVersion();
+			long newVer = objectInfo2.GetCommitTimestamp();
 			Assert.IsNotNull(objectInfo1.GetUUID());
 			Assert.IsNotNull(objectInfo2.GetUUID());
 			Assert.IsTrue(oldVer > 0);
