@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -28,11 +28,11 @@ namespace Db4objects.Db4o.Tests.Common.TA
 
 		protected override Type[] TestCases()
 		{
-			return new Type[] { typeof(ActivatableTestCase), typeof(TransparentActivationSupportTestCase
-				), typeof(TAWithGCBeforeCommitTestCase), typeof(Db4objects.Db4o.Tests.Common.TA.Events.AllTests
-				), typeof(Db4objects.Db4o.Tests.Common.TA.Mixed.AllTests), typeof(Db4objects.Db4o.Tests.Common.TA.Nonta.AllTests
-				), typeof(Db4objects.Db4o.Tests.Common.TA.Sample.AllTests), typeof(Db4objects.Db4o.Tests.Common.TA.TA.AllTests
-				) };
+			return new Type[] { typeof(ActivatableTestCase), typeof(ActivationBasedOnConcreteTypeTestCase
+				), typeof(TransparentActivationSupportTestCase), typeof(TAWithGCBeforeCommitTestCase
+				), typeof(Db4objects.Db4o.Tests.Common.TA.Events.AllTests), typeof(Db4objects.Db4o.Tests.Common.TA.Mixed.AllTests
+				), typeof(Db4objects.Db4o.Tests.Common.TA.Nonta.AllTests), typeof(Db4objects.Db4o.Tests.Common.TA.Sample.AllTests
+				), typeof(Db4objects.Db4o.Tests.Common.TA.TA.AllTests) };
 		}
 	}
 }
