@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,6 +15,7 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using Db4oUnit.Extensions;
+using Db4objects.Db4o.Tests.Common.TA;
 
 namespace Db4objects.Db4o.Tests.Common.TA
 {
@@ -24,6 +25,7 @@ namespace Db4objects.Db4o.Tests.Common.TA
 		{
 			return new Type[] { typeof(Db4objects.Db4o.Tests.Common.TA.Diagnostics.AllTests), 
 				typeof(Db4objects.Db4o.Tests.Common.TA.Hierarchy.AllTests), typeof(Db4objects.Db4o.Tests.Common.TA.Nested.AllTests
+				), typeof(ReentrantActivationTestCase), typeof(TPExplicitStoreFieldIndexConsistencyTestCase
 				) };
 		}
 	}
