@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -35,12 +35,12 @@ namespace Db4objects.Db4o.Tests.Common.TA
 
 		public virtual void Bind(IActivator activator)
 		{
-			Record(new MethodCall("bind", activator));
+			Record(new MethodCall("bind", new object[] { activator }));
 		}
 
 		public virtual void Activate(ActivationPurpose purpose)
 		{
-			Record(new MethodCall("activate", purpose));
+			Record(new MethodCall("activate", new object[] { purpose }));
 		}
 
 		private void Record(MethodCall methodCall)
