@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -25,12 +25,17 @@ namespace Db4objects.Db4o.Tests.Common.TP
 
 		public virtual void Rollback(IObjectContainer container, object obj)
 		{
-			_recorder.Record(new MethodCall("rollback", container, obj));
+			_recorder.Record(new MethodCall("rollback", new object[] { container, obj }));
 		}
 
 		public virtual void Verify(MethodCall[] expectedCalls)
 		{
 			_recorder.Verify(expectedCalls);
 		}
+
+		public virtual void VerifyUnordered(MethodCall[] methodCalls)
+		{
+			_recorder.VerifyUnordered(methodCalls);
+		}
 	}
 }
