@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,20 +14,19 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
-using System.Collections;
-using System.Collections.Specialized;
+using System.Collections.Generic;
 using System.IO;
 using Db4objects.Db4o.Config;
 using Db4objects.Db4o.Ext;
-using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Tests.Util;
 using Db4oUnit.Extensions.Fixtures;
+using Db4oUnit.Extensions.Util;
 
 namespace Db4objects.Db4o.Tests.CLI1.Aliases
 {
     /// <summary>
     /// </summary>
-    public class JavaFromNetAliasesTestCase : BaseAliasesTestCase, IOptOutCS
+	public class JavaFromNetAliasesTestCase : BaseAliasesTestCase, IOptOutMultiSession, IOptOutSilverlight
     {
 #if !CF
         public void TestAccessingJavaFromDotnet()
@@ -84,7 +83,7 @@ namespace Db4objects.Db4o.Tests.CLI1.Aliases
 
         private string[] UpdateAliasedData(IObjectContainer container)
         {
-            ArrayList newNames = new ArrayList();
+            List<string> newNames = new List<string>();
             foreach (IPerson person in QueryAliasedData(container))
             {
                 string newName = person.Name + "*";
@@ -99,7 +98,7 @@ namespace Db4objects.Db4o.Tests.CLI1.Aliases
             newNames.Add(newItemName);
 
             container.Commit();
-            return (string[])newNames.ToArray(typeof(string));
+        	return newNames.ToArray();
         }
 
         private void ConfigureAliases(IConfiguration configuration)
@@ -161,8 +160,8 @@ public class Program {
 	public static void main(String[] args) {
 		String fname = args[0];
 		ObjectContainer container = Db4o.openFile(fname);
-		container.set(new Person2(""Homer Simpson""));
-		container.set(new Person2(""John Cleese""));
+		container.store(new Person2(""Homer Simpson""));
+		container.store(new Person2(""John Cleese""));
 		container.close();
 		System.out.println(""success"");
 	}
