@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,6 +15,7 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Internal;
 using Db4oUnit.Extensions;
 
 namespace Db4objects.Db4o.Tests.CLI1.Aliases
@@ -30,7 +31,7 @@ namespace Db4objects.Db4o.Tests.CLI1.Aliases
 
 			Reopen();
 			Fixture().ConfigureAtRuntime(new AddAliasAction());
-		    Reopen();
+            Reopen();
 			AssertAliasedData(Db());
 		}
 
@@ -45,15 +46,10 @@ namespace Db4objects.Db4o.Tests.CLI1.Aliases
 					GetTypeName(typeof(Person2))));
 			}
 	
-		    private string GetTypeName(Type type)
+		    private static string GetTypeName(Type type)
 		    {
-		        return type.FullName + ", " + CurrentAssemblyName;
+		        return ReflectPlatform.FullyQualifiedName(type);
 		    }
-	
-	        private string CurrentAssemblyName
-	        {
-	            get { return GetType().Assembly.GetName().Name; }
-	        }
 		}
 	}
 }
