@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,24 +16,25 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using Db4oUnit;
 using Db4oUnit.Extensions;
+using Db4oUnit.Extensions.Fixtures;
 
 namespace Db4objects.Db4o.Tests.CLI1
 {
-    public class CsType : AbstractDb4oTestCase
+    public class CsType : AbstractDb4oTestCase, IOptOutSilverlight
     {
-        Type myType;
-        Type stringType;
+        public Type myType;
+		public Type stringType;
 
         override protected void Store()
         {
-            myType = this.GetType();
+            myType = GetType();
             stringType = typeof(String);
             Store(this);
         }
 
         public void Test()
         {
-            Assert.AreEqual(this.GetType(), myType);
+            Assert.AreEqual(GetType(), myType);
             Assert.AreEqual(typeof(String), stringType);
         }
     }
