@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -21,7 +21,7 @@ namespace Db4objects.Db4o.Tests.CLI1.Handlers
 	{
         public static void Main(string[] args)
         {
-            new Db4objects.Db4o.Tests.CLI1.Handlers.AllTests().RunSolo();
+            new AllTests().RunSolo();
         }
 
         protected override Type[] TestCases()
@@ -30,6 +30,9 @@ namespace Db4objects.Db4o.Tests.CLI1.Handlers
 		    {
                 typeof(DateTimeHandlerTestCase),
                 typeof(DecimalHandlerTestCase),
+                typeof(EnumInUntypedVariableTestCase),
+                typeof(EnumTypeHandlerTestCase),
+				typeof(GuidTypeHandlerTestCase),
                 typeof(SByteHandlerTestCase),
                 typeof(UIntHandlerTestCase),
                 typeof(ULongHandlerTestCase),
