@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -18,7 +18,7 @@ using Db4oUnit.Extensions;
 
 namespace Db4objects.Db4o.Tests.CLI2
 {
-	class AllTests : Db4oTestSuite
+	public class AllTests : Db4oTestSuite
 	{
 		protected override Type[] TestCases()
 		{
@@ -26,9 +26,12 @@ namespace Db4objects.Db4o.Tests.CLI2
 			{
 				typeof(Assorted.AllTests),
 				typeof(Collections.AllTests),
+				typeof(Defrag.AllTests),
                 typeof(Handlers.AllTests),
 				typeof(NativeQueries.Diagnostics.AllTests),
 				typeof(Regression.AllTests),
+				typeof(Refactor.AllTests),
+				typeof(Reflect.AllTests),
 				typeof(TA.AllTests),
 				typeof(Types.AllTests),
 			};
