@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -25,12 +25,19 @@ namespace Db4objects.Db4o.Tests.CLI2.Collections
                 typeof(ArrayDictionary4TATestCase),
 				typeof(ArrayDictionary4TransparentPersistenceTestCase),
 
+                typeof(ArrayList4TATestCase), 
+#if !SILVERLIGHT
 				typeof(ArrayList4ActivatableTestCase), 
 				typeof(ArrayList4TestCase), 
-                typeof(ArrayList4TATestCase), 
+                typeof(BindingListTestCase),
+#endif
                 typeof(GenericDictionaryTestCase),
+				typeof(GenericDictionaryTestSuite),
 
-				// typeof(GenericListTypeHandlerTestCase),
+#if NET_3_5 && ! CF
+                typeof(HashSetTestCase),
+#endif 
+				typeof(Transparent.AllTests),
             };
 		}
 	}
