@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Config;
+
 namespace Db4objects.Db4o.Config
 {
 	/// <summary>interface to configure the freespace system to be used.</summary>
@@ -26,14 +23,12 @@ namespace Db4objects.Db4o.Config
 	/// <br /><br />All methods should be called before opening database files.
 	/// If db4o is instructed to exchange the system
 	/// (
-	/// <see cref="Db4objects.Db4o.Config.IFreespaceConfiguration.UseIndexSystem">Db4objects.Db4o.Config.IFreespaceConfiguration.UseIndexSystem
-	/// 	</see>
+	/// <see cref="UseBTreeSystem()">UseBTreeSystem()</see>
 	/// ,
-	/// <see cref="Db4objects.Db4o.Config.IFreespaceConfiguration.UseRamSystem">Db4objects.Db4o.Config.IFreespaceConfiguration.UseRamSystem
-	/// 	</see>
+	/// <see cref="UseRamSystem()">UseRamSystem()</see>
 	/// )
 	/// this will happen on opening the database file.<br /><br />
-	/// By default the index-based system will be used.
+	/// By default the ram based system will be used.
 	/// </remarks>
 	public interface IFreespaceConfiguration
 	{
@@ -70,11 +65,11 @@ namespace Db4objects.Db4o.Config
 		/// reliably set after an object container has been opened.
 		/// </remarks>
 		/// <param name="freespaceFiller">The freespace overwriting callback to use</param>
-		void FreespaceFiller(Db4objects.Db4o.Config.IFreespaceFiller freespaceFiller);
+		void FreespaceFiller(IFreespaceFiller freespaceFiller);
 
-		/// <summary>configures db4o to use an index-based freespace system.</summary>
+		/// <summary>configures db4o to use a BTree-based freespace system.</summary>
 		/// <remarks>
-		/// configures db4o to use an index-based freespace system.
+		/// configures db4o to use a BTree-based freespace system.
 		/// <br /><br /><b>Advantages</b><br />
 		/// - ACID, no freespace is lost on abnormal system termination<br />
 		/// - low memory consumption<br />
@@ -82,6 +77,12 @@ namespace Db4objects.Db4o.Config
 		/// - slower than the RAM-based system, since freespace information
 		/// is written during every commit<br />
 		/// </remarks>
+		void UseBTreeSystem();
+
+		/// <summary>discontinued freespace system, only available before db4o 7.0.</summary>
+		/// <remarks>discontinued freespace system, only available before db4o 7.0.</remarks>
+		[System.ObsoleteAttribute(@"Please use the BTree freespace system instead by calling UseBTreeSystem() ."
+			)]
 		void UseIndexSystem();
 
 		/// <summary>configures db4o to use a RAM-based freespace system.</summary>
