@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -20,17 +20,12 @@ namespace Db4objects.Db4o.Config
 	/// <summary>configuration interface for classes.</summary>
 	/// <remarks>
 	/// configuration interface for classes.
-	/// <br/><br/>
-	/// Use the global Configuration object to configure db4o before opening an
-	/// <see cref="IObjectContainer">IObjectContainer</see>
-	/// .<br/><br/>
-	/// <b>Example:</b><br/>
-	/// <code>
-	/// IConfiguration config = Db4oFactory.Configure();<br/>
-	/// IObjectClass oc = config.ObjectClass("Namespace.ClassName");<br/>
-	/// oc.UpdateDepth(3);<br/>
-	/// oc.MinimumActivationDepth(3);<br/>
-	/// </code>
+	/// <br /><br />
+	/// Use the global
+	/// <see cref="ICommonConfiguration.ObjectClass(object)">ICommonConfiguration.ObjectClass(object)
+	/// 	</see>
+	/// to configure
+	/// object class settings.
 	/// </remarks>
 	public interface IObjectClass
 	{
@@ -41,28 +36,24 @@ namespace Db4objects.Db4o.Config
 		/// <remarks>
 		/// advises db4o to try instantiating objects of this class with/without
 		/// calling constructors.
-		/// <br /><br />
-		/// Not all JDKs / .NET-environments support this feature. db4o will
+		/// <br/><br/>
+		/// Not all .NET-environments support this feature. db4o will
 		/// attempt, to follow the setting as good as the enviroment supports.
-		/// In doing so, it may call implementation-specific features like
-		/// sun.reflect.ReflectionFactory#newConstructorForSerialization on the
-		/// Sun Java 1.4.x/5 VM (not available on other VMs) and
-		/// FormatterServices.GetUninitializedObject() on
-		/// the .NET framework (not available on CompactFramework).<br /><br />
+		/// <br/><br/>
 		/// This setting may also be set globally for all classes in
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration.CallConstructors">Db4objects.Db4o.Config.IConfiguration.CallConstructors
-		/// 	</see>
-		/// .<br /><br />
+		/// </see>
+		/// .<br/><br/>
 		/// In client-server environment this setting should be used on both
-		/// client and server. <br /><br />
-		/// This setting can be applied to an open object container. <br /><br />
+		/// client and server. <br/><br/>
+		/// This setting can be applied to an open object container. <br/><br/>
 		/// </remarks>
 		/// <param name="flag">
 		/// - specify true, to request calling constructors, specify
 		/// false to request <b>not</b> calling constructors.
 		/// </param>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.CallConstructors">Db4objects.Db4o.Config.IConfiguration.CallConstructors
-		/// 	</seealso>
+		/// </seealso>
 		void CallConstructor(bool flag);
 
 		/// <summary>sets cascaded activation behaviour.</summary>
@@ -78,55 +69,54 @@ namespace Db4objects.Db4o.Config
 		/// Can be applied to an open ObjectContainer.<br /><br />
 		/// </remarks>
 		/// <param name="flag">whether activation is to be cascaded to member objects.</param>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnActivate">Db4objects.Db4o.Config.IObjectField.CascadeOnActivate
+		/// <seealso cref="IObjectField.CascadeOnActivate(bool)">IObjectField.CascadeOnActivate(bool)
 		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Activate">Db4objects.Db4o.IObjectContainer.Activate
+		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Activate(object, int)">Db4objects.Db4o.IObjectContainer.Activate(object, int)
 		/// 	</seealso>
 		/// <seealso cref="Db4objects.Db4o.Ext.IObjectCallbacks">Using callbacks</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
-		/// 	</seealso>
+		/// <seealso cref="IConfiguration.ActivationDepth()">Why activation?</seealso>
 		void CascadeOnActivate(bool flag);
 
 		/// <summary>sets cascaded delete behaviour.</summary>
 		/// <remarks>
 		/// sets cascaded delete behaviour.
-		/// <br /><br />
-		/// Setting cascadeOnDelete to true will result in the deletion of
+		/// <br/><br/>
+		/// Setting CascadeOnDelete to true will result in the deletion of
 		/// all member objects of instances of this class, if they are
 		/// passed to
 		/// <see cref="Db4objects.Db4o.IObjectContainer.Delete">Db4objects.Db4o.IObjectContainer.Delete
-		/// 	</see>
+		/// </see>
 		/// .
-		/// <br /><br />
-		/// <b>Caution !</b><br />
+		/// <br/><br/>
+		/// <b>Caution !</b><br/>
 		/// This setting will also trigger deletion of old member objects, on
 		/// calls to
 		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
-		/// 	</see>
-		/// .<br /><br />
-		/// An example of the behaviour:<br />
+		/// </see>
+		/// .<br/><br/>
+		/// An example of the behaviour:<br/>
 		/// <code>
-		/// ObjectContainer con;<br />
-		/// Bar bar1 = new Bar();<br />
-		/// Bar bar2 = new Bar();<br />
-		/// foo.bar = bar1;<br />
-		/// con.set(foo);  // bar1 is stored as a member of foo<br />
-		/// foo.bar = bar2;<br />
-		/// con.set(foo);  // bar2 is stored as a member of foo
-		/// </code><br />The last statement will <b>also</b> delete bar1 from the
+		/// ObjectContainer con;<br/>
+		/// Bar bar1 = new Bar();<br/>
+		/// Bar bar2 = new Bar();<br/>
+		/// foo.bar = bar1;<br/>
+		/// con.Store(foo);  // bar1 is stored as a member of foo<br/>
+		/// foo.bar = bar2;<br/>
+		/// con.Store(foo);  // bar2 is stored as a member of foo
+		/// </code><br/>The last statement will <b>also</b> delete bar1 from the
 		/// ObjectContainer, no matter how many other stored objects hold references
 		/// to bar1.
-		/// <br /><br />
-		/// The default setting is <b>false</b>.<br /><br />
+		/// <br/><br/>
+		/// The default setting is <b>false</b>.<br/><br/>
 		/// In client-server environment this setting should be used on both
-		/// client and server. <br /><br />
-		/// This setting can be applied to an open object container. <br /><br />
+		/// client and server. <br/><br/>
+		/// This setting can be applied to an open object container. <br/><br/>
 		/// </remarks>
 		/// <param name="flag">whether deletes are to be cascaded to member objects.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnDelete">Db4objects.Db4o.Config.IObjectField.CascadeOnDelete
-		/// 	</seealso>
+		/// </seealso>
 		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Delete">Db4objects.Db4o.IObjectContainer.Delete
-		/// 	</seealso>
+		/// </seealso>
 		/// <seealso cref="Db4objects.Db4o.Ext.IObjectCallbacks">Using callbacks</seealso>
 		void CascadeOnDelete(bool flag);
 
@@ -137,19 +127,19 @@ namespace Db4objects.Db4o.Config
 		/// Setting cascadeOnUpdate to true will result in the update
 		/// of all member objects if a stored instance of this class is passed
 		/// to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store(object)">Db4objects.Db4o.IObjectContainer.Store(object)
 		/// 	</see>
 		/// .<br /><br />
-		/// The default setting is <b>false</b>.<br /><br />
+		/// The default setting is <b>false</b>. Setting it to true
+		/// may result in serious performance degradation.<br /><br />
 		/// In client-server environment this setting should be used on both
 		/// client and server. <br /><br />
 		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether updates are to be cascaded to member objects.</param>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnUpdate">Db4objects.Db4o.Config.IObjectField.CascadeOnUpdate
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <seealso cref="IObjectField.CascadeOnUpdate(bool)">IObjectField.CascadeOnUpdate(bool)
 		/// 	</seealso>
+		/// <seealso cref="com.db4o.ObjectContainer#set">com.db4o.ObjectContainer#set</seealso>
 		/// <seealso cref="Db4objects.Db4o.Ext.IObjectCallbacks">Using callbacks</seealso>
 		void CascadeOnUpdate(bool flag);
 
@@ -177,6 +167,8 @@ namespace Db4objects.Db4o.Config
 		/// for objects of this class, which is required for using replication.
 		/// </remarks>
 		/// <param name="setting"></param>
+		[System.ObsoleteAttribute(@"As of version 8.0 please use GenerateUUIDs(bool) and IFileConfiguration.GenerateCommitTimestamps(bool) instead"
+			)]
 		void EnableReplication(bool setting);
 
 		/// <summary>generate UUIDs for stored objects of this class.</summary>
@@ -193,6 +185,8 @@ namespace Db4objects.Db4o.Config
 		/// This setting should be used before the database is first created.<br /><br />
 		/// </remarks>
 		/// <param name="setting"></param>
+		[System.ObsoleteAttribute(@"As of version 8.0 please use IFileConfiguration.GenerateCommitTimestamps(bool) instead"
+			)]
 		void GenerateVersionNumbers(bool setting);
 
 		/// <summary>turns the class index on or off.</summary>
@@ -204,7 +198,7 @@ namespace Db4objects.Db4o.Config
 		/// to improve the performance to create and delete objects of
 		/// a class.
 		/// <br /><br />Common cases where a class index is not needed:<br />
-		/// - The application always works with subclasses or superclasses.<br />
+		/// - The application always works with sub classes or super classes.<br />
 		/// - There are convenient field indexes that will always find instances
 		/// of a class.<br />
 		/// - The application always works with IDs.<br /><br />
@@ -218,34 +212,30 @@ namespace Db4objects.Db4o.Config
 		/// <remarks>
 		/// sets the maximum activation depth to the desired value.
 		/// <br /><br />A class specific setting overrides the
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">global setting</see>
+		/// <see cref="IConfiguration.ActivationDepth(int)">global setting</see>
 		/// <br /><br />
 		/// In client-server environment this setting should be used on both
 		/// client and server. <br /><br />
 		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="depth">the desired maximum activation depth</param>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectClass.CascadeOnActivate">Db4objects.Db4o.Config.IObjectClass.CascadeOnActivate
-		/// 	</seealso>
+		/// <seealso cref="IConfiguration.ActivationDepth()">Why activation?</seealso>
+		/// <seealso cref="CascadeOnActivate(bool)">CascadeOnActivate(bool)</seealso>
 		void MaximumActivationDepth(int depth);
 
 		/// <summary>sets the minimum activation depth to the desired value.</summary>
 		/// <remarks>
 		/// sets the minimum activation depth to the desired value.
 		/// <br /><br />A class specific setting overrides the
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">global setting</see>
+		/// <see cref="IConfiguration.ActivationDepth(int)">global setting</see>
 		/// <br /><br />
 		/// In client-server environment this setting should be used on both
 		/// client and server. <br /><br />
 		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="depth">the desired minimum activation depth</param>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectClass.CascadeOnActivate">Db4objects.Db4o.Config.IObjectClass.CascadeOnActivate
-		/// 	</seealso>
+		/// <seealso cref="IConfiguration.ActivationDepth()">Why activation?</seealso>
+		/// <seealso cref="CascadeOnActivate(bool)">CascadeOnActivate(bool)</seealso>
 		void MinimumActivationDepth(int depth);
 
 		/// <summary>gets the configured minimum activation depth.</summary>
@@ -259,15 +249,15 @@ namespace Db4objects.Db4o.Config
 
 		/// <summary>
 		/// returns an
-		/// <see cref="Db4objects.Db4o.Config.IObjectField">IObjectField</see>
+		/// <see cref="IObjectField">IObjectField</see>
 		/// object
 		/// to configure the specified field.
 		/// <br /><br />
 		/// </summary>
-		/// <param name="fieldName">the fieldname of the field to be configured.<br /><br /></param>
+		/// <param name="fieldName">the name of the field to be configured.<br /><br /></param>
 		/// <returns>
 		/// an instance of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectField">IObjectField</see>
+		/// <see cref="IObjectField">IObjectField</see>
 		/// object for configuration.
 		/// </returns>
 		IObjectField ObjectField(string fieldName);
@@ -275,50 +265,31 @@ namespace Db4objects.Db4o.Config
 		/// <summary>turns on storing static field values for this class.</summary>
 		/// <remarks>
 		/// turns on storing static field values for this class.
-		/// <br /><br />By default, static field values of classes are not stored
+		/// <br/><br/>By default, static field values of classes are not stored
 		/// to the database file. By turning the setting on for a specific class
 		/// with this switch, all <b>non-simple-typed</b> static field values of this
 		/// class are stored the first time an object of the class is stored, and
 		/// restored, every time a database file is opened afterwards, <b>after
 		/// class meta information is loaded for this class</b> (which can happen
-		/// by querying for a class or by loading an instance of a class).<br /><br />
+		/// by querying for a class or by loading an instance of a class).<br/><br/>
 		/// To update a static field value, once it is stored, you have to the following
-		/// in this order:<br />
-		/// (1) open the database file you are working agains<br />
-		/// (2) make sure the class metadata is loaded<br />
-		/// <code>objectContainer.query().constrain(Foo.class); // Java</code><br />
-		/// <code>objectContainer.Query().Constrain(typeof(Foo)); // C#</code><br />
-		/// (3) change the static member<br />
-		/// (4) store the static member explicitely<br />
-		/// <code>objectContainer.set(Foo.staticMember); // C#</code>
-		/// <br /><br />The setting will be ignored for simple types.
-		/// <br /><br />Use this setting for constant static object members.
-		/// <br /><br />This option will slow down the process of opening database
+		/// in this order:<br/>
+		/// (1) open the database file you are working agains<br/>
+		/// (2) make sure the class metadata is loaded<br/>
+		/// <code>objectContainer.Query().Constrain(typeof(Foo)); </code><br/>
+		/// (3) change the static member<br/>
+		/// (4) store the static member explicitely<br/>
+		/// <code>objectContainer.Store(Foo.staticMember); </code>
+		/// <br/><br/>The setting will be ignored for simple types.
+		/// <br/><br/>Use this setting for constant static object members.
+		/// <br/><br/>This option will slow down the process of opening database
 		/// files and the stored objects will occupy space in the database file.
-		/// <br /><br />In client-server environment this setting should be used on both
-		/// client and server. <br /><br />
-		/// This setting can NOT be applied to an open object container. <br /><br />
+		/// <br/><br/>In client-server environment this setting should be used on both
+		/// client and server. <br/><br/>
+		/// This setting can NOT be applied to an open object container. <br/><br/>
 		/// </remarks>
 		void PersistStaticFieldValues();
 
-		/// <summary>creates a temporary mapping of a persistent class to a different class.</summary>
-		/// <remarks>
-		/// creates a temporary mapping of a persistent class to a different class.
-		/// <br /><br />If meta information for this ObjectClass has been stored to
-		/// the database file, it will be read from the database file as if it
-		/// was representing the class specified by the clazz parameter passed to
-		/// this method.
-		/// The clazz parameter can be any of the following:<br />
-		/// - a fully qualified classname as a String.<br />
-		/// - a Class object.<br />
-		/// - any other object to be used as a template.<br /><br />
-		/// This method will be ignored if the database file already contains meta
-		/// information for clazz.
-		/// </remarks>
-		/// <param name="clazz">class name, Class object, or example object.<br /><br /></param>
-		[System.ObsoleteAttribute(@"use")]
-		void ReadAs(object clazz);
-
 		/// <summary>renames a stored class.</summary>
 		/// <remarks>
 		/// renames a stored class.
@@ -327,7 +298,7 @@ namespace Db4objects.Db4o.Config
 		/// client and server. <br /><br />
 		/// This setting can NOT be applied to an open object container. <br /><br />
 		/// </remarks>
-		/// <param name="newName">the new fully qualified classname.</param>
+		/// <param name="newName">the new fully qualified class name.</param>
 		void Rename(string newName);
 
 		/// <summary>allows to specify if transient fields are to be stored.</summary>
@@ -346,7 +317,7 @@ namespace Db4objects.Db4o.Config
 		/// registers a translator for this class.
 		/// <br /><br />
 		/// <br /><br />The use of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">IObjectTranslator</see>
+		/// <see cref="IObjectTranslator">IObjectTranslator</see>
 		/// is not
 		/// compatible with the use of an
 		/// internal class ObjectMarshaller.<br /><br />
@@ -356,36 +327,32 @@ namespace Db4objects.Db4o.Config
 		/// </remarks>
 		/// <param name="translator">
 		/// this may be an
-		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">IObjectTranslator</see>
+		/// <see cref="IObjectTranslator">IObjectTranslator</see>
 		/// or an
-		/// <see cref="Db4objects.Db4o.Config.IObjectConstructor">IObjectConstructor</see>
+		/// <see cref="IObjectConstructor">IObjectConstructor</see>
 		/// </param>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectTranslator">Db4objects.Db4o.Config.IObjectTranslator
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectConstructor">Db4objects.Db4o.Config.IObjectConstructor
-		/// 	</seealso>
+		/// <seealso cref="IObjectTranslator">IObjectTranslator</seealso>
+		/// <seealso cref="IObjectConstructor">IObjectConstructor</seealso>
 		void Translate(IObjectTranslator translator);
 
 		/// <summary>specifies the updateDepth for this class.</summary>
 		/// <remarks>
 		/// specifies the updateDepth for this class.
 		/// <br /><br />see the documentation of
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store(object)">Db4objects.Db4o.IObjectContainer.Store(object)
 		/// 	</see>
 		/// for further details.<br /><br />
 		/// The default setting is 0: Only the object passed to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store(object)">Db4objects.Db4o.IObjectContainer.Store(object)
 		/// 	</see>
 		/// will be updated.<br /><br />
 		/// In client-server environment this setting should be used on both
 		/// client and server. <br /><br />
 		/// </remarks>
 		/// <param name="depth">the depth of the desired update for this class.</param>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.UpdateDepth">Db4objects.Db4o.Config.IConfiguration.UpdateDepth
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectClass.CascadeOnUpdate">Db4objects.Db4o.Config.IObjectClass.CascadeOnUpdate
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnUpdate">Db4objects.Db4o.Config.IObjectField.CascadeOnUpdate
+		/// <seealso cref="IConfiguration.UpdateDepth(int)">IConfiguration.UpdateDepth(int)</seealso>
+		/// <seealso cref="CascadeOnUpdate(bool)">CascadeOnUpdate(bool)</seealso>
+		/// <seealso cref="IObjectField.CascadeOnUpdate(bool)">IObjectField.CascadeOnUpdate(bool)
 		/// 	</seealso>
 		/// <seealso cref="Db4objects.Db4o.Ext.IObjectCallbacks">Using callbacks</seealso>
 		void UpdateDepth(int depth);
