@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,7 +16,7 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using System.IO;
 using System.Text;
 using Db4objects.Db4o.Foundation;
-using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Encoding;
 using Db4objects.Db4o.Internal.Handlers;
 using Db4objects.Db4o.Internal.Slots;
 using Sharpen.IO;
@@ -48,6 +48,7 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
+				int xxx = 1;
 			}
 		}
 
@@ -55,37 +56,26 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
-				BreakOnEvent(395);
-				//            breakOnEvent(10);
-				// addRange(4874);
-				// addRangeWithEnd(3835808, 3836267);
-				// breakOnEvent(5);
-				//addRangeWithLength(122866, 1);
-				AddRangeWithLength(122405, 1);
-				//addRangeWithLength(139520, 1);
-				// addRangeWithLength(119190, 1);
-				//        	 addRangeWithLength(139520,1);
-				//        	 
-				//        	 addRangeWithLength(122866, 265);
-				//        	addRangeWithLength(17673,1);
-				//            addRangeWithLength(455404,1);
-				//            
-				//            addRangeWithLength(455570,1);
-				//            
-				//            addRangeWithLength(455926,1);
-				//
-				//            addRangeWithLength(1647603457,1);
-				TrackEventsWithoutRange();
-				//            turnAllOffExceptFor(new DTrace[] {WRITE_BYTES});
-				//            turnAllOffExceptFor(new DTrace[] {
-				//                PERSISTENT_OWN_LENGTH,
-				//                });
-				TurnAllOffExceptFor(new Db4objects.Db4o.DTrace[] { GetSlot, FileFree, TransCommit
-					 });
 			}
 		}
 
-		//          turnAllOffExceptFor(new DTrace[] {BTREE_NODE_COMMIT_OR_ROLLBACK });
+		// addRange(15);
+		// breakOnEvent(540);
+		//        	
+		//        	addRangeWithEnd(448, 460);
+		//        	addRangeWithLength(770,53);
+		// breakOnEvent(125);
+		//            trackEventsWithoutRange();
+		//            turnAllOffExceptFor(new DTrace[] {WRITE_BYTES});
+		//            turnAllOffExceptFor(new DTrace[] {
+		//                PERSISTENT_OWN_LENGTH,
+		//                });
+		//            turnAllOffExceptFor(new DTrace[] {
+		//                GET_SLOT,
+		//                FILE_FREE,
+		//                TRANS_COMMIT,
+		//                });
+		// turnAllOffExceptFor(new DTrace[] {WRITE_BYTES});
 		//            turnAllOffExceptFor(new DTrace[] {BTREE_NODE_REMOVE, BTREE_NODE_COMMIT_OR_ROLLBACK YAPMETA_SET_ID});
 		private static void Init()
 		{
@@ -102,6 +92,8 @@ namespace Db4objects.Db4o
 					);
 				BtreeNodeCommitOrRollback = new Db4objects.Db4o.DTrace(true, true, "btreenode commit or rollback"
 					, true);
+				BtreeProduceNode = new Db4objects.Db4o.DTrace(true, true, "btree produce node", true
+					);
 				CandidateRead = new Db4objects.Db4o.DTrace(true, true, "candidate read", true);
 				ClassmetadataById = new Db4objects.Db4o.DTrace(true, true, "classmetadata by id", 
 					true);
@@ -125,9 +117,11 @@ namespace Db4objects.Db4o
 				FatalException = new Db4objects.Db4o.DTrace(true, true, "fatal exception", true);
 				Free = new Db4objects.Db4o.DTrace(true, true, "free", true);
 				FileFree = new Db4objects.Db4o.DTrace(true, true, "fileFree", true);
+				FileRead = new Db4objects.Db4o.DTrace(true, true, "fileRead", true);
+				FileWrite = new Db4objects.Db4o.DTrace(true, true, "fileWrite", true);
 				FreespacemanagerGetSlot = new Db4objects.Db4o.DTrace(true, true, "FreespaceManager getSlot"
 					, true);
-				FreespacemanagerRamFree = new Db4objects.Db4o.DTrace(true, true, "RamFreeSpaceManager free"
+				FreespacemanagerRamFree = new Db4objects.Db4o.DTrace(true, true, "InMemoryfreespaceManager free"
 					, true);
 				FreespacemanagerBtreeFree = new Db4objects.Db4o.DTrace(true, true, "BTreeFreeSpaceManager free"
 					, true);
@@ -139,14 +133,23 @@ namespace Db4objects.Db4o
 				GetPointerSlot = new Db4objects.Db4o.DTrace(true, true, "getPointerSlot", true);
 				GetSlot = new Db4objects.Db4o.DTrace(true, true, "getSlot", true);
 				GetFreespaceRam = new Db4objects.Db4o.DTrace(true, true, "getFreespaceRam", true);
-				GetYapobject = new Db4objects.Db4o.DTrace(true, true, "get yapObject", true);
+				GetYapobject = new Db4objects.Db4o.DTrace(true, true, "get ObjectReference", true
+					);
 				IdTreeAdd = new Db4objects.Db4o.DTrace(true, true, "id tree add", true);
 				IdTreeRemove = new Db4objects.Db4o.DTrace(true, true, "id tree remove", true);
 				IoCopy = new Db4objects.Db4o.DTrace(true, true, "io copy", true);
 				JustSet = new Db4objects.Db4o.DTrace(true, true, "just set", true);
 				NewInstance = new Db4objects.Db4o.DTrace(true, true, "newInstance", true);
+				NotifySlotCreated = new Db4objects.Db4o.DTrace(true, true, "notifySlotCreated", true
+					);
+				NotifySlotUpdated = new Db4objects.Db4o.DTrace(true, true, "notify Slot updated", 
+					true);
+				NotifySlotDeleted = new Db4objects.Db4o.DTrace(true, true, "notifySlotDeleted", true
+					);
 				ObjectReferenceCreated = new Db4objects.Db4o.DTrace(true, true, "new ObjectReference"
 					, true);
+				PersistentBaseNewSlot = new Db4objects.Db4o.DTrace(true, true, "PersistentBase new slot"
+					, true);
 				PersistentOwnLength = new Db4objects.Db4o.DTrace(true, true, "Persistent own length"
 					, true);
 				PersistentbaseWrite = new Db4objects.Db4o.DTrace(true, true, "persistentbase write"
@@ -159,7 +162,6 @@ namespace Db4objects.Db4o
 				ReadArrayWrapper = new Db4objects.Db4o.DTrace(true, true, "read array wrapper", true
 					);
 				ReadBytes = new Db4objects.Db4o.DTrace(true, true, "readBytes", true);
-				ReadId = new Db4objects.Db4o.DTrace(true, true, "read ID", true);
 				ReadSlot = new Db4objects.Db4o.DTrace(true, true, "read slot", true);
 				ReferenceRemoved = new Db4objects.Db4o.DTrace(true, true, "reference removed", true
 					);
@@ -169,14 +171,15 @@ namespace Db4objects.Db4o
 				RereadOldUuid = new Db4objects.Db4o.DTrace(true, true, "reread old uuid", true);
 				ServerMessageLoopException = new Db4objects.Db4o.DTrace(true, true, "server message loop exception"
 					, true);
-				SlotSetPointer = new Db4objects.Db4o.DTrace(true, true, "slot set pointer", true);
-				SlotDelete = new Db4objects.Db4o.DTrace(true, true, "slot delete", true);
+				SlotMapped = new Db4objects.Db4o.DTrace(true, true, "slot mapped", true);
+				SlotCommitted = new Db4objects.Db4o.DTrace(true, true, "slot committed", true);
 				SlotFreeOnCommit = new Db4objects.Db4o.DTrace(true, true, "slot free on commit", 
 					true);
 				SlotFreeOnRollbackId = new Db4objects.Db4o.DTrace(true, true, "slot free on rollback id"
 					, true);
 				SlotFreeOnRollbackAddress = new Db4objects.Db4o.DTrace(true, true, "slot free on rollback address"
 					, true);
+				SlotRead = new Db4objects.Db4o.DTrace(true, true, "slot read", true);
 				TransCommit = new Db4objects.Db4o.DTrace(true, true, "trans commit", true);
 				TransDelete = new Db4objects.Db4o.DTrace(true, true, "trans delete", true);
 				TransDontDelete = new Db4objects.Db4o.DTrace(true, true, "trans dontDelete", true
@@ -184,7 +187,7 @@ namespace Db4objects.Db4o
 				TransFlush = new Db4objects.Db4o.DTrace(true, true, "trans flush", true);
 				WriteBytes = new Db4objects.Db4o.DTrace(true, true, "writeBytes", true);
 				WritePointer = new Db4objects.Db4o.DTrace(true, true, "write pointer", true);
-				WriteUpdateDeleteMembers = new Db4objects.Db4o.DTrace(true, true, "trans writeUpdateDeleteMembers"
+				WriteUpdateAdjustIndexes = new Db4objects.Db4o.DTrace(true, true, "trans writeUpdateDeleteMembers"
 					, true);
 				WriteXbytes = new Db4objects.Db4o.DTrace(true, true, "writeXBytes", true);
 				Configure();
@@ -248,6 +251,8 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace BtreeNodeRemove;
 
+		public static Db4objects.Db4o.DTrace BtreeProduceNode;
+
 		public static Db4objects.Db4o.DTrace CandidateRead;
 
 		public static Db4objects.Db4o.DTrace ClassmetadataById;
@@ -280,6 +285,10 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace FileFree;
 
+		public static Db4objects.Db4o.DTrace FileRead;
+
+		public static Db4objects.Db4o.DTrace FileWrite;
+
 		public static Db4objects.Db4o.DTrace Free;
 
 		public static Db4objects.Db4o.DTrace FreespacemanagerGetSlot;
@@ -312,8 +321,16 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace NewInstance;
 
+		public static Db4objects.Db4o.DTrace NotifySlotCreated;
+
+		public static Db4objects.Db4o.DTrace NotifySlotUpdated;
+
+		public static Db4objects.Db4o.DTrace NotifySlotDeleted;
+
 		public static Db4objects.Db4o.DTrace ObjectReferenceCreated;
 
+		public static Db4objects.Db4o.DTrace PersistentBaseNewSlot;
+
 		public static Db4objects.Db4o.DTrace PersistentOwnLength;
 
 		public static Db4objects.Db4o.DTrace PersistentbaseSetId;
@@ -328,8 +345,6 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace ReadBytes;
 
-		public static Db4objects.Db4o.DTrace ReadId;
-
 		public static Db4objects.Db4o.DTrace ReadSlot;
 
 		public static Db4objects.Db4o.DTrace ReferenceRemoved;
@@ -342,9 +357,9 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace ServerMessageLoopException;
 
-		public static Db4objects.Db4o.DTrace SlotSetPointer;
+		public static Db4objects.Db4o.DTrace SlotMapped;
 
-		public static Db4objects.Db4o.DTrace SlotDelete;
+		public static Db4objects.Db4o.DTrace SlotCommitted;
 
 		public static Db4objects.Db4o.DTrace SlotFreeOnCommit;
 
@@ -352,6 +367,8 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace SlotFreeOnRollbackAddress;
 
+		public static Db4objects.Db4o.DTrace SlotRead;
+
 		public static Db4objects.Db4o.DTrace TransCommit;
 
 		public static Db4objects.Db4o.DTrace TransDontDelete;
@@ -366,7 +383,7 @@ namespace Db4objects.Db4o
 
 		public static Db4objects.Db4o.DTrace WriteXbytes;
 
-		public static Db4objects.Db4o.DTrace WriteUpdateDeleteMembers;
+		public static Db4objects.Db4o.DTrace WriteUpdateAdjustIndexes;
 
 		static DTrace()
 		{
@@ -385,15 +402,6 @@ namespace Db4objects.Db4o
 			}
 		}
 
-		public virtual void LogStack(string msg)
-		{
-			if (enabled)
-			{
-				Log(msg);
-				Log(Platform4.StackTrace());
-			}
-		}
-
 		public virtual void Log(string msg)
 		{
 			if (enabled)
@@ -414,7 +422,7 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
-				LogEnd(Unused, 0, info);
+				LogEnd(Unused, Unused, 0, info);
 			}
 		}
 
@@ -422,7 +430,7 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
-				LogEnd(p, 0, info);
+				LogEnd(Unused, p, 0, info);
 			}
 		}
 
@@ -430,7 +438,15 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
-				LogEnd(start, start + length - 1);
+				LogLength(Unused, start, length);
+			}
+		}
+
+		public virtual void LogLength(long id, long start, long length)
+		{
+			if (enabled)
+			{
+				LogEnd(id, start, start + length - 1);
 			}
 		}
 
@@ -438,7 +454,19 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
-				LogLength(slot.Address(), slot.Length());
+				LogLength(Unused, slot);
+			}
+		}
+
+		public virtual void LogLength(long id, Slot slot)
+		{
+			if (enabled)
+			{
+				if (slot == null)
+				{
+					return;
+				}
+				LogLength(id, slot.Address(), slot.Length());
 			}
 		}
 
@@ -446,12 +474,23 @@ namespace Db4objects.Db4o
 		{
 			if (enabled)
 			{
-				LogEnd(start, end, null);
+				LogEnd(Unused, start, end);
 			}
 		}
 
-		public virtual void LogEnd(long start, long end, string info)
+		public virtual void LogEnd(long id, long start, long end)
 		{
+			if (enabled)
+			{
+				LogEnd(id, start, end, null);
+			}
+		}
+
+		public virtual void LogEnd(long id, long start, long end, string info)
+		{
+			//    	if(! Deploy.log){
+			//    		return;
+			//    	}
 			if (enabled)
 			{
 				if (!_enabled)
@@ -465,6 +504,12 @@ namespace Db4objects.Db4o
 				}
 				for (int i = 0; i < _rangeCount; i++)
 				{
+					// Case 0 ID in range
+					if (id >= _rangeStart[i] && id <= _rangeEnd[i])
+					{
+						inRange = true;
+						break;
+					}
 					// Case 1 start in range
 					if (start >= _rangeStart[i] && start <= _rangeEnd[i])
 					{
@@ -495,6 +540,8 @@ namespace Db4objects.Db4o
 						StringBuilder sb = new StringBuilder(":");
 						sb.Append(FormatInt(_eventNr, 6));
 						sb.Append(":");
+						sb.Append(FormatInt(id));
+						sb.Append(":");
 						sb.Append(FormatInt(start));
 						sb.Append(":");
 						if (end != 0 && start != end)
@@ -653,8 +700,8 @@ namespace Db4objects.Db4o
 			{
 				if (_rangeStart == null)
 				{
-					_rangeStart = new long[100];
-					_rangeEnd = new long[100];
+					_rangeStart = new long[1000];
+					_rangeEnd = new long[1000];
 				}
 				_rangeStart[_rangeCount] = start;
 				_rangeEnd[_rangeCount] = end;
