@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,12 +15,9 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4objects.Db4o;
 using Db4objects.Db4o.Config;
-using Db4objects.Db4o.Ext;
 using Db4objects.Db4o.Foundation;
-using Db4objects.Db4o.Foundation.Network;
 using Db4objects.Db4o.Internal;
-using Db4objects.Db4o.Internal.CS;
-using Db4objects.Db4o.Reflect;
+using Db4objects.Db4o.Internal.Config;
 
 namespace Db4objects.Db4o
 {
@@ -29,27 +26,23 @@ namespace Db4objects.Db4o
 	/// factory class to start db4o database engines.
 	/// <br /><br />This class provides static methods to<br />
 	/// - open single-user databases
-	/// <see cref="Db4objects.Db4o.Db4oFactory.OpenFile">Db4objects.Db4o.Db4oFactory.OpenFile
-	/// 	</see>
+	/// <see cref="OpenFile(string)">OpenFile(string)</see>
 	/// <br />
 	/// - open db4o servers
-	/// <see cref="Db4objects.Db4o.Db4oFactory.OpenServer">Db4objects.Db4o.Db4oFactory.OpenServer
-	/// 	</see>
+	/// <see cref="OpenServer(string, int)">OpenServer(string, int)</see>
 	/// <br />
 	/// - connect to db4o servers
-	/// <see cref="Db4objects.Db4o.Db4oFactory.OpenClient">Db4objects.Db4o.Db4oFactory.OpenClient
+	/// <see cref="OpenClient(string, int, string, string)">OpenClient(string, int, string, string)
 	/// 	</see>
 	/// <br />
 	/// - provide access to the global configuration context
-	/// <see cref="Db4objects.Db4o.Db4oFactory.Configure">Db4objects.Db4o.Db4oFactory.Configure
-	/// 	</see>
+	/// <see cref="Configure()">Configure()</see>
 	/// <br />
 	/// - print the version number of this db4o version
-	/// <see cref="Db4objects.Db4o.Db4oFactory.Main">Db4objects.Db4o.Db4oFactory.Main</see>
+	/// <see cref="Main(java.lang.String[])">Main(java.lang.String[])</see>
 	/// 
 	/// </remarks>
-	/// <seealso cref="Db4objects.Db4o.Ext.ExtDb4oFactory">ExtDb4o for extended functionality.
-	/// 	</seealso>
+	/// <seealso cref="ExtDb4o">ExtDb4o for extended functionality.</seealso>
 	public class Db4oFactory
 	{
 		internal static readonly Config4Impl i_config = new Config4Impl();
@@ -98,6 +91,7 @@ namespace Db4objects.Db4o
 		/// </summary>
 		/// <returns>a fresh, independent configuration with all options set to their default values
 		/// 	</returns>
+		[System.ObsoleteAttribute(@"Use Db4oEmbedded.NewConfiguration() instead.")]
 		public static IConfiguration NewConfiguration()
 		{
 			Config4Impl config = new Config4Impl();
@@ -114,7 +108,8 @@ namespace Db4objects.Db4o
 		/// a fresh configuration with all option values set to the values
 		/// currently configured for the global db4o configuration context
 		/// </returns>
-		[System.ObsoleteAttribute(@"use explicit configuration via")]
+		[System.ObsoleteAttribute(@"use explicit configuration via Db4oEmbedded.NewConfiguration() instead"
+			)]
 		public static IConfiguration CloneConfiguration()
 		{
 			return (Config4Impl)((IDeepClone)Db4oFactory.Configure()).DeepClone(null);
@@ -122,20 +117,20 @@ namespace Db4objects.Db4o
 
 		/// <summary>
 		/// Operates just like
-		/// <see cref="Db4objects.Db4o.Db4oFactory.OpenClient">Db4objects.Db4o.Db4oFactory.OpenClient
-		/// 	</see>
-		/// , but uses
+		/// <see cref="Db4objects.Db4o.Db4oFactory.OpenClient">
+		/// Db4objects.Db4o.Db4oFactory.OpenClient
+		/// </see>, but uses
 		/// the global db4o
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// context.
 		/// opens an
 		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// client and connects it to the specified named server and port.
-		/// <br /><br />
+		/// <br/><br/>
 		/// The server needs to
 		/// <see cref="Db4objects.Db4o.IObjectServer.GrantAccess">allow access</see>
 		/// for the specified user and password.
-		/// <br /><br />
+		/// <br/><br/>
 		/// A client
 		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// can be cast to
@@ -146,8 +141,18 @@ namespace Db4objects.Db4o
 		/// and
 		/// <see cref="Db4objects.Db4o.Ext.IExtClient">IExtClient</see>
 		/// methods.
-		/// <br /><br />
+		/// <br/><br/>
+		/// This method is obsolete, see the Db4objects.Db4o.CS.Db4oClientServer class in
+		/// Db4objects.Db4o.CS.dll for methods to open db4o servers and db4o clients.
 		/// </summary>
+		/// <param name="config">
+		/// a custom
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
+		/// instance to be obtained via
+		/// <see cref="Db4objects.Db4o.Db4oEmbedded.NewConfiguration">
+		/// Db4objects.Db4o.Db4oEmbedded.NewConfiguration
+		/// </see>
+		/// </param>
 		/// <param name="hostName">the host name</param>
 		/// <param name="port">the port the server is using</param>
 		/// <param name="user">the user name</param>
@@ -156,15 +161,18 @@ namespace Db4objects.Db4o
 		/// an open
 		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.IObjectServer.GrantAccess">Db4objects.Db4o.IObjectServer.GrantAccess
-		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
+		/// <seealso cref="Db4objects.Db4o.IObjectServer.GrantAccess">
+		/// Db4objects.Db4o.IObjectServer.GrantAccess
+		/// </seealso>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">
+		/// I/O operation failed or was unexpectedly interrupted.
+		/// </exception>
 		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException">
 		/// open operation failed because the database file
 		/// is in old format and
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">
+		/// Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
+		/// </see>
 		/// 
 		/// is set to false.
 		/// </exception>
@@ -183,11 +191,11 @@ namespace Db4objects.Db4o
 		/// opens an
 		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// client and connects it to the specified named server and port.
-		/// <br /><br />
+		/// <br/><br/>
 		/// The server needs to
 		/// <see cref="Db4objects.Db4o.IObjectServer.GrantAccess">allow access</see>
 		/// for the specified user and password.
-		/// <br /><br />
+		/// <br/><br/>
 		/// A client
 		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// can be cast to
@@ -198,14 +206,17 @@ namespace Db4objects.Db4o
 		/// and
 		/// <see cref="Db4objects.Db4o.Ext.IExtClient">IExtClient</see>
 		/// methods.
-		/// <br /><br />
+		/// <br/><br/>
+		/// This method is obsolete, see the Db4objects.Db4o.CS.Db4oClientServer class in
+		/// Db4objects.Db4o.CS.dll for methods to open db4o servers and db4o clients.
 		/// </summary>
 		/// <param name="config">
 		/// a custom
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// instance to be obtained via
-		/// <see cref="Db4objects.Db4o.Db4oFactory.NewConfiguration">Db4objects.Db4o.Db4oFactory.NewConfiguration
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Db4oEmbedded.NewConfiguration">
+		/// Db4objects.Db4o.Db4oEmbedded.NewConfiguration
+		/// </see>
 		/// </param>
 		/// <param name="hostName">the host name</param>
 		/// <param name="port">the port the server is using</param>
@@ -215,15 +226,18 @@ namespace Db4objects.Db4o
 		/// an open
 		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.IObjectServer.GrantAccess">Db4objects.Db4o.IObjectServer.GrantAccess
-		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
+		/// <seealso cref="Db4objects.Db4o.IObjectServer.GrantAccess">
+		/// Db4objects.Db4o.IObjectServer.GrantAccess
+		/// </seealso>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">
+		/// I/O operation failed or was unexpectedly interrupted.
+		/// </exception>
 		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException">
 		/// open operation failed because the database file
 		/// is in old format and
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">
+		/// Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
+		/// </see>
 		/// 
 		/// is set to false.
 		/// </exception>
@@ -234,72 +248,8 @@ namespace Db4objects.Db4o
 		public static IObjectContainer OpenClient(IConfiguration config, string hostName, 
 			int port, string user, string password)
 		{
-			return OpenClient(config, hostName, port, user, password, new PlainSocketFactory(
-				));
-		}
-
-		/// <summary>
-		/// opens an
-		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
-		/// client and connects it to the specified named server and port.
-		/// <br /><br />
-		/// The server needs to
-		/// <see cref="Db4objects.Db4o.IObjectServer.GrantAccess">allow access</see>
-		/// for the specified user and password.
-		/// <br /><br />
-		/// A client
-		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
-		/// can be cast to
-		/// <see cref="Db4objects.Db4o.Ext.IExtClient">IExtClient</see>
-		/// to use extended
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer">IExtObjectContainer</see>
-		/// 
-		/// and
-		/// <see cref="Db4objects.Db4o.Ext.IExtClient">IExtClient</see>
-		/// methods.
-		/// <br /><br />
-		/// </summary>
-		/// <param name="config">
-		/// a custom
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
-		/// instance to be obtained via
-		/// <see cref="Db4objects.Db4o.Db4oFactory.NewConfiguration">Db4objects.Db4o.Db4oFactory.NewConfiguration
-		/// 	</see>
-		/// </param>
-		/// <param name="hostName">the host name</param>
-		/// <param name="port">the port the server is using</param>
-		/// <param name="user">the user name</param>
-		/// <param name="password">the user password</param>
-		/// <returns>
-		/// an open
-		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
-		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.IObjectServer.GrantAccess">Db4objects.Db4o.IObjectServer.GrantAccess
-		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException">
-		/// open operation failed because the database file
-		/// is in old format and
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
-		/// 	</see>
-		/// 
-		/// is set to false.
-		/// </exception>
-		/// <exception cref="Db4objects.Db4o.Ext.InvalidPasswordException">
-		/// password supplied for the connection is
-		/// invalid.
-		/// </exception>
-		public static IObjectContainer OpenClient(IConfiguration config, string hostName, 
-			int port, string user, string password, INativeSocketFactory socketFactory)
-		{
-			if (user == null || password == null)
-			{
-				throw new InvalidPasswordException();
-			}
-			Config4Impl.AssertIsNotTainted(config);
-			NetworkSocket networkSocket = new NetworkSocket(socketFactory, hostName, port);
-			return new ClientObjectContainer(config, networkSocket, user, password, true);
+			return ((Config4Impl)config).ClientServerFactory().OpenClient(config, hostName, port
+				, user, password);
 		}
 
 		/// <summary>
@@ -363,7 +313,7 @@ namespace Db4objects.Db4o
 		/// </exception>
 		public static IObjectContainer OpenFile(string databaseFileName)
 		{
-			return OpenFile(CloneConfiguration(), databaseFileName);
+			return Db4oFactory.OpenFile(CloneConfiguration(), databaseFileName);
 		}
 
 		/// <summary>
@@ -433,54 +383,45 @@ namespace Db4objects.Db4o
 		public static IObjectContainer OpenFile(IConfiguration config, string databaseFileName
 			)
 		{
-			return ObjectContainerFactory.OpenObjectContainer(config, databaseFileName);
-		}
-
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseFileLockedException"></exception>
-		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException"></exception>
-		protected static IObjectContainer OpenMemoryFile1(IConfiguration config, MemoryFile
-			 memoryFile)
-		{
-			Config4Impl.AssertIsNotTainted(config);
-			if (memoryFile == null)
-			{
-				memoryFile = new MemoryFile();
-			}
-			IObjectContainer oc = new InMemoryObjectContainer(config, memoryFile);
-			Db4objects.Db4o.Internal.Messages.LogMsg(config, 5, "Memory File");
-			return oc;
+			return ObjectContainerFactory.OpenObjectContainer(Db4oLegacyConfigurationBridge.AsEmbeddedConfiguration
+				(config), databaseFileName);
 		}
 
 		/// <summary>
 		/// Operates just like
-		/// <see cref="Db4objects.Db4o.Db4oFactory.OpenServer">Db4objects.Db4o.Db4oFactory.OpenServer
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Db4oFactory.OpenServer">
+		/// Db4objects.Db4o.Db4oFactory.OpenServer
+		/// </see>
 		/// , but uses
 		/// the global db4o
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// context.
-		/// opens an
+		/// Opens an
 		/// <see cref="Db4objects.Db4o.IObjectServer">IObjectServer</see>
 		/// on the specified database file and port.
-		/// <br /><br />
+		/// <br/><br/>
 		/// If the server does not need to listen on a port because it will only be used
 		/// in embedded mode with
-		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">
+		/// Db4objects.Db4o.IObjectServer.OpenClient
+		/// </see>
 		/// , specify '0' as the
 		/// port number.
+		/// <br/><br/>This method is obsolete, see the Db4objects.Db4o.CS.Db4oClientServer class in
+		/// Db4objects.Db4o.CS.dll for methods to open db4o servers and db4o clients.
 		/// </summary>
 		/// <param name="databaseFileName">an absolute or relative path to the database file</param>
 		/// <param name="port">
 		/// the port to be used, or 0, if the server should not open a port,
 		/// because it will only be used with
-		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">
+		/// Db4objects.Db4o.IObjectServer.OpenClient
+		/// </see>
 		/// .
 		/// Specify a value &lt; 0 if an arbitrary free port should be chosen - see
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectServer.Port">Db4objects.Db4o.Ext.IExtObjectServer.Port
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectServer.Port">
+		/// Db4objects.Db4o.Ext.IExtObjectServer.Port
+		/// </see>
 		/// .
 		/// </param>
 		/// <returns>
@@ -489,14 +430,18 @@ namespace Db4objects.Db4o
 		/// listening
 		/// on the specified port.
 		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ReadOnly">Db4objects.Db4o.Config.IConfiguration.ReadOnly
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Encrypt">Db4objects.Db4o.Config.IConfiguration.Encrypt
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Password">Db4objects.Db4o.Config.IConfiguration.Password
-		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ReadOnly">
+		/// Db4objects.Db4o.Config.IConfiguration.ReadOnly
+		/// </seealso>
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Encrypt">
+		/// Db4objects.Db4o.Config.IConfiguration.Encrypt
+		/// </seealso>
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Password">
+		/// Db4objects.Db4o.Config.IConfiguration.Password
+		/// </seealso>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">
+		/// I/O operation failed or was unexpectedly interrupted.
+		/// </exception>
 		/// <exception cref="Db4objects.Db4o.Ext.DatabaseFileLockedException">
 		/// the required database file is locked by
 		/// another process.
@@ -510,13 +455,15 @@ namespace Db4objects.Db4o
 		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException">
 		/// open operation failed because the database file
 		/// is in old format and
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">
+		/// Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
+		/// </see>
 		/// 
 		/// is set to false.
 		/// </exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseReadOnlyException">database was configured as read-only.
-		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseReadOnlyException">
+		/// database was configured as read-only.
+		/// </exception>
 		public static IObjectServer OpenServer(string databaseFileName, int port)
 		{
 			return OpenServer(CloneConfiguration(), databaseFileName, port);
@@ -526,31 +473,37 @@ namespace Db4objects.Db4o
 		/// opens an
 		/// <see cref="Db4objects.Db4o.IObjectServer">IObjectServer</see>
 		/// on the specified database file and port.
-		/// <br /><br />
+		/// <br/><br/>
 		/// If the server does not need to listen on a port because it will only be used
 		/// in embedded mode with
-		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">
+		/// Db4objects.Db4o.IObjectServer.OpenClient
+		/// </see>
 		/// , specify '0' as the
 		/// port number.
+		/// <br/><br/>This method is obsolete, see the Db4objects.Db4o.CS.Db4oClientServer class in
+		/// Db4objects.Db4o.CS.dll for methods to open db4o servers and db4o clients.
 		/// </summary>
 		/// <param name="config">
 		/// a custom
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// instance to be obtained via
-		/// <see cref="Db4objects.Db4o.Db4oFactory.NewConfiguration">Db4objects.Db4o.Db4oFactory.NewConfiguration
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Db4oEmbedded.NewConfiguration">
+		/// Db4objects.Db4o.Db4oEmbedded.NewConfiguration
+		/// </see>
 		/// </param>
 		/// <param name="databaseFileName">an absolute or relative path to the database file</param>
 		/// <param name="port">
 		/// the port to be used, or 0, if the server should not open a port,
 		/// because it will only be used with
-		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">
+		/// Db4objects.Db4o.IObjectServer.OpenClient
+		/// </see>
 		/// .
 		/// Specify a value &lt; 0 if an arbitrary free port should be chosen - see
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectServer.Port">Db4objects.Db4o.Ext.IExtObjectServer.Port
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectServer.Port">
+		/// Db4objects.Db4o.Ext.IExtObjectServer.Port
+		/// </see>
 		/// .
 		/// </param>
 		/// <returns>
@@ -559,14 +512,18 @@ namespace Db4objects.Db4o
 		/// listening
 		/// on the specified port.
 		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ReadOnly">Db4objects.Db4o.Config.IConfiguration.ReadOnly
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Encrypt">Db4objects.Db4o.Config.IConfiguration.Encrypt
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Password">Db4objects.Db4o.Config.IConfiguration.Password
-		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ReadOnly">
+		/// Db4objects.Db4o.Config.IConfiguration.ReadOnly
+		/// </seealso>
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Encrypt">
+		/// Db4objects.Db4o.Config.IConfiguration.Encrypt
+		/// </seealso>
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Password">
+		/// Db4objects.Db4o.Config.IConfiguration.Password
+		/// </seealso>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">
+		/// I/O operation failed or was unexpectedly interrupted.
+		/// </exception>
 		/// <exception cref="Db4objects.Db4o.Ext.DatabaseFileLockedException">
 		/// the required database file is locked by
 		/// another process.
@@ -580,108 +537,20 @@ namespace Db4objects.Db4o
 		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException">
 		/// open operation failed because the database file
 		/// is in old format and
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">
+		/// Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
+		/// </see>
 		/// 
 		/// is set to false.
 		/// </exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseReadOnlyException">database was configured as read-only.
-		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseReadOnlyException">
+		/// database was configured as read-only.
+		/// </exception>
 		public static IObjectServer OpenServer(IConfiguration config, string databaseFileName
 			, int port)
 		{
-			return OpenServer(config, databaseFileName, port, new PlainSocketFactory());
-		}
-
-		/// <summary>
-		/// opens an
-		/// <see cref="Db4objects.Db4o.IObjectServer">IObjectServer</see>
-		/// on the specified database file and port.
-		/// <br /><br />
-		/// If the server does not need to listen on a port because it will only be used
-		/// in embedded mode with
-		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
-		/// 	</see>
-		/// , specify '0' as the
-		/// port number.
-		/// </summary>
-		/// <param name="config">
-		/// a custom
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
-		/// instance to be obtained via
-		/// <see cref="Db4objects.Db4o.Db4oFactory.NewConfiguration">Db4objects.Db4o.Db4oFactory.NewConfiguration
-		/// 	</see>
-		/// </param>
-		/// <param name="databaseFileName">an absolute or relative path to the database file</param>
-		/// <param name="port">
-		/// the port to be used, or 0, if the server should not open a port,
-		/// because it will only be used with
-		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
-		/// 	</see>
-		/// .
-		/// Specify a value &lt; 0 if an arbitrary free port should be chosen - see
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectServer.Port">Db4objects.Db4o.Ext.IExtObjectServer.Port
-		/// 	</see>
-		/// .
-		/// </param>
-		/// <param name="socketFactory">
-		/// the
-		/// <see cref="Db4objects.Db4o.Config.INativeSocketFactory">Db4objects.Db4o.Config.INativeSocketFactory
-		/// 	</see>
-		/// to be used for socket creation
-		/// </param>
-		/// <returns>
-		/// an
-		/// <see cref="Db4objects.Db4o.IObjectServer">IObjectServer</see>
-		/// listening
-		/// on the specified port.
-		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ReadOnly">Db4objects.Db4o.Config.IConfiguration.ReadOnly
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Encrypt">Db4objects.Db4o.Config.IConfiguration.Encrypt
-		/// 	</seealso>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.Password">Db4objects.Db4o.Config.IConfiguration.Password
-		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseFileLockedException">
-		/// the required database file is locked by
-		/// another process.
-		/// </exception>
-		/// <exception cref="Db4objects.Db4o.Ext.IncompatibleFileFormatException">
-		/// runtime
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">configuration</see>
-		/// is not compatible
-		/// with the configuration of the database file.
-		/// </exception>
-		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException">
-		/// open operation failed because the database file
-		/// is in old format and
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates">Db4objects.Db4o.Config.IConfiguration.AllowVersionUpdates
-		/// 	</see>
-		/// 
-		/// is set to false.
-		/// </exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseReadOnlyException">database was configured as read-only.
-		/// 	</exception>
-		public static IObjectServer OpenServer(IConfiguration config, string databaseFileName
-			, int port, INativeSocketFactory socketFactory)
-		{
-			LocalObjectContainer stream = (LocalObjectContainer)OpenFile(config, databaseFileName
-				);
-			if (stream == null)
-			{
-				return null;
-			}
-			lock (stream.Lock())
-			{
-				return new ObjectServerImpl(stream, port, socketFactory);
-			}
-		}
-
-		internal static IReflector Reflector()
-		{
-			return i_config.Reflector();
+			return ((Config4Impl)config).ClientServerFactory().OpenServer(config, databaseFileName
+				, port);
 		}
 
 		/// <summary>returns the version name of the used db4o version.</summary>
