@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -20,27 +20,20 @@ namespace Db4objects.Db4o.Events
 {
 	/// <summary>Arguments for object related events.</summary>
 	/// <remarks>Arguments for object related events.</remarks>
-	/// <seealso cref="Db4objects.Db4o.Events.IEventRegistry">Db4objects.Db4o.Events.IEventRegistry
-	/// 	</seealso>
-	public class ObjectEventArgs : TransactionalEventArgs
+	/// <seealso cref="IEventRegistry">IEventRegistry</seealso>
+	public abstract class ObjectEventArgs : TransactionalEventArgs
 	{
-		private object _obj;
-
 		/// <summary>Creates a new instance for the specified object.</summary>
 		/// <remarks>Creates a new instance for the specified object.</remarks>
-		public ObjectEventArgs(Transaction transaction, object obj) : base(transaction)
+		protected ObjectEventArgs(Transaction transaction) : base(transaction)
 		{
-			_obj = obj;
 		}
 
 		/// <summary>The object that triggered this event.</summary>
 		/// <remarks>The object that triggered this event.</remarks>
-		public virtual object Object
+		public abstract object Object
 		{
-			get
-			{
-				return _obj;
-			}
+			get;
 		}
 	}
 }
