@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,8 +19,6 @@ using Db4objects.Db4o.Ext;
 using Db4objects.Db4o.IO;
 using Db4objects.Db4o.Reflect;
 using Db4objects.Db4o.Reflect.Generic;
-using Db4objects.Db4o.Replication;
-using Db4objects.Db4o.Types;
 
 namespace Db4objects.Db4o.Ext
 {
@@ -31,28 +29,27 @@ namespace Db4objects.Db4o.Ext
 	/// <br /><br />Every db4o
 	/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 	/// always is an <code>ExtObjectContainer</code> so a cast is possible.<br /><br />
-	/// <see cref="Db4objects.Db4o.IObjectContainer.Ext">Db4objects.Db4o.IObjectContainer.Ext
-	/// 	</see>
+	/// <see cref="Db4objects.Db4o.IObjectContainer.Ext()">ObjectContainer.ext()</see>
 	/// is a convenient method to perform the cast.<br /><br />
 	/// The ObjectContainer functionality is split to two interfaces to allow newcomers to
 	/// focus on the essential methods.
 	/// </summary>
-	public interface IExtObjectContainer : IObjectContainer
+	public partial interface IExtObjectContainer : IObjectContainer
 	{
 		/// <summary>activates an object with the current activation strategy.</summary>
 		/// <remarks>
 		/// activates an object with the current activation strategy.
 		/// In regular activation mode the object will be activated to the
 		/// global activation depth, ( see
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Db4objects.Db4o.Config.IConfiguration.ActivationDepth
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth()">Db4objects.Db4o.Config.IConfiguration.ActivationDepth()
 		/// 	</see>
 		/// )
 		/// and all configured settings for
-		/// <see cref="Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth">Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth
+		/// <see cref="Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth(int)">Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth(int)
 		/// 	</see>
 		/// 
 		/// and
-		/// <see cref="Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth">Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth
+		/// <see cref="Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth(int)">Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth(int)
 		/// 	</see>
 		/// will be respected.<br /><br />
 		/// In Transparent Activation Mode ( see
@@ -89,19 +86,21 @@ namespace Db4objects.Db4o.Ext
 		/// the open ObjectContainer and to the backup.<br /><br />
 		/// While the backup is running, the ObjectContainer should not be closed.<br /><br />
 		/// If a file already exists at the specified path, it will be overwritten.<br /><br />
-		/// The backup call may be started in a seperated thread by the application,
-		/// if concurrent execution with normal database access is desired.<br /><br />
-		/// For backup, the IoAdapter factory configured for the container is used.<br /><br />
+		/// The
+		/// <see cref="Db4objects.Db4o.IO.IStorage">Db4objects.Db4o.IO.IStorage</see>
+		/// used for backup is the one configured for this container.
 		/// </remarks>
 		/// <param name="path">a fully qualified path</param>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// <exception cref="DatabaseClosedException">db4o database file was closed or failed to open.
 		/// 	</exception>
 		/// <exception cref="System.NotSupportedException">
 		/// is thrown when the operation is not supported in current
 		/// configuration/environment
 		/// </exception>
+		/// <exception cref="Db4oIOException">I/O operation failed or was unexpectedly interrupted.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
 		void Backup(string path);
 
 		/// <summary>backs up a database file of an open ObjectContainer.</summary>
@@ -112,80 +111,64 @@ namespace Db4objects.Db4o.Ext
 		/// the open ObjectContainer and to the backup.<br /><br />
 		/// While the backup is running, the ObjectContainer should not be closed.<br /><br />
 		/// If a file already exists at the specified path, it will be overwritten.<br /><br />
-		/// The backup call may be started in a seperated thread by the application,
-		/// if concurrent execution with normal database access is desired.<br /><br />
+		/// This method is intended for cross-storage backups, i.e. backup from an in-memory
+		/// database to a file.
 		/// </remarks>
+		/// <param name="targetStorage">
+		/// the
+		/// <see cref="Db4objects.Db4o.IO.IStorage">Db4objects.Db4o.IO.IStorage</see>
+		/// to be used for backup
+		/// </param>
 		/// <param name="path">a fully qualified path</param>
-		/// <param name="targetIo">target IoAdapter factory for backup</param>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
-		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// <exception cref="DatabaseClosedException">db4o database file was closed or failed to open.
 		/// 	</exception>
 		/// <exception cref="System.NotSupportedException">
 		/// is thrown when the operation is not supported in current
 		/// configuration/environment
 		/// </exception>
-		void Backup(IoAdapter targetIo, string path);
+		/// <exception cref="Db4oIOException">I/O operation failed or was unexpectedly interrupted.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
+		void Backup(IStorage targetStorage, string path);
 
 		/// <summary>binds an object to an internal object ID.</summary>
 		/// <remarks>
 		/// binds an object to an internal object ID.
 		/// <br /><br />This method uses the ID parameter to load the
-		/// correspondig stored object into memory and replaces this memory
+		/// corresponding stored object into memory and replaces this memory
 		/// reference with the object parameter. The method may be used to replace
 		/// objects or to reassociate an object with it's stored instance
 		/// after closing and opening a database file. A subsequent call to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
-		/// 	</see>
+		/// <see cref="com.db4o.ObjectContainer#set">set(Object)</see>
 		/// is
 		/// necessary to update the stored object.<br /><br />
 		/// <b>Requirements:</b><br />- The ID needs to be a valid internal object ID,
 		/// previously retrieved with
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">Db4objects.Db4o.Ext.IExtObjectContainer.GetID
-		/// 	</see>
+		/// <see cref="GetID(object)">getID(Object)</see>
 		/// .<br />
 		/// - The object parameter needs to be of the same class as the stored object.<br /><br />
 		/// </remarks>
-		/// <seealso cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">Db4objects.Db4o.Ext.IExtObjectContainer.GetID
-		/// 	</seealso>
+		/// <seealso cref="GetID(object)">GetID(object)</seealso>
 		/// <param name="obj">the object that is to be bound</param>
 		/// <param name="id">the internal id the object is to be bound to</param>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// <exception cref="DatabaseClosedException">db4o database file was closed or failed to open.
 		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.InvalidIDException">
+		/// <exception cref="InvalidIDException">
 		/// when the provided id is outside the scope of the
 		/// database IDs.
 		/// </exception>
+		/// <exception cref="Db4objects.Db4o.Ext.InvalidIDException"></exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
 		void Bind(object obj, long id);
 
-		/// <summary>
-		/// returns the
-		/// <see cref="Db4objects.Db4o.Types.IDb4oCollections">Db4objects.Db4o.Types.IDb4oCollections
-		/// 	</see>
-		/// interface to create or modify database-aware
-		/// collections for this
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// .<br /><br />
-		/// </summary>
-		/// <returns>
-		/// the
-		/// <see cref="Db4objects.Db4o.Types.IDb4oCollections">Db4objects.Db4o.Types.IDb4oCollections
-		/// 	</see>
-		/// interface for this
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// .
-		/// </returns>
-		[System.ObsoleteAttribute(@"since 7.0. Use of old internal collections is discouraged. Please use  com.db4o.collections.ArrayList4 and com.db4o.collections.ArrayMap4 instead."
-			)]
-		IDb4oCollections Collections();
-
 		/// <summary>returns the Configuration context for this ObjectContainer.</summary>
 		/// <remarks>
 		/// returns the Configuration context for this ObjectContainer.
 		/// <br /><br />
 		/// Upon opening an ObjectContainer with any of the factory methods in the
-		/// <see cref="Db4objects.Db4o.Db4oFactory">Db4objects.Db4o.Db4oFactory</see>
-		/// class, the global
+		/// <see cref="Db4objects.Db4o.Db4oFactory">Db4o class</see>
+		/// , the global
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// context
 		/// is copied into the ObjectContainer. The
@@ -195,12 +178,11 @@ namespace Db4objects.Db4o.Ext
 		/// </remarks>
 		/// <returns>
 		/// 
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Db4objects.Db4o.Config.IConfiguration
-		/// 	</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// the Configuration
 		/// context for this ObjectContainer
 		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.Db4oFactory.Configure">Db4objects.Db4o.Db4oFactory.Configure
+		/// <seealso cref="Db4objects.Db4o.Db4oFactory.Configure()">Db4objects.Db4o.Db4oFactory.Configure()
 		/// 	</seealso>
 		IConfiguration Configure();
 
@@ -222,56 +204,59 @@ namespace Db4objects.Db4o.Ext
 		/// returns the stored object for an internal ID.
 		/// <br /><br />This is the fastest method for direct access to objects. Internal
 		/// IDs can be obtained with
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">Db4objects.Db4o.Ext.IExtObjectContainer.GetID
-		/// 	</see>
+		/// <see cref="GetID(object)">getID(Object)</see>
 		/// .
 		/// Objects will not be activated by this method. They will be returned in the
 		/// activation state they are currently in, in the local cache.<br /><br />
-		/// To activate the returned object with the current activation strategy, call
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.Activate">Db4objects.Db4o.Ext.IExtObjectContainer.Activate
-		/// 	</see>
-		/// .<br /><br />
+		/// Passing invalid id values to this method may result in all kinds of
+		/// exceptions being thrown. OutOfMemoryError and arithmetic exceptions
+		/// may occur. If an application is known to use invalid IDs, it is
+		/// recommended to call this method within a catch-all block.
 		/// </remarks>
-		/// <param name="id">the internal ID</param>
+		/// <param name="Id">the internal ID</param>
 		/// <returns>
 		/// the object associated with the passed ID or <code>null</code>,
 		/// if no object is associated with this ID in this <code>ObjectContainer</code>.
 		/// </returns>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth()">Why activation?
 		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// <exception cref="DatabaseClosedException">db4o database file was closed or failed to open.
 		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.InvalidIDException">when the provided id is not valid.
-		/// 	</exception>
-		object GetByID(long id);
+		/// <exception cref="InvalidIDException">
+		/// when the provided id is outside the scope of the
+		/// file length.
+		/// </exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
+		/// <exception cref="Db4objects.Db4o.Ext.InvalidIDException"></exception>
+		object GetByID(long Id);
 
 		/// <summary>
 		/// returns a stored object for a
-		/// <see cref="Db4objects.Db4o.Ext.Db4oUUID">Db4objects.Db4o.Ext.Db4oUUID</see>
+		/// <see cref="Db4oUUID">Db4oUUID</see>
 		/// .
 		/// <br /><br />
 		/// This method is intended for replication and for long-term
 		/// external references to objects. To get a
-		/// <see cref="Db4objects.Db4o.Ext.Db4oUUID">Db4objects.Db4o.Ext.Db4oUUID</see>
+		/// <see cref="Db4oUUID">Db4oUUID</see>
 		/// for an
 		/// object use
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetObjectInfo">Db4objects.Db4o.Ext.IExtObjectContainer.GetObjectInfo
-		/// 	</see>
+		/// <see cref="GetObjectInfo(object)">GetObjectInfo(object)</see>
 		/// and
-		/// <see cref="Db4objects.Db4o.Ext.IObjectInfo.GetUUID">Db4objects.Db4o.Ext.IObjectInfo.GetUUID
-		/// 	</see>
+		/// <see cref="IObjectInfo.GetUUID()">IObjectInfo.GetUUID()</see>
 		/// .<br /><br />
 		/// Objects will not be activated by this method. They will be returned in the
 		/// activation state they are currently in, in the local cache.<br /><br />
 		/// </summary>
 		/// <param name="uuid">the UUID</param>
 		/// <returns>the object for the UUID</returns>
-		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
+		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth()">Why activation?
 		/// 	</seealso>
-		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
+		/// <exception cref="Db4oIOException">I/O operation failed or was unexpectedly interrupted.
 		/// 	</exception>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// <exception cref="DatabaseClosedException">db4o database file was closed or failed to open.
 		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		object GetByUUID(Db4oUUID uuid);
 
 		/// <summary>returns the internal unique object ID.</summary>
@@ -281,18 +266,14 @@ namespace Db4objects.Db4o.Ext
 		/// guaranteed to be unique within one <code>ObjectContainer</code>.
 		/// An object carries the same ID in every db4o session. Internal IDs can
 		/// be used to look up objects with the very fast
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetByID">Db4objects.Db4o.Ext.IExtObjectContainer.GetByID
-		/// 	</see>
+		/// <see cref="GetByID(long)">getByID</see>
 		/// method.<br /><br />
 		/// Internal IDs will change when a database is defragmented. Use
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetObjectInfo">Db4objects.Db4o.Ext.IExtObjectContainer.GetObjectInfo
-		/// 	</see>
+		/// <see cref="GetObjectInfo(object)">GetObjectInfo(object)</see>
 		/// ,
-		/// <see cref="Db4objects.Db4o.Ext.IObjectInfo.GetUUID">Db4objects.Db4o.Ext.IObjectInfo.GetUUID
-		/// 	</see>
+		/// <see cref="IObjectInfo.GetUUID()">IObjectInfo.GetUUID()</see>
 		/// and
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetByUUID">Db4objects.Db4o.Ext.IExtObjectContainer.GetByUUID
-		/// 	</see>
+		/// <see cref="GetByUUID(Db4oUUID)">GetByUUID(Db4oUUID)</see>
 		/// for long-term external references to
 		/// objects.<br /><br />
 		/// </remarks>
@@ -305,7 +286,7 @@ namespace Db4objects.Db4o.Ext
 
 		/// <summary>
 		/// returns the
-		/// <see cref="Db4objects.Db4o.Ext.IObjectInfo">Db4objects.Db4o.Ext.IObjectInfo</see>
+		/// <see cref="IObjectInfo">IObjectInfo</see>
 		/// for a stored object.
 		/// <br /><br />This method will return null, if the passed
 		/// object is not stored to this <code>ObjectContainer</code>.<br /><br />
@@ -313,16 +294,13 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="obj">the stored object</param>
 		/// <returns>
 		/// the
-		/// <see cref="Db4objects.Db4o.Ext.IObjectInfo">Db4objects.Db4o.Ext.IObjectInfo</see>
+		/// <see cref="IObjectInfo">IObjectInfo</see>
 		/// 
 		/// </returns>
 		IObjectInfo GetObjectInfo(object obj);
 
-		/// <summary>
-		/// returns the
-		/// <see cref="Db4objects.Db4o.Ext.Db4oDatabase">Db4objects.Db4o.Ext.Db4oDatabase</see>
-		/// identity object for this ObjectContainer.
-		/// </summary>
+		/// <summary>returns the Db4oDatabase object for this ObjectContainer.</summary>
+		/// <remarks>returns the Db4oDatabase object for this ObjectContainer.</remarks>
 		/// <returns>the Db4oDatabase identity object for this ObjectContainer.</returns>
 		Db4oDatabase Identity();
 
@@ -341,8 +319,8 @@ namespace Db4objects.Db4o.Ext
 		/// tests if an object with this ID is currently cached.
 		/// <br /><br />
 		/// </remarks>
-		/// <param name="id">the internal id</param>
-		bool IsCached(long id);
+		/// <param name="Id">the internal ID</param>
+		bool IsCached(long Id);
 
 		/// <summary>tests if this <code>ObjectContainer</code> is closed.</summary>
 		/// <remarks>
@@ -359,8 +337,9 @@ namespace Db4objects.Db4o.Ext
 		/// </remarks>
 		/// <param name="obj">to be tested<br /><br /></param>
 		/// <returns><code>true</code> if the passed object is stored.</returns>
-		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// <exception cref="DatabaseClosedException">db4o database file was closed or failed to open.
 		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
 		bool IsStored(object obj);
 
 		/// <summary>
@@ -377,9 +356,9 @@ namespace Db4objects.Db4o.Ext
 		/// </returns>
 		IReflectClass[] KnownClasses();
 
-		/// <summary>returns the main synchronisation lock.</summary>
+		/// <summary>returns the main synchronization lock.</summary>
 		/// <remarks>
-		/// returns the main synchronisation lock.
+		/// returns the main synchronization lock.
 		/// <br /><br />
 		/// Synchronize over this object to ensure exclusive access to
 		/// the ObjectContainer.<br /><br />
@@ -387,27 +366,17 @@ namespace Db4objects.Db4o.Ext
 		/// since deadlocks can be produced with just two lines of code.
 		/// </remarks>
 		/// <returns>Object the ObjectContainer lock object</returns>
-		[System.ObsoleteAttribute(@"Use is not recommended. Use your own monitor objects instead."
-			)]
 		object Lock();
 
-		/// <summary>aids migration of objects between ObjectContainers.</summary>
+		/// <summary>opens a new ObjectContainer on top of this ObjectContainer.</summary>
 		/// <remarks>
-		/// aids migration of objects between ObjectContainers.
-		/// <br /><br />When objects are migrated from one ObjectContainer to another, it is
-		/// desirable to preserve virtual object attributes such as the object version number
-		/// or the UUID. Use this method to signal to an ObjectContainer that it should read
-		/// existing version numbers and UUIDs from another ObjectContainer. This method should
-		/// also be used during the Defragment. It is included in the default
-		/// implementation supplied in Defragment.java/Defragment.cs.<br /><br />
+		/// opens a new ObjectContainer on top of this ObjectContainer.
+		/// The ObjectContainer will have it's own transaction and
+		/// it's own reference system.
 		/// </remarks>
-		/// <param name="objectContainer">
-		/// the
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// objects are to be migrated
-		/// from or <code>null</code> to denote that migration is completed.
-		/// </param>
-		void MigrateFrom(IObjectContainer objectContainer);
+		/// <returns>the new ObjectContainer session.</returns>
+		/// <since>8.0</since>
+		IObjectContainer OpenSession();
 
 		/// <summary>
 		/// returns a transient copy of a persistent object with all members set
@@ -421,14 +390,14 @@ namespace Db4objects.Db4o.Ext
 		/// With the <code>committed</code> parameter it is possible to specify,
 		/// whether the desired object should contain the committed values or the
 		/// values that were set by the running transaction with
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store(object)">Db4objects.Db4o.IObjectContainer.Store(object)
 		/// 	</see>
 		/// .
-		/// <br /><br />A possible usecase for this feature:<br />
+		/// <br /><br />A possible use case for this feature:<br />
 		/// An application might want to check all changes applied to an object
 		/// by the running transaction.<br /><br />
 		/// </remarks>
-		/// <param name="@object">the object that is to be cloned</param>
+		/// <param name="object">the object that is to be cloned</param>
 		/// <param name="depth">the member depth to which the object is to be instantiated</param>
 		/// <param name="committed">whether committed or set values are to be returned</param>
 		/// <returns>the object</returns>
@@ -477,7 +446,7 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="obj">the object to be refreshed.</param>
 		/// <param name="depth">
 		/// the member
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">depth</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth(int)">depth</see>
 		/// to which refresh is to cascade.
 		/// </param>
 		void Refresh(object obj, int depth);
@@ -487,64 +456,17 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="name">the name of the semaphore to be released.</param>
 		void ReleaseSemaphore(string name);
 
-		/// <param name="peerB">
-		/// the
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// to replicate with.
-		/// </param>
-		/// <param name="conflictHandler">
-		/// the conflict handler for this ReplicationProcess.
-		/// Conflicts occur
-		/// whenever
-		/// <see cref="Db4objects.Db4o.Replication.IReplicationProcess.Replicate">Db4objects.Db4o.Replication.IReplicationProcess.Replicate
-		/// 	</see>
-		/// is called with an
-		/// object that was modified in both ObjectContainers since the last
-		/// replication run between the two. Upon a conflict the
-		/// <see cref="Db4objects.Db4o.Replication.IReplicationConflictHandler.ResolveConflict
-		/// 	">Db4objects.Db4o.Replication.IReplicationConflictHandler.ResolveConflict</see>
-		/// method will be called in the conflict handler.
-		/// </param>
-		/// <returns>
-		/// the
-		/// <see cref="Db4objects.Db4o.Replication.IReplicationProcess">Db4objects.Db4o.Replication.IReplicationProcess
-		/// 	</see>
-		/// interface for this replication process.
-		/// </returns>
-		[System.ObsoleteAttribute(@"Since db4o-5.2. Use db4o Replication System (dRS) instead.<br><br> prepares for replication with another"
-			)]
-		IReplicationProcess ReplicationBegin(IObjectContainer peerB, IReplicationConflictHandler
-			 conflictHandler);
-
 		/// <summary>deep update interface to store or update objects.</summary>
 		/// <remarks>
 		/// deep update interface to store or update objects.
 		/// <br /><br />In addition to the normal storage interface,
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
-		/// 	</see>
+		/// <see cref="com.db4o.ObjectContainer#set">ObjectContainer#set(Object)</see>
 		/// ,
 		/// this method allows a manual specification of the depth, the passed object is to be updated.<br /><br />
 		/// </remarks>
 		/// <param name="obj">the object to be stored or updated.</param>
 		/// <param name="depth">the depth to which the object is to be updated</param>
-		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
-		/// 	</seealso>
-		[System.ObsoleteAttribute(@"Use")]
-		void Set(object obj, int depth);
-
-		/// <summary>deep update interface to store or update objects.</summary>
-		/// <remarks>
-		/// deep update interface to store or update objects.
-		/// <br /><br />In addition to the normal storage interface,
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
-		/// 	</see>
-		/// ,
-		/// this method allows a manual specification of the depth, the passed object is to be updated.<br /><br />
-		/// </remarks>
-		/// <param name="obj">the object to be stored or updated.</param>
-		/// <param name="depth">the depth to which the object is to be updated</param>
-		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
-		/// 	</seealso>
+		/// <seealso cref="com.db4o.ObjectContainer#set">com.db4o.ObjectContainer#set</seealso>
 		void Store(object obj, int depth);
 
 		/// <summary>attempts to set a semaphore.</summary>
@@ -565,13 +487,12 @@ namespace Db4objects.Db4o.Ext
 		/// in milliseconds to wait for other transactions to release
 		/// the semaphore, in case the semaphore is already owned by
 		/// another transaction.<br /><br />
-		/// Semaphores are released by the first occurence of one of the
+		/// Semaphores are released by the first occurrence of one of the
 		/// following:<br />
 		/// - the transaction releases the semaphore with
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.ReleaseSemaphore">Db4objects.Db4o.Ext.IExtObjectContainer.ReleaseSemaphore
-		/// 	</see>
+		/// <see cref="ReleaseSemaphore(string)">ReleaseSemaphore(string)</see>
 		/// <br /> - the transaction is closed with
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Close">Db4objects.Db4o.IObjectContainer.Close
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Close()">Db4objects.Db4o.IObjectContainer.Close()
 		/// 	</see>
 		/// <br /> - C/S only: the corresponding
 		/// <see cref="Db4objects.Db4o.IObjectServer">Db4objects.Db4o.IObjectServer</see>
@@ -580,19 +501,19 @@ namespace Db4objects.Db4o.Ext
 		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
 		/// looses the connection and is timed
 		/// out.<br /><br /> Semaphores are set immediately. They are independant of calling
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Commit">Db4objects.Db4o.IObjectContainer.Commit
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Commit()">Db4objects.Db4o.IObjectContainer.Commit()
 		/// 	</see>
 		/// or
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Rollback">Db4objects.Db4o.IObjectContainer.Rollback
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Rollback()">Db4objects.Db4o.IObjectContainer.Rollback()
 		/// 	</see>
-		/// .<br /><br /> <b>Possible usecases
+		/// .<br /><br /> <b>Possible use cases
 		/// for semaphores:</b><br /> - prevent other clients from inserting a singleton at the same time.
 		/// A suggested name for the semaphore:  "SINGLETON_" + Object#getClass().getName().<br />  - lock
 		/// objects. A suggested name:   "LOCK_" +
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">getID(Object)</see>
+		/// <see cref="GetID(object)">getID(Object)</see>
 		/// <br /> -
 		/// generate a unique client ID. A suggested name:  "CLIENT_" +
-		/// currentTime.<br /><br />
+		/// System.currentTimeMillis().<br /><br />
 		/// </remarks>
 		/// <param name="name">the name of the semaphore to be set</param>
 		/// <param name="waitForAvailability">
@@ -611,43 +532,43 @@ namespace Db4objects.Db4o.Ext
 
 		/// <summary>
 		/// returns a
-		/// <see cref="Db4objects.Db4o.Ext.IStoredClass">Db4objects.Db4o.Ext.IStoredClass</see>
+		/// <see cref="IStoredClass">IStoredClass</see>
 		/// meta information object.
 		/// <br /><br />
 		/// There are three options how to use this method.<br />
 		/// Any of the following parameters are possible:<br />
-		/// - a fully qualified classname.<br />
+		/// - a fully qualified class name.<br />
 		/// - a Class object.<br />
 		/// - any object to be used as a template.<br /><br />
 		/// </summary>
 		/// <param name="clazz">class name, Class object, or example object.<br /><br /></param>
 		/// <returns>
 		/// an instance of an
-		/// <see cref="Db4objects.Db4o.Ext.IStoredClass">Db4objects.Db4o.Ext.IStoredClass</see>
+		/// <see cref="IStoredClass">IStoredClass</see>
 		/// meta information object.
 		/// </returns>
 		IStoredClass StoredClass(object clazz);
 
 		/// <summary>
 		/// returns an array of all
-		/// <see cref="Db4objects.Db4o.Ext.IStoredClass">Db4objects.Db4o.Ext.IStoredClass</see>
+		/// <see cref="IStoredClass">IStoredClass</see>
 		/// meta information objects.
 		/// </summary>
 		IStoredClass[] StoredClasses();
 
 		/// <summary>
 		/// returns the
-		/// <see cref="Db4objects.Db4o.Ext.ISystemInfo">Db4objects.Db4o.Ext.ISystemInfo</see>
+		/// <see cref="ISystemInfo">ISystemInfo</see>
 		/// for this ObjectContainer.
 		/// <br /><br />The
-		/// <see cref="Db4objects.Db4o.Ext.ISystemInfo">Db4objects.Db4o.Ext.ISystemInfo</see>
+		/// <see cref="ISystemInfo">ISystemInfo</see>
 		/// supplies methods that provide
 		/// information about system state and system settings of this
 		/// ObjectContainer.
 		/// </summary>
 		/// <returns>
 		/// the
-		/// <see cref="Db4objects.Db4o.Ext.ISystemInfo">Db4objects.Db4o.Ext.ISystemInfo</see>
+		/// <see cref="ISystemInfo">ISystemInfo</see>
 		/// for this ObjectContainer.
 		/// </returns>
 		ISystemInfo SystemInfo();
