@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,13 +13,25 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+using System.Collections;
+
 namespace Db4objects.Db4o.Foundation
 {
 	/// <exclude></exclude>
 	public interface IMap4
 	{
+		int Size();
+
 		object Get(object key);
 
 		void Put(object key, object value);
+
+		bool ContainsKey(object key);
+
+		object Remove(object key);
+
+		IEnumerable Values();
+
+		void Clear();
 	}
 }
