@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,6 +13,7 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+#if !SILVERLIGHT
 using Db4objects.Db4o.Internal;
 
 namespace Db4objects.Db4o
@@ -21,11 +22,12 @@ namespace Db4objects.Db4o
 	public interface IBlobTransport
 	{
 		/// <exception cref="System.IO.IOException"></exception>
-		void WriteBlobTo(Transaction trans, BlobImpl blob, Sharpen.IO.File file);
+		void WriteBlobTo(Transaction trans, BlobImpl blob);
 
 		/// <exception cref="System.IO.IOException"></exception>
-		void ReadBlobFrom(Transaction trans, BlobImpl blob, Sharpen.IO.File file);
+		void ReadBlobFrom(Transaction trans, BlobImpl blob);
 
 		void DeleteBlobFile(Transaction trans, BlobImpl blob);
 	}
 }
+#endif // !SILVERLIGHT
