@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,17 +16,22 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Collections;
 using System.Text;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Defragment;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Internal;
 using Db4objects.Db4o.Internal.Btree;
-using Db4objects.Db4o.Internal.Mapping;
+using Db4objects.Db4o.Internal.Caching;
+using Db4objects.Db4o.Internal.Ids;
 using Db4objects.Db4o.Marshall;
 
 namespace Db4objects.Db4o.Internal.Btree
 {
 	/// <exclude></exclude>
-	public class BTree : PersistentBase, ITransactionParticipant
+	public class BTree : LocalPersistentBase, ITransactionParticipant, IBTreeStructureListener
 	{
+		private readonly BTreeConfiguration _config;
+
 		private const byte BtreeVersion = (byte)1;
 
 		private const int DefragmentIncrementOffset = 1 + Const4.IntLength * 2;
@@ -43,7 +48,22 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private IVisitor4 _removeListener;
 
-		private Hashtable4 _sizesByTransaction;
+		private sealed class _TransactionLocal_40 : TransactionLocal
+		{
+			public _TransactionLocal_40()
+			{
+			}
+
+			// version byte
+			// size, node size  
+			public override object InitialValueFor(Transaction transaction)
+			{
+				return 0;
+			}
+		}
+
+		private readonly TransactionLocal _sizeDeltaInTransaction = new _TransactionLocal_40
+			();
 
 		protected IQueue4 _processing;
 
@@ -51,29 +71,29 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		internal int _halfNodeSize;
 
-		private readonly int _cacheHeight;
+		private IBTreeStructureListener _structureListener;
 
-		public BTree(Transaction trans, int id, IIndexable4 keyHandler) : this(trans, id, 
-			keyHandler, Config(trans).BTreeNodeSize(), Config(trans).BTreeCacheHeight())
-		{
-		}
+		private readonly ICache4 _nodeCache;
 
-		public BTree(Transaction trans, int id, IIndexable4 keyHandler, int treeNodeSize, 
-			int treeCacheHeight)
+		private TreeIntObject _evictedFromCache;
+
+		private bool _disposed;
+
+		public BTree(Transaction trans, BTreeConfiguration config, int id, IIndexable4 keyHandler
+			, int treeNodeSize) : base(config._idSystem)
 		{
-			// version byte
-			// size, node size  
+			_config = config;
 			if (null == keyHandler)
 			{
 				throw new ArgumentNullException();
 			}
 			_nodeSize = treeNodeSize;
+			_nodeCache = CacheFactory.NewLRUIntCache(config._cacheSize);
 			_halfNodeSize = _nodeSize / 2;
 			_nodeSize = _halfNodeSize * 2;
-			_cacheHeight = treeCacheHeight;
 			_keyHandler = keyHandler;
-			_sizesByTransaction = new Hashtable4();
-			if (id == 0)
+			SetID(id);
+			if (IsNew())
 			{
 				SetStateDirty();
 				_root = new BTreeNode(this, 0, true, 0, 0, 0);
@@ -83,11 +103,30 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			else
 			{
-				SetID(id);
 				SetStateDeactivated();
 			}
 		}
 
+		public BTree(Transaction trans, BTreeConfiguration config, IIndexable4 keyHandler
+			) : this(trans, config, 0, keyHandler)
+		{
+		}
+
+		public BTree(Transaction trans, BTreeConfiguration config, int id, IIndexable4 keyHandler
+			) : this(trans, config, id, keyHandler, Config(trans).BTreeNodeSize())
+		{
+		}
+
+		public BTree(Transaction trans, int id, IIndexable4 keyHandler) : this(trans, BTreeConfiguration
+			.Default, id, keyHandler)
+		{
+		}
+
+		public BTree(Transaction trans, int id, IIndexable4 keyHandler, int nodeSize) : this
+			(trans, BTreeConfiguration.Default, id, keyHandler, nodeSize)
+		{
+		}
+
 		public virtual BTreeNode Root()
 		{
 			return _root;
@@ -103,40 +142,82 @@ namespace Db4objects.Db4o.Internal.Btree
 			KeyCantBeNull(key);
 			IPreparedComparison preparedComparison = _keyHandler.PrepareComparison(trans.Context
 				(), key);
-			EnsureDirty(trans);
+			Add(trans, preparedComparison, key);
+		}
+
+		public virtual void Add(Transaction trans, IPreparedComparison preparedComparison
+			, object key)
+		{
+			EnsureActive(trans);
+			Enlist(trans);
 			BTreeNode rootOrSplit = _root.Add(trans, preparedComparison, key);
 			if (rootOrSplit != null && rootOrSplit != _root)
 			{
+				EnsureDirty(trans);
 				_root = new BTreeNode(trans, _root, rootOrSplit);
 				_root.Write(trans.SystemTransaction());
 				AddNode(_root);
 			}
+			ConvertCacheEvictedNodesToReadMode();
 		}
 
-		// FIXME: Change the signature to return true, if object could be removed.
-		public virtual void Remove(Transaction trans, object key)
+		public virtual object Remove(Transaction trans, object key)
 		{
+			BTreePointer bTreePointer = SearchPointer(trans, key);
+			if (bTreePointer == null)
+			{
+				return null;
+			}
+			object result = bTreePointer.Key();
+			Enlist(trans);
+			IPreparedComparison preparedComparison = KeyHandler().PrepareComparison(trans.Context
+				(), key);
+			BTreeNode node = bTreePointer.Node();
+			node.Remove(trans, preparedComparison, key, bTreePointer.Index());
+			ConvertCacheEvictedNodesToReadMode();
+			return result;
+		}
+
+		public virtual IBTreeRange SearchRange(Transaction trans, object key)
+		{
+			KeyCantBeNull(key);
+			return SearchRange(trans, KeyHandler().PrepareComparison(trans.Context(), key));
+		}
+
+		public virtual BTreePointer SearchPointer(Transaction trans, object key)
+		{
+			EnsureActive(trans);
 			KeyCantBeNull(key);
 			IPreparedComparison preparedComparison = KeyHandler().PrepareComparison(trans.Context
 				(), key);
-			IEnumerator pointers = Search(trans, preparedComparison).Pointers();
-			if (!pointers.MoveNext())
+			BTreeNodeSearchResult start = SearchLeaf(trans, preparedComparison, SearchTarget.
+				Lowest);
+			BTreePointer bTreePointer = start.FirstValidPointer();
+			if (bTreePointer == null)
 			{
-				return;
+				ConvertCacheEvictedNodesToReadMode();
+				return null;
 			}
-			BTreePointer first = (BTreePointer)pointers.Current;
-			EnsureDirty(trans);
-			BTreeNode node = first.Node();
-			node.Remove(trans, preparedComparison, key, first.Index());
+			object found = bTreePointer.Key();
+			ConvertCacheEvictedNodesToReadMode();
+			if (preparedComparison.CompareTo(found) == 0)
+			{
+				return bTreePointer;
+			}
+			return null;
 		}
 
-		public virtual IBTreeRange Search(Transaction trans, object key)
+		public virtual object Search(Transaction trans, object key)
 		{
-			KeyCantBeNull(key);
-			return Search(trans, KeyHandler().PrepareComparison(trans.Context(), key));
+			BTreePointer bTreePointer = SearchPointer(trans, key);
+			if (bTreePointer != null)
+			{
+				return bTreePointer.Key();
+			}
+			return null;
 		}
 
-		private IBTreeRange Search(Transaction trans, IPreparedComparison preparedComparison
+		private IBTreeRange SearchRange(Transaction trans, IPreparedComparison preparedComparison
 			)
 		{
 			EnsureActive(trans);
@@ -148,7 +229,9 @@ namespace Db4objects.Db4o.Internal.Btree
 				Lowest);
 			BTreeNodeSearchResult end = SearchLeaf(trans, preparedComparison, SearchTarget.Highest
 				);
-			return start.CreateIncludingRange(end);
+			IBTreeRange range = start.CreateIncludingRange(end);
+			ConvertCacheEvictedNodesToReadMode();
+			return range;
 		}
 
 		private void KeyCantBeNull(object key)
@@ -175,29 +258,63 @@ namespace Db4objects.Db4o.Internal.Btree
 			 preparedComparison, SearchTarget target)
 		{
 			EnsureActive(trans);
-			return _root.SearchLeaf(trans, preparedComparison, target);
+			BTreeNodeSearchResult result = _root.SearchLeaf(trans, preparedComparison, target
+				);
+			ConvertCacheEvictedNodesToReadMode();
+			return result;
 		}
 
-		public virtual void Commit(Transaction trans)
+		public virtual void Commit(Transaction transaction)
 		{
-			Transaction systemTransaction = trans.SystemTransaction();
-			object sizeDiff = _sizesByTransaction.Get(trans);
-			if (sizeDiff != null)
+			if (_disposed)
 			{
-				_size += ((int)sizeDiff);
+				return;
 			}
-			_sizesByTransaction.Remove(trans);
-			if (_nodes != null)
-			{
-				CommitNodes(trans);
-				WriteAllNodes(systemTransaction);
-			}
-			SetStateDirty();
-			Write(systemTransaction);
-			Purge();
+			UpdateSize(transaction);
+			CommitNodes(transaction);
+			FinishTransaction(transaction);
+			ConvertCacheEvictedNodesToReadMode();
 		}
 
-		public virtual void CommitNodes(Transaction trans)
+		private void UpdateSize(Transaction transaction)
+		{
+			ByRef sizeInTransaction = SizeIn(transaction);
+			int sizeModification = (((int)sizeInTransaction.value));
+			if (sizeModification == 0)
+			{
+				return;
+			}
+			EnsureDirty(transaction);
+			_size += sizeModification;
+			sizeInTransaction.value = 0;
+		}
+
+		private ByRef SizeIn(Transaction trans)
+		{
+			return trans.Get(_sizeDeltaInTransaction);
+		}
+
+		private void CommitNodes(Transaction trans)
+		{
+			ProcessEachNode(new _IProcedure4_237(trans));
+		}
+
+		private sealed class _IProcedure4_237 : IProcedure4
+		{
+			public _IProcedure4_237(Transaction trans)
+			{
+				this.trans = trans;
+			}
+
+			public void Apply(object node)
+			{
+				((BTreeNode)node).Commit(trans);
+			}
+
+			private readonly Transaction trans;
+		}
+
+		private void ProcessEachNode(IProcedure4 action)
 		{
 			if (_nodes == null)
 			{
@@ -206,51 +323,65 @@ namespace Db4objects.Db4o.Internal.Btree
 			ProcessAllNodes();
 			while (_processing.HasNext())
 			{
-				((BTreeNode)_processing.Next()).Commit(trans);
+				action.Apply((BTreeNode)_processing.Next());
 			}
 			_processing = null;
 		}
 
 		public virtual void Rollback(Transaction trans)
+		{
+			RollbackNodes(trans);
+			FinishTransaction(trans);
+			ConvertCacheEvictedNodesToReadMode();
+		}
+
+		private void FinishTransaction(Transaction trans)
 		{
 			Transaction systemTransaction = trans.SystemTransaction();
-			_sizesByTransaction.Remove(trans);
-			if (_nodes == null)
-			{
-				return;
-			}
-			ProcessAllNodes();
-			while (_processing.HasNext())
-			{
-				((BTreeNode)_processing.Next()).Rollback(trans);
-			}
-			_processing = null;
 			WriteAllNodes(systemTransaction);
-			SetStateDirty();
 			Write(systemTransaction);
 			Purge();
 		}
 
+		private void RollbackNodes(Transaction trans)
+		{
+			ProcessEachNode(new _IProcedure4_266(trans));
+		}
+
+		private sealed class _IProcedure4_266 : IProcedure4
+		{
+			public _IProcedure4_266(Transaction trans)
+			{
+				this.trans = trans;
+			}
+
+			public void Apply(object node)
+			{
+				((BTreeNode)node).Rollback(trans);
+			}
+
+			private readonly Transaction trans;
+		}
+
 		private void WriteAllNodes(Transaction systemTransaction)
 		{
 			if (_nodes == null)
 			{
 				return;
 			}
-			_nodes.Traverse(new _IVisitor4_205(systemTransaction));
+			_nodes.Traverse(new _IVisitor4_275(systemTransaction));
 		}
 
-		private sealed class _IVisitor4_205 : IVisitor4
+		private sealed class _IVisitor4_275 : IVisitor4
 		{
-			public _IVisitor4_205(Transaction systemTransaction)
+			public _IVisitor4_275(Transaction systemTransaction)
 			{
 				this.systemTransaction = systemTransaction;
 			}
 
 			public void Visit(object obj)
 			{
-				BTreeNode node = (BTreeNode)((TreeIntObject)obj).GetObject();
-				node.Write(systemTransaction);
+				((BTreeNode)((TreeIntObject)obj).GetObject()).Write(systemTransaction);
 			}
 
 			private readonly Transaction systemTransaction;
@@ -264,21 +395,19 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			Tree temp = _nodes;
 			_nodes = null;
-			if (_cacheHeight > 0)
+			_root.HoldChildrenAsIDs();
+			AddNode(_root);
+			temp.Traverse(new _IVisitor4_294());
+			for (IEnumerator entryIter = _nodeCache.GetEnumerator(); entryIter.MoveNext(); )
 			{
-				_root.MarkAsCached(_cacheHeight);
+				BTreeNodeCacheEntry entry = ((BTreeNodeCacheEntry)entryIter.Current);
+				entry._node.HoldChildrenAsIDs();
 			}
-			else
-			{
-				_root.HoldChildrenAsIDs();
-				AddNode(_root);
-			}
-			temp.Traverse(new _IVisitor4_229());
 		}
 
-		private sealed class _IVisitor4_229 : IVisitor4
+		private sealed class _IVisitor4_294 : IVisitor4
 		{
-			public _IVisitor4_229()
+			public _IVisitor4_294()
 			{
 			}
 
@@ -292,19 +421,19 @@ namespace Db4objects.Db4o.Internal.Btree
 		private void ProcessAllNodes()
 		{
 			_processing = new NonblockingQueue();
-			_nodes.Traverse(new _IVisitor4_239(this));
+			_nodes.Traverse(new _IVisitor4_311(this));
 		}
 
-		private sealed class _IVisitor4_239 : IVisitor4
+		private sealed class _IVisitor4_311 : IVisitor4
 		{
-			public _IVisitor4_239(BTree _enclosing)
+			public _IVisitor4_311(BTree _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
 
-			public void Visit(object obj)
+			public void Visit(object node)
 			{
-				this._enclosing._processing.Add(((TreeIntObject)obj).GetObject());
+				this._enclosing._processing.Add(((TreeIntObject)node).GetObject());
 			}
 
 			private readonly BTree _enclosing;
@@ -321,16 +450,21 @@ namespace Db4objects.Db4o.Internal.Btree
 		private void EnsureDirty(Transaction trans)
 		{
 			EnsureActive(trans);
+			Enlist(trans);
+			SetStateDirty();
+		}
+
+		private void Enlist(Transaction trans)
+		{
 			if (CanEnlistWithTransaction())
 			{
 				((LocalTransaction)trans).Enlist(this);
 			}
-			SetStateDirty();
 		}
 
 		protected virtual bool CanEnlistWithTransaction()
 		{
-			return true;
+			return _config._canEnlistWithTransaction;
 		}
 
 		public override byte GetIdentifier()
@@ -348,15 +482,19 @@ namespace Db4objects.Db4o.Internal.Btree
 			return 1 + Const4.ObjectLength + (Const4.IntLength * 2) + Const4.IdLength;
 		}
 
-		internal virtual BTreeNode ProduceNode(int id)
+		public virtual BTreeNode ProduceNode(int id)
 		{
+			if (DTrace.enabled)
+			{
+				DTrace.BtreeProduceNode.Log(id);
+			}
 			TreeIntObject addtio = new TreeIntObject(id);
-			_nodes = (TreeIntObject)Tree.Add(_nodes, addtio);
+			_nodes = (TreeIntObject)((TreeIntObject)Tree.Add(_nodes, addtio));
 			TreeIntObject tio = (TreeIntObject)addtio.AddedOrExisting();
 			BTreeNode node = (BTreeNode)tio.GetObject();
 			if (node == null)
 			{
-				node = new BTreeNode(id, this);
+				node = CacheEntry(new BTreeNode(id, this))._node;
 				tio.SetObject(node);
 				AddToProcessing(node);
 			}
@@ -365,7 +503,8 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		internal virtual void AddNode(BTreeNode node)
 		{
-			_nodes = (TreeIntObject)Tree.Add(_nodes, new TreeIntObject(node.GetID(), node));
+			_nodes = (TreeIntObject)((TreeIntObject)Tree.Add(_nodes, new TreeIntObject(node.GetID
+				(), node)));
 			AddToProcessing(node);
 		}
 
@@ -379,7 +518,7 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		internal virtual void RemoveNode(BTreeNode node)
 		{
-			_nodes = (TreeIntObject)_nodes.RemoveLike(new TreeInt(node.GetID()));
+			_nodes = (TreeIntObject)((TreeInt)_nodes.RemoveLike(new TreeInt(node.GetID())));
 		}
 
 		internal virtual void NotifyRemoveListener(object obj)
@@ -410,13 +549,12 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		public virtual int Size(Transaction trans)
 		{
+			// This implementation of size will not work accurately for multiple
+			// transactions. If two transactions call clear and both commit, _size
+			// can end up negative.
+			// For multiple transactions the size patches only are an estimate.
 			EnsureActive(trans);
-			object sizeDiff = _sizesByTransaction.Get(trans);
-			if (sizeDiff != null)
-			{
-				return _size + ((int)sizeDiff);
-			}
-			return _size;
+			return _size + (((int)SizeIn(trans).value));
 		}
 
 		public virtual void TraverseKeys(Transaction trans, IVisitor4 visitor)
@@ -427,24 +565,21 @@ namespace Db4objects.Db4o.Internal.Btree
 				return;
 			}
 			_root.TraverseKeys(trans, visitor);
+			ConvertCacheEvictedNodesToReadMode();
 		}
 
-		public virtual void SizeChanged(Transaction trans, int changeBy)
+		public virtual void SizeChanged(Transaction transaction, BTreeNode node, int changeBy
+			)
 		{
-			object sizeDiff = _sizesByTransaction.Get(trans);
-			if (sizeDiff == null)
-			{
-				_sizesByTransaction.Put(trans, changeBy);
-				return;
-			}
-			_sizesByTransaction.Put(trans, ((int)sizeDiff) + changeBy);
+			NotifyCountChanged(transaction, node, changeBy);
+			ByRef sizeInTransaction = SizeIn(transaction);
+			sizeInTransaction.value = (((int)sizeInTransaction.value)) + changeBy;
 		}
 
 		public virtual void Dispose(Transaction transaction)
 		{
 		}
 
-		// nothing to do here
 		public virtual BTreePointer FirstPointer(Transaction trans)
 		{
 			EnsureActive(trans);
@@ -452,7 +587,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return null;
 			}
-			return _root.FirstPointer(trans);
+			BTreePointer pointer = _root.FirstPointer(trans);
+			ConvertCacheEvictedNodesToReadMode();
+			return pointer;
 		}
 
 		public virtual BTreePointer LastPointer(Transaction trans)
@@ -462,7 +599,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return null;
 			}
-			return _root.LastPointer(trans);
+			BTreePointer pointer = _root.LastPointer(trans);
+			ConvertCacheEvictedNodesToReadMode();
+			return pointer;
 		}
 
 		public virtual Db4objects.Db4o.Internal.Btree.BTree DebugLoadFully(Transaction trans
@@ -492,14 +631,15 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		public virtual void DefragBTree(IDefragmentServices services)
 		{
-			DefragmentContextImpl.ProcessCopy(services, GetID(), new _ISlotCopyHandler_398(this
+			DefragmentContextImpl.ProcessCopy(services, GetID(), new _ISlotCopyHandler_481(this
 				));
-			services.TraverseAllIndexSlots(this, new _IVisitor4_403(this, services));
+			services.TraverseAllIndexSlots(this, new _IVisitor4_486(this, services));
+			ConvertCacheEvictedNodesToReadMode();
 		}
 
-		private sealed class _ISlotCopyHandler_398 : ISlotCopyHandler
+		private sealed class _ISlotCopyHandler_481 : ISlotCopyHandler
 		{
-			public _ISlotCopyHandler_398(BTree _enclosing)
+			public _ISlotCopyHandler_481(BTree _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -512,9 +652,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			private readonly BTree _enclosing;
 		}
 
-		private sealed class _IVisitor4_403 : IVisitor4
+		private sealed class _IVisitor4_486 : IVisitor4
 		{
-			public _IVisitor4_403(BTree _enclosing, IDefragmentServices services)
+			public _IVisitor4_486(BTree _enclosing, IDefragmentServices services)
 			{
 				this._enclosing = _enclosing;
 				this.services = services;
@@ -523,12 +663,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			public void Visit(object obj)
 			{
 				int id = ((int)obj);
-				DefragmentContextImpl.ProcessCopy(services, id, new _ISlotCopyHandler_406(this));
+				DefragmentContextImpl.ProcessCopy(services, id, new _ISlotCopyHandler_489(this));
 			}
 
-			private sealed class _ISlotCopyHandler_406 : ISlotCopyHandler
+			private sealed class _ISlotCopyHandler_489 : ISlotCopyHandler
 			{
-				public _ISlotCopyHandler_406(_IVisitor4_403 _enclosing)
+				public _ISlotCopyHandler_489(_IVisitor4_486 _enclosing)
 				{
 					this._enclosing = _enclosing;
 				}
@@ -538,7 +678,7 @@ namespace Db4objects.Db4o.Internal.Btree
 					this._enclosing._enclosing.DefragIndexNode(context);
 				}
 
-				private readonly _IVisitor4_403 _enclosing;
+				private readonly _IVisitor4_486 _enclosing;
 			}
 
 			private readonly BTree _enclosing;
@@ -546,7 +686,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			private readonly IDefragmentServices services;
 		}
 
-		public virtual int CompareKeys(IContext context, object key1, object key2)
+		internal virtual int CompareKeys(IContext context, object key1, object key2)
 		{
 			IPreparedComparison preparedComparison = _keyHandler.PrepareComparison(context, key1
 				);
@@ -559,34 +699,36 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				throw new ArgumentNullException();
 			}
-			return trans.Container().ConfigImpl();
+			return trans.Container().ConfigImpl;
 		}
 
-		public override void Free(Transaction systemTrans)
+		public override void Free(LocalTransaction systemTrans)
 		{
+			_disposed = true;
 			FreeAllNodeIds(systemTrans, AllNodeIds(systemTrans));
-			base.Free(systemTrans);
+			base.Free((LocalTransaction)systemTrans);
 		}
 
-		private void FreeAllNodeIds(Transaction systemTrans, IEnumerator allNodeIDs)
+		private void FreeAllNodeIds(LocalTransaction systemTrans, IEnumerator allNodeIDs)
 		{
+			ITransactionalIdSystem idSystem = IdSystem(systemTrans);
 			while (allNodeIDs.MoveNext())
 			{
 				int id = ((int)allNodeIDs.Current);
-				systemTrans.SlotFreePointerOnCommit(id);
+				idSystem.NotifySlotDeleted(id, SlotChangeFactory());
 			}
 		}
 
 		public virtual IEnumerator AllNodeIds(Transaction systemTrans)
 		{
 			Collection4 allNodeIDs = new Collection4();
-			TraverseAllNodes(systemTrans, new _IVisitor4_441(allNodeIDs));
+			TraverseAllNodes(systemTrans, new _IVisitor4_527(allNodeIDs));
 			return allNodeIDs.GetEnumerator();
 		}
 
-		private sealed class _IVisitor4_441 : IVisitor4
+		private sealed class _IVisitor4_527 : IVisitor4
 		{
-			public _IVisitor4_441(Collection4 allNodeIDs)
+			public _IVisitor4_527(Collection4 allNodeIDs)
 			{
 				this.allNodeIDs = allNodeIDs;
 			}
@@ -610,12 +752,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return;
 			}
-			_nodes.Traverse(new _IVisitor4_457(visitor));
+			_nodes.Traverse(new _IVisitor4_543(visitor));
 		}
 
-		private sealed class _IVisitor4_457 : IVisitor4
+		private sealed class _IVisitor4_543 : IVisitor4
 		{
-			public _IVisitor4_457(IVisitor4 visitor)
+			public _IVisitor4_543(IVisitor4 visitor)
 			{
 				this.visitor = visitor;
 			}
@@ -634,13 +776,13 @@ namespace Db4objects.Db4o.Internal.Btree
 			sb.Append("BTree ");
 			sb.Append(GetID());
 			sb.Append(" Active Nodes: \n");
-			TraverseAllNodes(new _IVisitor4_469(sb));
+			TraverseAllNodes(new _IVisitor4_555(sb));
 			return sb.ToString();
 		}
 
-		private sealed class _IVisitor4_469 : IVisitor4
+		private sealed class _IVisitor4_555 : IVisitor4
 		{
-			public _IVisitor4_469(StringBuilder sb)
+			public _IVisitor4_555(StringBuilder sb)
 			{
 				this.sb = sb;
 			}
@@ -653,5 +795,128 @@ namespace Db4objects.Db4o.Internal.Btree
 
 			private readonly StringBuilder sb;
 		}
+
+		public virtual void StructureListener(IBTreeStructureListener listener)
+		{
+			_structureListener = listener;
+		}
+
+		public virtual void NotifySplit(Transaction trans, BTreeNode originalNode, BTreeNode
+			 newRightNode)
+		{
+			if (_structureListener != null)
+			{
+				_structureListener.NotifySplit(trans, originalNode, newRightNode);
+			}
+		}
+
+		public virtual void NotifyDeleted(Transaction trans, BTreeNode node)
+		{
+			if (_structureListener != null)
+			{
+				_structureListener.NotifyDeleted(trans, node);
+			}
+		}
+
+		public virtual void NotifyCountChanged(Transaction trans, BTreeNode node, int diff
+			)
+		{
+			if (_structureListener != null)
+			{
+				_structureListener.NotifyCountChanged(trans, node, diff);
+			}
+		}
+
+		public virtual IEnumerator Iterator(Transaction trans)
+		{
+			return new BTreeIterator(trans, this);
+		}
+
+		public virtual void Clear(Transaction transaction)
+		{
+			BTreePointer currentPointer = FirstPointer(transaction);
+			while (currentPointer != null && currentPointer.IsValid())
+			{
+				BTreeNode node = currentPointer.Node();
+				int index = currentPointer.Index();
+				node.Remove(transaction, index);
+				currentPointer = currentPointer.Next();
+			}
+		}
+
+		public virtual ICache4 NodeCache()
+		{
+			return _nodeCache;
+		}
+
+		internal virtual BTreeNodeCacheEntry CacheEntry(BTreeNode node)
+		{
+			return ((BTreeNodeCacheEntry)_nodeCache.Produce(node.GetID(), new _IFunction4_605
+				(node), new _IProcedure4_609(this)));
+		}
+
+		private sealed class _IFunction4_605 : IFunction4
+		{
+			public _IFunction4_605(BTreeNode node)
+			{
+				this.node = node;
+			}
+
+			public object Apply(object id)
+			{
+				return new BTreeNodeCacheEntry(node);
+			}
+
+			private readonly BTreeNode node;
+		}
+
+		private sealed class _IProcedure4_609 : IProcedure4
+		{
+			public _IProcedure4_609(BTree _enclosing)
+			{
+				this._enclosing = _enclosing;
+			}
+
+			public void Apply(object entry)
+			{
+				this._enclosing.EvictedFromCache(((BTreeNodeCacheEntry)entry)._node);
+			}
+
+			private readonly BTree _enclosing;
+		}
+
+		public override Db4objects.Db4o.Internal.Slots.SlotChangeFactory SlotChangeFactory
+			()
+		{
+			return _config._slotChangeFactory;
+		}
+
+		public virtual void EvictedFromCache(BTreeNode node)
+		{
+			_evictedFromCache = ((TreeIntObject)Tree.Add(_evictedFromCache, new TreeIntObject
+				(node.GetID(), node)));
+		}
+
+		public virtual void ConvertCacheEvictedNodesToReadMode()
+		{
+			if (_evictedFromCache == null)
+			{
+				return;
+			}
+			Tree.Traverse(_evictedFromCache, new _IVisitor4_628());
+			_evictedFromCache = null;
+		}
+
+		private sealed class _IVisitor4_628 : IVisitor4
+		{
+			public _IVisitor4_628()
+			{
+			}
+
+			public void Visit(object treeIntObject)
+			{
+				((BTreeNode)((TreeIntObject)treeIntObject)._object).ToReadMode();
+			}
+		}
 	}
 }
