@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -18,6 +18,8 @@ using Db4objects.Db4o;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Internal;
 using Db4objects.Db4o.Internal.Btree;
+using Db4objects.Db4o.Internal.Ids;
+using Db4objects.Db4o.Marshall;
 using Sharpen;
 
 namespace Db4objects.Db4o.Internal.Btree
@@ -36,7 +38,7 @@ namespace Db4objects.Db4o.Internal.Btree
 	/// as needed with prepareRead() and prepareWrite().
 	/// </remarks>
 	/// <exclude></exclude>
-	public sealed class BTreeNode : PersistentBase
+	public sealed class BTreeNode : LocalPersistentBase
 	{
 		private const int CountLeafAnd3LinkLength = (Const4.IntLength * 4) + 1;
 
@@ -59,8 +61,6 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private int _nextID;
 
-		private bool _cached;
-
 		private bool _dead;
 
 		public BTreeNode(BTree btree, int count, bool isLeaf, int parentID, int previousID
@@ -108,10 +108,11 @@ namespace Db4objects.Db4o.Internal.Btree
 			 preparedComparison, object obj)
 		{
 			ByteArrayBuffer reader = PrepareRead(trans);
-			Searcher s = Search(preparedComparison, reader);
+			Searcher s = Search(trans, preparedComparison, reader);
 			if (_isLeaf)
 			{
 				PrepareWrite(trans);
+				SetStateDirty();
 				if (WasRemoved(trans, s))
 				{
 					CancelRemoval(trans, obj, s.Cursor());
@@ -122,7 +123,7 @@ namespace Db4objects.Db4o.Internal.Btree
 					s.MoveForward();
 				}
 				PrepareInsert(s.Cursor());
-				_keys[s.Cursor()] = NewAddPatch(trans, obj);
+				_keys[s.Cursor()] = ApplyNewAddPatch(trans, obj);
 			}
 			else
 			{
@@ -134,6 +135,7 @@ namespace Db4objects.Db4o.Internal.Btree
 					return null;
 				}
 				PrepareWrite(trans);
+				SetStateDirty();
 				_keys[s.Cursor()] = childNode._keys[0];
 				if (childNode != childNodeOrSplit)
 				{
@@ -159,7 +161,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _count >= _btree.NodeSize();
 		}
 
-		private BTreeAdd NewAddPatch(Transaction trans, object obj)
+		private BTreeAdd ApplyNewAddPatch(Transaction trans, object obj)
 		{
 			SizeIncrement(trans);
 			return new BTreeAdd(trans, obj);
@@ -182,7 +184,7 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private void SizeIncrement(Transaction trans)
 		{
-			_btree.SizeChanged(trans, 1);
+			_btree.SizeChanged(trans, this, 1);
 		}
 
 		private bool WasRemoved(Transaction trans, Searcher s)
@@ -199,7 +201,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			preparedComparison, SearchTarget target)
 		{
 			ByteArrayBuffer reader = PrepareRead(trans);
-			Searcher s = Search(preparedComparison, reader, target);
+			Searcher s = Search(trans, preparedComparison, reader, target);
 			if (!_isLeaf)
 			{
 				return Child(reader, s.Cursor()).SearchLeaf(trans, preparedComparison, target);
@@ -232,7 +234,7 @@ namespace Db4objects.Db4o.Internal.Btree
 		{
 			if (index >= 0)
 			{
-				if (!CompareEquals(preparedComparison, reader, index))
+				if (!CompareEquals(preparedComparison, trans, reader, index))
 				{
 					return null;
 				}
@@ -265,14 +267,14 @@ namespace Db4objects.Db4o.Internal.Btree
 			return CreateMatchingSearchResult(trans, reader, index);
 		}
 
-		private bool CompareEquals(IPreparedComparison preparedComparison, ByteArrayBuffer
-			 reader, int index)
+		private bool CompareEquals(IPreparedComparison preparedComparison, Transaction trans
+			, ByteArrayBuffer reader, int index)
 		{
 			if (CanWrite())
 			{
 				return CompareInWriteMode(preparedComparison, index) == 0;
 			}
-			return CompareInReadMode(preparedComparison, reader, index) == 0;
+			return CompareInReadMode(trans, preparedComparison, reader, index) == 0;
 		}
 
 		private BTreeNodeSearchResult CreateMatchingSearchResult(Transaction trans, ByteArrayBuffer
@@ -292,7 +294,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return (Db4objects.Db4o.Internal.Btree.BTreeNode)_children[index];
 			}
-			return _btree.ProduceNode(((int)_children[index]));
+			return ProduceChild(index, ((int)_children[index]));
 		}
 
 		internal Db4objects.Db4o.Internal.Btree.BTreeNode Child(ByteArrayBuffer reader, int
@@ -302,14 +304,16 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return (Db4objects.Db4o.Internal.Btree.BTreeNode)_children[index];
 			}
-			Db4objects.Db4o.Internal.Btree.BTreeNode child = _btree.ProduceNode(ChildID(reader
-				, index));
+			return ProduceChild(index, ChildID(reader, index));
+		}
+
+		private Db4objects.Db4o.Internal.Btree.BTreeNode ProduceChild(int index, int childID
+			)
+		{
+			Db4objects.Db4o.Internal.Btree.BTreeNode child = _btree.ProduceNode(childID);
 			if (_children != null)
 			{
-				if (_cached || child.CanWrite())
-				{
-					_children[index] = child;
-				}
+				_children[index] = child;
 			}
 			return child;
 		}
@@ -351,7 +355,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return ((Db4objects.Db4o.Internal.Btree.BTreeNode)_children[index]).CanWrite();
 		}
 
-		internal void Commit(Transaction trans)
+		public void Commit(Transaction trans)
 		{
 			CommitOrRollback(trans, true);
 		}
@@ -366,7 +370,6 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return;
 			}
-			_cached = false;
 			if (!_isLeaf)
 			{
 				return;
@@ -384,7 +387,8 @@ namespace Db4objects.Db4o.Internal.Btree
 				BTreePatch patch = KeyPatch(i);
 				if (patch != null)
 				{
-					key = isCommit ? patch.Commit(trans, _btree) : patch.Rollback(trans, _btree);
+					key = isCommit ? patch.Commit(trans, _btree, this) : patch.Rollback(trans, _btree
+						);
 				}
 				if (key != No4.Instance)
 				{
@@ -421,7 +425,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return false;
 			}
-			Free(trans);
+			Free((LocalTransaction)trans);
 			return true;
 		}
 
@@ -450,7 +454,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return GetID();
 		}
 
-		public override void Free(Transaction trans)
+		public override void Free(LocalTransaction trans)
 		{
 			_dead = true;
 			if (!IsRoot())
@@ -460,8 +464,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			PointPreviousTo(trans, _nextID);
 			PointNextTo(trans, _previousID);
-			base.Free(trans);
+			base.Free((LocalTransaction)trans);
 			_btree.RemoveNode(this);
+			_btree.NotifyDeleted(trans, this);
 		}
 
 		internal void HoldChildrenAsIDs()
@@ -483,6 +488,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			 child)
 		{
 			PrepareWrite(trans);
+			SetStateDirty();
 			int id = child.GetID();
 			for (int i = 0; i < _count; i++)
 			{
@@ -493,7 +499,7 @@ namespace Db4objects.Db4o.Internal.Btree
 						return;
 					}
 					Remove(i);
-					if (i <= 1)
+					if (i < 1)
 					{
 						TellParentAboutChangedKey(trans);
 					}
@@ -512,6 +518,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			 child)
 		{
 			PrepareWrite(trans);
+			SetStateDirty();
 			int id = child.GetID();
 			for (int i = 0; i < _count; i++)
 			{
@@ -556,11 +563,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			return -preparedComparison.CompareTo(Key(index));
 		}
 
-		private int CompareInReadMode(IPreparedComparison preparedComparison, ByteArrayBuffer
-			 reader, int index)
+		private int CompareInReadMode(Transaction trans, IPreparedComparison preparedComparison
+			, ByteArrayBuffer reader, int index)
 		{
 			SeekKey(reader, index);
-			return -preparedComparison.CompareTo(KeyHandler().ReadIndexEntry(reader));
+			return -preparedComparison.CompareTo(KeyHandler().ReadIndexEntry(trans.Context(), 
+				reader));
 		}
 
 		public int Count()
@@ -623,7 +631,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return No4.Instance;
 			}
-			return Key(trans, index);
+			return InternalKey(trans, index);
 		}
 
 		public override byte GetIdentifier()
@@ -674,17 +682,30 @@ namespace Db4objects.Db4o.Internal.Btree
 			return obj;
 		}
 
+		public object Key(Transaction trans, int index)
+		{
+			return Key(trans, PrepareRead(trans), index);
+		}
+
 		internal object Key(Transaction trans, ByteArrayBuffer reader, int index)
 		{
 			if (CanWrite())
 			{
-				return Key(trans, index);
+				return InternalKey(trans, index);
+			}
+			if (reader == null)
+			{
+				reader = PrepareRead(trans);
+			}
+			if (CanWrite())
+			{
+				return InternalKey(trans, index);
 			}
 			SeekKey(reader, index);
-			return KeyHandler().ReadIndexEntry(reader);
+			return KeyHandler().ReadIndexEntry(trans.Context(), reader);
 		}
 
-		internal object Key(Transaction trans, int index)
+		private object InternalKey(Transaction trans, int index)
 		{
 			BTreePatch patch = KeyPatch(index);
 			if (patch == null)
@@ -704,7 +725,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return null;
 		}
 
-		private BTreePatch KeyPatch(Transaction trans, int index)
+		internal BTreePatch KeyPatch(Transaction trans, int index)
 		{
 			object obj = _keys[index];
 			if (obj is BTreePatch)
@@ -719,29 +740,6 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _btree.KeyHandler();
 		}
 
-		internal void MarkAsCached(int height)
-		{
-			_cached = true;
-			_btree.AddNode(this);
-			if (_isLeaf || (_children == null))
-			{
-				return;
-			}
-			height--;
-			if (height < 1)
-			{
-				HoldChildrenAsIDs();
-				return;
-			}
-			for (int i = 0; i < _count; i++)
-			{
-				if (_children[i] is Db4objects.Db4o.Internal.Btree.BTreeNode)
-				{
-					((Db4objects.Db4o.Internal.Btree.BTreeNode)_children[i]).MarkAsCached(height);
-				}
-			}
-		}
-
 		public override int OwnLength()
 		{
 			return SlotLeadingLength + (_count * EntryLength()) + Const4.BracketsBytes;
@@ -749,6 +747,7 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		internal ByteArrayBuffer PrepareRead(Transaction trans)
 		{
+			BTreeNodeCacheEntry cacheEntry = Btree().CacheEntry(this);
 			if (CanWrite())
 			{
 				return null;
@@ -757,16 +756,21 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return null;
 			}
-			if (_cached)
+			Transaction systemTransaction = trans.SystemTransaction();
+			ByteArrayBuffer buffer = cacheEntry.Buffer();
+			if (buffer != null)
 			{
-				Read(trans.SystemTransaction());
+				// Cache hit, still unread
+				buffer.Seek(0);
+				Read(systemTransaction, buffer);
+				cacheEntry.Buffer(null);
 				_btree.AddToProcessing(this);
 				return null;
 			}
-			ByteArrayBuffer reader = ((LocalTransaction)trans).File().ReadReaderByID(trans.SystemTransaction
-				(), GetID());
-			ReadNodeHeader(reader);
-			return reader;
+			buffer = ProduceReadBuffer(systemTransaction);
+			ReadNodeHeader(buffer);
+			cacheEntry.Buffer(buffer);
+			return buffer;
 		}
 
 		internal void PrepareWrite(Transaction trans)
@@ -775,13 +779,22 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return;
 			}
+			BTreeNodeCacheEntry cacheEntry = Btree().CacheEntry(this);
 			if (CanWrite())
 			{
-				SetStateDirty();
 				return;
 			}
-			Read(trans.SystemTransaction());
-			SetStateDirty();
+			ByteArrayBuffer buffer = cacheEntry.Buffer();
+			if (buffer != null)
+			{
+				buffer.Seek(0);
+				Read(trans.SystemTransaction(), buffer);
+				cacheEntry.Buffer(null);
+			}
+			else
+			{
+				Read(trans.SystemTransaction());
+			}
 			_btree.AddToProcessing(this);
 		}
 
@@ -815,7 +828,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			bool isInner = !_isLeaf;
 			for (int i = 0; i < _count; i++)
 			{
-				_keys[i] = KeyHandler().ReadIndexEntry(reader);
+				_keys[i] = KeyHandler().ReadIndexEntry(trans.Context(), reader);
 				if (isInner)
 				{
 					_children[i] = reader.ReadInt();
@@ -823,21 +836,53 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		public void Remove(Transaction trans, IPreparedComparison preparedComparison, object
-			 obj, int index)
+		public void Remove(Transaction trans, int index)
 		{
 			if (!_isLeaf)
 			{
 				throw new InvalidOperationException();
 			}
 			PrepareWrite(trans);
+			SetStateDirty();
+			object obj = null;
+			BTreePatch patch = KeyPatch(index);
+			if (patch == null)
+			{
+				obj = _keys[index];
+			}
+			else
+			{
+				BTreePatch transPatch = patch.ForTransaction(trans);
+				if (transPatch != null)
+				{
+					obj = transPatch.GetObject();
+				}
+				else
+				{
+					// There could be more than one patch with different object
+					// identities. We have no means to determine a "best" object 
+					// so we just take any one. Could be problematic.
+					obj = patch.GetObject();
+				}
+			}
+			Remove(trans, obj, index);
+		}
+
+		public bool Remove(Transaction trans, object obj, int index)
+		{
+			if (!_isLeaf)
+			{
+				throw new InvalidOperationException();
+			}
+			PrepareWrite(trans);
+			SetStateDirty();
 			BTreePatch patch = KeyPatch(index);
 			// no patch, no problem, can remove
 			if (patch == null)
 			{
-				_keys[index] = NewRemovePatch(trans, obj);
+				_keys[index] = ApplyNewRemovePatch(trans, obj);
 				KeyChanged(trans, index);
-				return;
+				return true;
 			}
 			BTreePatch transPatch = patch.ForTransaction(trans);
 			if (transPatch != null)
@@ -845,14 +890,14 @@ namespace Db4objects.Db4o.Internal.Btree
 				if (transPatch.IsAdd())
 				{
 					CancelAdding(trans, index);
-					return;
+					return true;
 				}
 				if (transPatch.IsCancelledRemoval())
 				{
 					BTreeRemove removePatch = ApplyNewRemovePatch(trans, transPatch.GetObject());
 					_keys[index] = ((BTreeUpdate)patch).ReplacePatch(transPatch, removePatch);
 					KeyChanged(trans, index);
-					return;
+					return true;
 				}
 			}
 			else
@@ -861,10 +906,20 @@ namespace Db4objects.Db4o.Internal.Btree
 				// transaction, we need one for this transaction also.
 				if (!patch.IsAdd())
 				{
-					((BTreeUpdate)patch).Append(NewRemovePatch(trans, obj));
-					return;
+					((BTreeUpdate)patch).Append(ApplyNewRemovePatch(trans, obj));
+					return true;
 				}
 			}
+			return false;
+		}
+
+		public void Remove(Transaction trans, IPreparedComparison preparedComparison, object
+			 obj, int index)
+		{
+			if (Remove(trans, obj, index))
+			{
+				return;
+			}
 			// now we try if removal is OK for the next element in this node
 			if (index != LastIndex())
 			{
@@ -891,7 +946,8 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private void CancelAdding(Transaction trans, int index)
 		{
-			_btree.NotifyRemoveListener(KeyPatch(index).GetObject());
+			_btree.NotifyRemoveListener(new TransactionContext(trans, KeyPatch(index).GetObject
+				()));
 			if (FreeIfEmpty(trans, _count - 1))
 			{
 				SizeDecrement(trans);
@@ -904,7 +960,7 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private void SizeDecrement(Transaction trans)
 		{
-			_btree.SizeChanged(trans, -1);
+			_btree.SizeChanged(trans, this, -1);
 		}
 
 		private int LastIndex()
@@ -912,11 +968,6 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _count - 1;
 		}
 
-		private BTreeRemove NewRemovePatch(Transaction trans, object obj)
-		{
-			return ApplyNewRemovePatch(trans, obj);
-		}
-
 		private BTreeRemove ApplyNewRemovePatch(Transaction trans, object key)
 		{
 			SizeDecrement(trans);
@@ -936,14 +987,14 @@ namespace Db4objects.Db4o.Internal.Btree
 			CommitOrRollback(trans, false);
 		}
 
-		private Searcher Search(IPreparedComparison preparedComparison, ByteArrayBuffer reader
-			)
+		private Searcher Search(Transaction trans, IPreparedComparison preparedComparison
+			, ByteArrayBuffer reader)
 		{
-			return Search(preparedComparison, reader, SearchTarget.Any);
+			return Search(trans, preparedComparison, reader, SearchTarget.Any);
 		}
 
-		private Searcher Search(IPreparedComparison preparedComparison, ByteArrayBuffer reader
-			, SearchTarget target)
+		private Searcher Search(Transaction trans, IPreparedComparison preparedComparison
+			, ByteArrayBuffer reader, SearchTarget target)
 		{
 			Searcher s = new Searcher(target, _count);
 			if (CanWrite())
@@ -957,7 +1008,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				while (s.Incomplete())
 				{
-					s.ResultIs(CompareInReadMode(preparedComparison, reader, s.Cursor()));
+					s.ResultIs(CompareInReadMode(trans, preparedComparison, reader, s.Cursor()));
 				}
 			}
 			return s;
@@ -1016,6 +1067,7 @@ namespace Db4objects.Db4o.Internal.Btree
 					res.Child(i).SetParentID(trans, splitID);
 				}
 			}
+			_btree.NotifySplit(trans, this, res);
 			return res;
 		}
 
@@ -1120,7 +1172,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return new BTreePointer(trans, reader, this, index);
 		}
 
-		internal void Purge()
+		public void Purge()
 		{
 			if (_dead)
 			{
@@ -1128,40 +1180,52 @@ namespace Db4objects.Db4o.Internal.Btree
 				_children = null;
 				return;
 			}
-			if (_cached)
+			if (!IsPatched())
 			{
 				return;
 			}
+			HoldChildrenAsIDs();
+			_btree.AddNode(this);
+		}
+
+		private bool IsPatched()
+		{
+			if (_dead)
+			{
+				return false;
+			}
 			if (!CanWrite())
 			{
-				return;
+				return false;
 			}
 			for (int i = 0; i < _count; i++)
 			{
 				if (_keys[i] is BTreePatch)
 				{
-					HoldChildrenAsIDs();
-					_btree.AddNode(this);
-					return;
+					return true;
 				}
 			}
+			return false;
 		}
 
 		private void SetParentID(Transaction trans, int id)
 		{
 			PrepareWrite(trans);
+			SetStateDirty();
 			_parentID = id;
 		}
 
 		private void SetPreviousID(Transaction trans, int id)
 		{
 			PrepareWrite(trans);
+			SetStateDirty();
 			_previousID = id;
 		}
 
 		private void SetNextID(Transaction trans, int id)
 		{
 			PrepareWrite(trans);
+			SetStateDirty();
 			_nextID = id;
 		}
 
@@ -1201,20 +1265,21 @@ namespace Db4objects.Db4o.Internal.Btree
 			return base.WriteObjectBegin();
 		}
 
-		public override void WriteThis(Transaction trans, ByteArrayBuffer a_writer)
+		public override void WriteThis(Transaction trans, ByteArrayBuffer buffer)
 		{
 			int count = 0;
-			int startOffset = a_writer._offset;
-			a_writer.IncrementOffset(CountLeafAnd3LinkLength);
+			int startOffset = buffer._offset;
+			IContext context = trans.Context();
+			buffer.IncrementOffset(CountLeafAnd3LinkLength);
 			if (_isLeaf)
 			{
 				for (int i = 0; i < _count; i++)
 				{
-					object obj = Key(trans, i);
+					object obj = InternalKey(trans, i);
 					if (obj != No4.Instance)
 					{
 						count++;
-						KeyHandler().WriteIndexEntry(a_writer, obj);
+						KeyHandler().WriteIndexEntry(context, buffer, obj);
 					}
 				}
 			}
@@ -1230,26 +1295,26 @@ namespace Db4objects.Db4o.Internal.Btree
 						if (childKey != No4.Instance)
 						{
 							count++;
-							KeyHandler().WriteIndexEntry(a_writer, childKey);
-							a_writer.WriteIDOf(trans, child);
+							KeyHandler().WriteIndexEntry(context, buffer, childKey);
+							buffer.WriteIDOf(trans, child);
 						}
 					}
 					else
 					{
 						count++;
-						KeyHandler().WriteIndexEntry(a_writer, Key(i));
-						a_writer.WriteIDOf(trans, _children[i]);
+						KeyHandler().WriteIndexEntry(context, buffer, Key(i));
+						buffer.WriteIDOf(trans, _children[i]);
 					}
 				}
 			}
-			int endOffset = a_writer._offset;
-			a_writer._offset = startOffset;
-			a_writer.WriteInt(count);
-			a_writer.WriteByte(_isLeaf ? (byte)1 : (byte)0);
-			a_writer.WriteInt(_parentID);
-			a_writer.WriteInt(_previousID);
-			a_writer.WriteInt(_nextID);
-			a_writer._offset = endOffset;
+			int endOffset = buffer._offset;
+			buffer._offset = startOffset;
+			buffer.WriteInt(count);
+			buffer.WriteByte(_isLeaf ? (byte)1 : (byte)0);
+			buffer.WriteInt(_parentID);
+			buffer.WriteInt(_previousID);
+			buffer.WriteInt(_nextID);
+			buffer._offset = endOffset;
 		}
 
 		public override string ToString()
@@ -1327,11 +1392,6 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		public override bool IsFreespaceComponent()
-		{
-			return _btree.IsFreespaceComponent();
-		}
-
 		public bool IsLeaf()
 		{
 			return _isLeaf;
@@ -1351,5 +1411,61 @@ namespace Db4objects.Db4o.Internal.Btree
 				Child(reader, childIdx).TraverseAllNodes(trans, command);
 			}
 		}
+
+		public int Size(Transaction trans)
+		{
+			PrepareRead(trans);
+			if (!CanWrite())
+			{
+				return _count;
+			}
+			int size = 0;
+			for (int i = 0; i < _count; i++)
+			{
+				BTreePatch keyPatch = KeyPatch(i);
+				if (keyPatch != null)
+				{
+					size += keyPatch.SizeDiff(trans);
+				}
+				else
+				{
+					size++;
+				}
+			}
+			return size;
+		}
+
+		public override Db4objects.Db4o.Internal.Slots.SlotChangeFactory SlotChangeFactory
+			()
+		{
+			return _btree.SlotChangeFactory();
+		}
+
+		public override ITransactionalIdSystem IdSystem(Transaction trans)
+		{
+			return _btree.IdSystem(trans);
+		}
+
+		public void ToReadMode()
+		{
+			if (IsNew())
+			{
+				return;
+			}
+			if (!CanWrite())
+			{
+				return;
+			}
+			if (IsDirty())
+			{
+				return;
+			}
+			if (IsPatched())
+			{
+				return;
+			}
+			_keys = null;
+			_children = null;
+		}
 	}
 }
