@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,10 +13,12 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
 using System.Collections;
 using Db4objects.Db4o.Ext;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Metadata;
 using Db4objects.Db4o.Reflect;
 
 namespace Db4objects.Db4o.Internal
@@ -44,7 +46,7 @@ namespace Db4objects.Db4o.Internal
 
 		private readonly PendingClassInits _classInits;
 
-		internal ClassMetadataRepository(Transaction systemTransaction)
+		public ClassMetadataRepository(Transaction systemTransaction)
 		{
 			_systemTransaction = systemTransaction;
 			_initClassMetadataOnUp = new NonblockingQueue();
@@ -63,6 +65,11 @@ namespace Db4objects.Db4o.Internal
 			{
 				_classMetadataByClass.Put(clazz.ClassReflector(), clazz);
 			}
+			RegisterClassMetadataById(clazz);
+		}
+
+		private void RegisterClassMetadataById(ClassMetadata clazz)
+		{
 			if (clazz.GetID() == 0)
 			{
 				clazz.Write(_systemTransaction);
@@ -83,25 +90,24 @@ namespace Db4objects.Db4o.Internal
 				ClassMetadata classMetadata = i.CurrentClass();
 				if (!classMetadata.IsInternal())
 				{
-					classMetadata.ForEachField(new _IProcedure4_60(fieldName, visitor, classMetadata)
-						);
+					classMetadata.TraverseAllAspects(new _TraverseFieldCommand_65(fieldName, visitor, 
+						classMetadata));
 				}
 			}
 		}
 
-		private sealed class _IProcedure4_60 : IProcedure4
+		private sealed class _TraverseFieldCommand_65 : TraverseFieldCommand
 		{
-			public _IProcedure4_60(string fieldName, IVisitor4 visitor, ClassMetadata classMetadata
-				)
+			public _TraverseFieldCommand_65(string fieldName, IVisitor4 visitor, ClassMetadata
+				 classMetadata)
 			{
 				this.fieldName = fieldName;
 				this.visitor = visitor;
 				this.classMetadata = classMetadata;
 			}
 
-			public void Apply(object obj)
+			protected override void Process(FieldMetadata field)
 			{
-				FieldMetadata field = (FieldMetadata)obj;
 				if (field.CanAddToQuery(fieldName))
 				{
 					visitor.Visit(new object[] { classMetadata, field });
@@ -143,18 +149,25 @@ namespace Db4objects.Db4o.Internal
 		internal bool CreateClassMetadata(ClassMetadata clazz, IReflectClass reflectClazz
 			)
 		{
+			bool result = false;
 			_classMetadataCreationDepth++;
-			IReflectClass parentReflectClazz = reflectClazz.GetSuperclass();
-			ClassMetadata parentClazz = null;
-			if (parentReflectClazz != null && !parentReflectClazz.Equals(Container()._handlers
-				.IclassObject))
+			try
 			{
-				parentClazz = ProduceClassMetadata(parentReflectClazz);
+				IReflectClass parentReflectClazz = reflectClazz.GetSuperclass();
+				ClassMetadata parentClazz = null;
+				if (parentReflectClazz != null && !parentReflectClazz.Equals(Container()._handlers
+					.IclassObject))
+				{
+					parentClazz = ProduceClassMetadata(parentReflectClazz);
+				}
+				result = Container().CreateClassMetadata(clazz, reflectClazz, parentClazz);
+			}
+			finally
+			{
+				_classMetadataCreationDepth--;
 			}
-			bool ret = Container().CreateClassMetadata(clazz, reflectClazz, parentClazz);
-			_classMetadataCreationDepth--;
 			InitClassMetadataOnUp();
-			return ret;
+			return result;
 		}
 
 		private void EnsureAllClassesRead()
@@ -252,13 +265,22 @@ namespace Db4objects.Db4o.Internal
 
 		internal ClassMetadata ClassMetadataForReflectClass(IReflectClass reflectClazz)
 		{
-			ClassMetadata clazz = (ClassMetadata)_classMetadataByClass.Get(reflectClazz);
-			if (clazz != null)
+			ClassMetadata cached = (ClassMetadata)_classMetadataByClass.Get(reflectClazz);
+			if (cached != null)
 			{
-				return clazz;
+				return cached;
+			}
+			return ReadClassMetadata(reflectClazz);
+		}
+
+		private ClassMetadata ReadClassMetadata(IReflectClass reflectClazz)
+		{
+			ClassMetadata clazz = (ClassMetadata)_classMetadataByBytes.Remove(GetNameBytes(reflectClazz
+				.GetName()));
+			if (clazz == null)
+			{
+				return null;
 			}
-			clazz = (ClassMetadata)_classMetadataByBytes.Remove(GetNameBytes(reflectClazz.GetName
-				()));
 			return ReadClassMetadata(clazz, reflectClazz);
 		}
 
@@ -269,49 +291,56 @@ namespace Db4objects.Db4o.Internal
 			{
 				return classMetadata;
 			}
-			classMetadata = (ClassMetadata)_creating.Get(reflectClazz);
-			if (classMetadata != null)
+			ClassMetadata classBeingCreated = (ClassMetadata)_creating.Get(reflectClazz);
+			if (classBeingCreated != null)
 			{
-				return classMetadata;
+				return classBeingCreated;
 			}
-			classMetadata = new ClassMetadata(Container(), reflectClazz);
-			_creating.Put(reflectClazz, classMetadata);
-			if (!CreateClassMetadata(classMetadata, reflectClazz))
+			ClassMetadata newClassMetadata = new ClassMetadata(Container(), reflectClazz);
+			_creating.Put(reflectClazz, newClassMetadata);
+			try
+			{
+				if (!CreateClassMetadata(newClassMetadata, reflectClazz))
+				{
+					return null;
+				}
+				// ObjectContainerBase#createClassMetadata may add the ClassMetadata already,
+				// so we have to check again
+				if (!IsRegistered(reflectClazz))
+				{
+					AddClassMetadata(newClassMetadata);
+					_classInits.Process(newClassMetadata);
+				}
+				else
+				{
+					RegisterClassMetadataById(newClassMetadata);
+					if (newClassMetadata.AspectsAreNull())
+					{
+						_classInits.Process(newClassMetadata);
+					}
+				}
+				Container().SetDirtyInSystemTransaction(this);
+			}
+			finally
 			{
 				_creating.Remove(reflectClazz);
-				return null;
 			}
-			// ObjectContainerBase#createClassMetadata may add the ClassMetadata already,
-			// so we have to check again
-			bool addMembers = false;
-			if (_classMetadataByClass.Get(reflectClazz) == null)
-			{
-				AddClassMetadata(classMetadata);
-				addMembers = true;
-			}
-			int id = classMetadata.GetID();
-			if (id == 0)
-			{
-				classMetadata.Write(Container().SystemTransaction());
-				id = classMetadata.GetID();
-			}
-			if (_classMetadataByID.Get(id) == null)
-			{
-				_classMetadataByID.Put(id, classMetadata);
-				addMembers = true;
-			}
-			if (addMembers || classMetadata.AspectsAreNull())
-			{
-				_classInits.Process(classMetadata);
-			}
-			_creating.Remove(reflectClazz);
-			Container().SetDirtyInSystemTransaction(this);
-			return classMetadata;
+			return newClassMetadata;
 		}
 
-		internal ClassMetadata GetClassMetadata(int id)
+		private bool IsRegistered(IReflectClass reflectClazz)
 		{
-			return ReadClassMetadata((ClassMetadata)_classMetadataByID.Get(id), null);
+			return _classMetadataByClass.Get(reflectClazz) != null;
+		}
+
+		internal ClassMetadata ClassMetadataForId(int id)
+		{
+			ClassMetadata classMetadata = (ClassMetadata)_classMetadataByID.Get(id);
+			if (null == classMetadata)
+			{
+				return null;
+			}
+			return ReadClassMetadata(classMetadata, null);
 		}
 
 		public int ClassMetadataIdForName(string name)
@@ -382,10 +411,10 @@ namespace Db4objects.Db4o.Internal
 
 		private string ResolveAliasRuntimeName(string name)
 		{
-			return Container().ConfigImpl().ResolveAliasRuntimeName(name);
+			return Container().ConfigImpl.ResolveAliasRuntimeName(name);
 		}
 
-		internal void InitOnUp(Transaction systemTrans)
+		public void InitOnUp(Transaction systemTrans)
 		{
 			_classMetadataCreationDepth++;
 			systemTrans.Container().ShowInternalClasses(true);
@@ -400,8 +429,8 @@ namespace Db4objects.Db4o.Internal
 			finally
 			{
 				systemTrans.Container().ShowInternalClasses(false);
+				_classMetadataCreationDepth--;
 			}
-			_classMetadataCreationDepth--;
 			InitClassMetadataOnUp();
 		}
 
@@ -421,14 +450,15 @@ namespace Db4objects.Db4o.Internal
 
 		private void InitClassMetadataOnUp()
 		{
-			if (_classMetadataCreationDepth == 0)
+			if (_classMetadataCreationDepth != 0)
 			{
-				ClassMetadata clazz = (ClassMetadata)_initClassMetadataOnUp.Next();
-				while (clazz != null)
-				{
-					clazz.InitOnUp(_systemTransaction);
-					clazz = (ClassMetadata)_initClassMetadataOnUp.Next();
-				}
+				return;
+			}
+			ClassMetadata clazz = (ClassMetadata)_initClassMetadataOnUp.Next();
+			while (clazz != null)
+			{
+				clazz.InitOnUp(_systemTransaction);
+				clazz = (ClassMetadata)_initClassMetadataOnUp.Next();
 			}
 		}
 
@@ -474,19 +504,15 @@ namespace Db4objects.Db4o.Internal
 			int classCount = buffer.ReadInt();
 			InitTables(classCount);
 			ObjectContainerBase container = Container();
-			int[] ids = new int[classCount];
-			for (int i = 0; i < classCount; ++i)
-			{
-				ids[i] = buffer.ReadInt();
-			}
-			StatefulBuffer[] clazzWriters = container.ReadWritersByIDs(trans, ids);
+			int[] ids = ReadMetadataIds(buffer, classCount);
+			ByteArrayBuffer[] metadataSlots = container.ReadSlotBuffers(trans, ids);
 			for (int i = 0; i < classCount; ++i)
 			{
 				ClassMetadata classMetadata = new ClassMetadata(container, null);
 				classMetadata.SetID(ids[i]);
 				_classes.Add(classMetadata);
 				_classMetadataByID.Put(ids[i], classMetadata);
-				byte[] name = classMetadata.ReadName1(trans, clazzWriters[i]);
+				byte[] name = classMetadata.ReadName1(trans, metadataSlots[i]);
 				if (name != null)
 				{
 					_classMetadataByBytes.Put(name, classMetadata);
@@ -495,6 +521,16 @@ namespace Db4objects.Db4o.Internal
 			ApplyReadAs();
 		}
 
+		private int[] ReadMetadataIds(ByteArrayBuffer buffer, int classCount)
+		{
+			int[] ids = new int[classCount];
+			for (int i = 0; i < classCount; ++i)
+			{
+				ids[i] = buffer.ReadInt();
+			}
+			return ids;
+		}
+
 		internal Hashtable4 ClassByBytes()
 		{
 			return _classMetadataByBytes;
@@ -502,7 +538,7 @@ namespace Db4objects.Db4o.Internal
 
 		private void ApplyReadAs()
 		{
-			Hashtable4 readAs = Container().ConfigImpl().ReadAs();
+			Hashtable4 readAs = Container().ConfigImpl.ReadAs();
 			IEnumerator i = readAs.Iterator();
 			while (i.MoveNext())
 			{
@@ -527,7 +563,7 @@ namespace Db4objects.Db4o.Internal
 
 		private Config4Class ConfigClass(string name)
 		{
-			return Container().ConfigImpl().ConfigClass(name);
+			return Container().ConfigImpl.ConfigClass(name);
 		}
 
 		public ClassMetadata ReadClassMetadata(ClassMetadata classMetadata, IReflectClass
@@ -535,28 +571,43 @@ namespace Db4objects.Db4o.Internal
 		{
 			if (classMetadata == null)
 			{
-				return null;
+				throw new ArgumentNullException();
 			}
 			if (!classMetadata.StateUnread())
 			{
 				return classMetadata;
 			}
 			_classMetadataCreationDepth++;
-			string name = classMetadata.ResolveName(clazz);
-			classMetadata.CreateConfigAndConstructor(_classMetadataByBytes, clazz, name);
-			IReflectClass claxx = classMetadata.ClassReflector();
-			if (claxx != null)
+			try
 			{
-				_classMetadataByClass.Put(claxx, classMetadata);
-				classMetadata.ReadThis();
-				classMetadata.CheckChanges();
-				_initClassMetadataOnUp.Add(classMetadata);
+				classMetadata.CreateConfigAndConstructor(_classMetadataByBytes, clazz);
+				IReflectClass claxx = classMetadata.ClassReflector();
+				if (claxx != null)
+				{
+					_classMetadataByClass.Put(claxx, classMetadata);
+					classMetadata.ReadThis();
+					classMetadata.CheckChanges();
+					_initClassMetadataOnUp.Add(classMetadata);
+				}
+			}
+			finally
+			{
+				_classMetadataCreationDepth--;
 			}
-			_classMetadataCreationDepth--;
 			InitClassMetadataOnUp();
 			return classMetadata;
 		}
 
+		public void CheckAllClassChanges()
+		{
+			IEnumerator i = _classMetadataByID.Keys();
+			while (i.MoveNext())
+			{
+				int classMetadataID = ((int)i.Current);
+				ClassMetadataForId(classMetadataID);
+			}
+		}
+
 		public void RefreshClasses()
 		{
 			ClassMetadataRepository rereader = new ClassMetadataRepository(_systemTransaction
@@ -577,17 +628,7 @@ namespace Db4objects.Db4o.Internal
 			}
 		}
 
-		public void CheckAllClassChanges()
-		{
-			IEnumerator i = _classMetadataByID.Keys();
-			while (i.MoveNext())
-			{
-				int classMetadataID = ((int)i.Current);
-				GetClassMetadata(classMetadataID);
-			}
-		}
-
-		public void RefreshClass(ClassMetadata clazz)
+		private void RefreshClass(ClassMetadata clazz)
 		{
 			if (_classMetadataByID.Get(clazz.GetID()) == null)
 			{
@@ -617,7 +658,7 @@ namespace Db4objects.Db4o.Internal
 		{
 			if (clazz != null)
 			{
-				ReReadClassMetadata(clazz.i_ancestor);
+				ReReadClassMetadata(clazz._ancestor);
 				clazz.ReadName(_systemTransaction);
 				clazz.ForceRead();
 				clazz.SetStateClean();
@@ -692,7 +733,7 @@ namespace Db4objects.Db4o.Internal
 
 		public override void SetID(int id)
 		{
-			if (Container().IsClient())
+			if (Container().IsClient)
 			{
 				base.SetID(id);
 				return;
@@ -706,7 +747,7 @@ namespace Db4objects.Db4o.Internal
 
 		private SystemData SystemData()
 		{
-			return LocalSystemTransaction().File().SystemData();
+			return LocalSystemTransaction().LocalContainer().SystemData();
 		}
 
 		private LocalTransaction LocalSystemTransaction()
