@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,6 +14,7 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
 using Db4objects.Db4o.Internal.Freespace;
 using Db4objects.Db4o.Internal.Slots;
 
@@ -34,24 +35,32 @@ namespace Db4objects.Db4o.Internal.Freespace
 
 		int TotalFreespace();
 
-		Slot GetSlot(int length);
+		Slot AllocateTransactionLogSlot(int length);
+
+		Slot AllocateSlot(int length);
 
 		void MigrateTo(IFreespaceManager fm);
 
-		void Read(int freeSpaceID);
+		void Read(LocalObjectContainer container, Slot slot);
 
-		void Start(int slotAddress);
+		void Start(int id);
 
 		byte SystemType();
 
 		void Traverse(IVisitor4 visitor);
 
-		int Write();
+		void Write(LocalObjectContainer container);
 
 		void Commit();
 
-		Slot AllocateTransactionLogSlot(int length);
+		Slot AllocateSafeSlot(int length);
 
-		void FreeTransactionLogSlot(Slot slot);
+		void FreeSafeSlot(Slot slot);
+
+		void Listener(IFreespaceListener listener);
+
+		void SlotFreed(Slot slot);
+
+		bool IsStarted();
 	}
 }
