@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -13,12 +13,13 @@ for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Internal;
-using Db4objects.Db4o.Internal.Diagnostic;
-using Db4objects.Db4o.Internal.Fieldhandlers;
+using Db4objects.Db4o.Internal.Encoding;
 using Db4objects.Db4o.Internal.Handlers;
 using Db4objects.Db4o.Internal.Handlers.Array;
+using Db4objects.Db4o.Internal.Handlers.Versions;
 using Db4objects.Db4o.Internal.Marshall;
 using Db4objects.Db4o.Internal.Replication;
 using Db4objects.Db4o.Reflect;
@@ -30,54 +31,44 @@ namespace Db4objects.Db4o.Internal
 	/// <exclude>
 	/// TODO: This class was written to make ObjectContainerBase
 	/// leaner, so TransportObjectContainer has less members.
-	/// All funcionality of this class should become part of
+	/// All functionality of this class should become part of
 	/// ObjectContainerBase and the functionality in
-	/// ObjectContainerBase should delegate to independant
+	/// ObjectContainerBase should delegate to independent
 	/// modules without circular references.
 	/// </exclude>
 	public sealed class HandlerRegistry
 	{
-		public const byte HandlerVersion = (byte)3;
+		public const byte HandlerVersion = (byte)10;
 
 		private readonly ObjectContainerBase _container;
 
 		private static readonly IDb4oTypeImpl[] _db4oTypes = new IDb4oTypeImpl[] { new BlobImpl
 			() };
 
-		private ClassMetadata _untypedArrayHandler;
+		private ITypeHandler4 _openArrayHandler;
 
-		private ClassMetadata _untypedMultiDimensionalArrayHandler;
+		private ITypeHandler4 _openMultiDimensionalArrayHandler;
 
-		private IFieldHandler _untypedFieldHandler;
+		private ITypeHandler4 _openTypeHandler;
 
 		public StringHandler _stringHandler;
 
 		private Hashtable4 _mapIdToTypeInfo = NewHashtable();
 
-		private Hashtable4 _mapFieldHandlerToId = NewHashtable();
-
-		private Hashtable4 _mapTypeHandlerToId = NewHashtable();
-
 		private Hashtable4 _mapReflectorToClassMetadata = NewHashtable();
 
 		private int _highestBuiltinTypeID = Handlers4.AnyArrayNId + 1;
 
 		private readonly VirtualFieldMetadata[] _virtualFields = new VirtualFieldMetadata
-			[2];
-
-		private readonly Hashtable4 _mapReflectorToFieldHandler = NewHashtable();
+			[3];
 
 		private readonly Hashtable4 _mapReflectorToTypeHandler = NewHashtable();
 
-		private readonly Hashtable4 _mapFieldHandlerToReflector = NewHashtable();
-
 		private SharedIndexedFields _indexes;
 
-		internal Db4objects.Db4o.Internal.Replication.MigrationConnection i_migration;
-
 		internal IDb4oReplicationReferenceProvider _replicationReferenceProvider;
 
-		public readonly DiagnosticProcessor _diagnosticProcessor;
+		private readonly Db4objects.Db4o.Internal.Diagnostic.DiagnosticProcessor _diagnosticProcessor;
 
 		public bool i_encrypt;
 
@@ -111,22 +102,27 @@ namespace Db4objects.Db4o.Internal
 
 		internal IReflectClass IclassTransientclass;
 
+		private PrimitiveTypeMetadata _untypedArrayMetadata;
+
+		private PrimitiveTypeMetadata _untypedMultiDimensionalMetadata;
+
 		internal HandlerRegistry(ObjectContainerBase container, byte stringEncoding, GenericReflector
 			 reflector)
 		{
 			// this is the master container and not valid
 			// for TransportObjectContainer
-			// see comment in classReflectorForHandler
 			_handlerVersions = new HandlerVersionRegistry(this);
-			_stringIO = LatinStringIO.ForEncoding(stringEncoding);
+			_stringIO = BuiltInStringEncoding.StringIoForEncoding(stringEncoding, container.ConfigImpl
+				.StringEncoding());
 			_container = container;
 			container._handlers = this;
 			_reflector = reflector;
-			_diagnosticProcessor = container.ConfigImpl().DiagnosticProcessor();
+			_diagnosticProcessor = container.ConfigImpl.DiagnosticProcessor();
 			InitClassReflectors(reflector);
 			_indexes = new SharedIndexedFields();
 			_virtualFields[0] = _indexes._version;
 			_virtualFields[1] = _indexes._uUID;
+			_virtualFields[2] = _indexes._commitTimestamp;
 			RegisterBuiltinHandlers();
 			RegisterPlatformTypes();
 			InitArrayHandlers();
@@ -135,16 +131,16 @@ namespace Db4objects.Db4o.Internal
 
 		private void InitArrayHandlers()
 		{
-			ITypeHandler4 handler = (ITypeHandler4)FieldHandlerForId(Handlers4.UntypedId);
-			_untypedArrayHandler = new PrimitiveFieldHandler(Container(), new ArrayHandler(handler
+			ITypeHandler4 elementHandler = OpenTypeHandler();
+			_untypedArrayMetadata = new PrimitiveTypeMetadata(Container(), new ArrayHandler(elementHandler
 				, false), Handlers4.AnyArrayId, IclassObject);
-			MapTypeInfo(Handlers4.AnyArrayId, _untypedArrayHandler, new UntypedArrayFieldHandler
-				(), _untypedArrayHandler, null);
-			_untypedMultiDimensionalArrayHandler = new PrimitiveFieldHandler(Container(), new 
-				MultidimensionalArrayHandler(handler, false), Handlers4.AnyArrayNId, IclassObject
+			_openArrayHandler = _untypedArrayMetadata.TypeHandler();
+			MapTypeInfo(Handlers4.AnyArrayId, _untypedArrayMetadata, null);
+			_untypedMultiDimensionalMetadata = new PrimitiveTypeMetadata(Container(), new MultidimensionalArrayHandler
+				(elementHandler, false), Handlers4.AnyArrayNId, IclassObject);
+			_openMultiDimensionalArrayHandler = _untypedMultiDimensionalMetadata.TypeHandler(
 				);
-			MapTypeInfo(Handlers4.AnyArrayNId, _untypedMultiDimensionalArrayHandler, new UntypedMultidimensionalArrayFieldHandler
-				(), _untypedMultiDimensionalArrayHandler, null);
+			MapTypeInfo(Handlers4.AnyArrayNId, _untypedMultiDimensionalMetadata, null);
 		}
 
 		private void RegisterPlatformTypes()
@@ -203,38 +199,32 @@ namespace Db4objects.Db4o.Internal
 
 		private void RegisterUntypedHandlers()
 		{
-			int id = Handlers4.UntypedId;
-			_untypedFieldHandler = new Db4objects.Db4o.Internal.UntypedFieldHandler(Container
-				());
-			PrimitiveFieldHandler classMetadata = new PrimitiveFieldHandler(Container(), (ITypeHandler4
-				)_untypedFieldHandler, id, IclassObject);
-			Map(id, classMetadata, _untypedFieldHandler, new PlainObjectHandler(), IclassObject
-				);
-			RegisterHandlerVersion(_untypedFieldHandler, 0, new UntypedFieldHandler0(Container
-				()));
-			RegisterHandlerVersion(_untypedFieldHandler, 2, new UntypedFieldHandler2(Container
-				()));
+			_openTypeHandler = new Db4objects.Db4o.Internal.OpenTypeHandler(Container());
+			PrimitiveTypeMetadata classMetadata = new ObjectTypeMetadata(Container(), _openTypeHandler
+				, Handlers4.UntypedId, IclassObject);
+			Map(Handlers4.UntypedId, classMetadata, IclassObject);
+			RegisterHandlerVersion(_openTypeHandler, 0, new OpenTypeHandler0(Container()));
+			RegisterHandlerVersion(_openTypeHandler, 2, new OpenTypeHandler2(Container()));
+			RegisterHandlerVersion(_openTypeHandler, 7, new OpenTypeHandler7(Container()));
 		}
 
 		private void RegisterCompositeHandlerVersions()
 		{
-			FirstClassObjectHandler firstClassObjectHandler = new FirstClassObjectHandler();
-			RegisterHandlerVersion(firstClassObjectHandler, 0, new FirstClassObjectHandler0()
-				);
+			RegisterHandlerVersion(new StandardReferenceTypeHandler(), 0, new StandardReferenceTypeHandler0
+				());
 			ArrayHandler arrayHandler = new ArrayHandler();
 			RegisterHandlerVersion(arrayHandler, 0, new ArrayHandler0());
-			RegisterHandlerVersion(arrayHandler, 2, new ArrayHandler2());
+			RegisterHandlerVersion(arrayHandler, 1, new ArrayHandler1());
+			RegisterHandlerVersion(arrayHandler, 3, new ArrayHandler3());
+			RegisterHandlerVersion(arrayHandler, 5, new ArrayHandler5());
 			MultidimensionalArrayHandler multidimensionalArrayHandler = new MultidimensionalArrayHandler
 				();
 			RegisterHandlerVersion(multidimensionalArrayHandler, 0, new MultidimensionalArrayHandler0
 				());
-			PrimitiveFieldHandler primitiveFieldHandler = new PrimitiveFieldHandler();
-			RegisterHandlerVersion(primitiveFieldHandler, 0, primitiveFieldHandler);
-			// same handler, but making sure versions get cascaded
-			RegisterHandlerVersion(primitiveFieldHandler, 2, primitiveFieldHandler);
+			RegisterHandlerVersion(multidimensionalArrayHandler, 3, new MultidimensionalArrayHandler3
+				());
 		}
 
-		// same handler, but making sure versions get cascaded
 		private void RegisterBuiltinHandler(int id, IBuiltinTypeHandler handler)
 		{
 			RegisterBuiltinHandler(id, handler, true, null, null);
@@ -253,67 +243,56 @@ namespace Db4objects.Db4o.Internal
 				_reflector.RegisterPrimitiveClass(id, primitiveName, converter);
 			}
 			IReflectClass classReflector = typeHandler.ClassReflector();
-			PrimitiveFieldHandler classMetadata = new PrimitiveFieldHandler(Container(), typeHandler
+			PrimitiveTypeMetadata classMetadata = new PrimitiveTypeMetadata(Container(), typeHandler
 				, id, classReflector);
-			Map(id, classMetadata, typeHandler, typeHandler, classReflector);
-			if (NullableArrayHandling.UseJavaHandling())
+			Map(id, classMetadata, classReflector);
+			if (typeHandler is PrimitiveHandler)
 			{
-				if (typeHandler is PrimitiveHandler)
+				IReflectClass primitiveClassReflector = ((PrimitiveHandler)typeHandler).PrimitiveClassReflector
+					();
+				if (primitiveClassReflector != null)
 				{
-					IReflectClass primitiveClassReflector = ((PrimitiveHandler)typeHandler).PrimitiveClassReflector
-						();
-					if (primitiveClassReflector != null)
-					{
-						MapPrimitive(0, classMetadata, typeHandler, typeHandler, primitiveClassReflector);
-					}
+					MapPrimitive(0, classMetadata, primitiveClassReflector);
 				}
 			}
 		}
 
-		private void Map(int id, ClassMetadata classMetadata, IFieldHandler fieldHandler, 
-			ITypeHandler4 typeHandler, IReflectClass classReflector)
+		private void Map(int id, PrimitiveTypeMetadata classMetadata, IReflectClass classReflector
+			)
 		{
 			// TODO: remove when _mapIdToClassMetadata is gone 
-			MapTypeInfo(id, classMetadata, fieldHandler, typeHandler, classReflector);
-			MapPrimitive(id, classMetadata, fieldHandler, typeHandler, classReflector);
+			MapTypeInfo(id, classMetadata, classReflector);
+			MapPrimitive(id, classMetadata, classReflector);
 			if (id > _highestBuiltinTypeID)
 			{
 				_highestBuiltinTypeID = id;
 			}
 		}
 
-		private void MapTypeInfo(int id, ClassMetadata classMetadata, IFieldHandler fieldHandler
-			, ITypeHandler4 typeHandler, IReflectClass classReflector)
+		private void MapTypeInfo(int id, ClassMetadata classMetadata, IReflectClass classReflector
+			)
 		{
-			_mapIdToTypeInfo.Put(id, new TypeInfo(classMetadata, fieldHandler, typeHandler, classReflector
+			_mapIdToTypeInfo.Put(id, new HandlerRegistry.TypeInfo(classMetadata, classReflector
 				));
 		}
 
-		private void MapPrimitive(int id, ClassMetadata classMetadata, IFieldHandler fieldHandler
-			, ITypeHandler4 typeHandler, IReflectClass classReflector)
+		private void MapPrimitive(int id, ClassMetadata classMetadata, IReflectClass classReflector
+			)
 		{
-			_mapFieldHandlerToReflector.Put(fieldHandler, classReflector);
-			MapFieldHandler(classReflector, fieldHandler);
-			_mapReflectorToTypeHandler.Put(classReflector, typeHandler);
+			MapClassToTypeHandler(classReflector, classMetadata.TypeHandler());
 			if (classReflector != null)
 			{
 				_mapReflectorToClassMetadata.Put(classReflector, classMetadata);
 			}
-			if (id != 0)
-			{
-				int wrappedID = id;
-				_mapFieldHandlerToId.Put(fieldHandler, wrappedID);
-				_mapTypeHandlerToId.Put(typeHandler, wrappedID);
-			}
 		}
 
-		public void MapFieldHandler(IReflectClass classReflector, IFieldHandler fieldHandler
+		private void MapClassToTypeHandler(IReflectClass classReflector, ITypeHandler4 typeHandler
 			)
 		{
-			_mapReflectorToFieldHandler.Put(classReflector, fieldHandler);
+			_mapReflectorToTypeHandler.Put(classReflector, typeHandler);
 		}
 
-		private void RegisterHandlerVersion(IFieldHandler handler, int version, ITypeHandler4
+		public void RegisterHandlerVersion(ITypeHandler4 handler, int version, ITypeHandler4
 			 replacement)
 		{
 			if (replacement is IBuiltinTypeHandler)
@@ -328,18 +307,44 @@ namespace Db4objects.Db4o.Internal
 			return _handlerVersions.CorrectHandlerVersion(handler, version);
 		}
 
-		internal int ArrayType(object obj)
+		public static ITypeHandler4 CorrectHandlerVersion(IHandlerVersionContext context, 
+			ITypeHandler4 typeHandler, ClassMetadata classMetadata)
+		{
+			ITypeHandler4 correctHandlerVersion = CorrectHandlerVersion(context, typeHandler);
+			if (typeHandler != correctHandlerVersion)
+			{
+				CorrectClassMetadataOn(correctHandlerVersion, classMetadata);
+				if (correctHandlerVersion is ArrayHandler)
+				{
+					ArrayHandler arrayHandler = (ArrayHandler)correctHandlerVersion;
+					CorrectClassMetadataOn(arrayHandler.DelegateTypeHandler(), classMetadata);
+				}
+			}
+			return correctHandlerVersion;
+		}
+
+		private static void CorrectClassMetadataOn(ITypeHandler4 typeHandler, ClassMetadata
+			 classMetadata)
+		{
+			if (typeHandler is StandardReferenceTypeHandler)
+			{
+				StandardReferenceTypeHandler handler = (StandardReferenceTypeHandler)typeHandler;
+				handler.ClassMetadata(classMetadata);
+			}
+		}
+
+		internal Db4objects.Db4o.Internal.ArrayType ArrayType(object obj)
 		{
 			IReflectClass claxx = Reflector().ForObject(obj);
 			if (!claxx.IsArray())
 			{
-				return 0;
+				return Db4objects.Db4o.Internal.ArrayType.None;
 			}
-			if (Reflector().Array().IsNDimensional(claxx))
+			if (IsNDimensional(claxx))
 			{
-				return Const4.TypeNarray;
+				return Db4objects.Db4o.Internal.ArrayType.MultidimensionalArray;
 			}
-			return Const4.TypeArray;
+			return Db4objects.Db4o.Internal.ArrayType.PlainArray;
 		}
 
 		public void Decrypt(ByteArrayBuffer reader)
@@ -389,12 +394,12 @@ namespace Db4objects.Db4o.Internal
 			i_encrypt = false;
 			i_encryptor = null;
 			i_lastEncryptorByte = 0;
-			Container().ConfigImpl().OldEncryptionOff();
+			Container().ConfigImpl.OldEncryptionOff();
 		}
 
 		public IReflectClass ClassForID(int id)
 		{
-			TypeInfo typeInfo = TypeInfoForID(id);
+			HandlerRegistry.TypeInfo typeInfo = TypeInfoForID(id);
 			if (typeInfo == null)
 			{
 				return null;
@@ -402,33 +407,9 @@ namespace Db4objects.Db4o.Internal
 			return typeInfo.classReflector;
 		}
 
-		public ITypeHandler4 TypeHandlerForID(int id)
+		private HandlerRegistry.TypeInfo TypeInfoForID(int id)
 		{
-			TypeInfo typeInfo = TypeInfoForID(id);
-			if (typeInfo == null)
-			{
-				return null;
-			}
-			return typeInfo.typeHandler;
-		}
-
-		private TypeInfo TypeInfoForID(int id)
-		{
-			return (TypeInfo)_mapIdToTypeInfo.Get(id);
-		}
-
-		public int TypeHandlerID(ITypeHandler4 handler)
-		{
-			if (handler is ClassMetadata)
-			{
-				return ((ClassMetadata)handler).GetID();
-			}
-			object idAsInt = _mapTypeHandlerToId.Get(handler);
-			if (idAsInt == null)
-			{
-				return 0;
-			}
-			return ((int)idAsInt);
+			return (HandlerRegistry.TypeInfo)_mapIdToTypeInfo.Get(id);
 		}
 
 		private void InitClassReflectors(GenericReflector reflector)
@@ -477,7 +458,7 @@ namespace Db4objects.Db4o.Internal
 
 		public ClassMetadata ClassMetadataForId(int id)
 		{
-			TypeInfo typeInfo = TypeInfoForID(id);
+			HandlerRegistry.TypeInfo typeInfo = TypeInfoForID(id);
 			if (typeInfo == null)
 			{
 				return null;
@@ -485,51 +466,6 @@ namespace Db4objects.Db4o.Internal
 			return typeInfo.classMetadata;
 		}
 
-		public IFieldHandler FieldHandlerForId(int id)
-		{
-			TypeInfo typeInfo = TypeInfoForID(id);
-			if (typeInfo == null)
-			{
-				return null;
-			}
-			return typeInfo.fieldHandler;
-		}
-
-		public IFieldHandler FieldHandlerForClass(IReflectClass clazz)
-		{
-			// TODO: maybe need special handling for arrays here?
-			if (clazz == null)
-			{
-				return null;
-			}
-			if (clazz.IsInterface())
-			{
-				return UntypedFieldHandler();
-			}
-			if (clazz.IsArray())
-			{
-				if (Reflector().Array().IsNDimensional(clazz))
-				{
-					return _untypedMultiDimensionalArrayHandler;
-				}
-				return _untypedArrayHandler;
-			}
-			IFieldHandler fieldHandler = (IFieldHandler)_mapReflectorToFieldHandler.Get(clazz
-				);
-			if (fieldHandler != null)
-			{
-				return fieldHandler;
-			}
-			ITypeHandler4 configuredHandler = Container().ConfigImpl().TypeHandlerForClass(clazz
-				, Db4objects.Db4o.Internal.HandlerRegistry.HandlerVersion);
-			if (configuredHandler != null && SlotFormat.IsEmbedded(configuredHandler))
-			{
-				MapFieldHandler(clazz, configuredHandler);
-				return configuredHandler;
-			}
-			return null;
-		}
-
 		internal ClassMetadata ClassMetadataForClass(IReflectClass clazz)
 		{
 			if (clazz == null)
@@ -538,82 +474,70 @@ namespace Db4objects.Db4o.Internal
 			}
 			if (clazz.IsArray())
 			{
-				return (ClassMetadata)UntypedArrayHandler(clazz);
+				return IsNDimensional(clazz) ? _untypedMultiDimensionalMetadata : _untypedArrayMetadata;
 			}
 			return (ClassMetadata)_mapReflectorToClassMetadata.Get(clazz);
 		}
 
-		public IFieldHandler UntypedFieldHandler()
+		public ITypeHandler4 OpenTypeHandler()
 		{
-			return _untypedFieldHandler;
+			return _openTypeHandler;
 		}
 
-		public ITypeHandler4 UntypedObjectHandler()
-		{
-			return (ITypeHandler4)UntypedFieldHandler();
-		}
-
-		public ITypeHandler4 UntypedArrayHandler(IReflectClass clazz)
+		public ITypeHandler4 OpenArrayHandler(IReflectClass clazz)
 		{
 			if (clazz.IsArray())
 			{
-				if (Reflector().Array().IsNDimensional(clazz))
+				if (IsNDimensional(clazz))
 				{
-					return _untypedMultiDimensionalArrayHandler;
+					return _openMultiDimensionalArrayHandler;
 				}
-				return _untypedArrayHandler;
+				return _openArrayHandler;
 			}
 			return null;
 		}
 
+		private bool IsNDimensional(IReflectClass clazz)
+		{
+			return Reflector().Array().IsNDimensional(clazz);
+		}
+
 		public ITypeHandler4 TypeHandlerForClass(IReflectClass clazz)
 		{
 			if (clazz == null)
 			{
 				return null;
 			}
-			return (ITypeHandler4)_mapReflectorToTypeHandler.Get(clazz);
-		}
-
-		public IReflectClass ClassReflectorForHandler(ITypeHandler4 handler)
-		{
-			// This method never gets called from test cases so far.
-			// It is written for the usecase of custom Typehandlers and
-			// it is only require for arrays.
-			// The methodology is highly problematic since it implies that 
-			// one Typehandler can only be used for one ReflectClass.
-			return (IReflectClass)_mapFieldHandlerToReflector.Get(handler);
-		}
-
-		public bool IsSecondClass(object a_object)
-		{
-			if (a_object != null)
+			if (clazz.IsArray())
 			{
-				IReflectClass claxx = Reflector().ForObject(a_object);
-				if (_mapReflectorToFieldHandler.Get(claxx) != null)
+				if (IsNDimensional(clazz))
 				{
-					return true;
+					return _openMultiDimensionalArrayHandler;
 				}
-				return Platform4.IsValueType(claxx);
+				return _openArrayHandler;
 			}
-			return false;
+			ITypeHandler4 cachedTypeHandler = (ITypeHandler4)_mapReflectorToTypeHandler.Get(clazz
+				);
+			if (cachedTypeHandler != null)
+			{
+				return cachedTypeHandler;
+			}
+			ITypeHandler4 configuredTypeHandler = ConfiguredTypeHandler(clazz);
+			if (Handlers4.IsValueType(configuredTypeHandler))
+			{
+				return configuredTypeHandler;
+			}
+			return null;
 		}
 
 		public bool IsSystemHandler(int id)
 		{
-			return id <= _highestBuiltinTypeID;
+			return id > 0 && id <= _highestBuiltinTypeID;
 		}
 
-		public void MigrationConnection(Db4objects.Db4o.Internal.Replication.MigrationConnection
-			 mgc)
+		public int LowestValidId()
 		{
-			i_migration = mgc;
-		}
-
-		public Db4objects.Db4o.Internal.Replication.MigrationConnection MigrationConnection
-			()
-		{
-			return i_migration;
+			return _highestBuiltinTypeID + 1;
 		}
 
 		public VirtualFieldMetadata VirtualFieldByName(string name)
@@ -628,11 +552,6 @@ namespace Db4objects.Db4o.Internal
 			return null;
 		}
 
-		public bool IsVariableLength(ITypeHandler4 handler)
-		{
-			return handler is IVariableLengthTypeHandler;
-		}
-
 		public SharedIndexedFields Indexes()
 		{
 			return _indexes;
@@ -663,26 +582,72 @@ namespace Db4objects.Db4o.Internal
 			return new Hashtable4(32);
 		}
 
-		public int FieldHandlerIdForFieldHandler(IFieldHandler fieldHandler)
-		{
-			object wrappedIdObj = _mapFieldHandlerToId.Get(fieldHandler);
-			if (wrappedIdObj != null)
-			{
-				int wrappedId = (int)wrappedIdObj;
-				return wrappedId;
-			}
-			return 0;
-		}
-
 		public ITypeHandler4 ConfiguredTypeHandler(IReflectClass claxx)
 		{
-			ITypeHandler4 typeHandler = Container().ConfigImpl().TypeHandlerForClass(claxx, HandlerVersion
-				);
-			if (typeHandler != null && typeHandler is IEmbeddedTypeHandler)
+			object cachedHandler = _mapReflectorToTypeHandler.Get(claxx);
+			if (null != cachedHandler)
 			{
-				_mapReflectorToTypeHandler.Put(claxx, typeHandler);
+				return (ITypeHandler4)cachedHandler;
+			}
+			ITypeHandler4 typeHandler = Container().ConfigImpl.TypeHandlerForClass(claxx, HandlerVersion
+				);
+			if (typeHandler is IBuiltinTypeHandler)
+			{
+				((IBuiltinTypeHandler)typeHandler).RegisterReflector(Reflector());
+			}
+			if (Handlers4.IsValueType(typeHandler))
+			{
+				MapClassToTypeHandler(claxx, typeHandler);
 			}
 			return typeHandler;
 		}
+
+		public static ITypeHandler4 CorrectHandlerVersion(IHandlerVersionContext context, 
+			ITypeHandler4 handler)
+		{
+			int version = context.HandlerVersion();
+			if (version >= HandlerVersion)
+			{
+				return handler;
+			}
+			return context.Transaction().Container().Handlers.CorrectHandlerVersion(handler, 
+				version);
+		}
+
+		public bool IsTransient(IReflectClass claxx)
+		{
+			return IclassTransientclass.IsAssignableFrom(claxx) || Platform4.IsTransient(claxx
+				);
+		}
+
+		public void TreatAsOpenType(Type clazz)
+		{
+			MapClassToTypeHandler(ReflectClassFor(clazz), OpenTypeHandler());
+		}
+
+		private IReflectClass ReflectClassFor(Type clazz)
+		{
+			return Container().Reflector().ForClass(clazz);
+		}
+
+		public Db4objects.Db4o.Internal.Diagnostic.DiagnosticProcessor DiagnosticProcessor
+			()
+		{
+			return _diagnosticProcessor;
+		}
+
+		private class TypeInfo
+		{
+			public ClassMetadata classMetadata;
+
+			public IReflectClass classReflector;
+
+			public TypeInfo(ClassMetadata classMetadata_, IReflectClass classReflector_)
+			{
+				// TODO: remove when no longer needed in HandlerRegistry
+				classMetadata = classMetadata_;
+				classReflector = classReflector_;
+			}
+		}
 	}
 }
