@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -15,9 +15,9 @@ You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System.Collections;
 using Db4objects.Db4o;
+using Db4objects.Db4o.Ext;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Internal;
-using Db4objects.Db4o.Internal.Activation;
 using Db4objects.Db4o.Internal.Delete;
 using Db4objects.Db4o.Internal.Handlers;
 using Db4objects.Db4o.Internal.Handlers.Array;
@@ -32,8 +32,8 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 	/// <summary>This is the latest version, the one that should be used.</summary>
 	/// <remarks>This is the latest version, the one that should be used.</remarks>
 	/// <exclude></exclude>
-	public class ArrayHandler : IFirstClassHandler, IComparable4, ITypeHandler4, IVariableLengthTypeHandler
-		, IEmbeddedTypeHandler, IVersionedTypeHandler
+	public class ArrayHandler : ICascadingTypeHandler, IComparable4, IValueTypeHandler
+		, IVariableLengthTypeHandler, IVersionedTypeHandler, IQueryableTypeHandler
 	{
 		private ITypeHandler4 _handler;
 
@@ -58,12 +58,6 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			return new ArrayVersionHelper();
 		}
 
-		protected ArrayHandler(Db4objects.Db4o.Internal.Handlers.Array.ArrayHandler template
-			, HandlerRegistry registry, int version) : this(registry.CorrectHandlerVersion(template
-			._handler, version), template._usePrimitiveClassReflector)
-		{
-		}
-
 		protected virtual IReflectArray ArrayReflector(ObjectContainerBase container)
 		{
 			return container.Reflector().Array();
@@ -80,9 +74,9 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			return new ReflectArrayIterator(reflectArray, array);
 		}
 
-		public void CascadeActivation(ActivationContext4 context)
+		public void CascadeActivation(IActivationContext context)
 		{
-			if (!(_handler is ClassMetadata))
+			if (!Handlers4.IsCascading(_handler))
 			{
 				return;
 			}
@@ -99,28 +93,15 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			return trans.Container();
 		}
 
-		protected virtual IReflectClass ClassReflector(ObjectContainerBase container)
-		{
-			if (_handler is IBuiltinTypeHandler)
-			{
-				return ((IBuiltinTypeHandler)_handler).ClassReflector();
-			}
-			if (_handler is ClassMetadata)
-			{
-				return ((ClassMetadata)_handler).ClassReflector();
-			}
-			return container.Handlers().ClassReflectorForHandler(_handler);
-		}
-
 		public virtual void CollectIDs(QueryingReadContext context)
 		{
-			ITypeHandler4 handler = Handlers4.CorrectHandlerVersion(context, _handler);
-			ForEachElement(context, new _IRunnable_86(context, handler));
+			ITypeHandler4 handler = HandlerRegistry.CorrectHandlerVersion(context, _handler);
+			ForEachElement(context, new _IRunnable_71(context, handler));
 		}
 
-		private sealed class _IRunnable_86 : IRunnable
+		private sealed class _IRunnable_71 : IRunnable
 		{
-			public _IRunnable_86(QueryingReadContext context, ITypeHandler4 handler)
+			public _IRunnable_71(QueryingReadContext context, ITypeHandler4 handler)
 			{
 				this.context = context;
 				this.handler = handler;
@@ -140,13 +121,13 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			 elementRunnable)
 		{
 			ArrayInfo info = NewArrayInfo();
-			WithContent(context, new _IRunnable_96(this, context, info, elementRunnable));
+			WithContent(context, new _IRunnable_80(this, context, info, elementRunnable));
 			return info;
 		}
 
-		private sealed class _IRunnable_96 : IRunnable
+		private sealed class _IRunnable_80 : IRunnable
 		{
-			public _IRunnable_96(ArrayHandler _enclosing, AbstractBufferContext context, ArrayInfo
+			public _IRunnable_80(ArrayHandler _enclosing, AbstractBufferContext context, ArrayInfo
 				 info, IRunnable elementRunnable)
 			{
 				this._enclosing = _enclosing;
@@ -219,12 +200,12 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			{
 				return;
 			}
-			ForEachElement((AbstractBufferContext)context, new _IRunnable_143(this, context));
+			ForEachElement((AbstractBufferContext)context, new _IRunnable_127(this, context));
 		}
 
-		private sealed class _IRunnable_143 : IRunnable
+		private sealed class _IRunnable_127 : IRunnable
 		{
-			public _IRunnable_143(ArrayHandler _enclosing, IDeleteContext context)
+			public _IRunnable_127(ArrayHandler _enclosing, IDeleteContext context)
 			{
 				this._enclosing = _enclosing;
 				this.context = context;
@@ -242,7 +223,8 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 
 		private bool CascadeDelete(IDeleteContext context)
 		{
-			return context.CascadeDelete() && _handler is ClassMetadata;
+			// FIXME: ValueType could reference objects, shouldn't they be deleted too?
+			return context.CascadeDelete() && Handlers4.IsCascading(_handler);
 		}
 
 		// FIXME: This code has not been called in any test case when the 
@@ -250,19 +232,15 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 		//        Apparently it only frees slots.
 		//        For now the code simply returns without freeing.
 		/// <param name="classPrimitive"></param>
-		public void DeletePrimitiveEmbedded(StatefulBuffer buffer, PrimitiveFieldHandler 
+		public void DeletePrimitiveEmbedded(StatefulBuffer buffer, PrimitiveTypeMetadata 
 			classPrimitive)
 		{
 			buffer.ReadInt();
 			//int address = a_bytes.readInt();
 			buffer.ReadInt();
-			//int length = a_bytes.readInt();
-			if (true)
-			{
-				return;
-			}
 		}
 
+		//int length = a_bytes.readInt();
 		public override bool Equals(object obj)
 		{
 			if (!(obj is Db4objects.Db4o.Internal.Handlers.Array.ArrayHandler))
@@ -345,30 +323,23 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			info)
 		{
 			int classID = buffer.ReadInt();
-			if (!IsPreVersion0Format(classID))
+			if (IsPreVersion0Format(classID))
+			{
+				throw new UnsupportedOldFormatException();
+			}
+			else
 			{
 				_versionHelper.ReadTypeInfo(trans, buffer, info, classID);
 				ReflectClassFromElementsEntry(Container(trans), info, classID);
 				ReadDimensions(info, buffer);
 			}
-			else
-			{
-				info.ReflectClass(ClassReflector(Container(trans)));
-				DetectDimensionsPreVersion0Format(buffer, info, classID);
-			}
-			if (Debug.ExceedsMaximumArrayEntries(info.ElementCount(), _usePrimitiveClassReflector
+			if (Debug4.ExceedsMaximumArrayEntries(info.ElementCount(), _usePrimitiveClassReflector
 				))
 			{
 				info.ElementCount(0);
 			}
 		}
 
-		protected virtual void DetectDimensionsPreVersion0Format(IReadBuffer buffer, ArrayInfo
-			 info, int classID)
-		{
-			info.ElementCount(classID);
-		}
-
 		protected virtual void ReadDimensions(ArrayInfo info, IReadBuffer buffer)
 		{
 			info.ElementCount(buffer.ReadInt());
@@ -386,8 +357,8 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 				));
 		}
 
-		protected IReflectClass ClassReflector(IReflector reflector, ClassMetadata classMetadata
-			, bool isPrimitive)
+		protected IReflectClass ClassReflector(IReflector reflector, Db4objects.Db4o.Internal.ClassMetadata
+			 classMetadata, bool isPrimitive)
 		{
 			return _versionHelper.ClassReflector(reflector, classMetadata, isPrimitive);
 		}
@@ -397,7 +368,8 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			IReflectArray reflectArray = claxx.Reflector().Array();
 			if (reflectArray.IsNDimensional(claxx))
 			{
-				return MultidimensionalArrayHandler.AllElements(reflectArray, obj);
+				return MultidimensionalArrayHandler.AllElementsMultidimensional(reflectArray, obj
+					);
 			}
 			return Db4objects.Db4o.Internal.Handlers.Array.ArrayHandler.AllElements(reflectArray
 				, obj);
@@ -425,7 +397,7 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			return _versionHelper.ClassIdToMarshalledClassId(classID, primitive);
 		}
 
-		protected bool IsPrimitive(IReflector reflector, IReflectClass claxx, ClassMetadata
+		protected bool IsPrimitive(IReflector reflector, IReflectClass claxx, Db4objects.Db4o.Internal.ClassMetadata
 			 classMetadata)
 		{
 			return _versionHelper.IsPrimitive(reflector, claxx, classMetadata);
@@ -439,13 +411,13 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 
 		public virtual void Defragment(IDefragmentContext context)
 		{
-			if (Handlers4.HandlesSimple(_handler))
+			if (context.ClassMetadata().HasIdentity())
 			{
-				context.IncrementOffset(LinkLength());
+				DefragmentSlot(context);
 			}
 			else
 			{
-				DefragmentSlot(context);
+				context.IncrementOffset(LinkLength());
 			}
 		}
 
@@ -465,12 +437,29 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 				BitMap4 bitMap = ReadNullBitmap(context, elementCount);
 				elementCount -= ReducedCountForNullBitMap(elementCount, bitMap);
 			}
+			ITypeHandler4 correctTypeHandlerVersion = CorrectHandlerVersion(context, _handler
+				, info);
 			for (int i = 0; i < elementCount; i++)
 			{
-				context.Defragment(_handler);
+				context.Defragment(correctTypeHandlerVersion);
 			}
 		}
 
+		private ITypeHandler4 CorrectHandlerVersion(IDefragmentContext context, ITypeHandler4
+			 handler, ArrayInfo info)
+		{
+			Db4objects.Db4o.Internal.ClassMetadata classMetadata = ClassMetadata(context, info
+				);
+			return HandlerRegistry.CorrectHandlerVersion(context, handler, classMetadata);
+		}
+
+		private Db4objects.Db4o.Internal.ClassMetadata ClassMetadata(IDefragmentContext context
+			, ArrayInfo info)
+		{
+			int classMetadataId = ClassIDFromInfo(Container(context), info);
+			return Container(context).ClassMetadataForID(classMetadataId);
+		}
+
 		private void DefragmentWriteMappedClassId(IDefragmentContext context, ArrayInfo info
 			, int classIdOffset)
 		{
@@ -486,10 +475,10 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 
 		private bool IsUntypedByteArray(IBufferContext context)
 		{
-			return _handler is UntypedFieldHandler && HandleAsByteArray(context);
+			return Handlers4.IsUntyped(_handler) && HandleAsByteArray(context);
 		}
 
-		private bool HandleAsByteArray(IBufferContext context)
+		protected virtual bool HandleAsByteArray(IBufferContext context)
 		{
 			int offset = context.Offset();
 			ArrayInfo info = NewArrayInfo();
@@ -621,7 +610,8 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 			// TODO: Move as much analysis as possible to ReflectArray#analyze() 
 			ArrayReflector(container).Analyze(obj, info);
 			IReflectClass claxx = ComponentType(container, obj);
-			ClassMetadata classMetadata = container.ProduceClassMetadata(claxx);
+			Db4objects.Db4o.Internal.ClassMetadata classMetadata = container.ProduceClassMetadata
+				(claxx);
 			bool primitive = IsPrimitive(container.Reflector(), claxx, classMetadata);
 			if (primitive)
 			{
@@ -697,5 +687,16 @@ namespace Db4objects.Db4o.Internal.Handlers.Array
 		}
 
 		private const int HashcodeForNull = 9141078;
+
+		public override string ToString()
+		{
+			return "ArrayHandler(isPrimitive=" + _usePrimitiveClassReflector + ", handler=" +
+				 _handler + ")";
+		}
+
+		public virtual bool DescendsIntoMembers()
+		{
+			return true;
+		}
 	}
 }
