@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,6 +14,7 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Encoding;
 using Db4objects.Db4o.Internal.Marshall;
 
 namespace Db4objects.Db4o.Internal.Marshall
@@ -26,7 +27,7 @@ namespace Db4objects.Db4o.Internal.Marshall
 
 		RawFieldSpec ReadSpec(ObjectContainerBase stream, ByteArrayBuffer reader);
 
-		FieldMetadata Read(ObjectContainerBase stream, FieldMetadata field, ByteArrayBuffer
+		FieldMetadata Read(ObjectContainerBase stream, ClassMetadata clazz, ByteArrayBuffer
 			 reader);
 
 		int MarshalledLength(ObjectContainerBase stream, ClassAspect aspect);
