@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -28,10 +28,10 @@ namespace Db4objects.Db4o.Internal.Marshall
 
 		public virtual void AddId(int id)
 		{
-			_ids = (TreeInt)Tree.Add(_ids, new TreeInt(id));
+			_ids = (TreeInt)((TreeInt)Tree.Add(_ids, new TreeInt(id)));
 		}
 
-		public virtual Tree Ids()
+		public virtual TreeInt Ids()
 		{
 			return _ids;
 		}
