@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,19 +16,28 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4objects.Db4o;
 using Db4objects.Db4o.Config;
 using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Config;
 
 namespace Db4objects.Db4o.Internal
 {
 	public class ObjectContainerFactory
 	{
 		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException"></exception>
-		public static IObjectContainer OpenObjectContainer(IConfiguration config, string 
-			databaseFileName)
+		public static IEmbeddedObjectContainer OpenObjectContainer(IEmbeddedConfiguration
+			 config, string databaseFileName)
 		{
-			Config4Impl.AssertIsNotTainted(config);
-			IObjectContainer oc = new IoAdaptedObjectContainer(config, databaseFileName);
-			Db4objects.Db4o.Internal.Messages.LogMsg(config, 5, databaseFileName);
+			IConfiguration legacyConfig = Db4oLegacyConfigurationBridge.AsLegacy(config);
+			Config4Impl.AssertIsNotTainted(legacyConfig);
+			EmitDebugInfo();
+			IEmbeddedObjectContainer oc = new IoAdaptedObjectContainer(legacyConfig, databaseFileName
+				);
+			((EmbeddedConfigurationImpl)config).ApplyConfigurationItems(oc);
+			Db4objects.Db4o.Internal.Messages.LogMsg(legacyConfig, 5, databaseFileName);
 			return oc;
 		}
+
+		private static void EmitDebugInfo()
+		{
+		}
 	}
 }
