@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -22,6 +22,7 @@ using Db4objects.Db4o.Internal;
 using Db4objects.Db4o.Internal.Classindex;
 using Db4objects.Db4o.Internal.Diagnostic;
 using Db4objects.Db4o.Internal.Fieldindex;
+using Db4objects.Db4o.Internal.Handlers;
 using Db4objects.Db4o.Internal.Marshall;
 using Db4objects.Db4o.Internal.Query.Processor;
 using Db4objects.Db4o.Typehandlers;
@@ -30,16 +31,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <summary>
 	/// Holds the tree of
-	/// <see cref="Db4objects.Db4o.Internal.Query.Processor.QCandidate">Db4objects.Db4o.Internal.Query.Processor.QCandidate
-	/// 	</see>
+	/// <see cref="QCandidate">QCandidate</see>
 	/// objects and the list of
-	/// <see cref="Db4objects.Db4o.Internal.Query.Processor.QCon">Db4objects.Db4o.Internal.Query.Processor.QCon
-	/// 	</see>
+	/// <see cref="QCon">QCon</see>
 	/// during query evaluation.
 	/// The query work (adding and removing nodes) happens here.
 	/// Candidates during query evaluation.
-	/// <see cref="Db4objects.Db4o.Internal.Query.Processor.QCandidate">Db4objects.Db4o.Internal.Query.Processor.QCandidate
-	/// 	</see>
+	/// <see cref="QCandidate">QCandidate</see>
 	/// objects are stored in i_root
 	/// </summary>
 	/// <exclude></exclude>
@@ -51,22 +49,18 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private List4 _constraints;
 
-		internal ClassMetadata i_yapClass;
+		internal ClassMetadata i_classMetadata;
 
 		private QField _field;
 
 		internal QCon i_currentConstraint;
 
-		internal Tree i_ordered;
-
-		private int _majorOrderingID;
-
 		private IDGenerator _idGenerator;
 
 		private bool _loadedFromClassIndex;
 
-		internal QCandidates(LocalTransaction a_trans, ClassMetadata a_yapClass, QField a_field
-			)
+		internal QCandidates(LocalTransaction a_trans, ClassMetadata a_classMetadata, QField
+			 a_field)
 		{
 			// Transaction necessary as reference to stream
 			// root of the QCandidate tree
@@ -74,27 +68,26 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			// possible class information
 			// possible field information
 			// current executing constraint, only set where needed
-			// QOrder tree
-			// 
 			i_trans = a_trans;
-			i_yapClass = a_yapClass;
+			i_classMetadata = a_classMetadata;
 			_field = a_field;
-			if (a_field == null || a_field.i_yapField == null || !(a_field.i_yapField.GetHandler
-				() is ClassMetadata))
+			if (a_field == null || a_field._fieldMetadata == null || !(a_field._fieldMetadata
+				.GetHandler() is StandardReferenceTypeHandler))
 			{
 				return;
 			}
-			ClassMetadata yc = (ClassMetadata)a_field.i_yapField.GetHandler();
-			if (i_yapClass == null)
+			ClassMetadata yc = ((StandardReferenceTypeHandler)a_field._fieldMetadata.GetHandler
+				()).ClassMetadata();
+			if (i_classMetadata == null)
 			{
-				i_yapClass = yc;
+				i_classMetadata = yc;
 			}
 			else
 			{
-				yc = i_yapClass.GetHigherOrCommonHierarchy(yc);
+				yc = i_classMetadata.GetHigherOrCommonHierarchy(yc);
 				if (yc != null)
 				{
-					i_yapClass = yc;
+					i_classMetadata = yc;
 				}
 			}
 		}
@@ -119,31 +112,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			_constraints = new List4(_constraints, a_constraint);
 		}
 
-		internal void AddOrder(QOrder a_order)
-		{
-			i_ordered = Tree.Add(i_ordered, a_order);
-		}
-
-		internal void ApplyOrdering(Tree orderedCandidates, int orderingID)
-		{
-			if (orderedCandidates == null || i_root == null)
-			{
-				return;
-			}
-			int absoluteOrderingID = Math.Abs(orderingID);
-			bool major = TreatOrderingIDAsMajor(absoluteOrderingID);
-			if (major && !IsUnordered())
-			{
-				SwapMajorOrderToMinor();
-			}
-			HintNewOrder(orderedCandidates, major);
-			i_root = RecreateTreeFromCandidates();
-			if (major)
-			{
-				_majorOrderingID = absoluteOrderingID;
-			}
-		}
-
 		public QCandidate ReadSubCandidate(QueryingReadContext context, ITypeHandler4 handler
 			)
 		{
@@ -165,7 +133,10 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 					object obj = context.Read(handler);
 					if (obj != null)
 					{
-						return new QCandidate(this, obj, 0);
+						QCandidate candidate = new QCandidate(this, obj, context.Container().GetID(context
+							.Transaction(), obj));
+						candidate.ClassMetadata(context.Container().ClassMetadataForObject(obj));
+						return candidate;
 					}
 				}
 			}
@@ -176,114 +147,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return null;
 		}
 
-		private Tree RecreateTreeFromCandidates()
-		{
-			Collection4 col = CollectCandidates();
-			Tree newTree = null;
-			IEnumerator i = col.GetEnumerator();
-			while (i.MoveNext())
-			{
-				QCandidate candidate = (QCandidate)i.Current;
-				candidate._preceding = null;
-				candidate._subsequent = null;
-				candidate._size = 1;
-				newTree = Tree.Add(newTree, candidate);
-			}
-			return newTree;
-		}
-
-		private Collection4 CollectCandidates()
-		{
-			Collection4 col = new Collection4();
-			i_root.Traverse(new _IVisitor4_175(col));
-			return col;
-		}
-
-		private sealed class _IVisitor4_175 : IVisitor4
-		{
-			public _IVisitor4_175(Collection4 col)
-			{
-				this.col = col;
-			}
-
-			public void Visit(object a_object)
-			{
-				QCandidate candidate = (QCandidate)a_object;
-				col.Add(candidate);
-			}
-
-			private readonly Collection4 col;
-		}
-
-		private void HintNewOrder(Tree orderedCandidates, bool major)
-		{
-			int[] currentOrder = new int[] { 0 };
-			QOrder[] lastOrder = new QOrder[] { null };
-			orderedCandidates.Traverse(new _IVisitor4_188(lastOrder, currentOrder, major));
-		}
-
-		private sealed class _IVisitor4_188 : IVisitor4
-		{
-			public _IVisitor4_188(QOrder[] lastOrder, int[] currentOrder, bool major)
-			{
-				this.lastOrder = lastOrder;
-				this.currentOrder = currentOrder;
-				this.major = major;
-			}
-
-			public void Visit(object a_object)
-			{
-				QOrder qo = (QOrder)a_object;
-				if (!qo.IsEqual(lastOrder[0]))
-				{
-					currentOrder[0]++;
-				}
-				QCandidate candidate = qo._candidate.GetRoot();
-				candidate.HintOrder(currentOrder[0], major);
-				lastOrder[0] = qo;
-			}
-
-			private readonly QOrder[] lastOrder;
-
-			private readonly int[] currentOrder;
-
-			private readonly bool major;
-		}
-
-		private void SwapMajorOrderToMinor()
-		{
-			i_root.Traverse(new _IVisitor4_202());
-		}
-
-		private sealed class _IVisitor4_202 : IVisitor4
-		{
-			public _IVisitor4_202()
-			{
-			}
-
-			public void Visit(object obj)
-			{
-				QCandidate candidate = (QCandidate)obj;
-				Order order = (Order)candidate._order;
-				order.SwapMajorToMinor();
-			}
-		}
-
-		private bool TreatOrderingIDAsMajor(int absoluteOrderingID)
-		{
-			return (IsUnordered()) || (IsMoreRelevantOrderingID(absoluteOrderingID));
-		}
-
-		private bool IsUnordered()
-		{
-			return _majorOrderingID == 0;
-		}
-
-		private bool IsMoreRelevantOrderingID(int absoluteOrderingID)
-		{
-			return absoluteOrderingID < _majorOrderingID;
-		}
-
 		internal void Collect(Db4objects.Db4o.Internal.Query.Processor.QCandidates a_candidates
 			)
 		{
@@ -328,12 +191,12 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private IEnumerator SingleObjectSodaProcessor(IEnumerator indexIterator)
 		{
-			return Iterators.Map(indexIterator, new _IFunction4_255(this));
+			return Iterators.Map(indexIterator, new _IFunction4_159(this));
 		}
 
-		private sealed class _IFunction4_255 : IFunction4
+		private sealed class _IFunction4_159 : IFunction4
 		{
-			public _IFunction4_255(QCandidates _enclosing)
+			public _IFunction4_159(QCandidates _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -371,11 +234,11 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return result.IterateIDs();
 			}
-			if (i_yapClass.IsPrimitive())
+			if (!i_classMetadata.HasClassIndex())
 			{
 				return Iterators.EmptyIterator;
 			}
-			return BTreeClassIndexStrategy.Iterate(i_yapClass, i_trans);
+			return BTreeClassIndexStrategy.Iterate(i_classMetadata, i_trans);
 		}
 
 		private IEnumerator MapIdsToExecutionPath(IEnumerator singleObjectQueryIterator, 
@@ -390,20 +253,14 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			while (executionPathIterator.MoveNext())
 			{
 				string fieldName = (string)executionPathIterator.Current;
-				res = Iterators.Concat(Iterators.Map(res, new _IFunction4_301(this, fieldName)));
+				res = Iterators.Concat(Iterators.Map(res, new _IFunction4_205(this, fieldName)));
 			}
-			//                    Tree idTree = oh.classMetadata().collectFieldIDs(
-			//                            oh._marshallerFamily,
-			//                            oh._headerAttributes,
-			//                            null,
-			//                            reader,
-			//                            fieldName);
 			return res;
 		}
 
-		private sealed class _IFunction4_301 : IFunction4
+		private sealed class _IFunction4_205 : IFunction4
 		{
-			public _IFunction4_301(QCandidates _enclosing, string fieldName)
+			public _IFunction4_205(QCandidates _enclosing, string fieldName)
 			{
 				this._enclosing = _enclosing;
 				this.fieldName = fieldName;
@@ -412,16 +269,12 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			public object Apply(object current)
 			{
 				int id = ((int)current);
-				StatefulBuffer reader = this._enclosing.Stream().ReadWriterByID(this._enclosing.i_trans
-					, id);
-				if (reader == null)
+				CollectIdContext context = CollectIdContext.ForID(this._enclosing.i_trans, id);
+				if (context == null)
 				{
 					return Iterators.Skip;
 				}
-				ObjectHeader oh = new ObjectHeader(this._enclosing.Stream(), reader);
-				CollectIdContext context = new CollectIdContext(this._enclosing.i_trans, oh, reader
-					);
-				oh.ClassMetadata().CollectIDs(context, fieldName);
+				context.ClassMetadata().CollectIDs(context, fieldName);
 				return new TreeKeyIterator(context.Ids());
 			}
 
@@ -437,7 +290,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public int ClassIndexEntryCount()
 		{
-			return i_yapClass.IndexEntryCount(i_trans);
+			return i_classMetadata.IndexEntryCount(i_trans);
 		}
 
 		private FieldIndexProcessorResult ProcessFieldIndexes()
@@ -455,50 +308,114 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return;
 			}
+			ForEachConstraint(new _IProcedure4_243(this));
+			ForEachConstraint(new _IProcedure4_251());
+			ForEachConstraint(new _IProcedure4_257());
+			ForEachConstraint(new _IProcedure4_263());
+			ForEachConstraint(new _IProcedure4_269());
+			ForEachConstraint(new _IProcedure4_275());
+		}
+
+		private sealed class _IProcedure4_243 : IProcedure4
+		{
+			public _IProcedure4_243(QCandidates _enclosing)
+			{
+				this._enclosing = _enclosing;
+			}
+
+			public void Apply(object arg)
+			{
+				QCon qCon = (QCon)arg;
+				qCon.SetCandidates(this._enclosing);
+				qCon.EvaluateSelf();
+			}
+
+			private readonly QCandidates _enclosing;
+		}
+
+		private sealed class _IProcedure4_251 : IProcedure4
+		{
+			public _IProcedure4_251()
+			{
+			}
+
+			public void Apply(object arg)
+			{
+				((QCon)arg).EvaluateSimpleChildren();
+			}
+		}
+
+		private sealed class _IProcedure4_257 : IProcedure4
+		{
+			public _IProcedure4_257()
+			{
+			}
+
+			public void Apply(object arg)
+			{
+				((QCon)arg).EvaluateEvaluations();
+			}
+		}
+
+		private sealed class _IProcedure4_263 : IProcedure4
+		{
+			public _IProcedure4_263()
+			{
+			}
+
+			public void Apply(object arg)
+			{
+				((QCon)arg).EvaluateCreateChildrenCandidates();
+			}
+		}
+
+		private sealed class _IProcedure4_269 : IProcedure4
+		{
+			public _IProcedure4_269()
+			{
+			}
+
+			public void Apply(object arg)
+			{
+				((QCon)arg).EvaluateCollectChildren();
+			}
+		}
+
+		private sealed class _IProcedure4_275 : IProcedure4
+		{
+			public _IProcedure4_275()
+			{
+			}
+
+			public void Apply(object arg)
+			{
+				((QCon)arg).EvaluateChildren();
+			}
+		}
+
+		private void ForEachConstraint(IProcedure4 proc)
+		{
 			IEnumerator i = IterateConstraints();
 			while (i.MoveNext())
 			{
-				QCon qCon = (QCon)i.Current;
-				qCon.SetCandidates(this);
-				qCon.EvaluateSelf();
-			}
-			i = IterateConstraints();
-			while (i.MoveNext())
-			{
-				((QCon)i.Current).EvaluateSimpleChildren();
-			}
-			i = IterateConstraints();
-			while (i.MoveNext())
-			{
-				((QCon)i.Current).EvaluateEvaluations();
-			}
-			i = IterateConstraints();
-			while (i.MoveNext())
-			{
-				((QCon)i.Current).EvaluateCreateChildrenCandidates();
-			}
-			i = IterateConstraints();
-			while (i.MoveNext())
-			{
-				((QCon)i.Current).EvaluateCollectChildren();
-			}
-			i = IterateConstraints();
-			while (i.MoveNext())
-			{
-				((QCon)i.Current).EvaluateChildren();
+				QCon constraint = (QCon)i.Current;
+				if (!constraint.ProcessedByIndex())
+				{
+					proc.Apply(constraint);
+				}
 			}
 		}
 
 		internal bool IsEmpty()
 		{
 			bool[] ret = new bool[] { true };
-			Traverse(new _IVisitor4_386(ret));
+			Traverse(new _IVisitor4_295(ret));
 			return ret[0];
 		}
 
-		private sealed class _IVisitor4_386 : IVisitor4
+		private sealed class _IVisitor4_295 : IVisitor4
 		{
-			public _IVisitor4_386(bool[] ret)
+			public _IVisitor4_295(bool[] ret)
 			{
 				this.ret = ret;
 			}
@@ -519,14 +436,14 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			if (i_root != null)
 			{
 				i_root.Traverse(a_host);
-				i_root = i_root.Filter(new _IPredicate4_399());
+				i_root = i_root.Filter(new _IPredicate4_308());
 			}
 			return i_root != null;
 		}
 
-		private sealed class _IPredicate4_399 : IPredicate4
+		private sealed class _IPredicate4_308 : IPredicate4
 		{
-			public _IPredicate4_399()
+			public _IPredicate4_308()
 			{
 			}
 
@@ -560,7 +477,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 			public void Add(TreeInt node)
 			{
-				tree = (TreeInt)Tree.Add(tree, node);
+				tree = (TreeInt)((TreeInt)Tree.Add(tree, node));
 			}
 		}
 
@@ -571,20 +488,20 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				return;
 			}
 			QCandidates.TreeIntBuilder result = new QCandidates.TreeIntBuilder();
-			IClassIndexStrategy index = i_yapClass.Index();
-			index.TraverseAll(i_trans, new _IVisitor4_437(this, result));
+			IClassIndexStrategy index = i_classMetadata.Index();
+			index.TraverseAll(i_trans, new _IVisitor4_346(this, result));
 			i_root = result.tree;
-			DiagnosticProcessor dp = i_trans.Container()._handlers._diagnosticProcessor;
+			DiagnosticProcessor dp = i_trans.Container()._handlers.DiagnosticProcessor();
 			if (dp.Enabled() && !IsClassOnlyQuery())
 			{
-				dp.LoadedFromClassIndex(i_yapClass);
+				dp.LoadedFromClassIndex(i_classMetadata);
 			}
 			_loadedFromClassIndex = true;
 		}
 
-		private sealed class _IVisitor4_437 : IVisitor4
+		private sealed class _IVisitor4_346 : IVisitor4
 		{
-			public _IVisitor4_437(QCandidates _enclosing, QCandidates.TreeIntBuilder result)
+			public _IVisitor4_346(QCandidates _enclosing, QCandidates.TreeIntBuilder result)
 			{
 				this._enclosing = _enclosing;
 				this.result = result;
@@ -631,13 +548,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				QField qf = a_constraint.GetField();
 				if (qf != null)
 				{
-					if (_field.i_name != null && !_field.i_name.Equals(qf.i_name))
+					if (_field.Name() != null && !_field.Name().Equals(qf.Name()))
 					{
 						return false;
 					}
 				}
 			}
-			if (i_yapClass == null || a_constraint.IsNullConstraint())
+			if (i_classMetadata == null || a_constraint.IsNullConstraint())
 			{
 				AddConstraint(a_constraint);
 				return true;
@@ -645,10 +562,10 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			ClassMetadata yc = a_constraint.GetYapClass();
 			if (yc != null)
 			{
-				yc = i_yapClass.GetHigherOrCommonHierarchy(yc);
+				yc = i_classMetadata.GetHigherOrCommonHierarchy(yc);
 				if (yc != null)
 				{
-					i_yapClass = yc;
+					i_classMetadata = yc;
 					AddConstraint(a_constraint);
 					return true;
 				}
@@ -677,13 +594,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		public override string ToString()
 		{
 			StringBuilder sb = new StringBuilder();
-			i_root.Traverse(new _IVisitor4_521(sb));
+			i_root.Traverse(new _IVisitor4_430(sb));
 			return sb.ToString();
 		}
 
-		private sealed class _IVisitor4_521 : IVisitor4
+		private sealed class _IVisitor4_430 : IVisitor4
 		{
-			public _IVisitor4_521(StringBuilder sb)
+			public _IVisitor4_430(StringBuilder sb)
 			{
 				this.sb = sb;
 			}
@@ -698,11 +615,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			private readonly StringBuilder sb;
 		}
 
-		public void ClearOrdering()
-		{
-			i_ordered = null;
-		}
-
 		public Transaction Transaction()
 		{
 			return i_trans;
@@ -720,13 +632,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				QField qf = constraint.GetField();
 				if (qf != null)
 				{
-					if (_field.i_name != null && !_field.i_name.Equals(qf.i_name))
+					if (_field.Name() != null && !_field.Name().Equals(qf.Name()))
 					{
 						return false;
 					}
 				}
 			}
-			if (i_yapClass == null || constraint.IsNullConstraint())
+			if (i_classMetadata == null || constraint.IsNullConstraint())
 			{
 				return true;
 			}
@@ -735,18 +647,18 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return false;
 			}
-			classMetadata = i_yapClass.GetHigherOrCommonHierarchy(classMetadata);
+			classMetadata = i_classMetadata.GetHigherOrCommonHierarchy(classMetadata);
 			if (classMetadata == null)
 			{
 				return false;
 			}
-			i_yapClass = classMetadata;
+			i_classMetadata = classMetadata;
 			return true;
 		}
 
 		private bool IsClassOnlyQuery()
 		{
-			if (_constraints._next != null)
+			if (((List4)_constraints._next) != null)
 			{
 				return false;
 			}
@@ -754,7 +666,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return false;
 			}
-			return ((QCon)_constraints._element)._children == null;
+			return !((QCon)_constraints._element).HasChildren();
 		}
 	}
 }
