@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -35,25 +35,26 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		[System.NonSerialized]
 		internal QCandidates i_candidates;
 
-		public Collection4 i_childrenCandidates;
+		private Collection4 i_childrenCandidates;
 
-		public List4 _children;
+		protected List4 _children;
 
-		public QE i_evaluator = QE.Default;
+		protected QE i_evaluator = QE.Default;
 
-		public int i_id;
+		private int i_id;
 
-		public Collection4 i_joins;
+		internal Collection4 i_joins;
 
-		public int i_orderID = 0;
+		protected Db4objects.Db4o.Internal.Query.Processor.QCon i_parent;
 
-		public Db4objects.Db4o.Internal.Query.Processor.QCon i_parent;
-
-		public bool i_removed = false;
+		private bool i_removed = false;
 
 		[System.NonSerialized]
 		internal Db4objects.Db4o.Internal.Transaction i_trans;
 
+		[System.NonSerialized]
+		private bool _processedByIndex;
+
 		public QCon()
 		{
 		}
@@ -70,12 +71,11 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			// ID handling for fast find of QConstraint objects in 
 			// pending OR evaluations
 			// ANDs and ORs on this constraint
-			// positive indicates ascending, negative indicates descending
-			// value indicates ID supplied by ID generator.
-			// lower IDs are applied first
 			// the parent of this constraint or null, if this is a root
 			// prevents circular calls on removal
 			// our transaction to get a stream object anywhere
+			// whether or not this constraint was used to get the initial set
+			// in the FieldIndexProcessor
 			// C/S only
 			i_id = idGenerator.Next();
 			i_trans = a_trans;
@@ -123,21 +123,12 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		internal virtual void ApplyOrdering()
-		{
-			if (HasOrdering())
-			{
-				Db4objects.Db4o.Internal.Query.Processor.QCon root = GetRoot();
-				root.i_candidates.ApplyOrdering(i_candidates.i_ordered, i_orderID);
-			}
-		}
-
 		internal virtual bool Attach(QQuery query, string a_field)
 		{
 			Db4objects.Db4o.Internal.Query.Processor.QCon qcon = this;
 			ClassMetadata yc = GetYapClass();
 			bool[] foundField = new bool[] { false };
-			ForEachChildField(a_field, new _IVisitor4_112(foundField, query));
+			ForEachChildField(a_field, new _IVisitor4_104(foundField, query));
 			if (foundField[0])
 			{
 				return true;
@@ -147,7 +138,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				int[] count = new int[] { 0 };
 				FieldMetadata[] yfs = new FieldMetadata[] { null };
-				i_trans.Container().ClassCollection().AttachQueryNode(a_field, new _IVisitor4_130
+				i_trans.Container().ClassCollection().AttachQueryNode(a_field, new _IVisitor4_122
 					(yfs, count));
 				if (count[0] == 0)
 				{
@@ -164,9 +155,9 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 			else
 			{
-				if (yc.CustomizedNewInstance())
+				if (yc.IsTranslated())
 				{
-					i_trans.Container()._handlers._diagnosticProcessor.DescendIntoTranslator(yc, a_field
+					i_trans.Container()._handlers.DiagnosticProcessor().DescendIntoTranslator(yc, a_field
 						);
 				}
 				FieldMetadata yf = yc.FieldMetadataForName(a_field);
@@ -185,9 +176,9 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return true;
 		}
 
-		private sealed class _IVisitor4_112 : IVisitor4
+		private sealed class _IVisitor4_104 : IVisitor4
 		{
-			public _IVisitor4_112(bool[] foundField, QQuery query)
+			public _IVisitor4_104(bool[] foundField, QQuery query)
 			{
 				this.foundField = foundField;
 				this.query = query;
@@ -204,9 +195,9 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			private readonly QQuery query;
 		}
 
-		private sealed class _IVisitor4_130 : IVisitor4
+		private sealed class _IVisitor4_122 : IVisitor4
 		{
-			public _IVisitor4_130(FieldMetadata[] yfs, int[] count)
+			public _IVisitor4_122(FieldMetadata[] yfs, int[] count)
 			{
 				this.yfs = yfs;
 				this.count = count;
@@ -275,7 +266,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			if (DTrace.enabled)
 			{
-				DTrace.Donotinclude.Log(i_id);
+				DTrace.Donotinclude.Log(Id());
 			}
 			if (i_parent != null)
 			{
@@ -311,7 +302,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			if (DTrace.enabled)
 			{
-				DTrace.CollectChildren.Log(i_id);
+				DTrace.CollectChildren.Log(Id());
 			}
 			IEnumerator i = i_childrenCandidates.GetEnumerator();
 			while (i.MoveNext())
@@ -370,8 +361,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				i_candidates.SetCurrentConstraint(qcon);
 				qcon.SetCandidates(i_candidates);
 				qcon.EvaluateSimpleExec(i_candidates);
-				qcon.ApplyOrdering();
-				i_candidates.ClearOrdering();
 			}
 			i_candidates.SetCurrentConstraint(null);
 		}
@@ -393,15 +382,15 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				{
 					if (previous == null)
 					{
-						_children = current._next;
+						_children = ((List4)current._next);
 					}
 					else
 					{
-						previous._next = current._next;
+						previous._next = ((List4)current._next);
 					}
 				}
 				previous = current;
-				current = current._next;
+				current = ((List4)current._next);
 			}
 			_children = new List4(_children, a_with);
 		}
@@ -414,7 +403,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				object obj = i.Current;
 				if (obj is QConObject)
 				{
-					if (((QConObject)obj).i_field.i_name.Equals(name))
+					if (((QConObject)obj).GetField().Name().Equals(name))
 					{
 						visitor.Visit(obj);
 					}
@@ -545,7 +534,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return false;
 		}
 
-		internal virtual IEnumerator IterateJoins()
+		public virtual IEnumerator IterateJoins()
 		{
 			if (i_joins == null)
 			{
@@ -738,7 +727,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			if (IsNot())
 			{
-				i_evaluator = ((QENot)i_evaluator).i_evaluator;
+				i_evaluator = ((QENot)i_evaluator).Evaluator();
 			}
 		}
 
@@ -747,16 +736,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			i_candidates = a_candidates;
 		}
 
-		internal virtual void SetOrdering(int a_ordering)
-		{
-			i_orderID = a_ordering;
-		}
-
-		public virtual int Ordering()
-		{
-			return i_orderID;
-		}
-
 		internal virtual void SetParent(Db4objects.Db4o.Internal.Query.Processor.QCon a_newParent
 			)
 		{
@@ -766,7 +745,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		/// <param name="obj"></param>
 		/// <param name="removeExisting"></param>
 		internal virtual Db4objects.Db4o.Internal.Query.Processor.QCon ShareParent(object
-			 obj, bool[] removeExisting)
+			 obj, BooleanByRef removeExisting)
 		{
 			// virtual
 			return null;
@@ -774,8 +753,8 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		/// <param name="claxx"></param>
 		/// <param name="removeExisting"></param>
-		internal virtual QConClass ShareParentForClass(IReflectClass claxx, bool[] removeExisting
-			)
+		internal virtual QConClass ShareParentForClass(IReflectClass claxx, BooleanByRef 
+			removeExisting)
 		{
 			// virtual
 			return null;
@@ -788,12 +767,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		protected virtual object StreamLock()
 		{
-			return i_trans.Container()._lock;
-		}
-
-		internal virtual bool SupportsOrdering()
-		{
-			return false;
+			return i_trans.Container().Lock();
 		}
 
 		internal virtual void Unmarshall(Db4objects.Db4o.Internal.Transaction a_trans)
@@ -848,7 +822,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			Visit1(a_root, this, i_evaluator.Not(res));
 		}
 
-		/// <param name="reason"></param>
 		internal virtual void Visit1(QCandidate root, Db4objects.Db4o.Internal.Query.Processor.QCon
 			 reason, bool res)
 		{
@@ -898,26 +871,37 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return i_evaluator;
 		}
 
-		public virtual bool RequiresSort()
+		public virtual void SetProcessedByIndex()
 		{
-			if (HasOrdering())
-			{
-				return true;
-			}
-			IEnumerator i = IterateChildren();
-			while (i.MoveNext())
-			{
-				if (((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).RequiresSort())
-				{
-					return true;
-				}
-			}
-			return false;
+			InternalSetProcessedByIndex();
 		}
 
-		protected virtual bool HasOrdering()
+		protected virtual void InternalSetProcessedByIndex()
 		{
-			return i_orderID != 0;
+			_processedByIndex = true;
+			if (i_joins != null)
+			{
+				IEnumerator i = i_joins.GetEnumerator();
+				while (i.MoveNext())
+				{
+					((QConJoin)i.Current).SetProcessedByIndex();
+				}
+			}
+		}
+
+		public virtual bool ProcessedByIndex()
+		{
+			return _processedByIndex;
+		}
+
+		public virtual int ChildrenCount()
+		{
+			return List4.Size(_children);
+		}
+
+		public virtual int Id()
+		{
+			return i_id;
 		}
 	}
 }
