@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -20,7 +20,6 @@ using Db4objects.Db4o;
 using Db4objects.Db4o.Config;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Db4o.Internal;
-using Db4objects.Db4o.Internal.Callbacks;
 using Db4objects.Db4o.Internal.Marshall;
 using Db4objects.Db4o.Internal.Query;
 using Db4objects.Db4o.Internal.Query.Processor;
@@ -28,6 +27,7 @@ using Db4objects.Db4o.Internal.Query.Result;
 using Db4objects.Db4o.Query;
 using Db4objects.Db4o.Reflect;
 using Db4objects.Db4o.Types;
+using Sharpen.Util;
 
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
@@ -40,37 +40,41 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 	/// and should never be used explicitly.
 	/// </remarks>
 	/// <exclude></exclude>
-	public abstract class QQueryBase : IUnversioned
+	public abstract class QQueryBase : IInternalQuery, IUnversioned
 	{
 		[System.NonSerialized]
-		private static readonly IDGenerator i_orderingGenerator = new IDGenerator();
+		internal Db4objects.Db4o.Internal.Transaction _trans;
 
-		[System.NonSerialized]
-		internal Transaction _trans;
+		private Collection4 i_constraints = new Collection4();
 
-		public Collection4 i_constraints = new Collection4();
+		private QQuery i_parent;
 
-		public QQuery i_parent;
-
-		public string i_field;
+		private string i_field;
 
 		[System.NonSerialized]
 		private QueryEvaluationMode _evaluationMode;
 
-		public int _evaluationModeAsInt;
+		private int _prefetchDepth;
 
-		public IQueryComparator _comparator;
+		private int _prefetchCount;
+
+		private int _evaluationModeAsInt;
+
+		private IQueryComparator _comparator;
 
 		[System.NonSerialized]
 		private readonly QQuery _this;
 
+		private IList _orderings;
+
 		protected QQueryBase()
 		{
 			// C/S only
 			_this = Cast(this);
 		}
 
-		protected QQueryBase(Transaction a_trans, QQuery a_parent, string a_field)
+		protected QQueryBase(Db4objects.Db4o.Internal.Transaction a_trans, QQuery a_parent
+			, string a_field)
 		{
 			_this = Cast(this);
 			_trans = a_trans;
@@ -78,6 +82,14 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			i_field = a_field;
 		}
 
+		public virtual void CaptureQueryResultConfig()
+		{
+			Config4Impl config = _trans.Container().Config();
+			_evaluationMode = config.EvaluationMode();
+			_prefetchDepth = config.PrefetchDepth();
+			_prefetchCount = config.PrefetchObjectCount();
+		}
+
 		internal virtual void AddConstraint(QCon a_constraint)
 		{
 			i_constraints.Add(a_constraint);
@@ -98,30 +110,30 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			col.Add(newConstraint);
 		}
 
-		private bool AttachToExistingConstraints(Collection4 col, object obj, bool onlyForPaths
-			)
+		private bool AttachToExistingConstraints(Collection4 newConstraintsCollector, object
+			 obj, bool onlyForPaths)
 		{
 			bool found = false;
 			IEnumerator j = IterateConstraints();
 			while (j.MoveNext())
 			{
 				QCon existingConstraint = (QCon)j.Current;
-				bool[] removeExisting = new bool[] { false };
+				BooleanByRef removeExisting = new BooleanByRef(false);
 				if (!onlyForPaths || (existingConstraint is QConPath))
 				{
 					QCon newConstraint = existingConstraint.ShareParent(obj, removeExisting);
 					if (newConstraint != null)
 					{
+						newConstraintsCollector.Add(newConstraint);
 						AddConstraint(newConstraint);
-						col.Add(newConstraint);
-						if (removeExisting[0])
+						if (removeExisting.value)
 						{
 							RemoveConstraint(existingConstraint);
 						}
 						found = true;
 						if (!onlyForPaths)
 						{
-							return true;
+							break;
 						}
 					}
 				}
@@ -138,7 +150,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			lock (StreamLock())
 			{
-				example = Platform4.GetClassForType(example);
 				IReflectClass claxx = ReflectClassForClass(example);
 				if (claxx != null)
 				{
@@ -159,7 +170,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			if (i_constraints.Size() == 0)
 			{
-				_trans.Container().ClassCollection().IterateTopLevelClasses(new _IVisitor4_128(this
+				_trans.Container().ClassCollection().IterateTopLevelClasses(new _IVisitor4_139(this
 					));
 			}
 			IEnumerator i = IterateConstraints();
@@ -171,9 +182,9 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return null;
 		}
 
-		private sealed class _IVisitor4_128 : IVisitor4
+		private sealed class _IVisitor4_139 : IVisitor4
 		{
-			public _IVisitor4_128(QQueryBase _enclosing)
+			public _IVisitor4_139(QQueryBase _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -192,39 +203,50 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private IConstraint AddClassConstraint(IReflectClass claxx)
 		{
-			if (claxx.Equals(Stream()._handlers.IclassObject))
+			if (IsTheObjectClass(claxx))
 			{
 				return null;
 			}
-			Collection4 col = new Collection4();
 			if (claxx.IsInterface())
 			{
 				return AddInterfaceConstraint(claxx);
 			}
-			IEnumerator constraintsIterator = IterateConstraints();
-			while (constraintsIterator.MoveNext())
-			{
-				QCon existingConstraint = (QConObject)constraintsIterator.Current;
-				bool[] removeExisting = new bool[] { false };
-				QCon newConstraint = existingConstraint.ShareParentForClass(claxx, removeExisting
-					);
-				if (newConstraint != null)
-				{
-					AddConstraint(newConstraint);
-					col.Add(newConstraint);
-					if (removeExisting[0])
-					{
-						RemoveConstraint(existingConstraint);
-					}
-				}
-			}
-			if (col.Size() == 0)
+			Collection4 newConstraints = IntroduceClassConstrain(claxx);
+			if (newConstraints.IsEmpty())
 			{
 				QConClass qcc = new QConClass(_trans, claxx);
 				AddConstraint(qcc);
 				return qcc;
 			}
-			return ToConstraint(col);
+			return ToConstraint(newConstraints);
+		}
+
+		private Collection4 IntroduceClassConstrain(IReflectClass claxx)
+		{
+			Collection4 newConstraints = new Collection4();
+			IEnumerator existingConstraints = IterateConstraints();
+			while (existingConstraints.MoveNext())
+			{
+				QCon existingConstraint = (QConObject)existingConstraints.Current;
+				BooleanByRef removeExisting = new BooleanByRef(false);
+				QCon newConstraint = existingConstraint.ShareParentForClass(claxx, removeExisting
+					);
+				if (newConstraint != null)
+				{
+					newConstraints.Add(newConstraint);
+					AddConstraint(newConstraint);
+					if (removeExisting.value)
+					{
+						RemoveConstraint(existingConstraint);
+					}
+				}
+			}
+			return newConstraints;
+		}
+
+		private bool IsTheObjectClass(IReflectClass claxx)
+		{
+			return claxx.Equals(Stream()._handlers.IclassObject);
 		}
 
 		private IConstraint AddInterfaceConstraint(IReflectClass claxx)
@@ -240,19 +262,19 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			IConstraint constr = null;
 			while (i.MoveNext())
 			{
-				ClassMetadata yapClass = (ClassMetadata)i.Current;
-				IReflectClass yapClassClaxx = yapClass.ClassReflector();
-				if (yapClassClaxx != null)
+				ClassMetadata classMetadata = (ClassMetadata)i.Current;
+				IReflectClass classMetadataClaxx = classMetadata.ClassReflector();
+				if (classMetadataClaxx != null)
 				{
-					if (!yapClassClaxx.IsInterface())
+					if (!classMetadataClaxx.IsInterface())
 					{
 						if (constr == null)
 						{
-							constr = Constrain(yapClassClaxx);
+							constr = Constrain(classMetadataClaxx);
 						}
 						else
 						{
-							constr = constr.Or(Constrain(yapClass.ClassReflector()));
+							constr = constr.Or(Constrain(classMetadata.ClassReflector()));
 						}
 					}
 				}
@@ -307,7 +329,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		private bool Descend1(QQuery query, string a_field, IntByRef run)
+		private bool Descend1(QQuery query, string fieldName, IntByRef run)
 		{
 			if (run.value == 2 || i_constraints.Size() == 0)
 			{
@@ -317,16 +339,14 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				// Let's see how this works out. We may need to join networks.
 				run.value = 0;
 				// prevent a double run of this code
-				BooleanByRef anyClassCollected = new BooleanByRef(false);
-				Stream().ClassCollection().AttachQueryNode(a_field, new _IVisitor4_257(this, anyClassCollected
-					));
+				Stream().ClassCollection().AttachQueryNode(fieldName, new _IVisitor4_275(this));
 			}
 			CheckConstraintsEvaluationMode();
 			BooleanByRef foundClass = new BooleanByRef(false);
 			IEnumerator i = IterateConstraints();
 			while (i.MoveNext())
 			{
-				if (((QCon)i.Current).Attach(query, a_field))
+				if (((QCon)i.Current).Attach(query, fieldName))
 				{
 					foundClass.value = true;
 				}
@@ -334,94 +354,332 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return foundClass.value;
 		}
 
-		private sealed class _IVisitor4_257 : IVisitor4
+		private sealed class _IVisitor4_275 : IVisitor4
 		{
-			public _IVisitor4_257(QQueryBase _enclosing, BooleanByRef anyClassCollected)
+			public _IVisitor4_275(QQueryBase _enclosing)
 			{
 				this._enclosing = _enclosing;
-				this.anyClassCollected = anyClassCollected;
+				this.untypedFieldConstraintCollected = false;
 			}
 
+			internal bool untypedFieldConstraintCollected;
+
 			public void Visit(object obj)
 			{
 				object[] pair = ((object[])obj);
-				ClassMetadata parentYc = (ClassMetadata)pair[0];
-				FieldMetadata yf = (FieldMetadata)pair[1];
-				ClassMetadata childYc = yf.HandlerClassMetadata(this._enclosing.Stream());
-				bool take = true;
-				if (childYc is UntypedFieldHandler)
+				ClassMetadata containingClass = (ClassMetadata)pair[0];
+				FieldMetadata field = (FieldMetadata)pair[1];
+				if (this.IsTyped(field))
 				{
-					if (anyClassCollected.value)
-					{
-						take = false;
-					}
-					else
-					{
-						anyClassCollected.value = true;
-					}
+					this.AddFieldConstraint(containingClass, field);
+					return;
 				}
-				if (take)
+				if (this.untypedFieldConstraintCollected)
 				{
-					QConClass qcc = new QConClass(this._enclosing._trans, null, yf.QField(this._enclosing
-						._trans), parentYc.ClassReflector());
-					this._enclosing.AddConstraint(qcc);
-					this._enclosing.ToConstraint(this._enclosing.i_constraints).Or(qcc);
+					return;
 				}
+				this.AddFieldConstraint(containingClass, field);
+				this.untypedFieldConstraintCollected = true;
+			}
+
+			private bool IsTyped(FieldMetadata field)
+			{
+				return !Handlers4.IsUntyped(field.GetHandler());
+			}
+
+			private void AddFieldConstraint(ClassMetadata containingClass, FieldMetadata field
+				)
+			{
+				QConClass qcc = new QConClass(this._enclosing._trans, null, field.QField(this._enclosing
+					._trans), containingClass.ClassReflector());
+				this._enclosing.AddConstraint(qcc);
+				this._enclosing.ToConstraint(this._enclosing.i_constraints).Or(qcc);
 			}
 
 			private readonly QQueryBase _enclosing;
-
-			private readonly BooleanByRef anyClassCollected;
 		}
 
 		public virtual IObjectSet Execute()
 		{
 			lock (StreamLock())
 			{
-				ICallbacks callbacks = Stream().Callbacks();
-				callbacks.QueryOnStarted(_trans, Cast(this));
-				IQueryResult qresult = GetQueryResult();
-				callbacks.QueryOnFinished(_trans, Cast(this));
-				return new ObjectSetFacade(qresult);
+				return ((IObjectSet)TriggeringQueryEvents(new _IClosure4_331(this)));
 			}
 		}
 
+		private sealed class _IClosure4_331 : IClosure4
+		{
+			public _IClosure4_331(QQueryBase _enclosing)
+			{
+				this._enclosing = _enclosing;
+			}
+
+			public object Run()
+			{
+				return new ObjectSetFacade(this._enclosing.GetQueryResult());
+			}
+
+			private readonly QQueryBase _enclosing;
+		}
+
+		public virtual void ExecuteLocal(IdListQueryResult result)
+		{
+			CheckConstraintsEvaluationMode();
+			QQueryBase.CreateCandidateCollectionResult r = CreateCandidateCollection();
+			bool checkDuplicates = r.checkDuplicates;
+			bool topLevel = r.topLevel;
+			List4 candidateCollection = r.candidateCollection;
+			if (candidateCollection != null)
+			{
+				Collection4 executionPath = topLevel ? null : FieldPathFromTop();
+				IEnumerator i = new Iterator4Impl(candidateCollection);
+				while (i.MoveNext())
+				{
+					((QCandidates)i.Current).Execute();
+				}
+				if (((List4)candidateCollection._next) != null)
+				{
+					checkDuplicates = true;
+				}
+				if (checkDuplicates)
+				{
+					result.CheckDuplicates();
+				}
+				ObjectContainerBase stream = Stream();
+				i = new Iterator4Impl(candidateCollection);
+				while (i.MoveNext())
+				{
+					QCandidates candidates = (QCandidates)i.Current;
+					if (topLevel)
+					{
+						candidates.Traverse(result);
+					}
+					else
+					{
+						candidates.Traverse(new _IVisitor4_374(this, executionPath, stream, result));
+					}
+				}
+			}
+			Sort(result);
+		}
+
+		private sealed class _IVisitor4_374 : IVisitor4
+		{
+			public _IVisitor4_374(QQueryBase _enclosing, Collection4 executionPath, ObjectContainerBase
+				 stream, IdListQueryResult result)
+			{
+				this._enclosing = _enclosing;
+				this.executionPath = executionPath;
+				this.stream = stream;
+				this.result = result;
+			}
+
+			public void Visit(object a_object)
+			{
+				QCandidate candidate = (QCandidate)a_object;
+				if (candidate.Include())
+				{
+					TreeInt ids = new TreeInt(candidate._key);
+					ByRef idsNew = new ByRef();
+					IEnumerator itPath = executionPath.GetEnumerator();
+					while (itPath.MoveNext())
+					{
+						idsNew.value = null;
+						string fieldName = (string)(itPath.Current);
+						if (ids != null)
+						{
+							ids.Traverse(new _IVisitor4_385(this, stream, fieldName, idsNew));
+						}
+						ids = (TreeInt)((TreeInt)idsNew.value);
+					}
+					if (ids != null)
+					{
+						ids.Traverse(new _IVisitor4_406(result));
+					}
+				}
+			}
+
+			private sealed class _IVisitor4_385 : IVisitor4
+			{
+				public _IVisitor4_385(_IVisitor4_374 _enclosing, ObjectContainerBase stream, string
+					 fieldName, ByRef idsNew)
+				{
+					this._enclosing = _enclosing;
+					this.stream = stream;
+					this.fieldName = fieldName;
+					this.idsNew = idsNew;
+				}
+
+				public void Visit(object treeInt)
+				{
+					int id = ((TreeInt)treeInt)._key;
+					StatefulBuffer reader = stream.ReadStatefulBufferById(this._enclosing._enclosing.
+						_trans, id);
+					if (reader != null)
+					{
+						ObjectHeader oh = new ObjectHeader(stream, reader);
+						CollectIdContext context = new CollectIdContext(this._enclosing._enclosing._trans
+							, oh, reader);
+						oh.ClassMetadata().CollectIDs(context, fieldName);
+						Tree.Traverse(context.Ids(), new _IVisitor4_394(idsNew));
+					}
+				}
+
+				private sealed class _IVisitor4_394 : IVisitor4
+				{
+					public _IVisitor4_394(ByRef idsNew)
+					{
+						this.idsNew = idsNew;
+					}
+
+					public void Visit(object node)
+					{
+						idsNew.value = TreeInt.Add(((TreeInt)idsNew.value), ((TreeInt)node)._key);
+					}
+
+					private readonly ByRef idsNew;
+				}
+
+				private readonly _IVisitor4_374 _enclosing;
+
+				private readonly ObjectContainerBase stream;
+
+				private readonly string fieldName;
+
+				private readonly ByRef idsNew;
+			}
+
+			private sealed class _IVisitor4_406 : IVisitor4
+			{
+				public _IVisitor4_406(IdListQueryResult result)
+				{
+					this.result = result;
+				}
+
+				public void Visit(object treeInt)
+				{
+					result.AddKeyCheckDuplicates(((TreeInt)treeInt)._key);
+				}
+
+				private readonly IdListQueryResult result;
+			}
+
+			private readonly QQueryBase _enclosing;
+
+			private readonly Collection4 executionPath;
+
+			private readonly ObjectContainerBase stream;
+
+			private readonly IdListQueryResult result;
+		}
+
+		private void TriggerQueryOnFinished()
+		{
+			Stream().Callbacks().QueryOnFinished(_trans, Cast(this));
+		}
+
+		private void TriggerQueryOnStarted()
+		{
+			Stream().Callbacks().QueryOnStarted(_trans, Cast(this));
+		}
+
+		public virtual IEnumerator ExecuteLazy()
+		{
+			CheckConstraintsEvaluationMode();
+			QQueryBase.CreateCandidateCollectionResult r = CreateCandidateCollection();
+			Collection4 executionPath = ExecutionPath(r);
+			IEnumerator candidateCollection = new Iterator4Impl(r.candidateCollection);
+			MappingIterator executeCandidates = new _MappingIterator_438(executionPath, candidateCollection
+				);
+			CompositeIterator4 resultingIDs = new CompositeIterator4(executeCandidates);
+			if (!r.checkDuplicates)
+			{
+				return resultingIDs;
+			}
+			return CheckDuplicates(resultingIDs);
+		}
+
+		private sealed class _MappingIterator_438 : MappingIterator
+		{
+			public _MappingIterator_438(Collection4 executionPath, IEnumerator baseArg1) : base
+				(baseArg1)
+			{
+				this.executionPath = executionPath;
+			}
+
+			protected override object Map(object current)
+			{
+				return ((QCandidates)current).ExecuteLazy(executionPath);
+			}
+
+			private readonly Collection4 executionPath;
+		}
+
 		public virtual IQueryResult GetQueryResult()
 		{
 			lock (StreamLock())
 			{
 				if (i_constraints.Size() == 0)
 				{
-					return Stream().QueryAllObjects(_trans);
+					return ExecuteAllObjectsQuery();
 				}
-				IQueryResult result = ClassOnlyQuery();
+				IQueryResult result = ExecuteClassOnlyQuery();
 				if (result != null)
 				{
 					return result;
 				}
 				OptimizeJoins();
-				return Stream().ExecuteQuery(_this);
+				return ExecuteQuery();
 			}
 		}
 
+		protected IQueryResult ExecuteQuery()
+		{
+			return Stream().ExecuteQuery(_this);
+		}
+
+		private IQueryResult ExecuteAllObjectsQuery()
+		{
+			return Stream().QueryAllObjects(_trans);
+		}
+
 		protected virtual ObjectContainerBase Stream()
 		{
 			return _trans.Container();
 		}
 
-		private IQueryResult ClassOnlyQuery()
+		public virtual IInternalObjectContainer Container
 		{
-			if (i_constraints.Size() != 1 || _comparator != null)
+			get
+			{
+				return Stream();
+			}
+		}
+
+		private IQueryResult ExecuteClassOnlyQuery()
+		{
+			ClassMetadata clazz = SingleClassConstraint();
+			if (null == clazz)
 			{
 				return null;
 			}
-			IConstraint constr = SingleConstraint();
-			if (constr.GetType() != typeof(QConClass))
+			IQueryResult queryResult = Stream().ClassOnlyQuery(this, clazz);
+			Sort(queryResult);
+			return queryResult;
+		}
+
+		private ClassMetadata SingleClassConstraint()
+		{
+			if (RequiresSort())
 			{
 				return null;
 			}
-			QConClass clazzconstr = (QConClass)constr;
-			ClassMetadata clazz = clazzconstr.i_yapClass;
+			QConClass clazzconstr = ClassConstraint();
+			if (clazzconstr == null)
+			{
+				return null;
+			}
+			ClassMetadata clazz = clazzconstr._classMetadata;
 			if (clazz == null)
 			{
 				return null;
@@ -430,13 +688,21 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return null;
 			}
-			IQueryResult queryResult = Stream().ClassOnlyQuery(_trans, clazz);
-			if (queryResult == null)
+			return clazz;
+		}
+
+		private QConClass ClassConstraint()
+		{
+			if (i_constraints.Size() != 1)
 			{
 				return null;
 			}
-			Sort(queryResult);
-			return queryResult;
+			IConstraint constr = SingleConstraint();
+			if (constr.GetType() != typeof(QConClass))
+			{
+				return null;
+			}
+			return (QConClass)constr;
 		}
 
 		private IConstraint SingleConstraint()
@@ -481,46 +747,27 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return CheckDuplicates(resultingIDs);
 		}
 
-		public virtual IEnumerator ExecuteLazy()
+		public virtual object TriggeringQueryEvents(IClosure4 closure)
 		{
-			CheckConstraintsEvaluationMode();
-			QQueryBase.CreateCandidateCollectionResult r = CreateCandidateCollection();
-			Collection4 executionPath = ExecutionPath(r);
-			IEnumerator candidateCollection = new Iterator4Impl(r.candidateCollection);
-			MappingIterator executeCandidates = new _MappingIterator_411(executionPath, candidateCollection
-				);
-			CompositeIterator4 resultingIDs = new CompositeIterator4(executeCandidates);
-			if (!r.checkDuplicates)
+			TriggerQueryOnStarted();
+			try
 			{
-				return resultingIDs;
+				return closure.Run();
 			}
-			return CheckDuplicates(resultingIDs);
-		}
-
-		private sealed class _MappingIterator_411 : MappingIterator
-		{
-			public _MappingIterator_411(Collection4 executionPath, IEnumerator baseArg1) : base
-				(baseArg1)
+			finally
 			{
-				this.executionPath = executionPath;
+				TriggerQueryOnFinished();
 			}
-
-			protected override object Map(object current)
-			{
-				return ((QCandidates)current).ExecuteLazy(executionPath);
-			}
-
-			private readonly Collection4 executionPath;
 		}
 
 		private IEnumerator CheckDuplicates(CompositeIterator4 executeAllCandidates)
 		{
-			return Iterators.Filter(executeAllCandidates, new _IPredicate4_427());
+			return Iterators.Filter(executeAllCandidates, new _IPredicate4_573());
 		}
 
-		private sealed class _IPredicate4_427 : IPredicate4
+		private sealed class _IPredicate4_573 : IPredicate4
 		{
-			public _IPredicate4_427()
+			public _IPredicate4_573()
 			{
 				this.ids = new TreeInt(0);
 			}
@@ -534,7 +781,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				{
 					return false;
 				}
-				this.ids = (TreeInt)this.ids.Add(new TreeInt(id));
+				this.ids = (TreeInt)((TreeInt)this.ids.Add(new TreeInt(id)));
 				return true;
 			}
 		}
@@ -553,142 +800,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public virtual void ExecuteLocal(IdListQueryResult result)
-		{
-			CheckConstraintsEvaluationMode();
-			QQueryBase.CreateCandidateCollectionResult r = CreateCandidateCollection();
-			bool checkDuplicates = r.checkDuplicates;
-			bool topLevel = r.topLevel;
-			List4 candidateCollection = r.candidateCollection;
-			if (candidateCollection != null)
-			{
-				Collection4 executionPath = topLevel ? null : FieldPathFromTop();
-				IEnumerator i = new Iterator4Impl(candidateCollection);
-				while (i.MoveNext())
-				{
-					((QCandidates)i.Current).Execute();
-				}
-				if (candidateCollection._next != null)
-				{
-					checkDuplicates = true;
-				}
-				if (checkDuplicates)
-				{
-					result.CheckDuplicates();
-				}
-				ObjectContainerBase stream = Stream();
-				i = new Iterator4Impl(candidateCollection);
-				while (i.MoveNext())
-				{
-					QCandidates candidates = (QCandidates)i.Current;
-					if (topLevel)
-					{
-						candidates.Traverse(result);
-					}
-					else
-					{
-						candidates.Traverse(new _IVisitor4_491(this, executionPath, stream, result));
-					}
-				}
-			}
-			Sort(result);
-		}
-
-		private sealed class _IVisitor4_491 : IVisitor4
-		{
-			public _IVisitor4_491(QQueryBase _enclosing, Collection4 executionPath, ObjectContainerBase
-				 stream, IdListQueryResult result)
-			{
-				this._enclosing = _enclosing;
-				this.executionPath = executionPath;
-				this.stream = stream;
-				this.result = result;
-			}
-
-			public void Visit(object a_object)
-			{
-				QCandidate candidate = (QCandidate)a_object;
-				if (candidate.Include())
-				{
-					TreeInt ids = new TreeInt(candidate._key);
-					ObjectByRef idsNew = new ObjectByRef(null);
-					IEnumerator itPath = executionPath.GetEnumerator();
-					while (itPath.MoveNext())
-					{
-						idsNew.value = null;
-						string fieldName = (string)(itPath.Current);
-						if (ids != null)
-						{
-							ids.Traverse(new _IVisitor4_502(this, stream, fieldName, idsNew));
-						}
-						ids = (TreeInt)idsNew.value;
-					}
-					if (ids != null)
-					{
-						ids.Traverse(new _IVisitor4_519(result));
-					}
-				}
-			}
-
-			private sealed class _IVisitor4_502 : IVisitor4
-			{
-				public _IVisitor4_502(_IVisitor4_491 _enclosing, ObjectContainerBase stream, string
-					 fieldName, ObjectByRef idsNew)
-				{
-					this._enclosing = _enclosing;
-					this.stream = stream;
-					this.fieldName = fieldName;
-					this.idsNew = idsNew;
-				}
-
-				public void Visit(object treeInt)
-				{
-					int id = ((TreeInt)treeInt)._key;
-					StatefulBuffer reader = stream.ReadWriterByID(this._enclosing._enclosing._trans, 
-						id);
-					if (reader != null)
-					{
-						ObjectHeader oh = new ObjectHeader(stream, reader);
-						CollectIdContext context = new CollectIdContext(this._enclosing._enclosing._trans
-							, oh, reader);
-						oh.ClassMetadata().CollectIDs(context, fieldName);
-						idsNew.value = context.Ids();
-					}
-				}
-
-				private readonly _IVisitor4_491 _enclosing;
-
-				private readonly ObjectContainerBase stream;
-
-				private readonly string fieldName;
-
-				private readonly ObjectByRef idsNew;
-			}
-
-			private sealed class _IVisitor4_519 : IVisitor4
-			{
-				public _IVisitor4_519(IdListQueryResult result)
-				{
-					this.result = result;
-				}
-
-				public void Visit(object treeInt)
-				{
-					result.AddKeyCheckDuplicates(((TreeInt)treeInt)._key);
-				}
-
-				private readonly IdListQueryResult result;
-			}
-
-			private readonly QQueryBase _enclosing;
-
-			private readonly Collection4 executionPath;
-
-			private readonly ObjectContainerBase stream;
-
-			private readonly IdListQueryResult result;
-		}
-
 		private Collection4 FieldPathFromTop()
 		{
 			QQueryBase q = this;
@@ -786,7 +897,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return false;
 		}
 
-		public Transaction GetTransaction()
+		public Transaction Transaction()
 		{
 			return _trans;
 		}
@@ -801,29 +912,85 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public virtual IQuery OrderAscending()
 		{
+			if (i_parent == null)
+			{
+				throw new InvalidOperationException("Cannot apply ordering at top level.");
+			}
 			lock (StreamLock())
 			{
-				SetOrdering(i_orderingGenerator.Next());
+				AddOrdering(SodaQueryComparator.Direction.Ascending);
 				return _this;
 			}
 		}
 
 		public virtual IQuery OrderDescending()
 		{
+			if (i_parent == null)
+			{
+				throw new InvalidOperationException("Cannot apply ordering at top level.");
+			}
 			lock (StreamLock())
 			{
-				SetOrdering(-i_orderingGenerator.Next());
+				AddOrdering(SodaQueryComparator.Direction.Descending);
 				return _this;
 			}
 		}
 
-		private void SetOrdering(int ordering)
+		private void AddOrdering(SodaQueryComparator.Direction direction)
 		{
-			IEnumerator i = IterateConstraints();
-			while (i.MoveNext())
+			AddOrdering(direction, new ArrayList());
+		}
+
+		protected void AddOrdering(SodaQueryComparator.Direction direction, IList path)
+		{
+			if (i_field != null)
 			{
-				((QCon)i.Current).SetOrdering(ordering);
+				path.Add(i_field);
 			}
+			if (i_parent != null)
+			{
+				i_parent.AddOrdering(direction, path);
+				return;
+			}
+			string[] fieldPath = ReverseFieldPath(path);
+			RemoveExistingOrderingFor(fieldPath);
+			Orderings().Add(new SodaQueryComparator.Ordering(direction, fieldPath));
+		}
+
+		private void RemoveExistingOrderingFor(string[] fieldPath)
+		{
+			for (IEnumerator orderingIter = Orderings().GetEnumerator(); orderingIter.MoveNext
+				(); )
+			{
+				SodaQueryComparator.Ordering ordering = ((SodaQueryComparator.Ordering)orderingIter
+					.Current);
+				if (Arrays.Equals(ordering.FieldPath(), fieldPath))
+				{
+					Orderings().Remove(ordering);
+					break;
+				}
+			}
+		}
+
+		/// <summary>Public so it can be used by the LINQ test cases.</summary>
+		/// <remarks>Public so it can be used by the LINQ test cases.</remarks>
+		public IList Orderings()
+		{
+			if (null == _orderings)
+			{
+				_orderings = new ArrayList();
+			}
+			return _orderings;
+		}
+
+		private string[] ReverseFieldPath(IList path)
+		{
+			string[] reversedPath = new string[path.Count];
+			for (int i = 0; i < reversedPath.Length; i++)
+			{
+				reversedPath[i] = ((string)path[path.Count - i - 1]);
+			}
+			return reversedPath;
 		}
 
 		public virtual void Marshall()
@@ -873,7 +1040,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		protected virtual object StreamLock()
 		{
-			return Stream()._lock;
+			return Stream().Lock();
 		}
 
 		public virtual IQuery SortBy(IQueryComparator comparator)
@@ -884,12 +1051,28 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private void Sort(IQueryResult result)
 		{
+			if (_orderings != null)
+			{
+				result.SortIds(NewSodaQueryComparator());
+			}
 			if (_comparator != null)
 			{
 				result.Sort(_comparator);
 			}
 		}
 
+		private IIntComparator NewSodaQueryComparator()
+		{
+			return new SodaQueryComparator((LocalObjectContainer)this.Transaction().Container
+				(), ExtentType(), ((SodaQueryComparator.Ordering[])Sharpen.Collections.ToArray(_orderings
+				, new SodaQueryComparator.Ordering[_orderings.Count])));
+		}
+
+		private ClassMetadata ExtentType()
+		{
+			return ClassConstraint().GetYapClass();
+		}
+
 		// cheat emulating '(QQuery)this'
 		private static QQuery Cast(QQueryBase obj)
 		{
@@ -898,19 +1081,10 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public virtual bool RequiresSort()
 		{
-			if (_comparator != null)
+			if (_comparator != null || _orderings != null)
 			{
 				return true;
 			}
-			IEnumerator i = IterateConstraints();
-			while (i.MoveNext())
-			{
-				QCon qCon = (QCon)i.Current;
-				if (qCon.RequiresSort())
-				{
-					return true;
-				}
-			}
 			return false;
 		}
 
@@ -939,12 +1113,12 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private bool HasOrJoins()
 		{
-			return ForEachConstraintRecursively(new _IFunction4_736());
+			return ForEachConstraintRecursively(new _IFunction4_855());
 		}
 
-		private sealed class _IFunction4_736 : IFunction4
+		private sealed class _IFunction4_855 : IFunction4
 		{
-			public _IFunction4_736()
+			public _IFunction4_855()
 			{
 			}
 
@@ -966,12 +1140,12 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private void RemoveJoins()
 		{
-			ForEachConstraintRecursively(new _IFunction4_752());
+			ForEachConstraintRecursively(new _IFunction4_871());
 		}
 
-		private sealed class _IFunction4_752 : IFunction4
+		private sealed class _IFunction4_871 : IFunction4
 		{
-			public _IFunction4_752()
+			public _IFunction4_871()
 			{
 			}
 
@@ -1013,6 +1187,16 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return false;
 		}
 
+		public virtual int PrefetchDepth()
+		{
+			return _prefetchDepth;
+		}
+
+		public virtual int PrefetchCount()
+		{
+			return _prefetchCount;
+		}
+
 		public override string ToString()
 		{
 			StringBuilder sb = new StringBuilder();
@@ -1026,5 +1210,10 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 			return sb.ToString();
 		}
+
+		public virtual QQuery Parent()
+		{
+			return i_parent;
+		}
 	}
 }
