@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -20,8 +20,11 @@ namespace Db4objects.Db4o.Internal
 	/// <exclude></exclude>
 	public class SharedIndexedFields
 	{
-		internal readonly VersionFieldMetadata _version = new VersionFieldMetadata();
+		public readonly VersionFieldMetadata _version = new VersionFieldMetadata();
 
-		internal readonly UUIDFieldMetadata _uUID = new UUIDFieldMetadata();
+		public readonly UUIDFieldMetadata _uUID = new UUIDFieldMetadata();
+
+		public readonly CommitTimestampFieldMetadata _commitTimestamp = new CommitTimestampFieldMetadata
+			();
 	}
 }
