@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -24,7 +24,6 @@ namespace Db4objects.Db4o.Messaging
 	{
 		/// <summary>The container the message was dispatched to.</summary>
 		/// <remarks>The container the message was dispatched to.</remarks>
-		/// <returns></returns>
 		IObjectContainer Container
 		{
 			get;
@@ -35,10 +34,16 @@ namespace Db4objects.Db4o.Messaging
 		/// The sender of the current message.
 		/// The reference can be used to send a reply to it.
 		/// </remarks>
-		/// <returns></returns>
 		IMessageSender Sender
 		{
 			get;
 		}
+
+		/// <summary>The transaction the current message has been sent with.</summary>
+		/// <remarks>The transaction the current message has been sent with.</remarks>
+		Db4objects.Db4o.Internal.Transaction Transaction
+		{
+			get;
+		}
 	}
 }
