@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -33,7 +33,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 	/// ObjectContainer is opened. All subsequent reflector
 	/// calls are routed through this interface.<br /><br />
 	/// An instance of GenericReflector can be obtained through
-	/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.Reflector">Db4objects.Db4o.Ext.IExtObjectContainer.Reflector
+	/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.Reflector()">Db4objects.Db4o.Ext.IExtObjectContainer.Reflector()
 	/// 	</see>
 	/// .<br /><br />
 	/// GenericReflector keeps list of known classes in memory.
@@ -62,8 +62,6 @@ namespace Db4objects.Db4o.Reflect.Generic
 
 		private Collection4 _collectionPredicates = new Collection4();
 
-		private Collection4 _collectionUpdateDepths = new Collection4();
-
 		private readonly Hashtable4 _classByClass = new Hashtable4();
 
 		private Transaction _trans;
@@ -103,8 +101,6 @@ namespace Db4objects.Db4o.Reflect.Generic
 				(null, (IReflector)_delegate.DeepClone(this));
 			myClone._collectionPredicates = (Collection4)_collectionPredicates.DeepClone(myClone
 				);
-			myClone._collectionUpdateDepths = (Collection4)_collectionUpdateDepths.DeepClone(
-				myClone);
 			// Interesting, adding the following messes things up.
 			// Keep the code, since it may make sense to carry the
 			// global reflectors into a running db4o session.
@@ -154,24 +150,6 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _array;
 		}
 
-		/// <summary>Determines collection update depth for the specified class</summary>
-		/// <param name="candidate">candidate class</param>
-		/// <returns>collection update depth for the specified class</returns>
-		public virtual int CollectionUpdateDepth(IReflectClass candidate)
-		{
-			IEnumerator i = _collectionUpdateDepths.GetEnumerator();
-			while (i.MoveNext())
-			{
-				CollectionUpdateDepthEntry entry = (CollectionUpdateDepthEntry)i.Current;
-				if (entry._predicate.Match(candidate))
-				{
-					return entry._depth;
-				}
-			}
-			return 2;
-		}
-
-		//TODO: will need knowledge for .NET collections here
 		internal virtual Db4objects.Db4o.Reflect.Generic.GenericClass EnsureDelegate(IReflectClass
 			 clazz)
 		{
@@ -196,7 +174,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 		{
 			Db4objects.Db4o.Reflect.Generic.GenericClass ret;
 			string name = clazz.GetName();
-			if (name.Equals(typeof(GenericArray).FullName))
+			if (name.Equals(ReflectPlatform.FullyQualifiedName(typeof(GenericArray))))
 			{
 				// special case, comparing name because can't compare class == class directly with ReflectClass
 				ret = new GenericArrayClass(this, clazz, name, null);
@@ -250,12 +228,12 @@ namespace Db4objects.Db4o.Reflect.Generic
 		/// 	</seealso>
 		public virtual IReflectClass ForName(string className)
 		{
-			return (IReflectClass)WithLock(new _IClosure4_211(this, className));
+			return ((IReflectClass)WithLock(new _IClosure4_190(this, className)));
 		}
 
-		private sealed class _IClosure4_211 : IClosure4
+		private sealed class _IClosure4_190 : IClosure4
 		{
-			public _IClosure4_211(GenericReflector _enclosing, string className)
+			public _IClosure4_190(GenericReflector _enclosing, string className)
 			{
 				this._enclosing = _enclosing;
 				this.className = className;
@@ -301,8 +279,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 
 		private IReflectClass ForGenericObject(GenericObject genericObject)
 		{
-			Db4objects.Db4o.Reflect.Generic.GenericClass claxx = genericObject.GetGenericClass
-				();
+			Db4objects.Db4o.Reflect.Generic.GenericClass claxx = genericObject._class;
 			if (claxx == null)
 			{
 				throw new InvalidOperationException();
@@ -371,14 +348,14 @@ namespace Db4objects.Db4o.Reflect.Generic
 		private IReflectClassPredicate ClassPredicate(Type clazz)
 		{
 			IReflectClass collectionClass = ForClass(clazz);
-			IReflectClassPredicate predicate = new _IReflectClassPredicate_311(collectionClass
+			IReflectClassPredicate predicate = new _IReflectClassPredicate_290(collectionClass
 				);
 			return predicate;
 		}
 
-		private sealed class _IReflectClassPredicate_311 : IReflectClassPredicate
+		private sealed class _IReflectClassPredicate_290 : IReflectClassPredicate
 		{
-			public _IReflectClassPredicate_311(IReflectClass collectionClass)
+			public _IReflectClassPredicate_290(IReflectClass collectionClass)
 			{
 				this.collectionClass = collectionClass;
 			}
@@ -391,33 +368,16 @@ namespace Db4objects.Db4o.Reflect.Generic
 			private readonly IReflectClass collectionClass;
 		}
 
-		/// <summary>Register update depth for a collection class</summary>
-		/// <param name="clazz">class</param>
-		/// <param name="depth">update depth</param>
-		public virtual void RegisterCollectionUpdateDepth(Type clazz, int depth)
-		{
-			RegisterCollectionUpdateDepth(ClassPredicate(clazz), depth);
-		}
-
-		/// <summary>Register update depth for a collection class</summary>
-		/// <param name="predicate">class predicate</param>
-		/// <param name="depth">update depth</param>
-		public virtual void RegisterCollectionUpdateDepth(IReflectClassPredicate predicate
-			, int depth)
-		{
-			_collectionUpdateDepths.Add(new CollectionUpdateDepthEntry(predicate, depth));
-		}
-
 		/// <summary>Register a class</summary>
 		/// <param name="clazz">class</param>
 		public virtual void Register(Db4objects.Db4o.Reflect.Generic.GenericClass clazz)
 		{
-			WithLock(new _IClosure4_342(this, clazz));
+			WithLock(new _IClosure4_303(this, clazz));
 		}
 
-		private sealed class _IClosure4_342 : IClosure4
+		private sealed class _IClosure4_303 : IClosure4
 		{
-			public _IClosure4_342(GenericReflector _enclosing, Db4objects.Db4o.Reflect.Generic.GenericClass
+			public _IClosure4_303(GenericReflector _enclosing, Db4objects.Db4o.Reflect.Generic.GenericClass
 				 clazz)
 			{
 				this._enclosing = _enclosing;
@@ -443,12 +403,12 @@ namespace Db4objects.Db4o.Reflect.Generic
 		/// <returns>an array of classes known to the reflector</returns>
 		public virtual IReflectClass[] KnownClasses()
 		{
-			return (IReflectClass[])WithLock(new _IClosure4_358(this));
+			return ((IReflectClass[])WithLock(new _IClosure4_319(this)));
 		}
 
-		private sealed class _IClosure4_358 : IClosure4
+		private sealed class _IClosure4_319 : IClosure4
 		{
-			public _IClosure4_358(GenericReflector _enclosing)
+			public _IClosure4_319(GenericReflector _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -469,12 +429,12 @@ namespace Db4objects.Db4o.Reflect.Generic
 		public virtual void RegisterPrimitiveClass(int id, string name, IGenericConverter
 			 converter)
 		{
-			WithLock(new _IClosure4_373(this, id, converter, name));
+			WithLock(new _IClosure4_333(this, id, converter, name));
 		}
 
-		private sealed class _IClosure4_373 : IClosure4
+		private sealed class _IClosure4_333 : IClosure4
 		{
-			public _IClosure4_373(GenericReflector _enclosing, int id, IGenericConverter converter
+			public _IClosure4_333(GenericReflector _enclosing, int id, IGenericConverter converter
 				, string name)
 			{
 				this._enclosing = _enclosing;
@@ -491,10 +451,10 @@ namespace Db4objects.Db4o.Reflect.Generic
 				{
 					if (null != converter)
 					{
-						existing.SetSecondClass();
 					}
 					else
 					{
+						//						existing.setSecondClass();
 						existing.SetConverter(null);
 					}
 					return null;
@@ -513,7 +473,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 					claxx.InitFields(new GenericField[] { new GenericField(null, null, true) });
 					claxx.SetConverter(converter);
 				}
-				claxx.SetSecondClass();
+				//			    claxx.setSecondClass();
 				claxx.SetPrimitive();
 				this._enclosing._repository.Register(id, claxx);
 				return null;
