@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -17,12 +17,6 @@ namespace Db4objects.Db4o.Internal
 {
     public sealed partial class Const4
     {
-#if CF_2_0
-        // MixedArrayTestCase fails with StackOverflow exceptions
-        // when MaxStackDepth >= 20
-        public const int MaxStackDepth = 19;
-#else
         public const int MaxStackDepth = 20;
-#endif
     }
 }
