@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -17,20 +17,26 @@ using System;
 
 namespace Db4objects.Db4o.Internal.Handlers
 {
-	internal class WeakReferenceHandler : WeakReference
+	internal class WeakReferenceHandler
 	{
+		private readonly WeakReference _reference;
 		public object ObjectReference;
 
 		internal WeakReferenceHandler(Object queue, Object objectRef, Object obj)
-			: base(obj, false)
 		{
-			this.ObjectReference = objectRef;
+			_reference = new WeakReference(obj, false);
+			ObjectReference = objectRef;
 			((WeakReferenceHandlerQueue)queue).Add(this);
 		}
 
 		public object Get()
 		{
-			return this.Target;
+			return _reference.Target;
+		}
+
+		public bool IsAlive
+		{
+			get { return _reference.IsAlive; }
 		}
 	}
 }
\ No newline at end of file
