@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -18,11 +18,11 @@ using System.Collections;
 using System.Collections.Generic;
 using System.Globalization;
 using System.IO;
-using System.Text;
 using Db4objects.Db4o.Config;
 using Db4objects.Db4o.Config.Attributes;
 using Db4objects.Db4o.Ext;
 using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal.Activation;
 using Db4objects.Db4o.Internal.Handlers;
 using Db4objects.Db4o.Internal.Query;
 using Db4objects.Db4o.Internal.Query.Processor;
@@ -31,30 +31,18 @@ using Db4objects.Db4o.Reflect;
 using Db4objects.Db4o.Reflect.Generic;
 using Db4objects.Db4o.Reflect.Net;
 using Db4objects.Db4o.Typehandlers;
-using Db4objects.Db4o.Types;
 using Sharpen.IO;
-using Db4objects.Db4o.Foundation;
 
 namespace Db4objects.Db4o.Internal
 {
     /// <exclude />
     public class Platform4
     {
-        private static readonly string[] OldAssemblyNames = new String[] { "db4o", "db4o-4.0-net1", "db4o-4.0-compact1" };
+		private static readonly LegacyDb4oAssemblyNameMapper _assemlbyNameMapper = new LegacyDb4oAssemblyNameMapper();
 
-        private static readonly string[][] NamespaceRenamings = new string[][]
-                {
-                    new string[] { "com.db4o.ext", "Db4objects.Db4o.Ext"},
-                    new string[] { "com.db4o.inside", "Db4objects.Db4o.Internal"},
-                    new string[] { "com.db4o", "Db4objects.Db4o"}, 
-                };
+        private static List<ObjectContainerBase> _containersToBeShutdown;
 
-
-        private static ArrayList shutDownStreams;
-
-		private static object _lock = new object();
-
-        private static readonly byte[][] oldAssemblies;
+		private static readonly object _shutdownStreamsLock = new object();
 
 		public static object[] CollectionToArray(ObjectContainerBase stream, object obj)
         {
@@ -64,39 +52,19 @@ namespace Db4objects.Db4o.Internal
             return ret;
         }
 
-        static Platform4()
-        {   
-            LatinStringIO stringIO = new UnicodeStringIO();
-            oldAssemblies = new byte[OldAssemblyNames.Length][];
-            for (int i = 0; i < OldAssemblyNames.Length; i++)
-            {
-                oldAssemblies[i] = stringIO.Write(OldAssemblyNames[i]);
-            }
-        }
-
-        internal static bool IsDb4oClass(string className)
+    	internal static void AddShutDownHook(ObjectContainerBase container)
         {
-            if (className.IndexOf(".Tests.") > 0)
+            lock (_shutdownStreamsLock)
             {
-                return false;
-            }
-            return className.StartsWith("Db4objects.Db4o");
-        }
-
-        internal static void AddShutDownHook(PartialObjectContainer container)
-        {
-            lock (_lock)
-            {
-                if (shutDownStreams == null)
+                if (_containersToBeShutdown == null)
                 {
-                    shutDownStreams = new ArrayList();
-#if !CF
-					EventHandler handler = new EventHandler(OnShutDown);
-					AppDomain.CurrentDomain.ProcessExit += handler;
-					AppDomain.CurrentDomain.DomainUnload += handler;
+					_containersToBeShutdown = new List<ObjectContainerBase>();
+#if !CF && !SILVERLIGHT
+                	AppDomain.CurrentDomain.ProcessExit += OnShutDown;
+					AppDomain.CurrentDomain.DomainUnload += OnShutDown;
 #endif
                 }
-                shutDownStreams.Add(container);
+                _containersToBeShutdown.Add(container);
             }
         }
 
@@ -115,20 +83,23 @@ namespace Db4objects.Db4o.Internal
             return true;
         }
 
-        internal static IDb4oCollections Collections(Transaction transaction)
-        {
-            return new P2Collections(transaction);
-        }
-
         internal static IReflector CreateReflector(Object config)
-        {
-            return new NetReflector();
-        }
+		{
+#if USE_FAST_REFLECTOR && !CF && !SILVERLIGHT
+			return new Db4objects.Db4o.Internal.Reflect.FastNetReflector();
+#else
+			return new NetReflector();
+#endif
+		}
 
         public static IReflector ReflectorForType(Type typeInstance)
-        {
-            return new NetReflector();
-        }
+		{
+#if USE_FAST_REFLECTOR && !CF && !SILVERLIGHT
+			return new Db4objects.Db4o.Internal.Reflect.FastNetReflector();
+#else
+			return new NetReflector();
+#endif
+		}
 
         internal static Object CreateReferenceQueue()
         {
@@ -146,9 +117,9 @@ namespace Db4objects.Db4o.Internal
         }
 
         internal static long DoubleToLong(double a_double)
-        {
-#if CF
-            byte[] bytes = BitConverter.GetBytes(a_double);
+		{
+#if CF || SILVERLIGHT
+			byte[] bytes = BitConverter.GetBytes(a_double);
             return BitConverter.ToInt64(bytes, 0);
 #else
             return BitConverter.DoubleToInt64Bits(a_double);
@@ -284,16 +255,6 @@ namespace Db4objects.Db4o.Internal
             return date.ToString(fmt);
         }
 
-        public static Object GetClassForType(Object obj)
-        {
-            Type t = obj as Type;
-            if (t != null)
-            {
-                return t;
-            }
-            return obj;
-        }
-
         internal static IEnumerator GetCollectionEnumerator(object obj, bool allowArray)
         {
 			IEnumerable enumerable = obj as IEnumerable;
@@ -308,14 +269,13 @@ namespace Db4objects.Db4o.Internal
             if (IsCompact())
             {
                 config.SingleThreadedClient(true);
-                config.WeakReferenceCollectionInterval(0);
             }
 
             Translate(config, typeof(Delegate), new TNull());
             Translate(config, typeof(Type), new TType()); // TODO: unnecessary?
             Translate(config, typeof(Type).GetType(), new TType());
 
-#if !CF
+#if !CF && !SILVERLIGHT
             if (IsMono())
             {
 
@@ -323,24 +283,27 @@ namespace Db4objects.Db4o.Internal
             }
 #endif
 
+#if !SILVERLIGHT
             Translate(config, new ArrayList(), new TList());
             Translate(config, new Hashtable(), new TDictionary());
             Translate(config, new Queue(), new TQueue());
             Translate(config, new Stack(), new TStack());
+#endif
 			Translate(config, CultureInfo.InvariantCulture, new TCultureInfo());
 
             if (!IsCompact())
             {
-                Translate(config, "System.Collections.SortedList, mscorlib", new TDictionary());
+				Translate(config, "System.Collections.SortedList, mscorlib", new TDictionary());
             }
 
             new TypeHandlerConfigurationDotNet(config).Apply();
 
+        	config.ObjectClass(typeof (ActivatableBase)).Indexed(false);
         }
 
         public static bool IsCompact()
-        {
-#if CF
+		{
+#if CF || SILVERLIGHT
 			return true;
 #else
             return false;
@@ -372,17 +335,12 @@ namespace Db4objects.Db4o.Internal
             return true;
         }
 
-        public static bool HasLockFileThread()
+        public static bool NeedsLockFileThread()
         {
             return false;
         }
 
-        public static bool HasNio()
-        {
-            return false;
-        }
-
-        internal static bool HasWeakReferences()
+        public static bool HasWeakReferences()
         {
             return true;
         }
@@ -407,8 +365,12 @@ namespace Db4objects.Db4o.Internal
                 IObjectTranslator ot = config4class.GetTranslator();
                 if (ot != null)
                 {
-                    return ot is TList || ot is TDictionary || ot is TQueue || ot is TStack;
-                }
+#if SILVERLIGHT
+					return false;
+#else
+					return ot is TList || ot is TDictionary || ot is TQueue || ot is TStack;
+#endif
+				}
             }
             return false;
         }
@@ -422,7 +384,7 @@ namespace Db4objects.Db4o.Internal
             return socket.IsConnected();
         }
 
-        internal static bool IsValueType(IReflectClass claxx)
+        internal static bool IsStruct(IReflectClass claxx)
         {
             if (claxx == null)
             {
@@ -446,9 +408,9 @@ namespace Db4objects.Db4o.Internal
         }
 
         internal static double LongToDouble(long l)
-        {
-#if CF
-            byte[] bytes = BitConverter.GetBytes(l);
+		{
+#if CF || SILVERLIGHT
+			byte[] bytes = BitConverter.GetBytes(l);
             return BitConverter.ToDouble(bytes, 0);
 #else
             return BitConverter.Int64BitsToDouble(l);
@@ -456,9 +418,9 @@ namespace Db4objects.Db4o.Internal
         }
 
         internal static void LockFile(string path, object file)
-        {
-#if !CF
-            try
+		{
+#if !CF && !SILVERLIGHT
+			try
             {
                 FileStream stream = ((RandomAccessFile) file).Stream;
                 stream.Lock(0, 1);
@@ -485,25 +447,25 @@ namespace Db4objects.Db4o.Internal
             return false;
         }
 
-        internal static void PollReferenceQueue(Object stream, Object referenceQueue)
+        internal static void PollReferenceQueue(Object container, Object referenceQueue)
         {
-            ((WeakReferenceHandlerQueue)referenceQueue).Poll((IExtObjectContainer)stream);
+            ((WeakReferenceHandlerQueue)referenceQueue).Poll((ObjectContainerBase)container);
         }
 
         public static void RegisterCollections(GenericReflector reflector)
         {
-            reflector.RegisterCollectionUpdateDepth(
-                typeof(IDictionary),
-                3);
+//            reflector.RegisterCollectionUpdateDepth(
+//                typeof(IDictionary),
+//                3);
         }
 
-        internal static void RemoveShutDownHook(PartialObjectContainer container)
+        internal static void RemoveShutDownHook(ObjectContainerBase container)
         {
-            lock (_lock)
+            lock (_shutdownStreamsLock)
             {
-                if (shutDownStreams != null)
+                if (_containersToBeShutdown != null)
                 {
-                    shutDownStreams.Remove(container);
+                    _containersToBeShutdown.Remove(container);
                 }
             }
         }
@@ -515,9 +477,9 @@ namespace Db4objects.Db4o.Internal
 
         private static void OnShutDown(object sender, EventArgs args)
         {
-			lock (_lock)
+			lock (_shutdownStreamsLock)
 			{
-				foreach (ObjectContainerBase container in shutDownStreams.ToArray())
+				foreach (ObjectContainerBase container in _containersToBeShutdown.ToArray())
 				{
 					container.ShutdownHook(); // this will remove the stream for the list
 				}				
@@ -529,49 +491,14 @@ namespace Db4objects.Db4o.Internal
             return false;
         }
 
-		private static void Translate(Config4Impl config, object obj, IObjectTranslator translator)
+		private static void Translate(IConfiguration config, object obj, IObjectTranslator translator)
 		{
 			config.ObjectClass(obj).Translate(translator);
 		}
 
-        internal static byte[] UpdateClassName(byte[] bytes)
+        public static byte[] UpdateClassName(byte[] nameBytes)
         {
-            for (int i = 0; i < OldAssemblyNames.Length; i++)
-            {
-                int j = oldAssemblies[i].Length - 1;
-                for (int k = bytes.Length - 1; k >= 0; k--)
-                {
-                    if (bytes[k] != oldAssemblies[i][j])
-                    {
-                        break;
-                    }
-                    j--;
-                    if (j < 0)
-                    {
-                        return UpdateInternalClassName(bytes);
-                    }
-                }
-            }
-            return bytes;
-        }
-
-        private static byte[] UpdateInternalClassName(byte[] bytes)
-        {
-            StringBuilder typeNameBuffer = new StringBuilder();
-            UnicodeStringIO io = new UnicodeStringIO();
-            typeNameBuffer.Append(io.Read(bytes).Split(',')[0]);
-            foreach (string[] renaming in NamespaceRenamings)
-            {
-                typeNameBuffer.Replace(renaming[0], renaming[1]);
-            }
-            typeNameBuffer.Append(", ");
-            typeNameBuffer.Append(GetCurrentAssemblyName());
-            return io.Write(typeNameBuffer.ToString());
-        }
-
-        private static string GetCurrentAssemblyName()
-        {
-            return typeof(Platform4).Assembly.GetName().Name;
+            return _assemlbyNameMapper.MappedNameFor(nameBytes);
         }
 
         public static Object WeakReferenceTarget(Object weakRef)
@@ -585,8 +512,8 @@ namespace Db4objects.Db4o.Internal
         }
 
         internal static object WrapEvaluation(object evaluation)
-        {
-#if CF
+		{
+#if CF || SILVERLIGHT
 			// FIXME: How to better support EvaluationDelegate on the CompactFramework?
 			return evaluation;
 #else
@@ -606,7 +533,12 @@ namespace Db4objects.Db4o.Internal
     	public static bool IsTransient(Type type)
     	{
     		return type.IsPointer
-    		       || type.IsSubclassOf(typeof(Delegate));
+    		       || type.IsSubclassOf(typeof(Delegate))
+#if CF || SILVERLIGHT
+;
+#else
+    		       || type == typeof(System.Reflection.Pointer);
+#endif
     	}
 
     	private static Type GetNetType(IReflectClass clazz)
@@ -633,13 +565,11 @@ namespace Db4objects.Db4o.Internal
         {
 			return new NetTypeHandler[]
 				{
-					//new DoubleHandler(stream),
 					new SByteHandler(),
 					new DecimalHandler(),
 					new UIntHandler(),
 					new ULongHandler(),
 					new UShortHandler(),
-					new DateTimeHandler(),
 				};
         }
 
@@ -667,23 +597,24 @@ namespace Db4objects.Db4o.Internal
 		                                        	typeof(String),
 		                                        };
 
-        public static String StackTrace()
-        {
-#if CF_1_0 || CF
-            throw new NotImplementedException();
-#else
-            return Environment.StackTrace;
-#endif
-        }
-
         public static DateTime Now()
         {
             return DateTime.Now;
         }
 
+		internal static bool IsJavaEnum(IReflector genericReflector, IReflectClass iReflectClass)
+		{
+			return false;
+		}
+
 		internal static bool IsEnum(IReflector genericReflector, IReflectClass iReflectClass)
 		{
-			return GetNetType(iReflectClass).IsEnum;
+		    Type type = GetNetType(iReflectClass);
+            if(type == null)
+            {
+                return false;
+            }
+			return type.IsEnum;
 		}
 
         public static bool UseNativeSerialization() 
@@ -693,9 +624,31 @@ namespace Db4objects.Db4o.Internal
 
         public static void RegisterPlatformHandlers(ObjectContainerBase container)
         {
-            // do nothing
+            EnumTypeHandler enumTypeHandler = new EnumTypeHandler();
+            container.ConfigImpl.RegisterTypeHandler(new EnumTypeHandlerPredicate(), enumTypeHandler);
+			container.Handlers.RegisterHandlerVersion(enumTypeHandler, 4, new StandardReferenceTypeHandler());
+			container.Handlers.RegisterHandlerVersion(enumTypeHandler, 0, new StandardReferenceTypeHandler0());
+
+			GuidTypeHandler guidTypeHandler = new GuidTypeHandler();
+			container.ConfigImpl.RegisterTypeHandler(new SingleClassTypeHandlerPredicate(typeof(Guid)), guidTypeHandler);
+			container.Handlers.RegisterHandlerVersion(guidTypeHandler, 8, new StandardReferenceTypeHandler());
+
+            DateTimeHandler dateTimeHandler = new DateTimeHandler();
+            container.Handlers.RegisterNetTypeHandler(dateTimeHandler);
+            container.Handlers.RegisterHandlerVersion(dateTimeHandler, 6, new DateTimeHandler6());
+
+#if !CF
+        	DateTimeOffsetTypeHandler dateTimeOffsetHandler = new DateTimeOffsetTypeHandler();
+        	container.ConfigImpl.RegisterTypeHandler(new SingleClassTypeHandlerPredicate(typeof(DateTimeOffset)), dateTimeOffsetHandler);
+			container.Handlers.RegisterHandlerVersion(dateTimeOffsetHandler, 9, new StandardReferenceTypeHandler());
+#endif
         }
 
+		public static Type[] PrimitiveTypes()
+		{
+			return PRIMITIVE_TYPES;
+		}
+
         public static object NullValue(Type type) 
         {
             if(_nullValues == null) 
@@ -709,7 +662,7 @@ namespace Db4objects.Db4o.Internal
         private static void InitNullValues()
         {
     	    _nullValues = new Hashtable4();
-            _nullValues.Put(typeof(int), (int)0);
+            _nullValues.Put(typeof(int), 0);
             _nullValues.Put(typeof(uint), (uint)0);
             _nullValues.Put(typeof(byte), (byte)0);
     	    _nullValues.Put(typeof(short), (short)0);
@@ -734,31 +687,54 @@ namespace Db4objects.Db4o.Internal
                 InitPrimitive2Wrapper();
             Type wrapperClazz = (Type)_primitive2Wrapper.Get(primitiveType);
             if(wrapperClazz==null)        
-                throw new System.NotImplementedException();
+                throw new NotImplementedException();
             return wrapperClazz;
         }
     
         private static void InitPrimitive2Wrapper()
         {
     	    _primitive2Wrapper = new Hashtable4();
-            _primitive2Wrapper.Put(typeof(int), typeof(int?));
-            _primitive2Wrapper.Put(typeof(uint), typeof(uint?));
-            _primitive2Wrapper.Put(typeof(byte), typeof(byte?));
-    	    _primitive2Wrapper.Put(typeof(short), typeof(short?));
-    	    _primitive2Wrapper.Put(typeof(float), typeof(float?));
-    	    _primitive2Wrapper.Put(typeof(double), typeof(double?));
-            _primitive2Wrapper.Put(typeof(ulong), typeof(ulong?));
-            _primitive2Wrapper.Put(typeof(long), typeof(long?));
-    	    _primitive2Wrapper.Put(typeof(bool), typeof(bool?));
-            _primitive2Wrapper.Put(typeof(char), typeof(char?));
-            _primitive2Wrapper.Put(typeof(sbyte), typeof(sbyte?));
-            _primitive2Wrapper.Put(typeof(decimal), typeof(decimal?));
-            _primitive2Wrapper.Put(typeof(ushort), typeof(ushort?));
-            _primitive2Wrapper.Put(typeof(DateTime), typeof(DateTime?));
-        	
+
+        	foreach (Type type in PRIMITIVE_TYPES)
+        	{
+				_primitive2Wrapper.Put(type, ConcreteNullableTypeFor(type));
+        	}
         }
 
-        private static Hashtable4 _primitive2Wrapper;
+    	private static Type ConcreteNullableTypeFor(Type type)
+    	{
+    		return typeof (Nullable<>).MakeGenericType(type);
+    	}
 
-	}
+    	private static Hashtable4 _primitive2Wrapper;
+
+    	private static readonly Type[] PRIMITIVE_TYPES = new Type[]
+    	                                        	{
+														typeof(int),
+														typeof(uint), 
+														typeof(byte), 
+														typeof(short),
+														typeof(float),
+														typeof(double),
+														typeof(ulong),
+														typeof(long), 
+														typeof(bool), 
+														typeof(char), 
+														typeof(sbyte),
+														typeof(decimal),
+														typeof(ushort),
+														typeof(DateTime),
+    	                                        	};
+
+        public static void ThrowUncheckedException(Exception exc)
+        {
+            throw exc;
+        }
+
+        public static sbyte ToSByte(byte b)
+        {
+		    return (sbyte)b;
+	    }
+
+    }
 }
\ No newline at end of file
