@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Reflection;
 using Db4objects.Db4o;
@@ -58,22 +53,19 @@ namespace Db4objects.Db4o.Internal.Query
         private void Marshal()
         {
             _delegateType = _content.GetType();
-#if !CF_1_0 && !CF_2_0
             _target = _content.Target;
             _method = _content.Method.Name;
             _type = _content.Method.DeclaringType;
-#endif
         }
 
         private Delegate Unmarshal()
         {
-#if CF_1_0 || CF_2_0
-            throw new NotSupportedException();
-#else
-            return (null == _target)
-                       ? System.Delegate.CreateDelegate(_delegateType, _type, _method)
-                       : System.Delegate.CreateDelegate(_delegateType, _target, _method);
-#endif
+			if (null == _target)
+			{
+				return Delegate.CreateDelegate(_delegateType, null, _type.GetMethod(_method,  BindingFlags.Static | BindingFlags.NonPublic | BindingFlags.Public));
+			}
+				
+			return Delegate.CreateDelegate(_delegateType, _target, _target.GetType().GetMethod(_method, BindingFlags.Instance | BindingFlags.NonPublic | BindingFlags.Public));
         }
     }
 
@@ -94,7 +86,7 @@ namespace Db4objects.Db4o.Internal.Query
 		
         public void Evaluate(ICandidate candidate)
         {
-            // use starting _ for PascalCase conversion purposes
+			// use starting _ for PascalCase conversion purposes
             EvaluationDelegate _evaluation = GetEvaluationDelegate();
             _evaluation(candidate);
         }
