@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -21,12 +21,12 @@ namespace Db4objects.Db4o.Query
 	
 	public sealed class PredicatePlatform
 	{
-		public static readonly string PREDICATEMETHOD_NAME = "Match";
+		public static readonly string PredicatemethodName = "Match";
 		
 		public static bool IsFilterMethod(MethodInfo method)
 		{
 			if (method.GetParameters().Length != 1) return false;
-			return method.Name == PREDICATEMETHOD_NAME;
+			return method.Name == PredicatemethodName;
 		}
 
         public static T GetField<T>(Object obj, string fieldName)
