@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,7 +19,7 @@ namespace Sharpen.Util
 {
 	public class Random 
 	{
-		System.Random _random = new System.Random();
+		readonly System.Random _random = new System.Random();
 
 		public Random() 
 		{
@@ -29,5 +29,15 @@ namespace Sharpen.Util
 		{
 			return _random.Next();
 		}
+		
+		public int NextInt()
+		{
+			return _random.Next(int.MinValue, int.MaxValue);
+		}
+
+		public object NextInt(int ceiling)
+		{
+			return _random.Next(ceiling);
+		}
 	}
 }
\ No newline at end of file
