@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,14 +14,15 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
+using Db4objects.Db4o.Reflect.Core;
 
 namespace Db4objects.Db4o.Reflect.Net
 {
-#if !CF
+#if !CF && !SILVERLIGHT
 	/// <summary>Constructs objects by using System.Runtime.Serialization.FormatterServices.GetUninitializedObject
 	/// and bypasses calls to user contructors this way. Not available on CompactFramework
 	/// </summary>
-	public class SerializationConstructor : Db4objects.Db4o.Reflect.Core.IReflectConstructor
+	public class SerializationConstructor : IReflectConstructor
 	{
         private Type _type;
 
@@ -29,10 +30,13 @@ namespace Db4objects.Db4o.Reflect.Net
             _type = type;
 		}
 
-        public virtual Db4objects.Db4o.Reflect.IReflectClass[] GetParameterTypes() {
+        public virtual IReflectClass[] GetParameterTypes() {
             return null;
         }
 
+#if NET_4_0
+		[System.Security.SecurityCritical]
+#endif		
         public virtual object NewInstance(object[] parameters) {
             return System.Runtime.Serialization.FormatterServices.GetUninitializedObject(_type);
         }
