@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -23,12 +23,12 @@ namespace Db4objects.Drs.Tests
 	{
 		private static readonly FixtureVariable _variable = new FixtureVariable("drs");
 
-		public static DrsFixturePair Value()
+		public static DrsFixture Value()
 		{
-			return (DrsFixturePair)_variable.Value;
+			return (DrsFixture)_variable.Value;
 		}
 
-		public static object With(DrsFixturePair pair, IClosure4 closure)
+		public static object With(DrsFixture pair, IClosure4 closure)
 		{
 			return _variable.With(pair, closure);
 		}
