@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -16,16 +16,21 @@ with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Collections;
 using Db4oUnit;
+using Db4objects.Db4o;
 using Db4objects.Db4o.Foundation;
 using Db4objects.Drs;
 using Db4objects.Drs.Inside;
 using Db4objects.Drs.Tests;
+using Db4objects.Drs.Tests.Data;
 using Db4objects.Drs.Tests.Foundation;
+using Sharpen;
 
 namespace Db4objects.Drs.Tests
 {
 	public class ReplicationFeaturesMain : DrsTestCase
 	{
+		private const bool Debug = false;
+
 		private static readonly string AStuff = "A";
 
 		private static readonly string BStuff = "B";
@@ -122,29 +127,6 @@ namespace Db4objects.Drs.Tests
 			return _containerStateToPrevail != null && _containerStateToPrevail.IsEmpty();
 		}
 
-		protected virtual void ActualTest()
-		{
-			Clean();
-			_setA.Add(AStuff);
-			_setB.Add(BStuff);
-			_setBoth.AddAll(_setA);
-			_setBoth.AddAll(_setB);
-			_testCombination = 0;
-			TstWithDeletedObjectsIn(None);
-			TstWithDeletedObjectsIn(_setA);
-			TstWithDeletedObjectsIn(_setB);
-			TstWithDeletedObjectsIn(_setBoth);
-			if (_intermittentErrors.Length > 0)
-			{
-				Sharpen.Runtime.Err.WriteLine("Intermittent errors found in test combinations:" +
-					 _intermittentErrors);
-				Assert.IsTrue(false);
-			}
-		}
-
-		//	protected void clean() {
-		//		delete(new Class[]{Replicated.class});
-		//	}
 		private void ChangeObject(ITestableReplicationProviderInside container, string name
 			, string newName)
 		{
@@ -179,7 +161,7 @@ namespace Db4objects.Drs.Tests
 			checkNameCount++;
 			if (isExpected)
 			{
-				Assert.IsNotNull(obj);
+				Assert.IsNotNull(obj, "Expecting: " + name + " in " + ContainerName(container));
 			}
 			else
 			{
@@ -211,10 +193,6 @@ namespace Db4objects.Drs.Tests
 				(origin, inspected));
 		}
 
-		//	public void configure() {
-		//		Db4o.configure().generateUUIDs(Integer.MAX_VALUE);
-		//		Db4o.configure().generateVersionNumbers(Integer.MAX_VALUE);
-		//	}
 		private ITestableReplicationProviderInside Container(string aOrB)
 		{
 			return aOrB.Equals(AStuff) ? A().Provider() : B().Provider();
@@ -233,9 +211,10 @@ namespace Db4objects.Drs.Tests
 			PrintProvidersContent("before changes");
 			PerformChanges();
 			PrintProvidersContent("after changes");
-			IReplicationSession replication = new GenericReplicationSession(A().Provider(), B
-				().Provider(), new _IReplicationEventListener_192(this));
+			IReplicationEventListener listener = new _IReplicationEventListener_167(this);
 			//Default replication behaviour.
+			IReplicationSession replication = new GenericReplicationSession(A().Provider(), B
+				().Provider(), listener, _fixtures.reflector);
 			if (_direction.Size() == 1)
 			{
 				if (_direction.Contains(AStuff))
@@ -258,9 +237,9 @@ namespace Db4objects.Drs.Tests
 			Clean();
 		}
 
-		private sealed class _IReplicationEventListener_192 : IReplicationEventListener
+		private sealed class _IReplicationEventListener_167 : IReplicationEventListener
 		{
-			public _IReplicationEventListener_192(ReplicationFeaturesMain _enclosing)
+			public _IReplicationEventListener_167(ReplicationFeaturesMain _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -286,19 +265,35 @@ namespace Db4objects.Drs.Tests
 
 		private void PrintProvidersContent(string msg)
 		{
+			return;
+			Sharpen.Runtime.Out.WriteLine("*** " + msg);
+			PrintProviderContent(A().Provider());
+			PrintProviderContent(B().Provider());
+		}
+
+		private void PrintProviderContent(ITestableReplicationProviderInside provider)
+		{
+			IObjectSet storedObjects = provider.GetStoredObjects(typeof(Replicated));
+			Sharpen.Runtime.Out.WriteLine("PROVIDER: " + provider);
+			while (storedObjects.HasNext())
+			{
+				object @object = storedObjects.Next();
+				Sharpen.Runtime.Out.WriteLine("-> " + @object + " - c:" + CreationTime(provider, 
+					@object) + " v:" + Version(provider, @object));
+			}
+		}
+
+		private long Version(ITestableReplicationProviderInside provider, object obj)
+		{
+			return provider.ObjectVersion(obj);
+		}
+
+		private long CreationTime(ITestableReplicationProviderInside provider, object obj
+			)
+		{
+			return provider.CreationTime(obj);
 		}
 
-		//		System.out.println("*** "+msg);
-		//		printProviderContent(a().provider());
-		//		printProviderContent(b().provider());
-		//	private void printProviderContent(TestableReplicationProviderInside provider) {
-		//		ObjectContainer db=((Db4oReplicationProvider)provider).objectContainer();
-		//		ObjectSet result=db.query(Replicated.class);
-		//		System.out.println("PROVIDER: "+provider);
-		//		while(result.hasNext()) {
-		//			System.out.println(result.next());
-		//		}
-		//	}
 		private bool TryToReplicate(IReplicationSession replication)
 		{
 			try
@@ -386,8 +381,9 @@ namespace Db4objects.Drs.Tests
 			B().Provider().StoreNew(new Replicated("oldFromB"));
 			A().Provider().Commit();
 			B().Provider().Commit();
+			PrintProvidersContent("init state");
 			IReplicationSession replication = new GenericReplicationSession(A().Provider(), B
-				().Provider());
+				().Provider(), null, _fixtures.reflector);
 			ReplicateQueryingFrom(replication, A().Provider(), B().Provider());
 			ReplicateQueryingFrom(replication, B().Provider(), A().Provider());
 			replication.Commit();
@@ -604,17 +600,6 @@ namespace Db4objects.Drs.Tests
 			return (string)Iterators.Next(iterator);
 		}
 
-		private void PrintCombination()
-		{
-			Out(string.Empty + _testCombination + " =================================");
-			Out("New Objects In: " + Print(_containersWithNewObjects));
-			Out("Changed Objects In: " + Print(_containersWithChangedObjects));
-			Out("Deleted Objects In: " + Print(_containersWithDeletedObjects));
-			Out("Querying From: " + Print(_containersToQueryFrom));
-			Out("Direction: To " + Print(_direction));
-			Out("Prevailing State: " + Print(_containerStateToPrevail));
-		}
-
 		private void RunCurrentCombination()
 		{
 			_testCombination++;
@@ -651,14 +636,58 @@ namespace Db4objects.Drs.Tests
 			}
 		}
 
+		public virtual void Test()
+		{
+			long start = Runtime.CurrentTimeMillis();
+			ActualTest();
+			long stop = Runtime.CurrentTimeMillis();
+			long duration = stop - start;
+			Sharpen.Runtime.Out.WriteLine("ReplicationFeaturesMain takes " + duration + "ms");
+			Sharpen.Runtime.Out.WriteLine("Run combinations " + _testCombination);
+		}
+
 		private static void Out(string @string)
 		{
 		}
 
-		//System.out.println(string);
-		public virtual void Test()
+		private void PrintCombination()
 		{
-			ActualTest();
+			return;
+			Out(string.Empty + _testCombination + " =================================");
+			Out("Deleted Objects In: " + Print(_containersWithDeletedObjects));
+			Out("Direction: To " + Print(_direction));
+			Out("Querying From: " + Print(_containersToQueryFrom));
+			Out("New Objects In: " + Print(_containersWithNewObjects));
+			Out("Changed Objects In: " + Print(_containersWithChangedObjects));
+			Out("Prevailing State: " + Print(_containerStateToPrevail));
+		}
+
+		protected virtual void ActualTest()
+		{
+			Clean();
+			_setA.Add(AStuff);
+			_setB.Add(BStuff);
+			_setBoth.AddAll(_setA);
+			_setBoth.AddAll(_setB);
+			_testCombination = 0;
+			TstWithDeletedObjectsIn(None);
+			TstWithDeletedObjectsIn(_setA);
+			TstWithDeletedObjectsIn(_setB);
+			TstWithDeletedObjectsIn(_setBoth);
+			if (_intermittentErrors.Length > 0)
+			{
+				Sharpen.Runtime.Err.WriteLine("Intermittent errors found in test combinations:" +
+					 _intermittentErrors);
+				Assert.IsTrue(false);
+			}
+		}
+
+		private void TstWithDeletedObjectsIn(Set4 containers)
+		{
+			_containersWithDeletedObjects = containers;
+			TstDirection(_setA);
+			TstDirection(_setB);
+			TstDirection(_setBoth);
 		}
 
 		private void TstDirection(Set4 direction)
@@ -678,23 +707,6 @@ namespace Db4objects.Drs.Tests
 			TstWithNewObjectsIn(_setBoth);
 		}
 
-		private void TstWithChangedObjectsIn(Set4 containers)
-		{
-			_containersWithChangedObjects = containers;
-			TstWithContainerStateToPrevail(None);
-			TstWithContainerStateToPrevail(_setA);
-			TstWithContainerStateToPrevail(_setB);
-			TstWithContainerStateToPrevail(null);
-		}
-
-		private void TstWithDeletedObjectsIn(Set4 containers)
-		{
-			_containersWithDeletedObjects = containers;
-			TstDirection(_setA);
-			TstDirection(_setB);
-			TstDirection(_setBoth);
-		}
-
 		private void TstWithNewObjectsIn(Set4 containersWithNewObjects)
 		{
 			_containersWithNewObjects = containersWithNewObjects;
@@ -704,6 +716,17 @@ namespace Db4objects.Drs.Tests
 			TstWithChangedObjectsIn(_setBoth);
 		}
 
+		private void TstWithChangedObjectsIn(Set4 containers)
+		{
+			_containersWithChangedObjects = containers;
+			TstWithContainerStateToPrevail(_setA);
+			return;
+			TstWithContainerStateToPrevail(None);
+			TstWithContainerStateToPrevail(_setA);
+			TstWithContainerStateToPrevail(_setB);
+			TstWithContainerStateToPrevail(null);
+		}
+
 		private void TstWithContainerStateToPrevail(Set4 containers)
 		{
 			_containerStateToPrevail = containers;
