@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -14,7 +14,7 @@ for more details.
 You should have received a copy of the GNU General Public License along
 with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4objects.Db4o;
-using Db4objects.Db4o.Internal.CS;
+using Db4objects.Db4o.Internal;
 using Db4objects.Drs.Db4o;
 
 namespace Db4objects.Drs.Db4o
@@ -25,13 +25,13 @@ namespace Db4objects.Drs.Db4o
 		public static IDb4oReplicationProvider NewInstance(IObjectContainer oc, string name
 			)
 		{
-			if (oc is ClientObjectContainer)
+			if (IsClient(oc))
 			{
-				return new ClientServerReplicationProvider(oc, name);
+				return new Db4oClientServerReplicationProvider(oc, name);
 			}
 			else
 			{
-				return new FileReplicationProvider(oc, name);
+				return new Db4oEmbeddedReplicationProvider(oc, name);
 			}
 		}
 
@@ -39,5 +39,10 @@ namespace Db4objects.Drs.Db4o
 		{
 			return NewInstance(oc, null);
 		}
+
+		private static bool IsClient(IObjectContainer oc)
+		{
+			return ((IInternalObjectContainer)oc).IsClient;
+		}
 	}
 }
