@@ -1,6 +1,6 @@
 /* This file is part of the db4o object database http://www.db4o.com
 
-Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
+Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
 the terms of version 3 of the GNU General Public License as published
@@ -19,20 +19,34 @@ namespace Db4objects.Drs.Inside
 {
 	/// <summary>A default implementation of ConflictResolver.</summary>
 	/// <remarks>
-	/// A default implementation of ConflictResolver. In case of a conflict
+	/// A default implementation of ConflictResolver. In case of a conflict,
+	/// if the object is known to only one database the object is copied
+	/// to the other database. If the object is known in both databases
 	/// a
-	/// <see cref="ReplicationConflictException">ReplicationConflictException</see>
+	/// <see cref="Db4objects.Drs.ReplicationConflictException">Db4objects.Drs.ReplicationConflictException
+	/// 	</see>
 	/// is thrown.
 	/// </remarks>
-	/// <author>Albert Kwan</author>
-	/// <author>Carl Rosenberger</author>
-	/// <author>Klaus Wuestefeld</author>
-	/// <version>1.0</version>
+	/// <version>1.1</version>
 	/// <since>dRS 1.0</since>
 	public class DefaultReplicationEventListener : IReplicationEventListener
 	{
 		public virtual void OnReplicate(IReplicationEvent e)
 		{
+			if (e.IsConflict())
+			{
+				if (!e.StateInProviderA().IsKnown())
+				{
+					e.OverrideWith(e.StateInProviderB());
+				}
+				else
+				{
+					if (!e.StateInProviderB().IsKnown())
+					{
+						e.OverrideWith(e.StateInProviderA());
+					}
+				}
+			}
 		}
 	}
 }
